--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

--
-- Name: engine; Type: DATABASE; Schema: -; Owner: engine
--

CREATE DATABASE engine WITH TEMPLATE = template0 ENCODING = 'UTF8' LC_COLLATE = 'en_US.UTF-8' LC_CTYPE = 'en_US.UTF-8';


ALTER DATABASE engine OWNER TO engine;

\connect engine

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

--
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: engine
--

CREATE PROCEDURAL LANGUAGE plpgsql;


ALTER PROCEDURAL LANGUAGE plpgsql OWNER TO engine;

SET search_path = public, pg_catalog;

--
-- Name: async_tasks_info_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE async_tasks_info_rs AS (
	dc_id uuid,
	dc_name character varying,
	spm_host_id uuid,
	spm_host_name character varying,
	task_count integer
);


ALTER TYPE public.async_tasks_info_rs OWNER TO engine;

--
-- Name: booleanresulttype; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE booleanresulttype AS (
	result boolean
);


ALTER TYPE public.booleanresulttype OWNER TO engine;

--
-- Name: get_all_commands_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE get_all_commands_rs AS (
	command_id uuid,
	command_type character varying(256)
);


ALTER TYPE public.get_all_commands_rs OWNER TO engine;

--
-- Name: getallfromsnapshotsbyvmid_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE getallfromsnapshotsbyvmid_rs AS (
	snapshot_id uuid,
	vm_id uuid,
	snapshot_type character varying(32),
	status character varying(32),
	description character varying(4000),
	creation_date timestamp with time zone,
	app_list text,
	vm_configuration text,
	vm_configuration_available boolean
);


ALTER TYPE public.getallfromsnapshotsbyvmid_rs OWNER TO engine;

--
-- Name: getallfromvm_pools_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE getallfromvm_pools_rs AS (
	vm_pool_id uuid,
	assigned_vm_count integer,
	vm_running_count integer,
	vm_pool_description character varying(4000),
	vm_pool_name character varying(255),
	vm_pool_type integer,
	parameters character varying(200),
	prestarted_vms integer,
	vds_group_id uuid,
	vds_group_name character varying(40)
);


ALTER TYPE public.getallfromvm_pools_rs OWNER TO engine;

--
-- Name: getnamesofvmstaticdedicatedtovds_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE getnamesofvmstaticdedicatedtovds_rs AS (
	vm_name character varying
);


ALTER TYPE public.getnamesofvmstaticdedicatedtovds_rs OWNER TO engine;

--
-- Name: getorderedvmguidsforrunmultipleactions_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE getorderedvmguidsforrunmultipleactions_rs AS (
	vm_guid uuid
);


ALTER TYPE public.getorderedvmguidsforrunmultipleactions_rs OWNER TO engine;

--
-- Name: getrepo_files_in_all_storage_pools_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE getrepo_files_in_all_storage_pools_rs AS (
	storage_domain_id uuid,
	last_refreshed bigint,
	file_type integer
);


ALTER TYPE public.getrepo_files_in_all_storage_pools_rs OWNER TO engine;

--
-- Name: getstoragedomainidsbystoragepoolidandstatus_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE getstoragedomainidsbystoragepoolidandstatus_rs AS (
	storage_id uuid
);


ALTER TYPE public.getstoragedomainidsbystoragepoolidandstatus_rs OWNER TO engine;

--
-- Name: getsystem_statistics_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE getsystem_statistics_rs AS (
	val integer
);


ALTER TYPE public.getsystem_statistics_rs OWNER TO engine;

--
-- Name: idtexttype; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE idtexttype AS (
	id text
);


ALTER TYPE public.idtexttype OWNER TO engine;

--
-- Name: iduuidtype; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE iduuidtype AS (
	id uuid
);


ALTER TYPE public.iduuidtype OWNER TO engine;

--
-- Name: networkviewclustertype; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE networkviewclustertype AS (
	id uuid,
	name character varying(50),
	description character varying(4000),
	type integer,
	addr character varying(50),
	subnet character varying(20),
	gateway character varying(20),
	vlan_id integer,
	stp boolean,
	storage_pool_id uuid,
	mtu integer,
	vm_network boolean,
	network_id uuid,
	cluster_id uuid,
	status integer,
	is_display boolean,
	required boolean
);


ALTER TYPE public.networkviewclustertype OWNER TO engine;

--
-- Name: user_permissions; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE user_permissions AS (
	permission_id uuid,
	role_id uuid,
	user_id uuid
);


ALTER TYPE public.user_permissions OWNER TO engine;

--
-- Name: vds_group_usage_rs; Type: TYPE; Schema: public; Owner: engine
--

CREATE TYPE vds_group_usage_rs AS (
	virtual_cpu_usage integer,
	mem_size_mb_usage bigint
);


ALTER TYPE public.vds_group_usage_rs OWNER TO engine;

--
-- Name: attach_user_to_su_role(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION attach_user_to_su_role() RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_user_entry VARCHAR(255);
   v_user_id  UUID;
   v_name  VARCHAR(255);
   v_domain  VARCHAR(255);
   v_user_name  VARCHAR(255);

   v_document  VARCHAR(64);
   v_index  INTEGER;
BEGIN

   select   option_value INTO v_user_entry from vdc_options where option_name = ''AdUserId'';
   select   option_value INTO v_name from vdc_options where option_name = ''AdUserName'';
   select   option_value INTO v_domain from vdc_options where option_name = ''DomainName'';

   v_index := POSITION('':'' IN v_user_entry);
   if ( v_index <> 0 ) then
      v_user_entry := substring( v_user_entry from v_index + 1 );
      v_user_id := CAST( v_user_entry AS uuid );
   end if;

   v_index := POSITION('':'' IN v_name);
   if ( v_index <> 0 ) then
      v_name := substring( v_name from v_index + 1 );
   end if;

-- find if name already includes domain (@)
   v_index := POSITION(''@'' IN v_name);

   if (v_index = 0) then
      v_user_name := coalesce(v_name,'''') || ''@'' || coalesce(v_domain,'''');
   else
      v_user_name := v_name;
   end if;


insert into users(user_id,name,domain,username,groups,status) select v_user_id, v_name, v_domain, v_user_name,'''',1 where not exists (select user_id,name,domain,username,groups,status from users where user_id = v_user_id and name = v_name and domain = v_domain and username = v_user_name and groups = '''' and status = 1);

insert into permissions(id,role_id,ad_element_id,object_id,object_type_id) select uuid_generate_v1(), ''00000000-0000-0000-0000-000000000001'', v_user_id, getGlobalIds(''system''), 1 where not exists(select role_id,ad_element_id,object_id,object_type_id from permissions where role_id = ''00000000-0000-0000-0000-000000000001'' and ad_element_id = v_user_id and object_id= getGlobalIds(''system'') and object_type_id = 1);
END; ';


ALTER FUNCTION public.attach_user_to_su_role() OWNER TO engine;

--
-- Name: attach_user_to_su_role(character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION attach_user_to_su_role(v_user_id character varying, v_name character varying, v_domain character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_user_name VARCHAR(255);
   v_document  VARCHAR(64);
   v_index  INTEGER;
   input_uuid uuid;
BEGIN
   input_uuid = CAST( v_user_id AS uuid );
-- find if name already includes domain (@)
   v_index := POSITION(''@'' IN v_name);

   if (v_index = 0) then
      v_user_name := coalesce(v_name,'''') || ''@'' || coalesce(v_domain,'''');
   else
      v_user_name := v_name;
   end if;


insert into users(user_id,name,domain,username,groups,status) select input_uuid, v_name, v_domain, v_user_name,'''',1 where not exists (select user_id,name,domain,username,groups,status from users where user_id = input_uuid);

insert into permissions(id,role_id,ad_element_id,object_id,object_type_id) select uuid_generate_v1(), ''00000000-0000-0000-0000-000000000001'', input_uuid, getGlobalIds(''system''), 1 where not exists(select role_id,ad_element_id,object_id,object_type_id from permissions where role_id = ''00000000-0000-0000-0000-000000000001'' and ad_element_id = input_uuid and object_id= getGlobalIds(''system'') and object_type_id = 1);
END; ';


ALTER FUNCTION public.attach_user_to_su_role(v_user_id character varying, v_name character varying, v_domain character varying) OWNER TO engine;

--
-- Name: calculatestorageusage(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION calculatestorageusage(v_quota_id uuid, v_storage_id uuid) RETURNS double precision
    LANGUAGE plpgsql
    AS '
DECLARE
	v_virtual_size double precision;
	v_actual_size double precision;
BEGIN
	-- Summarize size of all disks that are active.
    SELECT COALESCE(sum(size) / (1024 * 1024 * 1024),0) INTO v_virtual_size
	FROM disk_image_dynamic, images_storage_domain_view
	WHERE image_guid = disk_image_dynamic.image_id
    AND image_guid in (SELECT image_guid
                       FROM   images i JOIN vm_device vd ON i.image_group_id = vd.device_id
                       WHERE  active = TRUE)
	AND quota_id = v_quota_id
    AND (v_storage_id = images_storage_domain_view.storage_id or v_storage_id IS NULL);

	-- Summarize the actual size of all the rest disks that are read only disks such as snapshots, not active, template disks.
	SELECT COALESCE(sum(disk_image_dynamic.actual_size) / (1024 * 1024 * 1024),0) INTO v_actual_size
	FROM disk_image_dynamic, images_storage_domain_view
	WHERE image_guid = disk_image_dynamic.image_id
    AND image_guid not in (SELECT image_guid
                           FROM   images i JOIN vm_device vd ON i.image_group_id = vd.device_id
                           WHERE  active = TRUE)
	AND quota_id = v_quota_id
	AND (v_storage_id = images_storage_domain_view.storage_id or v_storage_id IS NULL);
	RETURN v_actual_size + v_virtual_size;
END; ';


ALTER FUNCTION public.calculatestorageusage(v_quota_id uuid, v_storage_id uuid) OWNER TO engine;

--
-- Name: calculatevdsgroupusage(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION calculatevdsgroupusage(v_quota_id uuid, v_vds_group_id uuid) RETURNS SETOF vds_group_usage_rs
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT cast(COALESCE(sum(num_of_sockets * cpu_per_socket), 0) as INTEGER) as virtual_cpu_usage,
    COALESCE(sum(mem_size_mb), 0) as mem_size_mb_usage
    FROM vm_static,vm_dynamic
    WHERE quota_id = v_quota_id
      AND vm_dynamic.vm_guid = vm_static.vm_guid
      AND vm_dynamic.status not in (0, 13 , 14, 15)
      AND (v_vds_group_id = vm_static.vds_group_id or v_vds_group_id IS NULL);
END; ';


ALTER FUNCTION public.calculatevdsgroupusage(v_quota_id uuid, v_vds_group_id uuid) OWNER TO engine;

--
-- Name: checkdbconnection(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION checkdbconnection() RETURNS SETOF integer
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT 1;
END; ';


ALTER FUNCTION public.checkdbconnection() OWNER TO engine;

--
-- Name: checkifjobhastasks(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION checkifjobhastasks(v_job_id uuid) RETURNS SETOF booleanresulttype
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT EXISTS(
        SELECT *
        FROM   step
        WHERE  job_id = v_job_id
        AND    external_id is not null
        AND    external_system_type = ''VDSM'');
END; ';


ALTER FUNCTION public.checkifjobhastasks(v_job_id uuid) OWNER TO engine;

--
-- Name: checkifsnapshotexistsbyvmidandsnapshotid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION checkifsnapshotexistsbyvmidandsnapshotid(v_vm_id uuid, v_snapshot_id uuid) RETURNS SETOF booleanresulttype
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT EXISTS(
        SELECT *
        FROM   snapshots
        WHERE  vm_id = v_vm_id
        AND    snapshot_id = v_snapshot_id);
END; ';


ALTER FUNCTION public.checkifsnapshotexistsbyvmidandsnapshotid(v_vm_id uuid, v_snapshot_id uuid) OWNER TO engine;

--
-- Name: checkifsnapshotexistsbyvmidandstatus(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION checkifsnapshotexistsbyvmidandstatus(v_vm_id uuid, v_status character varying) RETURNS SETOF booleanresulttype
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT EXISTS(
        SELECT *
        FROM   snapshots
        WHERE  vm_id = v_vm_id
        AND    status = v_status);
END; ';


ALTER FUNCTION public.checkifsnapshotexistsbyvmidandstatus(v_vm_id uuid, v_status character varying) OWNER TO engine;

--
-- Name: checkifsnapshotexistsbyvmidandtype(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION checkifsnapshotexistsbyvmidandtype(v_vm_id uuid, v_snapshot_type character varying) RETURNS SETOF booleanresulttype
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT EXISTS(
        SELECT *
        FROM   snapshots
        WHERE  vm_id = v_vm_id
        AND    snapshot_type = v_snapshot_type);
END; ';


ALTER FUNCTION public.checkifsnapshotexistsbyvmidandtype(v_vm_id uuid, v_snapshot_type character varying) OWNER TO engine;

--
-- Name: clearvmdeviceaddress(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION clearvmdeviceaddress(v_device_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
begin
    update vm_device set address = '''' where device_id = v_device_id;
end;
';


ALTER FUNCTION public.clearvmdeviceaddress(v_device_id uuid) OWNER TO engine;

--
-- Name: delete_entity_snapshot_by_command_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION delete_entity_snapshot_by_command_id(v_command_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	BEGIN
		delete from business_entity_snapshot where command_id = v_command_id;
	END;
	RETURN;
END; ';


ALTER FUNCTION public.delete_entity_snapshot_by_command_id(v_command_id uuid) OWNER TO engine;

--
-- Name: delete_roles_groups(integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION delete_roles_groups(v_action_group_id integer, v_role_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

   DELETE FROM roles_groups
   WHERE action_group_id = v_action_group_id AND role_id = v_role_id;

END; ';


ALTER FUNCTION public.delete_roles_groups(v_action_group_id integer, v_role_id uuid) OWNER TO engine;

--
-- Name: deleteaction_version_map(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteaction_version_map(v_action_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM action_version_map
   WHERE action_type = v_action_type;
    
END; ';


ALTER FUNCTION public.deleteaction_version_map(v_action_type integer) OWNER TO engine;

--
-- Name: deletead_groups(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletead_groups(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM tags_user_group_map
      WHERE group_id = v_id;
      DELETE FROM ad_groups
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.deletead_groups(v_id uuid) OWNER TO engine;

--
-- Name: deletealluser_sessions(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletealluser_sessions() RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      TRUNCATE TABLE user_sessions;
      UPDATE users
      SET session_count = 0
      WHERE
      session_count > 0;
END; ';


ALTER FUNCTION public.deletealluser_sessions() OWNER TO engine;

--
-- Name: deleteasync_tasks(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteasync_tasks(v_task_id uuid) RETURNS integer
    LANGUAGE plpgsql
    AS '
DECLARE
deleted_rows int;
BEGIN
   DELETE FROM async_tasks
   WHERE task_id = v_task_id;
   GET DIAGNOSTICS deleted_rows = ROW_COUNT;
   RETURN deleted_rows;
    
END; ';


ALTER FUNCTION public.deleteasync_tasks(v_task_id uuid) OWNER TO engine;

--
-- Name: deleteauditalertlogbyvdsidandtype(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteauditalertlogbyvdsidandtype(v_vds_id uuid, v_log_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      delete from audit_log where vds_id = v_vds_id and log_type = v_log_type;
END; ';


ALTER FUNCTION public.deleteauditalertlogbyvdsidandtype(v_vds_id uuid, v_log_type integer) OWNER TO engine;

--
-- Name: deleteauditlog(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteauditlog(v_audit_log_id integer) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  INTEGER;
BEGIN
		-- Get (and keep) a shared lock with "right to upgrade to exclusive"
		-- in order to force locking parent before children 
      select   audit_log_id INTO v_val FROM audit_log  WHERE audit_log_id = v_audit_log_id     FOR UPDATE;
      DELETE FROM audit_log
      WHERE audit_log_id = v_audit_log_id;
END; ';


ALTER FUNCTION public.deleteauditlog(v_audit_log_id integer) OWNER TO engine;

--
-- Name: deleteauditlogalertsbyvdsid(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteauditlogalertsbyvdsid(v_vds_id uuid, v_delete_config_alerts boolean DEFAULT true) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_min_alret_severity  INTEGER;
   v_no_config_alret_type  INTEGER;
BEGIN
      v_min_alret_severity := 10;
      v_no_config_alret_type := 9000;
      if (v_delete_config_alerts = true) then
         delete from audit_log where vds_id = v_vds_id and severity >= v_min_alret_severity;
      else
         delete from audit_log where vds_id = v_vds_id and severity >= v_min_alret_severity and log_type > v_no_config_alret_type;
      end if;
END; ';


ALTER FUNCTION public.deleteauditlogalertsbyvdsid(v_vds_id uuid, v_delete_config_alerts boolean) OWNER TO engine;

--
-- Name: deleteauditlogolderthendate(timestamp with time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteauditlogolderthendate(v_date timestamp with time zone) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_id  INTEGER;
   SWV_RowCount INTEGER;
BEGIN
        -- get first the id from which to remove in order to use index
      select   audit_log_id INTO v_id FROM audit_log WHERE LOG_TIME < v_date   order by audit_log_id desc LIMIT 1;
        -- check if there are candidates to remove
      GET DIAGNOSTICS SWV_RowCount = ROW_COUNT;
      if (SWV_RowCount > 0) then
         DELETE FROM audit_log
         WHERE audit_log_id <= v_id and
         audit_log_id not in(select audit_log_id from event_notification_hist);
      end if;
END; ';


ALTER FUNCTION public.deleteauditlogolderthendate(v_date timestamp with time zone) OWNER TO engine;

--
-- Name: deletebasedisk(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletebasedisk(v_disk_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
DECLARE
    v_val  UUID;
BEGIN
    DELETE
    FROM   base_disks
    WHERE  disk_id = v_disk_id;
END; ';


ALTER FUNCTION public.deletebasedisk(v_disk_id uuid) OWNER TO engine;

--
-- Name: deletebookmark(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletebookmark(v_bookmark_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM bookmarks
      WHERE bookmark_Id = v_bookmark_id;
END; ';


ALTER FUNCTION public.deletebookmark(v_bookmark_id uuid) OWNER TO engine;

--
-- Name: deletebypoolvds_spm_id_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletebypoolvds_spm_id_map(v_vds_id uuid, v_storage_pool_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

   DELETE FROM vds_spm_id_map
   WHERE vds_id = v_vds_id AND storage_pool_id = v_storage_pool_id;

END; ';


ALTER FUNCTION public.deletebypoolvds_spm_id_map(v_vds_id uuid, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: deletecompletedjobsolderthandate(timestamp with time zone, timestamp with time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletecompletedjobsolderthandate(v_succeeded_end_time timestamp with time zone, v_failed_end_time timestamp with time zone) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM job
    WHERE (end_time < v_succeeded_end_time
    AND    status = ''FINISHED'')
    OR    (end_time < v_failed_end_time
    AND    status IN (''FAILED'', ''ABORTED'', ''UNKNOWN''));
END; ';


ALTER FUNCTION public.deletecompletedjobsolderthandate(v_succeeded_end_time timestamp with time zone, v_failed_end_time timestamp with time zone) OWNER TO engine;

--
-- Name: deletecustom_actions(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletecustom_actions(v_action_id integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM custom_actions
      WHERE action_id = v_action_id;
END; ';


ALTER FUNCTION public.deletecustom_actions(v_action_id integer) OWNER TO engine;

--
-- Name: deletedisk_image_dynamic(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletedisk_image_dynamic(v_image_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM disk_image_dynamic
   WHERE image_id = v_image_id;
    
END; ';


ALTER FUNCTION public.deletedisk_image_dynamic(v_image_id uuid) OWNER TO engine;

--
-- Name: deletedisklunmap(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletedisklunmap(v_disk_id uuid, v_lun_id character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE
    FROM   disk_lun_map
    WHERE  disk_id = v_disk_id
    AND    lun_id = v_lun_id;
END; ';


ALTER FUNCTION public.deletedisklunmap(v_disk_id uuid, v_lun_id character varying) OWNER TO engine;

--
-- Name: deleteevent_notification_hist(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteevent_notification_hist(v_sent_at timestamp without time zone) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM event_notification_hist WHERE sent_at < v_sent_at;
END; ';


ALTER FUNCTION public.deleteevent_notification_hist(v_sent_at timestamp without time zone) OWNER TO engine;

--
-- Name: deleteevent_subscriber(character varying, integer, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteevent_subscriber(v_event_up_name character varying, v_method_id integer, v_subscriber_id uuid, v_tag_name character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      if (v_tag_name IS NULL) then
         delete from event_subscriber
         where event_up_name = v_event_up_name
         and method_id = v_method_id
         and subscriber_id = v_subscriber_id;
      else
         delete from event_subscriber
         where event_up_name = v_event_up_name
         and method_id = v_method_id
         and subscriber_id = v_subscriber_id
         and tag_name = v_tag_name;
      end if;
END; ';


ALTER FUNCTION public.deleteevent_subscriber(v_event_up_name character varying, v_method_id integer, v_subscriber_id uuid, v_tag_name character varying) OWNER TO engine;

--
-- Name: deleteglustervolumeaccessprotocol(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteglustervolumeaccessprotocol(v_volume_id uuid, v_access_protocol character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM gluster_volume_access_protocols
    WHERE volume_id = v_volume_id
    AND   access_protocol = v_access_protocol;
END; ';


ALTER FUNCTION public.deleteglustervolumeaccessprotocol(v_volume_id uuid, v_access_protocol character varying) OWNER TO engine;

--
-- Name: deleteglustervolumebrick(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteglustervolumebrick(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM gluster_volume_bricks
    WHERE id = v_id;
END; ';


ALTER FUNCTION public.deleteglustervolumebrick(v_id uuid) OWNER TO engine;

--
-- Name: deleteglustervolumebyguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteglustervolumebyguid(v_volume_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM gluster_volumes
    WHERE id = v_volume_id;
END; ';


ALTER FUNCTION public.deleteglustervolumebyguid(v_volume_id uuid) OWNER TO engine;

--
-- Name: deleteglustervolumebyname(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteglustervolumebyname(v_cluster_id uuid, v_vol_name character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM gluster_volumes
    WHERE cluster_id = v_cluster_id
    AND   vol_name = v_vol_name;
END; ';


ALTER FUNCTION public.deleteglustervolumebyname(v_cluster_id uuid, v_vol_name character varying) OWNER TO engine;

--
-- Name: deleteglustervolumeoption(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteglustervolumeoption(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM gluster_volume_options
    WHERE id = v_id;
END; ';


ALTER FUNCTION public.deleteglustervolumeoption(v_id uuid) OWNER TO engine;

--
-- Name: deleteglustervolumetransporttype(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteglustervolumetransporttype(v_volume_id uuid, v_transport_type character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM gluster_volume_transport_types
    WHERE volume_id = v_volume_id
    AND   transport_type = v_transport_type;
END; ';


ALTER FUNCTION public.deleteglustervolumetransporttype(v_volume_id uuid, v_transport_type character varying) OWNER TO engine;

--
-- Name: deleteimage(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteimage(v_image_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
DECLARE
    v_val  UUID;
BEGIN
    DELETE
    FROM   images
    WHERE  image_guid = v_image_guid;
END; ';


ALTER FUNCTION public.deleteimage(v_image_guid uuid) OWNER TO engine;

--
-- Name: deleteimage_storage_domain_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteimage_storage_domain_map(v_image_id uuid, v_storage_domain_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM image_storage_domain_map
   WHERE image_id = v_image_id AND storage_domain_id = v_storage_domain_id;
    
END; ';


ALTER FUNCTION public.deleteimage_storage_domain_map(v_image_id uuid, v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: deleteimage_storage_domain_map_by_image_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteimage_storage_domain_map_by_image_id(v_image_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM image_storage_domain_map
   WHERE image_id = v_image_id;
    
END; ';


ALTER FUNCTION public.deleteimage_storage_domain_map_by_image_id(v_image_id uuid) OWNER TO engine;

--
-- Name: deletejob(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletejob(v_job_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM job
    WHERE job_id = v_job_id;
END; ';


ALTER FUNCTION public.deletejob(v_job_id uuid) OWNER TO engine;

--
-- Name: deletejobolderthandatewithstatus(timestamp with time zone, text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletejobolderthandatewithstatus(v_end_time timestamp with time zone, v_status text) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM job
    WHERE end_time < v_end_time
    AND status = any (string_to_array(v_status,'','')::VARCHAR[] );
END; ';


ALTER FUNCTION public.deletejobolderthandatewithstatus(v_end_time timestamp with time zone, v_status text) OWNER TO engine;

--
-- Name: deletelun(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletelun(v_lun_id character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  VARCHAR(50);
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children 
   select   LUN_id INTO v_val FROM LUNs  WHERE LUN_id = v_LUN_id     FOR UPDATE;

   DELETE FROM LUNs
   WHERE LUN_id = v_LUN_id;
    
END; ';


ALTER FUNCTION public.deletelun(v_lun_id character varying) OWNER TO engine;

--
-- Name: deletelun_storage_server_connection_map(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletelun_storage_server_connection_map(v_lun_id character varying, v_storage_server_connection character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM LUN_storage_server_connection_map
   WHERE LUN_id = v_LUN_id AND storage_server_connection = v_storage_server_connection;
    
END; ';


ALTER FUNCTION public.deletelun_storage_server_connection_map(v_lun_id character varying, v_storage_server_connection character varying) OWNER TO engine;

--
-- Name: deletenetwork(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletenetwork(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN

	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children
   select   id INTO v_val FROM network  WHERE id = v_id     FOR UPDATE;

   DELETE FROM network
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.deletenetwork(v_id uuid) OWNER TO engine;

--
-- Name: deletenetwork_cluster(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletenetwork_cluster(v_cluster_id uuid, v_network_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM network_cluster
   WHERE cluster_id = v_cluster_id AND network_id = v_network_id;
    
END; ';


ALTER FUNCTION public.deletenetwork_cluster(v_cluster_id uuid, v_network_id uuid) OWNER TO engine;

--
-- Name: deletepermission(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletepermission(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children
   select   id INTO v_val FROM permissions  WHERE id = v_id     FOR UPDATE;

   DELETE FROM permissions
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.deletepermission(v_id uuid) OWNER TO engine;

--
-- Name: deletepermissionsbyentityid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletepermissionsbyentityid(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   DELETE FROM permissions
   WHERE object_id = v_id;
END; ';


ALTER FUNCTION public.deletepermissionsbyentityid(v_id uuid) OWNER TO engine;

--
-- Name: deletequotabyquotaguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletequotabyquotaguid(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   DELETE FROM quota
   WHERE id = v_id;
END; ';


ALTER FUNCTION public.deletequotabyquotaguid(v_id uuid) OWNER TO engine;

--
-- Name: deletequotalimitationbyquotaguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletequotalimitationbyquotaguid(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   DELETE FROM quota_limitation
   WHERE quota_id = v_id;
END; ';


ALTER FUNCTION public.deletequotalimitationbyquotaguid(v_id uuid) OWNER TO engine;

--
-- Name: deleterepo_domain_file_list(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleterepo_domain_file_list(v_repo_domain_id uuid, v_file_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    
   DELETE FROM repo_file_meta_data
   WHERE repo_domain_id = v_repo_domain_id
     AND file_type = v_file_type;
    
   RETURN;
END; ';


ALTER FUNCTION public.deleterepo_domain_file_list(v_repo_domain_id uuid, v_file_type integer) OWNER TO engine;

--
-- Name: deleterole(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleterole(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
    -- in order to force locking parent before children
   select   id INTO v_val FROM roles  WHERE id = v_id     FOR UPDATE;

   DELETE FROM roles
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.deleterole(v_id uuid) OWNER TO engine;

--
-- Name: deleteroles_relations(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteroles_relations(v_role_container_id uuid, v_role_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

   DELETE FROM roles_relations
   WHERE role_container_id = v_role_container_id AND role_id = v_role_id;

END; ';


ALTER FUNCTION public.deleteroles_relations(v_role_container_id uuid, v_role_id uuid) OWNER TO engine;

--
-- Name: deletesnapshot(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletesnapshot(v_snapshot_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE
    FROM   snapshots
    WHERE  snapshot_id = v_snapshot_id;
END; ';


ALTER FUNCTION public.deletesnapshot(v_snapshot_id uuid) OWNER TO engine;

--
-- Name: deletestep(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletestep(v_step_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE FROM step
    WHERE step_id = v_step_id;
END; ';


ALTER FUNCTION public.deletestep(v_step_id uuid) OWNER TO engine;

--
-- Name: deletestorage_domain_dynamic(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletestorage_domain_dynamic(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM storage_domain_dynamic
   WHERE id = v_id;
    
END; ';


ALTER FUNCTION public.deletestorage_domain_dynamic(v_id uuid) OWNER TO engine;

--
-- Name: deletestorage_domain_static(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletestorage_domain_static(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children 
   select   id INTO v_val FROM storage_domain_static  WHERE id = v_id     FOR UPDATE;
	
   DELETE FROM storage_domain_static
   WHERE id = v_id;
    
	-- delete Storage permissions --
   DELETE FROM permissions where object_id = v_id; 	

END; ';


ALTER FUNCTION public.deletestorage_domain_static(v_id uuid) OWNER TO engine;

--
-- Name: deletestorage_pool(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletestorage_pool(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
	
         -- Get (and keep) a shared lock with "right to upgrade to exclusive"
    select vm_guid INTO v_val FROM vm_static where vm_guid in (select vm_guid from vms where storage_pool_id = v_id) FOR UPDATE;
    DELETE
    FROM   snapshots
    WHERE  vm_id IN (
        SELECT vm_guid
        FROM   vms
        WHERE  storage_pool_id = v_id);
    delete FROM vm_static where vm_guid in (select vm_guid from vms where storage_pool_id = v_id);

	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children 
   select   id INTO v_val FROM storage_pool  WHERE id = v_id     FOR UPDATE;
	
   DELETE FROM storage_pool
   WHERE id = v_id;

	-- delete StoragePool permissions --
   DELETE FROM permissions where object_id = v_id; 
    
END; ';


ALTER FUNCTION public.deletestorage_pool(v_id uuid) OWNER TO engine;

--
-- Name: deletestorage_pool_iso_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletestorage_pool_iso_map(v_storage_id uuid, v_storage_pool_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM storage_pool_iso_map
   WHERE storage_id = v_storage_id AND storage_pool_id = v_storage_pool_id;
    
END; ';


ALTER FUNCTION public.deletestorage_pool_iso_map(v_storage_id uuid, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: deletestorage_server_connections(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletestorage_server_connections(v_id character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  VARCHAR(50);
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children 
   select   id INTO v_val FROM storage_server_connections  WHERE id = v_id     FOR UPDATE;
	
   DELETE FROM storage_server_connections
   WHERE id = v_id;
    
END; ';


ALTER FUNCTION public.deletestorage_server_connections(v_id character varying) OWNER TO engine;

--
-- Name: deletetags(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletetags(v_tag_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
			-- Get (and keep) a shared lock with "right to upgrade to exclusive"
			-- in order to force locking parent before children 
      select   tag_id INTO v_val FROM tags  WHERE tag_id = v_tag_id     FOR UPDATE;
      DELETE FROM tags_user_group_map
      WHERE tag_id = v_tag_id;
      DELETE FROM tags_user_map
      WHERE tag_id = v_tag_id;
      DELETE FROM tags_vm_map
      WHERE tag_id = v_tag_id;
      DELETE FROM tags_vds_map
      WHERE tag_id = v_tag_id;
      DELETE FROM tags_vm_pool_map
      WHERE tag_id = v_tag_id;
      DELETE FROM tags
      WHERE tag_id = v_tag_id;
END; ';


ALTER FUNCTION public.deletetags(v_tag_id uuid) OWNER TO engine;

--
-- Name: deletetags_user_group_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletetags_user_group_map(v_group_id uuid, v_tag_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM tags_user_group_map
      WHERE group_id = v_group_id AND tag_id = v_tag_id;
END; ';


ALTER FUNCTION public.deletetags_user_group_map(v_group_id uuid, v_tag_id uuid) OWNER TO engine;

--
-- Name: deletetags_user_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletetags_user_map(v_tag_id uuid, v_user_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM tags_user_map
      WHERE tag_id = v_tag_id AND user_id = v_user_id;
END; ';


ALTER FUNCTION public.deletetags_user_map(v_tag_id uuid, v_user_id uuid) OWNER TO engine;

--
-- Name: deletetags_vds_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletetags_vds_map(v_tag_id uuid, v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM tags_vds_map
      WHERE tag_id = v_tag_id AND vds_id = v_vds_id;
END; ';


ALTER FUNCTION public.deletetags_vds_map(v_tag_id uuid, v_vds_id uuid) OWNER TO engine;

--
-- Name: deletetags_vm_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletetags_vm_map(v_tag_id uuid, v_vm_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM tags_vm_map
      WHERE tag_id = v_tag_id AND vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.deletetags_vm_map(v_tag_id uuid, v_vm_id uuid) OWNER TO engine;

--
-- Name: deletetags_vm_pool_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletetags_vm_pool_map(v_tag_id uuid, v_vm_pool_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM tags_vm_pool_map
   WHERE tag_id = v_tag_id AND vm_pool_id = v_vm_pool_id;
    
END; ';


ALTER FUNCTION public.deletetags_vm_pool_map(v_tag_id uuid, v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: deleteuser(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteuser(v_user_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
			-- Get (and keep) a shared lock with "right to upgrade to exclusive"
			-- in order to force locking parent before children 
      select   user_id INTO v_val FROM users  WHERE user_id = v_user_id     FOR UPDATE;
      DELETE FROM tags_user_map
      WHERE user_id = v_user_id;
      DELETE FROM users
      WHERE user_id = v_user_id;
END; ';


ALTER FUNCTION public.deleteuser(v_user_id uuid) OWNER TO engine;

--
-- Name: deleteuser_sessions(character, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteuser_sessions(v_session_id character, v_user_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_counter  INTEGER;
   SWV_RowCount INTEGER;
BEGIN
      DELETE FROM user_sessions
      WHERE session_id = v_session_id AND user_id = v_user_id;
      GET DIAGNOSTICS SWV_RowCount = ROW_COUNT;
      if (SWV_RowCount > 0) then
         select   session_count INTO v_counter from users WHERE
         user_id = v_user_id;
         if (v_counter > 0) then
            UPDATE users
            SET session_count = session_count -1
            WHERE
            user_id = v_user_id;
         end if;
      end if;
END; ';


ALTER FUNCTION public.deleteuser_sessions(v_session_id character, v_user_id uuid) OWNER TO engine;

--
-- Name: deleteuser_sessionsbyuser_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deleteuser_sessionsbyuser_id(v_user_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM user_sessions
      WHERE user_id = v_user_id;
      UPDATE users
      SET session_count = 0
      WHERE
      user_id = v_user_id;
END; ';


ALTER FUNCTION public.deleteuser_sessionsbyuser_id(v_user_id uuid) OWNER TO engine;

--
-- Name: deletevdcoption(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevdcoption(v_option_id integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM vdc_options
      WHERE option_id = v_option_id;
END; ';


ALTER FUNCTION public.deletevdcoption(v_option_id integer) OWNER TO engine;

--
-- Name: deletevds(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevds(v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN  
   BEGIN
      UPDATE vm_static
      SET dedicated_vm_for_vds = null
      WHERE dedicated_vm_for_vds = v_vds_id;
      DELETE FROM tags_vds_map
      WHERE vds_id = v_vds_id;  
   -- Delete all Vds Alerts from the database  
      PERFORM DeleteAuditLogAlertsByVdsID(v_vds_id);
      DELETE FROM vds_statistics WHERE vds_id = v_vds_id;
      DELETE FROM vds_dynamic WHERE vds_id = v_vds_id;
      DELETE FROM vds_static WHERE vds_id = v_vds_id;
      DELETE FROM permissions where object_id = v_vds_id;
   END;  
   RETURN;
END; ';


ALTER FUNCTION public.deletevds(v_vds_id uuid) OWNER TO engine;

--
-- Name: deletevds_interface(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevds_interface(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM vds_interface
   WHERE id = v_id;
    
END; ';


ALTER FUNCTION public.deletevds_interface(v_id uuid) OWNER TO engine;

--
-- Name: deletevds_interface_statistics(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevds_interface_statistics(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children 
   select   id INTO v_val FROM vds_interface_statistics  WHERE id = v_id     FOR UPDATE;

   DELETE FROM vds_interface_statistics
   WHERE id = v_id;
    
END; ';


ALTER FUNCTION public.deletevds_interface_statistics(v_id uuid) OWNER TO engine;

--
-- Name: deletevds_spm_id_map(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevds_spm_id_map(v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   DELETE FROM vds_spm_id_map
   WHERE vds_id = v_vds_id;
    
END; ';


ALTER FUNCTION public.deletevds_spm_id_map(v_vds_id uuid) OWNER TO engine;

--
-- Name: deletevdsdynamic(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevdsdynamic(v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   BEGIN
      DELETE FROM vds_dynamic
      WHERE vds_id = v_vds_id;
   END;
    
   RETURN;
END; ';


ALTER FUNCTION public.deletevdsdynamic(v_vds_id uuid) OWNER TO engine;

--
-- Name: deletevdsgroup(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevdsgroup(v_vds_group_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
		-- Get (and keep) a shared lock with "right to upgrade to exclusive"
		-- in order to force locking parent before children 
      select   vds_group_id INTO v_val FROM vds_groups  WHERE vds_group_id = v_vds_group_id     FOR UPDATE;
      DELETE FROM vds_groups
      WHERE vds_group_id = v_vds_group_id;
		-- delete VDS group permissions --
      DELETE FROM permissions where object_id = v_vds_group_id;
END; ';


ALTER FUNCTION public.deletevdsgroup(v_vds_group_id uuid) OWNER TO engine;

--
-- Name: deletevdsstatic(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevdsstatic(v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN  
   BEGIN
      UPDATE vm_static
      SET dedicated_vm_for_vds = null,
          migration_support = 0
      WHERE dedicated_vm_for_vds = v_vds_id;
      DELETE FROM tags_vds_map
      WHERE vds_id = v_vds_id;  
   -- Delete all Vds Alerts from the database  
      PERFORM DeleteAuditLogAlertsByVdsID(v_vds_id);
      DELETE FROM vds_static
      WHERE vds_id = v_vds_id;
	-- delete VDS permissions --
      DELETE FROM permissions where object_id = v_vds_id;
   END;  
       
   RETURN;
END; ';


ALTER FUNCTION public.deletevdsstatic(v_vds_id uuid) OWNER TO engine;

--
-- Name: deletevdsstatistics(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevdsstatistics(v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   BEGIN
      DELETE FROM vds_statistics
      WHERE vds_id = v_vds_id;
   END;
    
   RETURN;
END; ';


ALTER FUNCTION public.deletevdsstatistics(v_vds_id uuid) OWNER TO engine;

--
-- Name: deletevm(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevm(v_vm_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_vmt_guid  UUID;
BEGIN
      select   vm_static.vmt_guid INTO v_vmt_guid FROM vm_static WHERE vm_guid = v_vm_guid;
      UPDATE vm_static
      SET child_count =(SELECT COUNT(*) FROM vm_static WHERE vmt_guid = v_vmt_guid) -1
      WHERE vm_guid = v_vmt_guid;
      DELETE FROM tags_vm_map
      WHERE vm_id = v_vm_guid;
      DELETE
      FROM   snapshots
      WHERE  vm_id = v_vm_guid;
      DELETE FROM vm_statistics WHERE vm_guid = v_vm_guid;
      DELETE FROM vm_dynamic WHERE vm_guid = v_vm_guid;
      DELETE FROM vm_static WHERE vm_guid = v_vm_guid;
      DELETE FROM permissions where object_id = v_vm_guid;
END; ';


ALTER FUNCTION public.deletevm(v_vm_guid uuid) OWNER TO engine;

--
-- Name: deletevm_interface(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevm_interface(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children 
   select   id INTO v_val FROM vm_interface  WHERE id = v_id     FOR UPDATE;
	
   DELETE FROM vm_interface
   WHERE id = v_id;
    
END; ';


ALTER FUNCTION public.deletevm_interface(v_id uuid) OWNER TO engine;

--
-- Name: deletevm_interface_statistics(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevm_interface_statistics(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
	
	-- Get (and keep) a shared lock with "right to upgrade to exclusive"
	-- in order to force locking parent before children 
   select   id INTO v_val FROM vm_interface_statistics  WHERE id = v_id     FOR UPDATE;

   DELETE FROM vm_interface_statistics
   WHERE id = v_id;
    
END; ';


ALTER FUNCTION public.deletevm_interface_statistics(v_id uuid) OWNER TO engine;

--
-- Name: deletevm_pool_map(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevm_pool_map(v_vm_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  VARCHAR(50);
BEGIN
		-- Get (and keep) a shared lock with "right to upgrade to exclusive"
		-- in order to force locking parent before children 
      select   vm_guid INTO v_val FROM vm_pool_map  WHERE vm_guid = v_vm_guid     FOR UPDATE;
      DELETE FROM vm_pool_map
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.deletevm_pool_map(v_vm_guid uuid) OWNER TO engine;

--
-- Name: deletevm_pools(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevm_pools(v_vm_pool_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
		-- Get (and keep) a shared lock with "right to upgrade to exclusive"
		-- in order to force locking parent before children 
      select   vm_pool_id INTO v_val FROM vm_pools  WHERE vm_pool_id = v_vm_pool_id     FOR UPDATE;
      DELETE FROM vm_pools
      WHERE vm_pool_id = v_vm_pool_id;

		-- delete VmPool permissions --
      DELETE FROM permissions where object_id = v_vm_pool_id;
END; ';


ALTER FUNCTION public.deletevm_pools(v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: deletevmdevice(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevmdevice(v_device_id uuid, v_vm_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    DELETE
    FROM   vm_device
    WHERE  device_id = v_device_id
    AND (v_vm_id IS NULL or vm_id = v_vm_id);
END; ';


ALTER FUNCTION public.deletevmdevice(v_device_id uuid, v_vm_id uuid) OWNER TO engine;

--
-- Name: deletevmdynamic(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevmdynamic(v_vm_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM vm_dynamic
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.deletevmdynamic(v_vm_guid uuid) OWNER TO engine;

--
-- Name: deletevmstatic(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevmstatic(v_vm_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
			-- Get (and keep) a shared lock with "right to upgrade to exclusive"
            -- in order to force locking parent before children 
      select   vm_guid INTO v_val FROM vm_static  WHERE vm_guid = v_vm_guid     FOR UPDATE;
      DELETE FROM vm_static
      WHERE vm_guid = v_vm_guid
      AND   entity_type = ''VM'';

			-- delete VM permissions --
      DELETE FROM permissions where object_id = v_vm_guid;
END; ';


ALTER FUNCTION public.deletevmstatic(v_vm_guid uuid) OWNER TO engine;

--
-- Name: deletevmstatistics(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevmstatistics(v_vm_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      DELETE FROM vm_statistics
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.deletevmstatistics(v_vm_guid uuid) OWNER TO engine;

--
-- Name: deletevmtemplates(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION deletevmtemplates(v_vmt_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_val  UUID;
BEGIN
        -- Get (and keep) a shared lock with "right to upgrade to exclusive"
		-- in order to force locking parent before children 
      select   vm_guid INTO v_val FROM vm_static  WHERE vm_guid = v_vmt_guid AND entity_type = ''TEMPLATE'' FOR UPDATE;
      DELETE FROM vm_static
      WHERE vm_guid = v_vmt_guid
      AND   entity_type = ''TEMPLATE'';
		-- delete Template permissions --
      DELETE FROM permissions where object_id = v_vmt_guid;
END; ';


ALTER FUNCTION public.deletevmtemplates(v_vmt_guid uuid) OWNER TO engine;

--
-- Name: fn_db_add_column(character varying, character varying, text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_add_column(v_table character varying, v_column character varying, v_column_def text) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
v_sql text;

begin
	if (not exists (select 1 from information_schema.columns where table_name ilike v_table and column_name ilike v_column)) then
	    begin
		v_sql := ''ALTER TABLE '' || v_table || '' ADD COLUMN '' || v_column || '' '' || v_column_def;
		EXECUTE v_sql;
            end;
	end if;
END; ';


ALTER FUNCTION public.fn_db_add_column(v_table character varying, v_column character varying, v_column_def text) OWNER TO engine;

--
-- Name: fn_db_add_column_to_object_white_list(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_add_column_to_object_white_list(v_object_name character varying, v_column_name character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
begin
    if (not exists (select 1 from object_column_white_list
                    where object_name = v_object_name and column_name = v_column_name)) then
        begin
            -- verify that there is such object in db
            if exists (select 1 from information_schema.columns
                       where table_name = v_object_name and column_name = v_column_name) then
                insert into object_column_white_list (object_name, column_name) values (v_object_name, v_column_name);
            end if;
        end;
    end if;
END; ';


ALTER FUNCTION public.fn_db_add_column_to_object_white_list(v_object_name character varying, v_column_name character varying) OWNER TO engine;

--
-- Name: fn_db_add_config_value(character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_add_config_value(v_option_name character varying, v_option_value character varying, v_version character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
begin
    if (not exists (select 1 from vdc_options where option_name ilike v_option_name and version = v_version)) then
        begin
            insert into vdc_options (option_name, option_value, version) values (v_option_name, v_option_value, v_version);
        end;
    end if;
END; ';


ALTER FUNCTION public.fn_db_add_config_value(v_option_name character varying, v_option_value character varying, v_version character varying) OWNER TO engine;

--
-- Name: fn_db_change_column_type(character varying, character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_change_column_type(v_table character varying, v_column character varying, v_type character varying, v_new_type character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
v_sql text;

begin
	if (exists (select 1 from information_schema.columns where table_name ilike v_table and column_name ilike v_column and (udt_name ilike v_type or data_type ilike v_type))) then
	    begin
		v_sql := ''ALTER TABLE '' || v_table || '' ALTER COLUMN '' || v_column || '' TYPE '' || v_new_type;
		EXECUTE v_sql;
            end;
	end if;
END; ';


ALTER FUNCTION public.fn_db_change_column_type(v_table character varying, v_column character varying, v_type character varying, v_new_type character varying) OWNER TO engine;

--
-- Name: fn_db_delete_config_value(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_delete_config_value(v_option_name character varying, v_version character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
begin
    if (exists (select 1 from vdc_options where option_name ilike v_option_name and version = v_version)) then
        begin
            delete from vdc_options where option_name ilike v_option_name and version = v_version;
        end;
    end if;
END; ';


ALTER FUNCTION public.fn_db_delete_config_value(v_option_name character varying, v_version character varying) OWNER TO engine;

--
-- Name: fn_db_drop_column(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_drop_column(v_table character varying, v_column character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
v_sql text;
begin
        if (exists (select 1 from information_schema.columns where table_name ilike v_table and column_name ilike v_column)) then
            begin
                v_sql := ''ALTER TABLE '' || v_table || '' DROP COLUMN '' || v_column;
                EXECUTE v_sql;
            end;
        end if;
end;';


ALTER FUNCTION public.fn_db_drop_column(v_table character varying, v_column character varying) OWNER TO engine;

--
-- Name: fn_db_get_async_tasks(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_get_async_tasks() RETURNS SETOF async_tasks_info_rs
    LANGUAGE plpgsql
    AS '
DECLARE
    v_record async_tasks_info_rs;

    -- selects storage_pool_id uuid found in async_tasks
    v_tasks_cursor cursor for select distinct storage_pool_id from async_tasks;
begin

    OPEN v_tasks_cursor;
    FETCH v_tasks_cursor into v_record.dc_id;
    WHILE FOUND LOOP
        -- get dc_name and SPM Host id
        v_record.dc_name := name from storage_pool where id = v_record.dc_id;
        v_record.spm_host_id :=
            spm_vds_id from storage_pool where id = v_record.dc_id;
        -- get Host name if we have non NULL SPM Host
        if (v_record.spm_host_id IS NOT NULL) then
            v_record.spm_host_name :=
                vds_name from vds_static where vds_id = v_record.spm_host_id;
        else
            v_record.spm_host_name:='''';
        end if;
        -- get tasks count for this DC
        v_record.task_count := count(*) from async_tasks
            where position (cast(v_record.dc_id as varchar) in action_parameters) > 0;
        -- return the record
        RETURN NEXT v_record;
        FETCH v_tasks_cursor into v_record.dc_id;
    END LOOP;
    CLOSE v_tasks_cursor;
    -- return full set of generated records
    RETURN;
END; ';


ALTER FUNCTION public.fn_db_get_async_tasks() OWNER TO engine;

--
-- Name: fn_db_grant_action_group_to_all_roles_filter(integer, uuid[]); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_grant_action_group_to_all_roles_filter(v_action_group_id integer, uuid[]) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
v_role_id_to_filter alias for $2;
begin
    insert into roles_groups (role_id, action_group_id)
    select distinct role_id, v_action_group_id
    from roles_groups rg
    where not ARRAY [role_id] <@ v_role_id_to_filter and not exists (select 1 from roles_groups where role_id = rg.role_id and action_group_id = v_action_group_id);
END; ';


ALTER FUNCTION public.fn_db_grant_action_group_to_all_roles_filter(v_action_group_id integer, uuid[]) OWNER TO engine;

--
-- Name: fn_db_mask_object(regclass); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_mask_object(v_object regclass) RETURNS SETOF record
    LANGUAGE plpgsql
    AS '
DECLARE
    v_sql TEXT;
    v_table record;
    v_table_name TEXT;
    temprec record;
BEGIN
    -- get full table/view name from v_object (i.e <namespace>.<name>)
    select c.relname, n.nspname INTO v_table
        FROM pg_class c join pg_namespace n on c.relnamespace = n.oid WHERE c.oid = v_object;
    -- try to get filtered query syntax from previous execution
    if exists (select 1 from object_column_white_list_sql where object_name = v_table.relname) then
	select sql into v_sql from object_column_white_list_sql where object_name = v_table.relname;
    else
        v_table_name := quote_ident( v_table.nspname ) || ''.'' || quote_ident( v_table.relname );
        -- compose sql statement while skipping values for columns not defined in object_column_white_list for this table.
        for temprec in select a.attname, t.typname
                       FROM pg_attribute a join pg_type t on a.atttypid = t.oid
                       WHERE a.attrelid = v_object AND a.attnum > 0 AND NOT a.attisdropped ORDER BY a.attnum
        loop
            v_sql := coalesce( v_sql || '', '', ''SELECT '' );
            if exists(select 1 from object_column_white_list
               where object_name = v_table.relname and column_name = temprec.attname) then
               v_sql := v_sql || quote_ident( temprec.attname );
            ELSE
               v_sql := v_sql || ''NULL::'' || quote_ident( temprec.typname ) || '' as '' || quote_ident( temprec.attname );
            END IF;
        END LOOP;
        v_sql := v_sql || '' FROM '' || v_table_name;
        v_sql := ''SELECT x::'' || v_table_name || '' as rec FROM ('' || v_sql || '') as x'';
        -- save generated query for further use
        insert into object_column_white_list_sql(object_name,sql) values (v_table.relname, v_sql);
    end if;
    RETURN QUERY EXECUTE v_sql;
END; ';


ALTER FUNCTION public.fn_db_mask_object(v_object regclass) OWNER TO engine;

--
-- Name: fn_db_rename_column(character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_rename_column(v_table character varying, v_column character varying, v_new_name character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
v_sql text;

begin
	if (exists (select 1 from information_schema.columns where table_name ilike v_table and column_name ilike v_column)) then
	    begin
		v_sql := ''ALTER TABLE '' || v_table || '' RENAME COLUMN '' || v_column || '' TO '' || v_new_name;
		EXECUTE v_sql;
            end;
	end if;
END; ';


ALTER FUNCTION public.fn_db_rename_column(v_table character varying, v_column character varying, v_new_name character varying) OWNER TO engine;

--
-- Name: fn_db_split_config_value(character varying, character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_split_config_value(v_option_name character varying, v_old_option_value character varying, v_new_option_value character varying, v_update_from_version character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
v_old_value varchar(4000);
v_cur cursor for select distinct version from vdc_options where version <> ''general'' order by version;
v_version varchar(40);
v_index integer;
v_count integer;
v_total_count integer;
v_version_count integer;
begin
    v_total_count := count(version) from vdc_options where option_name = v_option_name;
    v_old_value := option_value from vdc_options where option_name = v_option_name and version = ''general'';
    v_version_count := count(distinct version) from vdc_options where version <> ''general'';
    if (v_total_count <= v_version_count) then
        begin
            if (v_old_value IS NULL) then
                v_old_value := v_old_option_value;
            end if;
            v_count := count(distinct version) from vdc_options where version <> ''general'';
            v_index := 1;
        open v_cur;
        loop
            fetch v_cur into v_version;
            exit when not found;
            -- We shouldn''t update if already exists
            if (not exists (select 1 from vdc_options where option_name = v_option_name and version = v_version)) then
                -- Might not work well for versions such as 3.10, but we currently don''t have any
                if (v_version >= v_update_from_version) then
                    insert into vdc_options (option_name, option_value, version) values (v_option_name, v_new_option_value, v_version);
                else
                    insert into vdc_options (option_name, option_value, version) values (v_option_name, v_old_value, v_version);
                end if;
            end if;
            v_index := v_index +1;
        end loop;
        close v_cur;
        delete from vdc_options where option_name = v_option_name and version = ''general'';
        end;
    end if;
END; ';


ALTER FUNCTION public.fn_db_split_config_value(v_option_name character varying, v_old_option_value character varying, v_new_option_value character varying, v_update_from_version character varying) OWNER TO engine;

--
-- Name: fn_db_unlock_disk(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_unlock_disk(v_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
    OK integer;
    LOCKED integer;
begin
    OK:=1;
    LOCKED:=2;
    update images set imagestatus = OK where imagestatus = LOCKED and
    image_group_id in (select device_id from vm_device where device_id = v_id and is_plugged);
END; ';


ALTER FUNCTION public.fn_db_unlock_disk(v_id uuid) OWNER TO engine;

--
-- Name: fn_db_unlock_entity(character varying, character varying, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_unlock_entity(v_object_type character varying, v_name character varying, v_recursive boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
declare
    DOWN integer;
    OK integer;
    LOCKED integer;
    TEMPLATE_OK integer;
    TEMPLATE_LOCKED integer;
    IMAGE_LOCKED integer;
    v_id UUID;
begin
    DOWN:=0;
    OK:=1;
    LOCKED:=2;
    TEMPLATE_OK:=0;
    TEMPLATE_LOCKED:=1;
    IMAGE_LOCKED:=15;
    if (v_recursive) then
        v_id := vm_guid from vm_static where vm_name = v_name and entity_type ilike v_object_type;
        update images set imagestatus = OK where imagestatus = LOCKED and
        image_group_id in (select device_id from vm_device where vm_id = v_id and is_plugged);
    end if;
    -- set VM status to DOWN
    if (v_object_type = ''vm'') then
        update vm_dynamic set status = DOWN where status = IMAGE_LOCKED and
        vm_guid in
            (select vm_guid from vm_static where vm_name = v_name);
    -- set Template status to OK
    else
        if (v_object_type = ''template'') then
            update vm_static set template_status = TEMPLATE_OK
            where template_status = TEMPLATE_LOCKED and
            vm_guid in
                (select vm_guid from vm_static where vm_name = v_name);
        end if;
    end if;
END; ';


ALTER FUNCTION public.fn_db_unlock_entity(v_object_type character varying, v_name character varying, v_recursive boolean) OWNER TO engine;

--
-- Name: fn_db_update_config_value(character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_update_config_value(v_option_name character varying, v_option_value character varying, v_version character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
begin
    if (exists (select 1 from vdc_options where option_name ilike v_option_name and version = v_version)) then
        begin
            update  vdc_options set option_value = v_option_value
            where option_name ilike v_option_name and version = v_version;
        end;
    end if;
END; ';


ALTER FUNCTION public.fn_db_update_config_value(v_option_name character varying, v_option_value character varying, v_version character varying) OWNER TO engine;

--
-- Name: fn_db_update_default_config_value(character varying, character varying, character varying, character varying, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_db_update_default_config_value(v_option_name character varying, v_default_option_value character varying, v_option_value character varying, v_version character varying, v_ignore_default_value_case boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
begin
    if (exists (select 1 from vdc_options where option_name ilike v_option_name and version = v_version)) then
        begin
            if (v_ignore_default_value_case)
            then
               update  vdc_options set option_value = v_option_value
               where option_name ilike v_option_name and option_value ilike v_default_option_value and version = v_version;
            else
               update  vdc_options set option_value = v_option_value
               where option_name ilike v_option_name and option_value = v_default_option_value and version = v_version;
            end if;
        end;
    end if;
END; ';


ALTER FUNCTION public.fn_db_update_default_config_value(v_option_name character varying, v_default_option_value character varying, v_option_value character varying, v_version character varying, v_ignore_default_value_case boolean) OWNER TO engine;

--
-- Name: fn_get_ad_element_name(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_get_ad_element_name(v_ad_element_id uuid) RETURNS text
    LANGUAGE plpgsql
    AS '
DECLARE
    result text;

BEGIN
   if (v_ad_element_id = getGlobalIds(''everyone'')) then
      result := ''Everyone'';
   else
      select(COALESCE(name,'''') || '' '' || COALESCE(surname,'''') || '' ('' || COALESCE(username,'''') || '')'') INTO result from users where user_id = v_ad_element_id;
      if (result is null) then
         select   name INTO result from ad_groups where ID = v_ad_element_id;
      end if;
   end if;
   return result;
END; ';


ALTER FUNCTION public.fn_get_ad_element_name(v_ad_element_id uuid) OWNER TO engine;

--
-- Name: fn_get_column_size(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_get_column_size(v_table character varying, v_column character varying) RETURNS integer
    LANGUAGE plpgsql
    AS '
   declare
   retvalue  integer;
BEGIN
   retvalue := character_maximum_length from information_schema.columns
    where
    table_name ilike v_table and column_name ilike v_column and
    table_schema = ''public'' and udt_name in (''char'',''varchar'');
   return retvalue;
END; ';


ALTER FUNCTION public.fn_get_column_size(v_table character varying, v_column character varying) OWNER TO engine;

--
-- Name: fn_get_disk_commited_value_by_storage(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_get_disk_commited_value_by_storage(v_storage_domain_id uuid) RETURNS integer
    LANGUAGE plpgsql
    AS '
DECLARE
    result integer;
    mult bigint;

BEGIN
	mult := ( SELECT
	    		COALESCE(SUM(images_storage_domain_view.size - disk_image_dynamic.actual_size),0)
				FROM images_storage_domain_view JOIN
	    			disk_image_dynamic ON ( images_storage_domain_view.image_guid = disk_image_dynamic.image_id )
				WHERE
   					images_storage_domain_view.storage_id = v_storage_domain_id );
        -- convert to GB from bytes
	mult := CAST((mult * 0.000000000931322574615478515625) AS bigint);
    result := CAST(mult as integer);

	RETURN result;
END;';


ALTER FUNCTION public.fn_get_disk_commited_value_by_storage(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: fn_get_entity_name(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_get_entity_name(v_entity_id uuid, v_object_type integer) RETURNS text
    LANGUAGE plpgsql
    AS '
/*    Gets object name by its id and type

    Object Types (compatible with VdcObjectType, XXX entries are unused currently)
        Unknown XXX,
        System XXX,
        VM = 2,
        VDS = 3,
        VmTemplate = 4,
        VmPool = 5,
        AdElements XXX,
        Tags XXX,
        Bookmarks XXX,
        VdsGroups = 9,
        MultiLevelAdministration XXX,
        Storage = 11,
        EventNotification XXX,
        ImportExport XXX,
        StoragePool = 14,
        User = 15,
        Role = 16,
        Quota = 17,
        Disk = 19,
        VmInterface = 20
*/
DECLARE
    v_entity_type int4 := v_object_type;
    result text;

BEGIN

    CASE
    WHEN v_entity_type = 1 THEN
        result := ''System'';
    WHEN v_entity_type = 2 OR v_entity_type = 4 THEN
        result := ( SELECT vm_name FROM vm_static WHERE vm_guid = v_entity_id );
    WHEN v_entity_type = 3 THEN
        result := ( SELECT vds_name FROM vds_static WHERE vds_id = v_entity_id );
    WHEN v_entity_type = 5 THEN
        result := ( SELECT vm_pool_name FROM vm_pools WHERE vm_pool_id = v_entity_id );
    WHEN v_entity_type = 7 THEN
        result := ( SELECT tag_name FROM tags WHERE tag_id = v_entity_id );
    WHEN v_entity_type = 8 THEN
        result := ( SELECT bookmark_name FROM bookmarks WHERE bookmark_id = v_entity_id );
    WHEN v_entity_type = 9 THEN
        result := ( SELECT name FROM vds_groups WHERE vds_group_id = v_entity_id );
    WHEN v_entity_type = 11 THEN
        result := ( SELECT storage_name FROM storage_domain_static WHERE id = v_entity_id );
    WHEN v_entity_type = 14 THEN
        result := ( SELECT name FROM storage_pool WHERE id = v_entity_id );
    WHEN v_entity_type = 15 THEN
        result := ( SELECT username FROM users WHERE user_id = v_entity_id );
    WHEN v_entity_type = 16 THEN
        result := ( SELECT name FROM roles WHERE id = v_entity_id );
    WHEN v_entity_type = 17 THEN
        result := ( SELECT quota_name FROM quota WHERE id = v_entity_id );
    WHEN v_entity_type = 19 THEN
        result := ( SELECT disk_alias FROM base_disks WHERE disk_id = v_entity_id );
    WHEN v_entity_type = 20 THEN
        result := ( SELECT name FROM vm_interface WHERE id = v_entity_id );
    ELSE
        result := ''Unknown type '' ||  v_entity_type;
    END CASE;

--      -- This should be written to an error var or include object_id that is missing
--    IF result IS NULL THEN
--        result := v_entity_id || '''' NOT FOUND'''';
--    END IF;
    RETURN result;
END;';


ALTER FUNCTION public.fn_get_entity_name(v_entity_id uuid, v_object_type integer) OWNER TO engine;

--
-- Name: fn_get_entity_parents(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_get_entity_parents(v_entity_id uuid, v_object_type integer) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
/*	Gets a list of all parent GUID to the system root (including)

	Object Types (compatible with VdcObjectType, XXX entries are unused currently)
		Unknown XXX,
		System XXX,
        Bottom = 0,
		VM = 2,
		VDS = 3,
		VmTemplate = 4,
		VmPool = 5,
		AdElements XXX,
		Tags XXX,
		Bookmarks XXX,
		VdsGroups = 9,
		MultiLevelAdministration XXX,
		Storage = 11,
		EventNotification XXX,
		ImportExport XXX,
		StoragePool = 14,
		User = 15,
		Role = 16,
		Quota = 17,
		GlusterVolume = 18,
        Disk = 19,
        VmInterface = 20
*/
DECLARE
	v_entity_type int4 := v_object_type;
	system_root_id uuid;
	cluster_id uuid;
	ds_id uuid;
	v_image_id uuid;
	v_storage_id uuid;
    v_vm_id uuid;
    v_vm_interface_id uuid;
    v_storage_pool_id uuid;

BEGIN

	system_root_id := ( SELECT getGlobalIds(''system'') ); -- hardcoded also in MLA Handler
	CASE
	WHEN v_entity_type = 0 THEN -- Bottom
		RETURN QUERY
			SELECT object_id
			FROM permissions;
	WHEN v_entity_type = 2 THEN -- VM
        -- get cluster id
		cluster_id := ( SELECT vds_group_id FROM vm_static WHERE vm_guid = v_entity_id );
		-- get data center id
		ds_id := ( SELECT storage_pool_id FROM vds_groups WHERE vds_group_id = cluster_id );

		RETURN QUERY
			SELECT system_root_id AS id
			UNION
			SELECT ds_id AS id
			UNION
			SELECT cluster_id AS id
			UNION
			SELECT v_entity_id AS id;
	WHEN v_entity_type = 3 THEN -- VDS
        -- get cluster id
		cluster_id := ( SELECT vds_group_id FROM vds_static WHERE vds_id = v_entity_id );
		-- get data center id
		ds_id := ( SELECT storage_pool_id FROM vds_groups WHERE vds_group_id = cluster_id );

		RETURN QUERY
			SELECT system_root_id AS id
			UNION
			SELECT ds_id AS id
			UNION
			SELECT cluster_id AS id
			UNION
			SELECT v_entity_id AS id;
	WHEN v_entity_type = 4 THEN -- Template
		-- get image id first
		v_image_id := ( SELECT image_guid FROM images i JOIN vm_device vd ON i.image_group_id = vd.device_id WHERE vm_id = v_entity_id limit 1);
		-- get the storage id from images
		v_storage_id := ( SELECT storage_domain_id FROM image_storage_domain_map WHERE image_id = v_image_id limit 1);
		-- finally get data center id
		ds_id := ( SELECT storage_pool_id FROM storage_pool_iso_map WHERE storage_id = v_storage_id );

		RETURN QUERY
			SELECT system_root_id AS id
			UNION
			SELECT ds_id AS id
			UNION
			SELECT v_entity_id AS id;
	WHEN v_entity_type = 5 THEN -- VM Pool
        -- get cluster id
		cluster_id := ( SELECT vds_group_id FROM vm_pools WHERE vm_pool_id = v_entity_id );
		-- get data center id
		ds_id := ( SELECT storage_pool_id FROM vds_groups WHERE vds_group_id = cluster_id );

		RETURN QUERY
			SELECT system_root_id AS id
			UNION
			SELECT ds_id AS id
			UNION
			SELECT cluster_id AS id
			UNION
			SELECT v_entity_id AS id;
	WHEN v_entity_type = 9 THEN -- Cluster
		-- get data center id
		ds_id := ( SELECT storage_pool_id FROM vds_groups WHERE vds_group_id = v_entity_id );

		RETURN QUERY
			SELECT system_root_id AS id
			UNION
			SELECT ds_id AS id
			UNION
			SELECT v_entity_id AS id;
	WHEN v_entity_type = 11 THEN -- Storage Domain

		RETURN QUERY
			SELECT system_root_id AS id
			UNION ALL
			SELECT storage_pool_id as id FROM storage_pool_iso_map WHERE storage_id = v_entity_id
			UNION
			SELECT v_entity_id AS id;
	WHEN v_entity_type = 17 THEN -- Quota
		-- get data center id
		ds_id := ( SELECT storage_pool_id FROM quota WHERE id = v_entity_id );

		RETURN QUERY
			SELECT system_root_id AS id
			UNION
			SELECT ds_id AS id
			UNION
			SELECT v_entity_id AS id;
	WHEN v_entity_type = 18 THEN -- GlusterVolume
        -- get cluster id
		cluster_id := ( SELECT v.cluster_id FROM gluster_volumes v WHERE id = v_entity_id );
		-- get data center id
		ds_id := ( SELECT storage_pool_id FROM vds_groups WHERE vds_group_id = cluster_id );

		RETURN QUERY
			SELECT system_root_id AS id
			UNION
			SELECT ds_id AS id
			UNION
			SELECT cluster_id AS id
			UNION
			SELECT v_entity_id AS id;

	WHEN v_entity_type = 19 THEN -- Disk

        -- get data center, storage domain and vm
        SELECT INTO ds_id, v_storage_id, v_vm_id
                    storage_pool_id, storage_id, vm_id
        FROM images_storage_domain_view
        LEFT OUTER JOIN vm_device ON vm_device.device_id = images_storage_domain_view.disk_id
        WHERE image_group_id = v_entity_id;

        -- get cluster
        cluster_id := ( SELECT vds_group_id FROM vm_static WHERE vm_guid = v_vm_id );

        RETURN QUERY
            SELECT system_root_id AS id
            UNION
            SELECT ds_id AS id
            UNION
            SELECT v_storage_id AS id
            UNION
            SELECT v_vm_id AS id
            UNION
            SELECT cluster_id AS id
            UNION
            SELECT v_entity_id AS id;

	WHEN v_entity_type = 20 THEN -- VmInterface

        select into v_vm_interface_id, v_storage_pool_id
               vm_interface.id, network.storage_pool_id
               from vm_interface inner join network on vm_interface.network_name=network.name;

        RETURN QUERY
            SELECT system_root_id AS id
            UNION
            SELECT v_vm_interface_id AS id
            UNION
            SELECT v_storage_pool_id AS id;
	ELSE
		IF v_entity_type IN ( 1,14,15,16 ) THEN -- Data Center, users and roles are under system
			RETURN QUERY
				SELECT system_root_id AS id
				UNION
				SELECT v_entity_id AS id;
		END IF;
	END CASE;
END;';


ALTER FUNCTION public.fn_get_entity_parents(v_entity_id uuid, v_object_type integer) OWNER TO engine;

--
-- Name: fn_get_storage_domain_shared_status_by_domain_id(uuid, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_get_storage_domain_shared_status_by_domain_id(v_storage_domain_id uuid, v_storage character varying, v_storage_type integer) RETURNS integer
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_result  INTEGER;
   v_rowsCount  INTEGER;
   v_status  INTEGER;
BEGIN
   BEGIN
      CREATE GLOBAL TEMPORARY TABLE tt_TEMP22
      (
         status INTEGER,
         count INTEGER
      ) WITH OIDS;
      exception when others then
         truncate table tt_TEMP22;
   END;
   delete from tt_TEMP22;
   Insert INTO tt_TEMP22
   select status, count(storage_id) from storage_pool_iso_map
   where storage_id = v_storage_domain_id
   group by status;

   select   count(*) INTO v_rowsCount from tt_TEMP22;

	-- if return 0 rows then the domain is unattached (0) or locked (4) if storage is null or empty for @storage_type iscsi (2) and fcp (3)
   if (v_rowsCount = 0) then
      if (v_storage_type in(2,3) and (v_storage is null or v_storage = '''')) then
         v_result := 4;
      else
         v_result := 0;
      end if;
   else
      if (v_rowsCount = 1) then
         select   status INTO v_status from tt_TEMP22    LIMIT 1;
			-- if 1 row and status active (3) then domain is active (1)
         if v_status = 3 then
            v_result := 1;
			-- if 1 row and status not active then domain is inactive (2)
         else
            v_result := 2;
         end if;
	-- else (if return more then 1 row)
      else
         select   count(*) INTO v_rowsCount from tt_TEMP22 where status = 3;
         if (v_rowsCount > 0) then
            v_result := 3;
			-- non of the statuses is active
         else
            v_result := 2;
         end if;
      end if;
   end if;
   return v_result;
END; ';


ALTER FUNCTION public.fn_get_storage_domain_shared_status_by_domain_id(v_storage_domain_id uuid, v_storage character varying, v_storage_type integer) OWNER TO engine;

SET default_tablespace = '';

SET default_with_oids = true;

--
-- Name: storage_pool; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE storage_pool (
    id uuid NOT NULL,
    name character varying(40) NOT NULL,
    description character varying(4000) NOT NULL,
    storage_pool_type integer NOT NULL,
    storage_pool_format_type character varying(50),
    status integer NOT NULL,
    master_domain_version integer NOT NULL,
    spm_vds_id uuid,
    compatibility_version character varying(40) DEFAULT '2.2'::character varying NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    quota_enforcement_type integer
);


ALTER TABLE public.storage_pool OWNER TO engine;

--
-- Name: fn_perms_get_storage_pools_with_permitted_action_on_vds_groups(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_perms_get_storage_pools_with_permitted_action_on_vds_groups(v_user_id uuid, v_action_group_id integer) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT * 
      FROM storage_pool
      WHERE storage_pool.id in 
	(SELECT storage_pool_id 
	 FROM vds_groups 
	 WHERE (SELECT get_entity_permissions(v_user_id, v_action_group_id, vds_groups.vds_group_id, 9)) IS NOT NULL);
END; ';


ALTER FUNCTION public.fn_perms_get_storage_pools_with_permitted_action_on_vds_groups(v_user_id uuid, v_action_group_id integer) OWNER TO engine;

--
-- Name: quota; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE quota (
    id uuid NOT NULL,
    storage_pool_id uuid NOT NULL,
    quota_name character varying(65) NOT NULL,
    description character varying(250),
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    threshold_vds_group_percentage integer DEFAULT 80,
    threshold_storage_percentage integer DEFAULT 80,
    grace_vds_group_percentage integer DEFAULT 20,
    grace_storage_percentage integer DEFAULT 20
);


ALTER TABLE public.quota OWNER TO engine;

--
-- Name: vds_groups; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vds_groups (
    vds_group_id uuid NOT NULL,
    name character varying(40) NOT NULL,
    description character varying(4000),
    cpu_name character varying(255),
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    selection_algorithm integer DEFAULT 0 NOT NULL,
    high_utilization integer DEFAULT 75 NOT NULL,
    low_utilization integer DEFAULT 0 NOT NULL,
    cpu_over_commit_duration_minutes integer DEFAULT 2 NOT NULL,
    hypervisor_type integer DEFAULT 0 NOT NULL,
    storage_pool_id uuid,
    max_vds_memory_over_commit integer DEFAULT 100 NOT NULL,
    compatibility_version character varying(40) DEFAULT '2.2'::character varying NOT NULL,
    transparent_hugepages boolean DEFAULT false NOT NULL,
    migrate_on_error integer DEFAULT 1 NOT NULL,
    virt_service boolean DEFAULT true NOT NULL,
    gluster_service boolean DEFAULT false NOT NULL
);


ALTER TABLE public.vds_groups OWNER TO engine;

--
-- Name: vm_static; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_static (
    vm_guid uuid NOT NULL,
    vm_name character varying(255) NOT NULL,
    mem_size_mb integer NOT NULL,
    vmt_guid uuid NOT NULL,
    os integer DEFAULT 0 NOT NULL,
    description character varying(4000),
    vds_group_id uuid NOT NULL,
    domain character varying(40),
    creation_date timestamp with time zone,
    num_of_monitors integer NOT NULL,
    is_initialized boolean,
    is_auto_suspend boolean DEFAULT false,
    num_of_sockets integer DEFAULT 1 NOT NULL,
    cpu_per_socket integer DEFAULT 1 NOT NULL,
    usb_policy integer,
    time_zone character varying(40),
    is_stateless boolean,
    fail_back boolean DEFAULT false NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    dedicated_vm_for_vds uuid,
    auto_startup boolean,
    vm_type integer DEFAULT 0 NOT NULL,
    hypervisor_type integer DEFAULT 0 NOT NULL,
    operation_mode integer DEFAULT 0 NOT NULL,
    nice_level integer DEFAULT 0 NOT NULL,
    default_boot_sequence integer DEFAULT 0 NOT NULL,
    default_display_type integer DEFAULT 0 NOT NULL,
    priority integer DEFAULT 0 NOT NULL,
    iso_path character varying(4000) DEFAULT ''::character varying,
    origin integer DEFAULT 0,
    initrd_url character varying(4000),
    kernel_url character varying(4000),
    kernel_params character varying(4000),
    migration_support integer DEFAULT 0 NOT NULL,
    userdefined_properties character varying(4000),
    predefined_properties character varying(4000),
    min_allocated_mem integer DEFAULT 0 NOT NULL,
    entity_type character varying(32) NOT NULL,
    child_count integer DEFAULT 0,
    template_status integer,
    quota_id uuid,
    allow_console_reconnect boolean DEFAULT false NOT NULL,
    cpu_pinning character varying(4000) DEFAULT NULL::character varying
);


ALTER TABLE public.vm_static OWNER TO engine;

--
-- Name: vm_templates_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_templates_view AS
    SELECT vm_templates.vm_guid AS vmt_guid, vm_templates.vm_name AS name, vm_templates.mem_size_mb, vm_templates.os, vm_templates.creation_date, vm_templates.child_count, vm_templates.num_of_sockets, vm_templates.cpu_per_socket, (vm_templates.num_of_sockets * vm_templates.cpu_per_socket) AS num_of_cpus, vm_templates.description, vm_templates.vds_group_id, vm_templates.domain, vm_templates.num_of_monitors, vm_templates.allow_console_reconnect, vm_templates.template_status AS status, vm_templates.usb_policy, vm_templates.time_zone, vm_templates.is_auto_suspend, vm_templates.fail_back, vds_groups.name AS vds_group_name, vm_templates.vm_type, vm_templates.hypervisor_type, vm_templates.operation_mode, vm_templates.nice_level, storage_pool.id AS storage_pool_id, storage_pool.name AS storage_pool_name, storage_pool.quota_enforcement_type, vm_templates.default_boot_sequence, vm_templates.default_display_type, vm_templates.priority, vm_templates.auto_startup, vm_templates.is_stateless, vm_templates.iso_path, vm_templates.origin, vm_templates.initrd_url, vm_templates.kernel_url, vm_templates.kernel_params, vm_templates.quota_id, quota.quota_name, vm_templates.migration_support, vm_templates.dedicated_vm_for_vds FROM (((vm_static vm_templates JOIN vds_groups ON ((vm_templates.vds_group_id = vds_groups.vds_group_id))) LEFT JOIN storage_pool ON ((storage_pool.id = vds_groups.storage_pool_id))) LEFT JOIN quota ON ((vm_templates.quota_id = quota.id))) WHERE ((vm_templates.entity_type)::text = 'TEMPLATE'::text);


ALTER TABLE public.vm_templates_view OWNER TO engine;

--
-- Name: fn_perms_get_templates_with_permitted_action(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_perms_get_templates_with_permitted_action(v_user_id uuid, v_action_group_id integer) RETURNS SETOF vm_templates_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_templates_view.*
      FROM vm_templates_view, user_vm_template_permissions_view
      WHERE vm_templates_view.vmt_guid = user_vm_template_permissions_view.entity_id AND
            user_vm_template_permissions_view.user_id = v_user_id AND
            (SELECT get_entity_permissions(v_user_id, v_action_group_id, vm_templates_view.vmt_guid, 4) IS NOT NULL);
END; ';


ALTER FUNCTION public.fn_perms_get_templates_with_permitted_action(v_user_id uuid, v_action_group_id integer) OWNER TO engine;

--
-- Name: fn_perms_get_vds_groups_with_permitted_action(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_perms_get_vds_groups_with_permitted_action(v_user_id uuid, v_action_group_id integer) RETURNS SETOF vds_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT * 
      FROM vds_groups 
      WHERE (SELECT get_entity_permissions(v_user_id, v_action_group_id, vds_groups.vds_group_id, 9)) IS NOT NULL;
END; ';


ALTER FUNCTION public.fn_perms_get_vds_groups_with_permitted_action(v_user_id uuid, v_action_group_id integer) OWNER TO engine;

--
-- Name: fn_user_permissions(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fn_user_permissions(v_userid uuid) RETURNS SETOF user_permissions
    LANGUAGE plpgsql
    AS '
DECLARE

BEGIN
	RETURN QUERY
	    SELECT
		    permissions.id AS permission_id,
		    permissions.role_id,
		    permissions.ad_element_id AS user_id
	    FROM permissions
		INNER JOIN users ON permissions.ad_element_id = users.user_id
	    WHERE users.user_id = v_userId

	    UNION

	    SELECT
		    permissions.id AS permission_id,
		    permissions.role_id,
		    temp.user_id AS user_id
	    FROM permissions INNER JOIN
	    (
		    -- get all groups of admin users
		    SELECT ad_groups.id group_id, users.user_id
		    FROM ad_groups, users
		    WHERE ad_groups.id IN
		    (SELECT * FROM fnsplitteruuid(users.group_ids))
			AND users.user_id = v_userId ) temp
		ON permissions.ad_element_id = temp.group_id;

END; ';


ALTER FUNCTION public.fn_user_permissions(v_userid uuid) OWNER TO engine;

--
-- Name: fnsplitter(text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fnsplitter(ids text) RETURNS SETOF idtexttype
    LANGUAGE plpgsql
    AS '
BEGIN
	RETURN QUERY
		SELECT regexp_split_to_table(ids, '','') AS id;
END; ';


ALTER FUNCTION public.fnsplitter(ids text) OWNER TO engine;

--
-- Name: fnsplitteruuid(text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION fnsplitteruuid(ids text) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
DECLARE
    tempc REFCURSOR;
    currow TEXT;
    result idUuidType;
BEGIN
  IF ids != '''' THEN
    OPEN tempc FOR SELECT regexp_split_to_table(ids, '','');
    FETCH tempc INTO currow;
    WHILE FOUND LOOP
        result := CAST (ROW(currow) AS idUuidType);
        RETURN NEXT result;
        FETCH tempc INTO currow;
   END LOOP;
   CLOSE tempc;
  END IF;
END; ';


ALTER FUNCTION public.fnsplitteruuid(ids text) OWNER TO engine;

--
-- Name: force_delete_storage_domain(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION force_delete_storage_domain(v_storage_domain_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   BEGIN
      -- Images residing on only the specified storage domain
      CREATE GLOBAL TEMPORARY TABLE tt_TEMPSTORAGEDOMAINMAPTABLE AS select image_id
         from image_storage_domain_map where storage_domain_id = v_storage_domain_id
         except select image_id from image_storage_domain_map where storage_domain_id != v_storage_domain_id;
      exception when others then
         truncate table tt_TEMPSTORAGEDOMAINMAPTABLE;
         insert into tt_TEMPSTORAGEDOMAINMAPTABLE select image_id
         from image_storage_domain_map where storage_domain_id = v_storage_domain_id
         except select image_id from image_storage_domain_map where storage_domain_id != v_storage_domain_id;
   END;

   BEGIN
      -- Templates with any images residing on only the specified storage domain
      CREATE GLOBAL TEMPORARY TABLE TEMPLATES_IDS_TEMPORARY_TABLE AS select vm_device.vm_id as vm_guid
         from images_storage_domain_view
         JOIN vm_device ON vm_device.device_id = images_storage_domain_view.disk_id
         JOIN tt_TEMPSTORAGEDOMAINMAPTABLE ON tt_TEMPSTORAGEDOMAINMAPTABLE.image_id = images_storage_domain_view.image_guid
         where entity_type = ''TEMPLATE'' and storage_id = v_storage_domain_id;
      exception when others then
         truncate table TEMPLATES_IDS_TEMPORARY_TABLE;
         insert into TEMPLATES_IDS_TEMPORARY_TABLE select vm_device.vm_id as vm_guid
         from images_storage_domain_view
         JOIN vm_device ON vm_device.device_id = images_storage_domain_view.disk_id
         JOIN tt_TEMPSTORAGEDOMAINMAPTABLE ON tt_TEMPSTORAGEDOMAINMAPTABLE.image_id = images_storage_domain_view.image_guid
         where entity_type = ''TEMPLATE'' and storage_id = v_storage_domain_id;
   END;

   delete FROM image_storage_domain_map where storage_domain_id = v_storage_domain_id;

   delete FROM permissions where object_id in (select vm_id as vm_guid from vm_images_view
                                                              JOIN vm_device ON vm_device.device_id = vm_images_view.disk_id
                                                              where v_storage_domain_id in (SELECT id FROM fnsplitteruuid(storage_id)) and vm_images_view.entity_type <> ''TEMPLATE'');
   delete FROM snapshots WHERE vm_id in (select vm_id as vm_guid from vm_images_view
                                         JOIN vm_device ON vm_device.device_id = vm_images_view.disk_id
                                         where v_storage_domain_id in (SELECT id FROM fnsplitteruuid(storage_id)));
   delete FROM images where image_guid in (select image_id from tt_TEMPSTORAGEDOMAINMAPTABLE);
   delete FROM vm_interface where vmt_guid in(select vm_guid from TEMPLATES_IDS_TEMPORARY_TABLE);
   delete FROM permissions where object_id in (select vm_guid from TEMPLATES_IDS_TEMPORARY_TABLE);
   delete FROM permissions where object_id = v_storage_domain_id;
   delete FROM vm_static where vm_guid in(select vm_id as vm_guid from vm_images_view
                                          JOIN vm_device ON vm_device.device_id = vm_images_view.disk_id
                                          where v_storage_domain_id in (SELECT id FROM fnsplitteruuid(storage_id)) and vm_images_view.entity_type <> ''TEMPLATE'');

   -- Delete pools and snapshots of pools based on templates from the storage domain to be removed
   delete FROM snapshots where vm_id in (select vm_guid FROM vm_static where vmt_guid in (select vm_guid from TEMPLATES_IDS_TEMPORARY_TABLE));
   delete FROM vm_static where vmt_guid in (select vm_guid from TEMPLATES_IDS_TEMPORARY_TABLE);

   delete FROM vm_static where vm_guid in(select vm_guid from TEMPLATES_IDS_TEMPORARY_TABLE);
   delete FROM storage_domain_dynamic where id  = v_storage_domain_id;
   delete FROM storage_domain_static where id  = v_storage_domain_id;

END; ';


ALTER FUNCTION public.force_delete_storage_domain(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: generate_drop_all_functions_syntax(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION generate_drop_all_functions_syntax() RETURNS SETOF text
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY select ''drop function if exists '' || ns.nspname || ''.'' || proname || ''('' || oidvectortypes(proargtypes) || '') cascade;'' from pg_proc inner join pg_namespace ns on (pg_proc.pronamespace=ns.oid) where ns.nspname = ''public'' and proname not ilike ''uuid%'' order by proname;
END; ';


ALTER FUNCTION public.generate_drop_all_functions_syntax() OWNER TO engine;

--
-- Name: generate_drop_all_views_syntax(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION generate_drop_all_views_syntax() RETURNS SETOF text
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY select ''DROP VIEW if exists '' || table_name || '' CASCADE;'' from information_schema.views where table_schema = ''public'' order by table_name;
END; ';


ALTER FUNCTION public.generate_drop_all_views_syntax() OWNER TO engine;

--
-- Name: get_all_child_roles_of_role(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_all_child_roles_of_role(v_roleid uuid) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
   DECLARE
   SWV_Rs idUuidType;
BEGIN
   BEGIN
      CREATE GLOBAL TEMPORARY TABLE tt_TEMP
      (
         id UUID
      ) WITH OIDS;
      exception when others then
         truncate table tt_TEMP;
   END;
   insert into tt_TEMP(id) values(v_roleId);

   insert into tt_TEMP   with recursive c(role_id,role_container_id)
   as(select role_id AS role_id, role_container_id AS role_container_id from roles_relations
   where role_container_id = v_roleId
   union all
   select t.role_id AS role_id, t.role_container_id AS role_container_id
   from c join roles_relations t on c.role_id = t.role_container_id) select distinct role_id from c;

   FOR SWV_Rs IN(SELECT * FROM  tt_TEMP) LOOP
      RETURN NEXT SWV_Rs;
   END LOOP;
   RETURN;
END; ';


ALTER FUNCTION public.get_all_child_roles_of_role(v_roleid uuid) OWNER TO engine;

--
-- Name: get_all_commands(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_all_commands() RETURNS SETOF get_all_commands_rs
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT distinct business_entity_snapshot.command_id, business_entity_snapshot.command_type
      FROM business_entity_snapshot;

END; ';


ALTER FUNCTION public.get_all_commands() OWNER TO engine;

--
-- Name: get_entity_permissions(uuid, integer, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_entity_permissions(v_user_id uuid, v_action_group_id integer, v_object_id uuid, v_object_type_id integer, OUT v_permission_id uuid) RETURNS uuid
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_everyone_object_id  UUID;
BEGIN
   v_everyone_object_id := getGlobalIds(''everyone''); -- hardcoded also in MLA Handler
   select   id INTO v_permission_id from permissions where
		-- get all roles of action
   role_id in(select role_id from roles_groups where action_group_id = v_action_group_id)
		-- get allparents of object
   and (object_id in(select id from  fn_get_entity_parents(v_object_id,v_object_type_id)))
		-- get user and his groups
   and (ad_element_id = v_everyone_object_id or
   ad_element_id = v_user_id or ad_element_id in(select id from getUserAndGroupsById(v_user_id)))   LIMIT 1;
END; ';


ALTER FUNCTION public.get_entity_permissions(v_user_id uuid, v_action_group_id integer, v_object_id uuid, v_object_type_id integer, OUT v_permission_id uuid) OWNER TO engine;

--
-- Name: get_entity_permissions_for_user_and_groups(uuid, text, integer, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_entity_permissions_for_user_and_groups(v_user_id uuid, v_group_ids text, v_action_group_id integer, v_object_id uuid, v_object_type_id integer, OUT v_permission_id uuid) RETURNS uuid
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_everyone_object_id  UUID;
BEGIN
   v_everyone_object_id := getGlobalIds(''everyone''); -- hardcoded also in MLA Handler
   select   id INTO v_permission_id from permissions where
		-- get all roles of action
   role_id in(select role_id from roles_groups where action_group_id = v_action_group_id)
		-- get allparents of object
   and (object_id in(select id from  fn_get_entity_parents(v_object_id,v_object_type_id)))
		-- get user and his groups
   and (ad_element_id = v_everyone_object_id or
   ad_element_id = v_user_id or ad_element_id in(select ID from fnsplitteruuid(v_group_ids)))   LIMIT 1;
END; ';


ALTER FUNCTION public.get_entity_permissions_for_user_and_groups(v_user_id uuid, v_group_ids text, v_action_group_id integer, v_object_id uuid, v_object_type_id integer, OUT v_permission_id uuid) OWNER TO engine;

--
-- Name: business_entity_snapshot; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE business_entity_snapshot (
    id uuid NOT NULL,
    command_id uuid NOT NULL,
    command_type character varying(256) NOT NULL,
    entity_id character varying(128),
    entity_type character varying(128),
    entity_snapshot text,
    snapshot_class character varying(128),
    snapshot_type integer,
    insertion_order integer,
    started_at timestamp with time zone DEFAULT now()
);


ALTER TABLE public.business_entity_snapshot OWNER TO engine;

--
-- Name: get_entity_snapshot_by_command_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_entity_snapshot_by_command_id(v_command_id uuid) RETURNS SETOF business_entity_snapshot
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT business_entity_snapshot.*
      FROM business_entity_snapshot
      WHERE command_id = v_command_id order by insertion_order desc;
END; ';


ALTER FUNCTION public.get_entity_snapshot_by_command_id(v_command_id uuid) OWNER TO engine;

--
-- Name: get_entity_snapshot_by_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_entity_snapshot_by_id(v_id uuid) RETURNS SETOF business_entity_snapshot
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT business_entity_snapshot.*
      FROM business_entity_snapshot
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.get_entity_snapshot_by_id(v_id uuid) OWNER TO engine;

--
-- Name: roles_groups; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE roles_groups (
    role_id uuid NOT NULL,
    action_group_id integer NOT NULL
);


ALTER TABLE public.roles_groups OWNER TO engine;

--
-- Name: get_role_groups_by_role_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_role_groups_by_role_id(v_role_id uuid) RETURNS SETOF roles_groups
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles_groups
   where
   role_id = v_role_id;

END; ';


ALTER FUNCTION public.get_role_groups_by_role_id(v_role_id uuid) OWNER TO engine;

--
-- Name: get_roles_groups_by_action_group_id_and_by_role_id(integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_roles_groups_by_action_group_id_and_by_role_id(v_action_group_id integer, v_role_id uuid) RETURNS SETOF roles_groups
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles_groups
   where
   action_group_id = v_action_group_id AND
   role_id = v_role_id;

END; ';


ALTER FUNCTION public.get_roles_groups_by_action_group_id_and_by_role_id(v_action_group_id integer, v_role_id uuid) OWNER TO engine;

--
-- Name: get_seconds_to_wait_before_pm_operation(character varying, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION get_seconds_to_wait_before_pm_operation(v_vds_name character varying, v_event character varying, v_wait_for_sec integer) RETURNS integer
    LANGUAGE plpgsql
    AS '
declare v_last_event_dt timestamp with time zone;
declare v_now_dt timestamp with time zone;
BEGIN
      if exists(select 1 from audit_log where vds_name = v_vds_name and log_type_name = v_event) then
       begin
          v_last_event_dt := log_time
          from audit_log
          where vds_name = v_vds_name and log_type_name = v_event
          order by audit_log_id desc limit 1;
          v_now_dt :=  CURRENT_TIMESTAMP;
          RETURN cast((extract(epoch from v_last_event_dt) + v_wait_for_sec) - extract(epoch from v_now_dt) as int);
       end;
     else
          RETURN 0;
     end if;
END; ';


ALTER FUNCTION public.get_seconds_to_wait_before_pm_operation(v_vds_name character varying, v_event character varying, v_wait_for_sec integer) OWNER TO engine;

--
-- Name: gluster_volume_access_protocols; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE gluster_volume_access_protocols (
    volume_id uuid NOT NULL,
    access_protocol character varying(32) NOT NULL
);


ALTER TABLE public.gluster_volume_access_protocols OWNER TO engine;

--
-- Name: getaccessprotocolsbyglustervolumeguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getaccessprotocolsbyglustervolumeguid(v_volume_id uuid) RETURNS SETOF gluster_volume_access_protocols
    LANGUAGE plpgsql
    AS '
BEGIN
       RETURN QUERY SELECT *
       FROM  gluster_volume_access_protocols
       WHERE volume_id = v_volume_id;
END; ';


ALTER FUNCTION public.getaccessprotocolsbyglustervolumeguid(v_volume_id uuid) OWNER TO engine;

--
-- Name: action_version_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE action_version_map (
    action_type integer NOT NULL,
    cluster_minimal_version character varying(40) NOT NULL,
    storage_pool_minimal_version character varying(40) NOT NULL
);


ALTER TABLE public.action_version_map OWNER TO engine;

--
-- Name: getaction_version_mapbyaction_type(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getaction_version_mapbyaction_type(v_action_type integer) RETURNS SETOF action_version_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM action_version_map
   WHERE action_type = v_action_type;

END; ';


ALTER FUNCTION public.getaction_version_mapbyaction_type(v_action_type integer) OWNER TO engine;

--
-- Name: vds_static; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vds_static (
    vds_id uuid NOT NULL,
    vds_name character varying(255) NOT NULL,
    ip character varying(255),
    vds_unique_id character varying(128),
    host_name character varying(255) NOT NULL,
    port integer NOT NULL,
    vds_group_id uuid NOT NULL,
    server_ssl_enabled boolean,
    vds_type integer DEFAULT 0 NOT NULL,
    vds_strength integer DEFAULT 100 NOT NULL,
    pm_type character varying(20),
    pm_user character varying(50),
    pm_password text,
    pm_port integer,
    pm_options character varying(4000) DEFAULT ''::character varying NOT NULL,
    pm_enabled boolean DEFAULT false NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    otp_validity bigint,
    vds_spm_priority smallint DEFAULT 5,
    recoverable boolean DEFAULT true NOT NULL,
    CONSTRAINT vds_static_vds_spm_priority_check CHECK (((vds_spm_priority >= (-1)) AND (vds_spm_priority <= 10)))
);


ALTER TABLE public.vds_static OWNER TO engine;

--
-- Name: vm_dynamic; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_dynamic (
    vm_guid uuid NOT NULL,
    status integer NOT NULL,
    vm_ip text,
    vm_host character varying(255),
    vm_pid integer,
    last_start_time timestamp with time zone,
    guest_cur_user_name character varying(255),
    guest_cur_user_id uuid,
    guest_last_login_time timestamp with time zone,
    guest_last_logout_time timestamp with time zone,
    guest_os character varying(255),
    run_on_vds uuid,
    migrating_to_vds uuid,
    app_list text,
    display integer,
    acpi_enable boolean,
    session integer,
    display_ip character varying(255),
    display_type integer,
    kvm_enable boolean,
    display_secure_port integer,
    utc_diff integer,
    last_vds_run_on uuid,
    client_ip character varying(255),
    guest_requested_memory integer,
    hibernation_vol_handle character varying(255),
    boot_sequence integer,
    exit_status integer DEFAULT 0 NOT NULL,
    pause_status integer DEFAULT 0 NOT NULL,
    exit_message character varying(4000),
    hash character varying(30),
    console_user_id uuid
);


ALTER TABLE public.vm_dynamic OWNER TO engine;

--
-- Name: vm_pool_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_pool_map (
    vm_pool_id uuid,
    vm_guid uuid NOT NULL
);


ALTER TABLE public.vm_pool_map OWNER TO engine;

--
-- Name: vm_pools; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_pools (
    vm_pool_id uuid NOT NULL,
    vm_pool_name character varying(255) NOT NULL,
    vm_pool_description character varying(4000) NOT NULL,
    vm_pool_type integer,
    parameters character varying(200),
    vds_group_id uuid,
    prestarted_vms smallint DEFAULT 0
);


ALTER TABLE public.vm_pools OWNER TO engine;

--
-- Name: vm_pool_map_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_pool_map_view AS
    SELECT vm_pool_map.vm_guid, vm_pool_map.vm_pool_id, vm_pools.vm_pool_name FROM (vm_pool_map JOIN vm_pools ON ((vm_pool_map.vm_pool_id = vm_pools.vm_pool_id)));


ALTER TABLE public.vm_pool_map_view OWNER TO engine;

--
-- Name: vm_statistics; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_statistics (
    vm_guid uuid NOT NULL,
    cpu_user numeric(18,0) DEFAULT 0,
    cpu_sys numeric(18,0) DEFAULT 0,
    elapsed_time numeric(18,0) DEFAULT 0,
    usage_network_percent integer DEFAULT 0,
    usage_mem_percent integer DEFAULT 0,
    usage_cpu_percent integer DEFAULT 0,
    disks_usage text
);


ALTER TABLE public.vm_statistics OWNER TO engine;

--
-- Name: vms; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vms AS
    SELECT vm_static.vm_name, vm_static.mem_size_mb AS vm_mem_size_mb, vm_static.nice_level, vm_static.vmt_guid, vm_static.os AS vm_os, vm_static.description AS vm_description, vm_static.vds_group_id, vm_static.domain AS vm_domain, vm_static.creation_date AS vm_creation_date, vm_static.auto_startup, vm_static.is_stateless, vm_static.dedicated_vm_for_vds, vm_static.fail_back, vm_static.default_boot_sequence, vm_static.vm_type, vm_static.hypervisor_type, vm_static.operation_mode, vds_groups.name AS vds_group_name, vds_groups.selection_algorithm, vds_groups.transparent_hugepages, storage_pool.id AS storage_pool_id, storage_pool.name AS storage_pool_name, vds_groups.description AS vds_group_description, vm_templates.vm_name AS vmt_name, vm_templates.mem_size_mb AS vmt_mem_size_mb, vm_templates.os AS vmt_os, vm_templates.creation_date AS vmt_creation_date, vm_templates.child_count AS vmt_child_count, vm_templates.num_of_sockets AS vmt_num_of_sockets, vm_templates.cpu_per_socket AS vmt_cpu_per_socket, (vm_templates.num_of_sockets * vm_templates.cpu_per_socket) AS vmt_num_of_cpus, vm_templates.description AS vmt_description, vm_dynamic.status, vm_dynamic.vm_ip, vm_dynamic.vm_host, vm_dynamic.vm_pid, vm_dynamic.last_start_time, vm_dynamic.guest_cur_user_name, vm_dynamic.guest_last_login_time, vm_dynamic.guest_cur_user_id, vm_dynamic.guest_last_logout_time, vm_dynamic.guest_os, vm_dynamic.console_user_id, vm_dynamic.run_on_vds, vm_dynamic.migrating_to_vds, vm_dynamic.app_list, vm_dynamic.display, vm_dynamic.hibernation_vol_handle, vm_pool_map_view.vm_pool_name, vm_pool_map_view.vm_pool_id, vm_static.vm_guid, vm_static.num_of_monitors, vm_static.allow_console_reconnect, vm_static.is_initialized, vm_static.is_auto_suspend, vm_static.num_of_sockets, vm_static.cpu_per_socket, vm_static.usb_policy, vm_dynamic.acpi_enable, vm_dynamic.session, (vm_static.num_of_sockets * vm_static.cpu_per_socket) AS num_of_cpus, vm_static.quota_id, quota.quota_name, storage_pool.quota_enforcement_type, vm_dynamic.display_ip, vm_dynamic.display_type, vm_dynamic.kvm_enable, vm_dynamic.boot_sequence, vm_dynamic.display_secure_port, vm_dynamic.utc_diff, vm_dynamic.last_vds_run_on, vm_dynamic.client_ip, vm_dynamic.guest_requested_memory, vm_static.time_zone, vm_statistics.cpu_user, vm_statistics.cpu_sys, vm_statistics.elapsed_time, vm_statistics.usage_network_percent, vm_statistics.usage_mem_percent, vm_statistics.usage_cpu_percent, vds_static.vds_name AS run_on_vds_name, vds_groups.cpu_name AS vds_group_cpu_name, vm_static.default_display_type, vm_static.priority, vm_static.iso_path, vm_static.origin, vds_groups.compatibility_version AS vds_group_compatibility_version, vm_static.initrd_url, vm_static.kernel_url, vm_static.kernel_params, vm_dynamic.pause_status, vm_dynamic.exit_message, vm_dynamic.exit_status, vm_static.migration_support, vm_static.predefined_properties, vm_static.userdefined_properties, vm_static.min_allocated_mem, vm_dynamic.hash, vm_static.cpu_pinning FROM ((((((((vm_static JOIN vm_dynamic ON ((vm_static.vm_guid = vm_dynamic.vm_guid))) JOIN vm_static vm_templates ON ((vm_static.vmt_guid = vm_templates.vm_guid))) JOIN vm_statistics ON ((vm_static.vm_guid = vm_statistics.vm_guid))) JOIN vds_groups ON ((vm_static.vds_group_id = vds_groups.vds_group_id))) LEFT JOIN storage_pool ON (((vm_static.vds_group_id = vds_groups.vds_group_id) AND (vds_groups.storage_pool_id = storage_pool.id)))) LEFT JOIN quota ON ((vm_static.quota_id = quota.id))) LEFT JOIN vds_static ON ((vm_dynamic.run_on_vds = vds_static.vds_id))) LEFT JOIN vm_pool_map_view ON ((vm_static.vm_guid = vm_pool_map_view.vm_guid))) WHERE ((vm_static.entity_type)::text = 'VM'::text);


ALTER TABLE public.vms OWNER TO engine;

--
-- Name: getactivevmsbystoragedomainid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getactivevmsbystoragedomainid(v_storage_domain_id uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT vms.*
      FROM vms
      INNER JOIN vm_device vd ON vd.vm_id = vms.vm_guid
      INNER JOIN images i ON i.image_group_id = vd.device_id AND i.active = TRUE
      inner join image_storage_domain_map on i.image_guid = image_storage_domain_map.image_id
      WHERE status <> 0 and image_storage_domain_map.storage_domain_id = v_storage_domain_id;
END; ';


ALTER FUNCTION public.getactivevmsbystoragedomainid(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: ad_groups; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE ad_groups (
    id uuid NOT NULL,
    name character varying(256) NOT NULL,
    status integer NOT NULL,
    domain character varying(100),
    distinguishedname character varying(4000) DEFAULT NULL::character varying
);


ALTER TABLE public.ad_groups OWNER TO engine;

--
-- Name: getad_groupsbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getad_groupsbyid(v_id uuid) RETURNS SETOF ad_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM ad_groups
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.getad_groupsbyid(v_id uuid) OWNER TO engine;

--
-- Name: getad_groupsbyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getad_groupsbyname(v_name character varying) RETURNS SETOF ad_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM ad_groups
      WHERE name = v_name;
END; ';


ALTER FUNCTION public.getad_groupsbyname(v_name character varying) OWNER TO engine;

--
-- Name: base_disks; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE base_disks (
    disk_id uuid NOT NULL,
    disk_interface character varying(32) NOT NULL,
    wipe_after_delete boolean DEFAULT false NOT NULL,
    propagate_errors character varying(32) DEFAULT 'Off'::character varying NOT NULL,
    disk_alias character varying(255),
    disk_description character varying(500),
    shareable boolean DEFAULT false,
    boot boolean DEFAULT false NOT NULL
);


ALTER TABLE public.base_disks OWNER TO engine;

--
-- Name: disk_image_dynamic; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE disk_image_dynamic (
    image_id uuid NOT NULL,
    read_rate integer,
    write_rate integer,
    actual_size bigint NOT NULL,
    read_latency_seconds numeric(18,9),
    write_latency_seconds numeric(18,9),
    flush_latency_seconds numeric(18,9)
);


ALTER TABLE public.disk_image_dynamic OWNER TO engine;

SET default_with_oids = false;

--
-- Name: disk_lun_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE disk_lun_map (
    disk_id uuid NOT NULL,
    lun_id character varying NOT NULL
);


ALTER TABLE public.disk_lun_map OWNER TO engine;

SET default_with_oids = true;

--
-- Name: image_storage_domain_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE image_storage_domain_map (
    image_id uuid NOT NULL,
    storage_domain_id uuid NOT NULL
);


ALTER TABLE public.image_storage_domain_map OWNER TO engine;

--
-- Name: images; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE images (
    image_guid uuid NOT NULL,
    creation_date timestamp with time zone NOT NULL,
    size bigint NOT NULL,
    it_guid uuid NOT NULL,
    parentid uuid,
    imagestatus integer DEFAULT 0,
    lastmodified timestamp with time zone,
    vm_snapshot_id uuid,
    volume_type integer DEFAULT 2 NOT NULL,
    volume_format integer DEFAULT 4 NOT NULL,
    image_group_id uuid,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    quota_id uuid,
    active boolean DEFAULT false NOT NULL
);


ALTER TABLE public.images OWNER TO engine;

--
-- Name: snapshots; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE snapshots (
    snapshot_id uuid NOT NULL,
    vm_id uuid NOT NULL,
    snapshot_type character varying(32) NOT NULL,
    status character varying(32) NOT NULL,
    description character varying(4000),
    creation_date timestamp with time zone NOT NULL,
    app_list text,
    vm_configuration text,
    _create_date timestamp with time zone DEFAULT now(),
    _update_date timestamp with time zone
);


ALTER TABLE public.snapshots OWNER TO engine;

--
-- Name: storage_domain_static; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE storage_domain_static (
    id uuid NOT NULL,
    storage character varying(250) NOT NULL,
    storage_name character varying(250) NOT NULL,
    storage_domain_type integer NOT NULL,
    storage_type integer NOT NULL,
    storage_domain_format_type character varying(50) DEFAULT 0 NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    recoverable boolean DEFAULT true NOT NULL,
    last_time_used_as_master bigint
);


ALTER TABLE public.storage_domain_static OWNER TO engine;

--
-- Name: storage_pool_iso_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE storage_pool_iso_map (
    storage_id uuid NOT NULL,
    storage_pool_id uuid NOT NULL,
    status integer,
    owner integer
);


ALTER TABLE public.storage_pool_iso_map OWNER TO engine;

--
-- Name: storage_domain_static_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW storage_domain_static_view AS
    SELECT storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_name, storage_pool_iso_map.storage_pool_id, storage_pool_iso_map.status, storage_domain_static.storage_domain_type, storage_domain_static.storage_type, storage_domain_static.storage_domain_format_type, storage_domain_static.last_time_used_as_master, storage_pool.name AS storage_pool_name FROM ((storage_domain_static LEFT JOIN storage_pool_iso_map ON ((storage_pool_iso_map.storage_id = storage_domain_static.id))) LEFT JOIN storage_pool ON ((storage_pool.id = storage_pool_iso_map.storage_pool_id)));


ALTER TABLE public.storage_domain_static_view OWNER TO engine;

--
-- Name: vm_device; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_device (
    device_id uuid NOT NULL,
    vm_id uuid NOT NULL,
    type character varying(30) NOT NULL,
    device character varying(30) NOT NULL,
    address character varying(255) NOT NULL,
    boot_order integer DEFAULT 0,
    spec_params text,
    is_managed boolean DEFAULT false NOT NULL,
    is_plugged boolean,
    is_readonly boolean DEFAULT false NOT NULL,
    _create_date timestamp with time zone DEFAULT now(),
    _update_date timestamp with time zone,
    alias character varying(255) DEFAULT ''::character varying
);


ALTER TABLE public.vm_device OWNER TO engine;

--
-- Name: vms_for_disk_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vms_for_disk_view AS
    SELECT array_agg(vm_static.vm_name) AS array_vm_names, vm_device.device_id, vm_static.entity_type FROM (vm_static JOIN vm_device ON ((vm_static.vm_guid = vm_device.vm_id))) WHERE ((vm_device.device)::text = 'disk'::text) GROUP BY vm_device.device_id, vm_static.entity_type;


ALTER TABLE public.vms_for_disk_view OWNER TO engine;

--
-- Name: images_storage_domain_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW images_storage_domain_view AS
    SELECT images.image_guid, storage_domain_static_view.storage_name, storage_domain_static_view.storage AS storage_path, storage_domain_static_view.storage_pool_id, images.creation_date, images.size, images.it_guid, snapshots.description, images.parentid, images.lastmodified, snapshots.app_list, image_storage_domain_map.storage_domain_id AS storage_id, images.vm_snapshot_id, images.volume_type, images.volume_format, images.imagestatus, images.image_group_id, images.active, vms_for_disk_view.entity_type, array_to_string(vms_for_disk_view.array_vm_names, ','::text) AS vm_names, COALESCE(array_upper(vms_for_disk_view.array_vm_names, 1), 0) AS number_of_vms, base_disks.disk_id, base_disks.disk_alias, base_disks.disk_description, base_disks.shareable, base_disks.disk_interface, base_disks.wipe_after_delete, base_disks.propagate_errors, base_disks.boot, images.quota_id, quota.quota_name, storage_pool.quota_enforcement_type, disk_image_dynamic.actual_size, disk_image_dynamic.read_rate, disk_image_dynamic.write_rate, disk_image_dynamic.read_latency_seconds, disk_image_dynamic.write_latency_seconds, disk_image_dynamic.flush_latency_seconds FROM ((((((((images LEFT JOIN disk_image_dynamic ON ((images.image_guid = disk_image_dynamic.image_id))) LEFT JOIN base_disks ON ((images.image_group_id = base_disks.disk_id))) LEFT JOIN vms_for_disk_view ON ((vms_for_disk_view.device_id = images.image_group_id))) LEFT JOIN image_storage_domain_map ON ((image_storage_domain_map.image_id = images.image_guid))) LEFT JOIN storage_domain_static_view ON ((image_storage_domain_map.storage_domain_id = storage_domain_static_view.id))) LEFT JOIN snapshots ON ((images.vm_snapshot_id = snapshots.snapshot_id))) LEFT JOIN quota ON ((images.quota_id = quota.id))) LEFT JOIN storage_pool ON ((storage_pool.id = quota.storage_pool_id))) WHERE (images.image_guid <> '00000000-0000-0000-0000-000000000000'::uuid);


ALTER TABLE public.images_storage_domain_view OWNER TO engine;

--
-- Name: luns; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE luns (
    physical_volume_id character varying(50),
    lun_id character varying(50) NOT NULL,
    volume_group_id character varying(50),
    serial character varying(4000),
    lun_mapping integer,
    vendor_id character varying(50),
    product_id character varying(50),
    device_size integer DEFAULT 0
);


ALTER TABLE public.luns OWNER TO engine;

--
-- Name: all_disks; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW all_disks AS
    SELECT storage_impl.disk_storage_type, storage_impl.storage_id, storage_impl.storage_path, storage_impl.storage_name, storage_impl.storage_pool_id, storage_impl.image_guid, storage_impl.creation_date, storage_impl.actual_size, storage_impl.read_rate, storage_impl.write_rate, storage_impl.read_latency_seconds, storage_impl.write_latency_seconds, storage_impl.flush_latency_seconds, storage_impl.size, storage_impl.it_guid, storage_impl.imagestatus, storage_impl.lastmodified, storage_impl.volume_type, storage_impl.volume_format, storage_impl.image_group_id, storage_impl.description, storage_impl.parentid, storage_impl.app_list, storage_impl.vm_snapshot_id, storage_impl.active, storage_impl.entity_type, storage_impl.number_of_vms, storage_impl.vm_names, storage_impl.quota_id, storage_impl.quota_name, storage_impl.quota_enforcement_type, storage_impl.lun_id, storage_impl.physical_volume_id, storage_impl.volume_group_id, storage_impl.serial, storage_impl.lun_mapping, storage_impl.vendor_id, storage_impl.product_id, storage_impl.device_size, bd.disk_id, bd.disk_interface, bd.wipe_after_delete, bd.propagate_errors, bd.disk_alias, bd.disk_description, bd.shareable, bd.boot FROM ((SELECT 0 AS disk_storage_type, array_to_string(array_agg(images_storage_domain_view.storage_id), ','::text) AS storage_id, array_to_string(array_agg(images_storage_domain_view.storage_path), ','::text) AS storage_path, array_to_string(array_agg(images_storage_domain_view.storage_name), ','::text) AS storage_name, images_storage_domain_view.storage_pool_id, images_storage_domain_view.image_guid, images_storage_domain_view.creation_date, images_storage_domain_view.actual_size, images_storage_domain_view.read_rate, images_storage_domain_view.write_rate, images_storage_domain_view.read_latency_seconds, images_storage_domain_view.write_latency_seconds, images_storage_domain_view.flush_latency_seconds, images_storage_domain_view.size, images_storage_domain_view.it_guid, images_storage_domain_view.imagestatus, images_storage_domain_view.lastmodified, images_storage_domain_view.volume_type, images_storage_domain_view.volume_format, images_storage_domain_view.image_group_id, images_storage_domain_view.description, images_storage_domain_view.parentid, images_storage_domain_view.app_list, images_storage_domain_view.vm_snapshot_id, images_storage_domain_view.active, images_storage_domain_view.entity_type, images_storage_domain_view.number_of_vms, images_storage_domain_view.vm_names, images_storage_domain_view.quota_id, images_storage_domain_view.quota_name, images_storage_domain_view.quota_enforcement_type, NULL::unknown AS lun_id, NULL::unknown AS physical_volume_id, NULL::unknown AS volume_group_id, NULL::unknown AS serial, NULL::unknown AS lun_mapping, NULL::unknown AS vendor_id, NULL::unknown AS product_id, NULL::unknown AS device_size FROM images_storage_domain_view WHERE (images_storage_domain_view.active = true) GROUP BY images_storage_domain_view.storage_pool_id, images_storage_domain_view.image_guid, images_storage_domain_view.creation_date, images_storage_domain_view.actual_size, images_storage_domain_view.read_rate, images_storage_domain_view.write_rate, images_storage_domain_view.read_latency_seconds, images_storage_domain_view.write_latency_seconds, images_storage_domain_view.flush_latency_seconds, images_storage_domain_view.size, images_storage_domain_view.it_guid, images_storage_domain_view.imagestatus, images_storage_domain_view.lastmodified, images_storage_domain_view.volume_type, images_storage_domain_view.volume_format, images_storage_domain_view.image_group_id, images_storage_domain_view.boot, images_storage_domain_view.description, images_storage_domain_view.parentid, images_storage_domain_view.app_list, images_storage_domain_view.vm_snapshot_id, images_storage_domain_view.active, images_storage_domain_view.entity_type, images_storage_domain_view.number_of_vms, images_storage_domain_view.vm_names, images_storage_domain_view.quota_id, images_storage_domain_view.quota_name, images_storage_domain_view.quota_enforcement_type UNION SELECT 1 AS disk_storage_type, NULL::unknown AS storage_id, NULL::unknown AS storage_path, NULL::unknown AS storage_name, NULL::unknown AS storage_pool_id, NULL::unknown AS image_guid, NULL::unknown AS creation_date, NULL::unknown AS actual_size, NULL::unknown AS read_rate, NULL::unknown AS write_rate, NULL::unknown AS read_latency_seconds, NULL::unknown AS write_latency_seconds, NULL::unknown AS flush_latency_seconds, NULL::unknown AS size, NULL::unknown AS it_guid, NULL::unknown AS imagestatus, NULL::unknown AS lastmodified, NULL::unknown AS volume_type, NULL::unknown AS volume_format, dlm.disk_id AS image_group_id, NULL::unknown AS description, NULL::unknown AS parentid, NULL::unknown AS app_list, NULL::unknown AS vm_snapshot_id, NULL::unknown AS active, vms_for_disk_view.entity_type, COALESCE(array_upper(vms_for_disk_view.array_vm_names, 1), 0) AS number_of_vms, array_to_string(vms_for_disk_view.array_vm_names, ','::text) AS vm_names, NULL::unknown AS quota_id, NULL::unknown AS quota_name, NULL::unknown AS quota_enforcement_type, l.lun_id, l.physical_volume_id, l.volume_group_id, l.serial, l.lun_mapping, l.vendor_id, l.product_id, l.device_size FROM ((disk_lun_map dlm JOIN luns l ON (((l.lun_id)::text = (dlm.lun_id)::text))) LEFT JOIN vms_for_disk_view ON ((vms_for_disk_view.device_id = dlm.disk_id)))) storage_impl JOIN base_disks bd ON ((bd.disk_id = storage_impl.image_group_id)));


ALTER TABLE public.all_disks OWNER TO engine;

--
-- Name: getallattachabledisksbypoolid(uuid, uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallattachabledisksbypoolid(v_storage_pool_id uuid, v_vm_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF all_disks
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT distinct all_disks.*
    FROM all_disks
    WHERE (v_storage_pool_id IS NULL OR all_disks.storage_pool_id = v_storage_pool_id)
    AND (all_disks.number_of_vms = 0 OR all_disks.shareable)
        -- ImageStatus.ILLEGAL=4 / imagestatus IS NULL -> LunDiski / ImageStatus.Locked=2
        AND (all_disks.imagestatus IS NULL OR (all_disks.imagestatus != 4 AND all_disks.imagestatus != 2))
        AND (v_vm_id IS NULL OR v_vm_id NOT IN (SELECT vm_id FROM vm_device WHERE vm_device.device_id = all_disks.image_group_id))
    AND   (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_disk_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = disk_id));
END; ';


ALTER FUNCTION public.getallattachabledisksbypoolid(v_storage_pool_id uuid, v_vm_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallfromaction_version_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromaction_version_map() RETURNS SETOF action_version_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM action_version_map;

END; ';


ALTER FUNCTION public.getallfromaction_version_map() OWNER TO engine;

--
-- Name: getallfromad_groups(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromad_groups() RETURNS SETOF ad_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM ad_groups;
END; ';


ALTER FUNCTION public.getallfromad_groups() OWNER TO engine;

--
-- Name: async_tasks; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE async_tasks (
    task_id uuid NOT NULL,
    action_type integer NOT NULL,
    status integer NOT NULL,
    result integer NOT NULL,
    action_parameters text,
    action_params_class character varying(256),
    step_id uuid,
    command_id uuid NOT NULL,
    started_at timestamp with time zone,
    storage_pool_id uuid,
    task_type integer DEFAULT 0 NOT NULL
);


ALTER TABLE public.async_tasks OWNER TO engine;

--
-- Name: getallfromasync_tasks(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromasync_tasks() RETURNS SETOF async_tasks
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM async_tasks;

END; ';


ALTER FUNCTION public.getallfromasync_tasks() OWNER TO engine;

--
-- Name: audit_log_seq; Type: SEQUENCE; Schema: public; Owner: engine
--

CREATE SEQUENCE audit_log_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.audit_log_seq OWNER TO engine;

--
-- Name: audit_log_seq; Type: SEQUENCE SET; Schema: public; Owner: engine
--

SELECT pg_catalog.setval('audit_log_seq', 4154, true);


--
-- Name: audit_log; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE audit_log (
    audit_log_id bigint DEFAULT nextval('audit_log_seq'::regclass) NOT NULL,
    user_id uuid,
    user_name character varying(255),
    vm_id uuid,
    vm_name character varying(255),
    vm_template_id uuid,
    vm_template_name character varying(40),
    vds_id uuid,
    vds_name character varying(255),
    log_time timestamp with time zone NOT NULL,
    log_type_name character varying(100) DEFAULT ''::character varying,
    log_type integer NOT NULL,
    severity integer NOT NULL,
    message text NOT NULL,
    processed boolean DEFAULT false NOT NULL,
    storage_pool_id uuid,
    storage_pool_name character varying(40),
    storage_domain_id uuid,
    storage_domain_name character varying(250),
    vds_group_id uuid,
    vds_group_name character varying(255),
    correlation_id character varying(50),
    job_id uuid,
    quota_id uuid,
    quota_name character varying(60),
    gluster_volume_id uuid,
    gluster_volume_name character varying(1000)
);


ALTER TABLE public.audit_log OWNER TO engine;

--
-- Name: getallfromauditlog(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromauditlog() RETURNS SETOF audit_log
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM audit_log;
END; ';


ALTER FUNCTION public.getallfromauditlog() OWNER TO engine;

--
-- Name: getallfrombasedisks(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfrombasedisks() RETURNS SETOF base_disks
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   base_disks;
END; ';


ALTER FUNCTION public.getallfrombasedisks() OWNER TO engine;

--
-- Name: bookmarks; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE bookmarks (
    bookmark_id uuid NOT NULL,
    bookmark_name character varying(40),
    bookmark_value character varying(300) NOT NULL
);


ALTER TABLE public.bookmarks OWNER TO engine;

--
-- Name: getallfrombookmarks(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfrombookmarks() RETURNS SETOF bookmarks
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM bookmarks;
END; ';


ALTER FUNCTION public.getallfrombookmarks() OWNER TO engine;

--
-- Name: custom_actions_seq; Type: SEQUENCE; Schema: public; Owner: engine
--

CREATE SEQUENCE custom_actions_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.custom_actions_seq OWNER TO engine;

--
-- Name: custom_actions_seq; Type: SEQUENCE SET; Schema: public; Owner: engine
--

SELECT pg_catalog.setval('custom_actions_seq', 1, false);


--
-- Name: custom_actions; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE custom_actions (
    action_id integer DEFAULT nextval('custom_actions_seq'::regclass) NOT NULL,
    action_name character varying(50) NOT NULL,
    path character varying(300) NOT NULL,
    tab integer NOT NULL,
    description character varying(4000)
);


ALTER TABLE public.custom_actions OWNER TO engine;

--
-- Name: getallfromcustom_actions(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromcustom_actions() RETURNS SETOF custom_actions
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM custom_actions;
END; ';


ALTER FUNCTION public.getallfromcustom_actions() OWNER TO engine;

--
-- Name: getallfromdisk_image_dynamic(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromdisk_image_dynamic() RETURNS SETOF disk_image_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM disk_image_dynamic;

END; ';


ALTER FUNCTION public.getallfromdisk_image_dynamic() OWNER TO engine;

--
-- Name: getallfromdisklunmaps(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromdisklunmaps() RETURNS SETOF disk_lun_map
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   disk_lun_map;
END; ';


ALTER FUNCTION public.getallfromdisklunmaps() OWNER TO engine;

--
-- Name: getallfromdisks(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromdisks() RETURNS SETOF all_disks
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   all_disks;
END; ';


ALTER FUNCTION public.getallfromdisks() OWNER TO engine;

--
-- Name: event_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE event_map (
    event_up_name character varying(100) NOT NULL,
    event_down_name character varying(100) NOT NULL
);


ALTER TABLE public.event_map OWNER TO engine;

--
-- Name: event_subscriber; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE event_subscriber (
    subscriber_id uuid NOT NULL,
    event_up_name character varying(100) NOT NULL,
    method_id integer NOT NULL,
    method_address character varying(255),
    tag_name character varying(50) DEFAULT ''::character varying NOT NULL
);


ALTER TABLE public.event_subscriber OWNER TO engine;

--
-- Name: event_audit_log_subscriber_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW event_audit_log_subscriber_view AS
    SELECT 1 AS event_type, event_subscriber_1.subscriber_id, event_subscriber_1.event_up_name, event_subscriber_1.method_id, event_subscriber_1.method_address, event_subscriber_1.tag_name, audit_log_1.audit_log_id, audit_log_1.user_id, audit_log_1.user_name, audit_log_1.vm_id, audit_log_1.vm_name, audit_log_1.vm_template_id, audit_log_1.vm_template_name, audit_log_1.vds_id, audit_log_1.vds_name, audit_log_1.storage_pool_id, audit_log_1.storage_pool_name, audit_log_1.storage_domain_id, audit_log_1.storage_domain_name, audit_log_1.log_time, audit_log_1.severity, audit_log_1.message FROM (audit_log audit_log_1 JOIN event_subscriber event_subscriber_1 ON (((audit_log_1.log_type_name)::text = (event_subscriber_1.event_up_name)::text))) WHERE (audit_log_1.processed = false) UNION SELECT DISTINCT 0 AS event_type, event_subscriber.subscriber_id, audit_log.log_type_name AS event_up_name, event_subscriber.method_id, event_subscriber.method_address, event_subscriber.tag_name, audit_log.audit_log_id, audit_log.user_id, audit_log.user_name, audit_log.vm_id, audit_log.vm_name, audit_log.vm_template_id, audit_log.vm_template_name, audit_log.vds_id, audit_log.vds_name, audit_log.storage_pool_id, audit_log.storage_pool_name, audit_log.storage_domain_id, audit_log.storage_domain_name, audit_log.log_time, audit_log.severity, audit_log.message FROM ((audit_log audit_log JOIN event_map ON (((audit_log.log_type_name)::text = (event_map.event_down_name)::text))) JOIN event_subscriber event_subscriber ON (((event_subscriber.event_up_name)::text = (event_map.event_up_name)::text))) WHERE (audit_log.processed = false);


ALTER TABLE public.event_audit_log_subscriber_view OWNER TO engine;

--
-- Name: getallfromevent_audit_log_subscriber(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromevent_audit_log_subscriber() RETURNS SETOF event_audit_log_subscriber_view
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_last  BIGINT;
BEGIN
      -- begin tran

			
			-- get last event
			select   audit_log_id INTO v_last from audit_log    order by audit_log_id desc LIMIT 1;
			-- mark processed events
      update audit_log set processed = TRUE where audit_log_id <= v_last;
			-- get from view all events with id <= @last
      RETURN QUERY SELECT *
      from event_audit_log_subscriber_view  event_audit_log_subscriber_view
      where audit_log_id <= v_last;
END; ';


ALTER FUNCTION public.getallfromevent_audit_log_subscriber() OWNER TO engine;

--
-- Name: getallfromevent_audit_log_subscriber_only(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromevent_audit_log_subscriber_only() RETURNS SETOF event_audit_log_subscriber_view
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_last  BIGINT;
BEGIN
        -- get last event
        select   audit_log_id INTO v_last from audit_log order by audit_log_id desc LIMIT 1;
        -- get from view all events with id <= @last
        RETURN QUERY select *
                   from event_audit_log_subscriber_view  where audit_log_id <= v_last;
END; ';


ALTER FUNCTION public.getallfromevent_audit_log_subscriber_only() OWNER TO engine;

--
-- Name: getallfromevent_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromevent_map() RETURNS SETOF event_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM event_map;

END; ';


ALTER FUNCTION public.getallfromevent_map() OWNER TO engine;

--
-- Name: event_notification_hist; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE event_notification_hist (
    subscriber_id uuid NOT NULL,
    event_name character varying(100) NOT NULL,
    audit_log_id bigint NOT NULL,
    method_type character(10) NOT NULL,
    sent_at timestamp with time zone NOT NULL,
    status boolean NOT NULL,
    reason character(255)
);


ALTER TABLE public.event_notification_hist OWNER TO engine;

--
-- Name: getallfromevent_notification_hist(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromevent_notification_hist() RETURNS SETOF event_notification_hist
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM event_notification_hist;

END; ';


ALTER FUNCTION public.getallfromevent_notification_hist() OWNER TO engine;

--
-- Name: event_notification_methods; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE event_notification_methods (
    method_id integer NOT NULL,
    method_type character(10) NOT NULL
);


ALTER TABLE public.event_notification_methods OWNER TO engine;

--
-- Name: getallfromevent_notification_methods(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromevent_notification_methods() RETURNS SETOF event_notification_methods
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM event_notification_methods;

END; ';


ALTER FUNCTION public.getallfromevent_notification_methods() OWNER TO engine;

--
-- Name: getallfromevent_subscriber(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromevent_subscriber() RETURNS SETOF event_subscriber
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM event_subscriber;

END; ';


ALTER FUNCTION public.getallfromevent_subscriber() OWNER TO engine;

--
-- Name: event_subscriber_notification_methods_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW event_subscriber_notification_methods_view AS
    SELECT event_subscriber.subscriber_id, event_subscriber.event_up_name, event_notification_methods.method_type FROM (event_notification_methods JOIN event_subscriber ON ((event_notification_methods.method_id = event_subscriber.method_id)));


ALTER TABLE public.event_subscriber_notification_methods_view OWNER TO engine;

--
-- Name: getallfromevent_subscriber_notification_methods(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromevent_subscriber_notification_methods() RETURNS SETOF event_subscriber_notification_methods_view
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT *
from event_subscriber_notification_methods_view;
END; ';


ALTER FUNCTION public.getallfromevent_subscriber_notification_methods() OWNER TO engine;

--
-- Name: getallfromimages(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromimages() RETURNS SETOF images
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   images;
END; ';


ALTER FUNCTION public.getallfromimages() OWNER TO engine;

--
-- Name: lun_storage_server_connection_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE lun_storage_server_connection_map (
    lun_id character varying(50) NOT NULL,
    storage_server_connection character varying(50) NOT NULL
);


ALTER TABLE public.lun_storage_server_connection_map OWNER TO engine;

--
-- Name: getallfromlun_storage_server_connection_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromlun_storage_server_connection_map() RETURNS SETOF lun_storage_server_connection_map
    LANGUAGE plpgsql
    AS '
BEGIN
	
   RETURN QUERY SELECT *
   FROM LUN_storage_server_connection_map lUN_storage_server_connection_map;

END; ';


ALTER FUNCTION public.getallfromlun_storage_server_connection_map() OWNER TO engine;

--
-- Name: luns_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW luns_view AS
    SELECT luns.physical_volume_id, luns.lun_id, luns.volume_group_id, luns.serial, luns.lun_mapping, luns.vendor_id, luns.product_id, luns.device_size, storage_domain_static.id AS storage_id, storage_domain_static.storage_name, disk_lun_map.disk_id, all_disks.disk_alias FROM (((luns LEFT JOIN storage_domain_static ON (((luns.volume_group_id)::text = (storage_domain_static.storage)::text))) LEFT JOIN disk_lun_map ON (((luns.lun_id)::text = (disk_lun_map.lun_id)::text))) LEFT JOIN all_disks ON ((disk_lun_map.disk_id = all_disks.disk_id)));


ALTER TABLE public.luns_view OWNER TO engine;

--
-- Name: getallfromluns(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromluns() RETURNS SETOF luns_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM luns_view;

END; ';


ALTER FUNCTION public.getallfromluns() OWNER TO engine;

--
-- Name: network; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE network (
    id uuid NOT NULL,
    name character varying(50) NOT NULL,
    description character varying(4000),
    type integer,
    addr character varying(50),
    subnet character varying(20),
    gateway character varying(20),
    vlan_id integer,
    stp boolean DEFAULT false NOT NULL,
    storage_pool_id uuid,
    mtu integer,
    vm_network boolean DEFAULT true NOT NULL
);


ALTER TABLE public.network OWNER TO engine;

--
-- Name: getallfromnetwork(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromnetwork() RETURNS SETOF network
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM network;

END; ';


ALTER FUNCTION public.getallfromnetwork() OWNER TO engine;

--
-- Name: network_cluster; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE network_cluster (
    network_id uuid NOT NULL,
    cluster_id uuid NOT NULL,
    status integer DEFAULT 0 NOT NULL,
    is_display boolean DEFAULT false NOT NULL,
    required boolean DEFAULT true NOT NULL
);


ALTER TABLE public.network_cluster OWNER TO engine;

--
-- Name: getallfromnetwork_cluster(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromnetwork_cluster() RETURNS SETOF network_cluster
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM network_cluster;

END; ';


ALTER FUNCTION public.getallfromnetwork_cluster() OWNER TO engine;

--
-- Name: getallfromnetwork_clusterbyclusterid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromnetwork_clusterbyclusterid(v_cluster_id uuid) RETURNS SETOF network_cluster
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM network_cluster
   WHERE cluster_id = v_cluster_id;

END; ';


ALTER FUNCTION public.getallfromnetwork_clusterbyclusterid(v_cluster_id uuid) OWNER TO engine;

--
-- Name: getallfromnetwork_clusterbynetworkid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromnetwork_clusterbynetworkid(v_network_id uuid) RETURNS SETOF network_cluster
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM network_cluster
   WHERE network_id = v_network_id;

END; ';


ALTER FUNCTION public.getallfromnetwork_clusterbynetworkid(v_network_id uuid) OWNER TO engine;

--
-- Name: roles; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE roles (
    id uuid NOT NULL,
    name character varying(126) NOT NULL,
    description character varying(4000),
    is_readonly boolean NOT NULL,
    role_type integer NOT NULL,
    allows_viewing_children boolean DEFAULT false NOT NULL
);


ALTER TABLE public.roles OWNER TO engine;

--
-- Name: getallfromrole(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromrole() RETURNS SETOF roles
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles;

END; ';


ALTER FUNCTION public.getallfromrole() OWNER TO engine;

--
-- Name: roles_relations; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE roles_relations (
    role_id uuid NOT NULL,
    role_container_id uuid NOT NULL
);


ALTER TABLE public.roles_relations OWNER TO engine;

--
-- Name: getallfromroles_relations(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromroles_relations() RETURNS SETOF roles_relations
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles_relations;

END; ';


ALTER FUNCTION public.getallfromroles_relations() OWNER TO engine;

--
-- Name: getallfromsnapshots(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromsnapshots() RETURNS SETOF snapshots
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   snapshots;
END; ';


ALTER FUNCTION public.getallfromsnapshots() OWNER TO engine;

--
-- Name: getallfromsnapshotsbyvmid(uuid, uuid, boolean, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromsnapshotsbyvmid(v_vm_id uuid, v_user_id uuid, v_is_filtered boolean, v_fill_configuration boolean) RETURNS SETOF getallfromsnapshotsbyvmid_rs
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT snapshot_id,
           vm_id,
           snapshot_type,
           status,
           description,
           creation_date,
           app_list,
           CASE WHEN v_fill_configuration = TRUE THEN vm_configuration ELSE NULL END,
           vm_configuration IS NOT NULL AND LENGTH(vm_configuration) > 0
    FROM   snapshots
    WHERE  vm_id = v_vm_id
    AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                      FROM   user_vm_permissions_view
                                      WHERE  user_id = v_user_id AND entity_id = v_vm_id))
    ORDER BY creation_date ASC;
END; ';


ALTER FUNCTION public.getallfromsnapshotsbyvmid(v_vm_id uuid, v_user_id uuid, v_is_filtered boolean, v_fill_configuration boolean) OWNER TO engine;

--
-- Name: storage_domain_dynamic; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE storage_domain_dynamic (
    id uuid NOT NULL,
    available_disk_size integer,
    used_disk_size integer
);


ALTER TABLE public.storage_domain_dynamic OWNER TO engine;

--
-- Name: getallfromstorage_domain_dynamic(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromstorage_domain_dynamic() RETURNS SETOF storage_domain_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domain_dynamic;

END; ';


ALTER FUNCTION public.getallfromstorage_domain_dynamic() OWNER TO engine;

--
-- Name: getallfromstorage_domain_static(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromstorage_domain_static() RETURNS SETOF storage_domain_static
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domain_static;
END; ';


ALTER FUNCTION public.getallfromstorage_domain_static() OWNER TO engine;

--
-- Name: storage_domains; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW storage_domains AS
    SELECT storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_name, storage_pool_iso_map.storage_pool_id, storage_domain_dynamic.available_disk_size, storage_domain_dynamic.used_disk_size, fn_get_disk_commited_value_by_storage(storage_domain_static.id) AS commited_disk_size, storage_pool_iso_map.status, storage_pool.name AS storage_pool_name, storage_domain_static.storage_type, storage_domain_static.storage_domain_type, storage_domain_static.storage_domain_format_type, storage_domain_static.last_time_used_as_master, storage_pool_iso_map.owner, fn_get_storage_domain_shared_status_by_domain_id(storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_type) AS storage_domain_shared_status, storage_domain_static.recoverable FROM (((storage_domain_static JOIN storage_domain_dynamic ON ((storage_domain_static.id = storage_domain_dynamic.id))) LEFT JOIN storage_pool_iso_map ON ((storage_domain_static.id = storage_pool_iso_map.storage_id))) LEFT JOIN storage_pool ON ((storage_pool_iso_map.storage_pool_id = storage_pool.id)));


ALTER TABLE public.storage_domains OWNER TO engine;

--
-- Name: getallfromstorage_domains(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromstorage_domains(v_user_id uuid, v_is_filtered boolean) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE (NOT v_is_filtered OR EXISTS (SELECT 1
                                       FROM user_storage_domain_permissions_view
                                       WHERE user_id = v_user_id AND entity_id = id));
END; ';


ALTER FUNCTION public.getallfromstorage_domains(v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallfromstorage_pool(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromstorage_pool(v_user_id uuid, v_is_filtered boolean) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool
   WHERE (NOT v_is_filtered OR EXISTS (SELECT 1
                                       FROM   user_storage_pool_permissions_view
                                       WHERE  user_id = v_user_id AND entity_id = id));
END; ';


ALTER FUNCTION public.getallfromstorage_pool(v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallfromstorage_pool_iso_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromstorage_pool_iso_map() RETURNS SETOF storage_pool_iso_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool_iso_map;

END; ';


ALTER FUNCTION public.getallfromstorage_pool_iso_map() OWNER TO engine;

--
-- Name: storage_server_connections; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE storage_server_connections (
    id character varying(50) NOT NULL,
    connection character varying(250) NOT NULL,
    user_name character varying(50),
    password text,
    iqn character varying(128),
    port character varying(50),
    portal character varying(50),
    storage_type integer NOT NULL,
    mount_options character varying(500),
    vfs_type character varying(128),
    nfs_version character varying(4),
    nfs_timeo smallint,
    nfs_retrans smallint
);


ALTER TABLE public.storage_server_connections OWNER TO engine;

--
-- Name: getallfromstorage_server_connections(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromstorage_server_connections() RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_server_connections;

END; ';


ALTER FUNCTION public.getallfromstorage_server_connections() OWNER TO engine;

--
-- Name: getallfromstoragedomainsbyconnectionid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromstoragedomainsbyconnectionid(v_connection_id character varying) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE storage = v_connection_id;
END; ';


ALTER FUNCTION public.getallfromstoragedomainsbyconnectionid(v_connection_id character varying) OWNER TO engine;

--
-- Name: tags; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE tags (
    tag_id uuid NOT NULL,
    tag_name character varying(50) DEFAULT ''::character varying NOT NULL,
    description character varying(4000),
    parent_id uuid,
    readonly boolean,
    type integer DEFAULT 0 NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone
);


ALTER TABLE public.tags OWNER TO engine;

--
-- Name: getallfromtags(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromtags() RETURNS SETOF tags
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags.*
      FROM tags;
END; ';


ALTER FUNCTION public.getallfromtags() OWNER TO engine;

--
-- Name: tags_user_group_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE tags_user_group_map (
    tag_id uuid NOT NULL,
    group_id uuid NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone
);


ALTER TABLE public.tags_user_group_map OWNER TO engine;

--
-- Name: getallfromtags_user_group_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromtags_user_group_map() RETURNS SETOF tags_user_group_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_user_group_map.*
      FROM tags_user_group_map;
END; ';


ALTER FUNCTION public.getallfromtags_user_group_map() OWNER TO engine;

--
-- Name: tags_user_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE tags_user_map (
    tag_id uuid NOT NULL,
    user_id uuid NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone
);


ALTER TABLE public.tags_user_map OWNER TO engine;

--
-- Name: getallfromtags_user_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromtags_user_map() RETURNS SETOF tags_user_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_user_map.*
      FROM tags_user_map;
END; ';


ALTER FUNCTION public.getallfromtags_user_map() OWNER TO engine;

--
-- Name: tags_vds_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE tags_vds_map (
    tag_id uuid NOT NULL,
    vds_id uuid NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone
);


ALTER TABLE public.tags_vds_map OWNER TO engine;

--
-- Name: getallfromtags_vds_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromtags_vds_map() RETURNS SETOF tags_vds_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_vds_map.*
      FROM tags_vds_map;
END; ';


ALTER FUNCTION public.getallfromtags_vds_map() OWNER TO engine;

--
-- Name: tags_vm_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE tags_vm_map (
    tag_id uuid NOT NULL,
    vm_id uuid NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    defaultdisplaytype integer DEFAULT 0
);


ALTER TABLE public.tags_vm_map OWNER TO engine;

--
-- Name: getallfromtags_vm_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromtags_vm_map() RETURNS SETOF tags_vm_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_vm_map.*
      FROM tags_vm_map;
END; ';


ALTER FUNCTION public.getallfromtags_vm_map() OWNER TO engine;

--
-- Name: tags_vm_pool_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE tags_vm_pool_map (
    tag_id uuid NOT NULL,
    vm_pool_id uuid NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone
);


ALTER TABLE public.tags_vm_pool_map OWNER TO engine;

--
-- Name: getallfromtags_vm_pool_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromtags_vm_pool_map() RETURNS SETOF tags_vm_pool_map
    LANGUAGE plpgsql
    AS '
BEGIN
	
   RETURN QUERY SELECT tags_vm_pool_map.*
   FROM tags_vm_pool_map;

END; ';


ALTER FUNCTION public.getallfromtags_vm_pool_map() OWNER TO engine;

--
-- Name: user_sessions; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE user_sessions (
    session_id character(32) NOT NULL,
    user_id uuid NOT NULL,
    os character(10),
    browser character(10),
    client_type character(10),
    login_time timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone
);


ALTER TABLE public.user_sessions OWNER TO engine;

--
-- Name: getallfromuser_sessions(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromuser_sessions() RETURNS SETOF user_sessions
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT user_sessions.*
      FROM user_sessions;
END; ';


ALTER FUNCTION public.getallfromuser_sessions() OWNER TO engine;

--
-- Name: users; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE users (
    user_id uuid NOT NULL,
    name character varying(255),
    surname character varying(255),
    domain character varying(255) NOT NULL,
    username character varying(255) NOT NULL,
    groups character varying NOT NULL,
    department character varying(255),
    role character varying(255),
    user_icon_path character varying(255),
    desktop_device character varying(255),
    email character varying(255),
    note character varying(255),
    status integer NOT NULL,
    session_count integer DEFAULT 0 NOT NULL,
    last_admin_check_status boolean DEFAULT false NOT NULL,
    group_ids text
);


ALTER TABLE public.users OWNER TO engine;

--
-- Name: getallfromusers(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromusers() RETURNS SETOF users
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT users.*
      FROM users;
END; ';


ALTER FUNCTION public.getallfromusers() OWNER TO engine;

--
-- Name: vdc_options_seq; Type: SEQUENCE; Schema: public; Owner: engine
--

CREATE SEQUENCE vdc_options_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.vdc_options_seq OWNER TO engine;

--
-- Name: vdc_options_seq; Type: SEQUENCE SET; Schema: public; Owner: engine
--

SELECT pg_catalog.setval('vdc_options_seq', 382, true);


--
-- Name: vdc_options; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vdc_options (
    option_id integer DEFAULT nextval('vdc_options_seq'::regclass) NOT NULL,
    option_name character varying(100) NOT NULL,
    option_value character varying(4000) NOT NULL,
    version character varying(40) DEFAULT 'general'::character varying NOT NULL
);


ALTER TABLE public.vdc_options OWNER TO engine;

--
-- Name: getallfromvdcoption(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvdcoption() RETURNS SETOF vdc_options
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vdc_options.*
      FROM vdc_options;
END; ';


ALTER FUNCTION public.getallfromvdcoption() OWNER TO engine;

--
-- Name: vds_dynamic; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vds_dynamic (
    vds_id uuid NOT NULL,
    status integer NOT NULL,
    cpu_cores integer,
    cpu_model character varying(255),
    cpu_speed_mh numeric(18,0),
    if_total_speed character varying(40),
    kvm_enabled boolean,
    physical_mem_mb integer,
    mem_commited integer DEFAULT 0,
    vm_active integer DEFAULT 0,
    vm_count integer DEFAULT 0 NOT NULL,
    vm_migrating integer DEFAULT 0,
    reserved_mem integer,
    guest_overhead integer,
    software_version character varying(40),
    version_name character varying(40),
    build_name character varying(40),
    previous_status integer,
    cpu_flags character varying(4000),
    cpu_over_commit_time_stamp timestamp with time zone,
    hypervisor_type integer,
    vms_cores_count integer,
    pending_vcpus_count integer,
    cpu_sockets integer,
    net_config_dirty boolean,
    supported_cluster_levels character varying(40),
    host_os character varying(4000),
    kvm_version character varying(4000),
    spice_version character varying(4000),
    kernel_version character varying(4000),
    iscsi_initiator_name character varying(4000),
    transparent_hugepages_state integer DEFAULT 0 NOT NULL,
    anonymous_hugepages integer DEFAULT 0 NOT NULL,
    hooks character varying(4000) DEFAULT ''::character varying,
    _update_date timestamp with time zone,
    non_operational_reason integer DEFAULT 0 NOT NULL,
    pending_vmem_size integer DEFAULT 0 NOT NULL,
    supported_engines character varying(40),
    rpm_version character varying(256) DEFAULT NULL::character varying
);


ALTER TABLE public.vds_dynamic OWNER TO engine;

--
-- Name: vds_spm_id_map; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vds_spm_id_map (
    storage_pool_id uuid NOT NULL,
    vds_spm_id integer NOT NULL,
    vds_id uuid NOT NULL
);


ALTER TABLE public.vds_spm_id_map OWNER TO engine;

--
-- Name: vds_statistics; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vds_statistics (
    vds_id uuid NOT NULL,
    cpu_idle numeric(18,0) DEFAULT 0,
    cpu_load numeric(18,0) DEFAULT 0,
    cpu_sys numeric(18,0) DEFAULT 0,
    cpu_user numeric(18,0) DEFAULT 0,
    usage_mem_percent integer DEFAULT 0,
    usage_cpu_percent integer DEFAULT 0,
    usage_network_percent integer,
    mem_available bigint,
    mem_shared bigint,
    swap_free bigint,
    swap_total bigint,
    ksm_cpu_percent integer DEFAULT 0,
    ksm_pages bigint,
    ksm_state boolean
);


ALTER TABLE public.vds_statistics OWNER TO engine;

--
-- Name: vds; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vds AS
    SELECT vds_groups.vds_group_id, vds_groups.name AS vds_group_name, vds_groups.description AS vds_group_description, vds_groups.selection_algorithm, vds_static.vds_id, vds_static.vds_name, vds_static.ip, vds_static.vds_unique_id, vds_static.host_name, vds_static.port, vds_static.vds_strength, vds_static.server_ssl_enabled, vds_static.vds_type, vds_static.pm_type, vds_static.pm_user, vds_static.pm_password, vds_static.pm_port, vds_static.pm_options, vds_static.pm_enabled, vds_static.vds_spm_priority, vds_dynamic.hooks, vds_dynamic.status, vds_dynamic.cpu_cores, vds_dynamic.cpu_model, vds_dynamic.cpu_speed_mh, vds_dynamic.if_total_speed, vds_dynamic.kvm_enabled, vds_dynamic.physical_mem_mb, vds_dynamic.pending_vcpus_count, vds_dynamic.pending_vmem_size, vds_dynamic.mem_commited, vds_dynamic.vm_active, vds_dynamic.vm_count, vds_dynamic.vm_migrating, vds_dynamic.vms_cores_count, vds_dynamic.cpu_over_commit_time_stamp, vds_dynamic.hypervisor_type, vds_dynamic.net_config_dirty, vds_groups.high_utilization, vds_groups.low_utilization, vds_groups.max_vds_memory_over_commit, vds_groups.cpu_over_commit_duration_minutes, storage_pool.id AS storage_pool_id, storage_pool.name AS storage_pool_name, vds_dynamic.reserved_mem, vds_dynamic.guest_overhead, vds_dynamic.rpm_version, vds_dynamic.software_version, vds_dynamic.version_name, vds_dynamic.build_name, vds_dynamic.previous_status, vds_statistics.cpu_idle, vds_statistics.cpu_load, vds_statistics.cpu_sys, vds_statistics.cpu_user, vds_statistics.usage_mem_percent, vds_statistics.usage_cpu_percent, vds_statistics.usage_network_percent, vds_statistics.mem_available, vds_statistics.mem_shared, vds_statistics.swap_free, vds_statistics.swap_total, vds_statistics.ksm_cpu_percent, vds_statistics.ksm_pages, vds_statistics.ksm_state, vds_dynamic.cpu_flags, vds_groups.cpu_name AS vds_group_cpu_name, vds_dynamic.cpu_sockets, vds_spm_id_map.vds_spm_id, vds_static.otp_validity, CASE WHEN (storage_pool.spm_vds_id = vds_static.vds_id) THEN CASE WHEN (storage_pool.status = 5) THEN 1 ELSE 2 END ELSE 0 END AS spm_status, vds_dynamic.supported_cluster_levels, vds_dynamic.supported_engines, vds_groups.compatibility_version AS vds_group_compatibility_version, vds_dynamic.host_os, vds_dynamic.kvm_version, vds_dynamic.spice_version, vds_dynamic.kernel_version, vds_dynamic.iscsi_initiator_name, vds_dynamic.transparent_hugepages_state, vds_dynamic.anonymous_hugepages, vds_dynamic.non_operational_reason, vds_static.recoverable FROM (((((vds_groups JOIN vds_static ON ((vds_groups.vds_group_id = vds_static.vds_group_id))) JOIN vds_dynamic ON ((vds_static.vds_id = vds_dynamic.vds_id))) JOIN vds_statistics ON ((vds_static.vds_id = vds_statistics.vds_id))) LEFT JOIN storage_pool ON ((vds_groups.storage_pool_id = storage_pool.id))) LEFT JOIN vds_spm_id_map ON ((vds_static.vds_id = vds_spm_id_map.vds_id)));


ALTER TABLE public.vds OWNER TO engine;

--
-- Name: getallfromvds(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvds(v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM vds
      WHERE (NOT v_is_filtered OR EXISTS (SELECT 1
                                          FROM user_vds_permissions_view
                                          WHERE user_id = v_user_id AND entity_id = vds_id));
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getallfromvds(v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallfromvds_spm_id_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvds_spm_id_map() RETURNS SETOF vds_spm_id_map
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vds_spm_id_map.*
   FROM vds_spm_id_map;

END; ';


ALTER FUNCTION public.getallfromvds_spm_id_map() OWNER TO engine;

--
-- Name: getallfromvdsdynamic(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvdsdynamic() RETURNS SETOF vds_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_dynamic.*
      FROM vds_dynamic;
   END;
	
   RETURN;
END; ';


ALTER FUNCTION public.getallfromvdsdynamic() OWNER TO engine;

--
-- Name: getallfromvdsgroups(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvdsgroups(v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vds_groups.*
      FROM vds_groups
      WHERE (NOT v_is_filtered OR EXISTS (SELECT 1
                                          FROM   user_vds_groups_permissions_view
                                          WHERE  user_id = v_user_id and entity_id = vds_group_id));

END; ';


ALTER FUNCTION public.getallfromvdsgroups(v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallfromvdsstatic(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvdsstatic() RETURNS SETOF vds_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vds_static.*
   FROM vds_static;

   RETURN;
END; ';


ALTER FUNCTION public.getallfromvdsstatic() OWNER TO engine;

--
-- Name: getallfromvdsstatistics(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvdsstatistics() RETURNS SETOF vds_statistics
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_statistics.*
      FROM vds_statistics;
   END;
	

   RETURN;
END; ';


ALTER FUNCTION public.getallfromvdsstatistics() OWNER TO engine;

--
-- Name: vm_interface; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_interface (
    id uuid NOT NULL,
    network_name character varying(50),
    vm_guid uuid,
    vmt_guid uuid,
    mac_addr character varying(20),
    name character varying(50) NOT NULL,
    speed integer,
    type integer DEFAULT 0,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    port_mirroring boolean DEFAULT false NOT NULL
);


ALTER TABLE public.vm_interface OWNER TO engine;

--
-- Name: getallfromvm_interface(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvm_interface() RETURNS SETOF vm_interface
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT *
   FROM vm_interface;

END; ';


ALTER FUNCTION public.getallfromvm_interface() OWNER TO engine;

--
-- Name: getallfromvm_pool_map(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvm_pool_map() RETURNS SETOF vm_pool_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_pool_map.*
      FROM vm_pool_map;
END; ';


ALTER FUNCTION public.getallfromvm_pool_map() OWNER TO engine;

--
-- Name: getallfromvm_pools(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvm_pools() RETURNS SETOF getallfromvm_pools_rs
    LANGUAGE plpgsql
    AS '
BEGIN
      -- BEGIN TRAN
BEGIN
         CREATE GLOBAL TEMPORARY TABLE tt_VM_POOL_GROUP
         (
            vm_pool_id UUID,
            assigned_vm_count INTEGER
         ) WITH OIDS;
         exception when others then
            truncate table tt_VM_POOL_GROUP;
      END;
      insert INTO tt_VM_POOL_GROUP(vm_pool_id,
					assigned_vm_count)
      select
      vm_pools_view.vm_pool_id,
			  count(vm_pool_map.vm_pool_id)
      from vm_pools_view
      left join vm_pool_map on vm_pools_view.vm_pool_id = vm_pool_map.vm_pool_id
      group by vm_pools_view.vm_pool_id,vm_pool_map.vm_pool_id;
      BEGIN
         CREATE GLOBAL TEMPORARY TABLE tt_VM_POOL_RUNNING
         (
            vm_pool_id UUID,
            vm_running_count INTEGER
         ) WITH OIDS;
         exception when others then
            truncate table tt_VM_POOL_RUNNING;
      END;
      insert INTO tt_VM_POOL_RUNNING(vm_pool_id,
					vm_running_count)
      select vm_pools_view.vm_pool_id, count(vm_pools_view.vm_pool_id)
      from vm_pools_view
      left join vm_pool_map on vm_pools_view.vm_pool_id = vm_pool_map.vm_pool_id
      left join vm_dynamic on vm_pool_map.vm_guid = vm_dynamic.vm_guid
      where vm_dynamic.status > 0
      group by vm_pools_view.vm_pool_id;
      BEGIN
         CREATE GLOBAL TEMPORARY TABLE tt_VM_POOL_PRERESULT
         (
            vm_pool_id UUID,
            assigned_vm_count INTEGER,
            vm_running_count INTEGER
         ) WITH OIDS;
         exception when others then
            truncate table tt_VM_POOL_PRERESULT;
      END;
      insert INTO tt_VM_POOL_PRERESULT(vm_pool_id,
					assigned_vm_count,
					vm_running_count)
      select pg.vm_pool_id, pg.assigned_vm_count, pr.vm_running_count
      from tt_VM_POOL_GROUP pg
      left join tt_VM_POOL_RUNNING pr on pg.vm_pool_id = pr.vm_pool_id;
      update tt_VM_POOL_PRERESULT
      set vm_running_count = 0
      where vm_running_count is NULL;
      BEGIN
         CREATE GLOBAL TEMPORARY TABLE tt_VM_POOL_RESULT
         (
            vm_pool_id UUID,
            assigned_vm_count INTEGER,
            vm_running_count INTEGER,
            vm_pool_description VARCHAR(4000),
            vm_pool_name VARCHAR(255),
            vm_pool_type INTEGER,
            parameters VARCHAR(200),
            prestarted_vms INTEGER,
            vds_group_id UUID,
            vds_group_name VARCHAR(40)
         ) WITH OIDS;
         exception when others then
            truncate table tt_VM_POOL_RESULT;
      END;
      insert INTO tt_VM_POOL_RESULT(vm_pool_id,
            assigned_vm_count,
            vm_running_count,
            vm_pool_description,
            vm_pool_name,
            vm_pool_type,
            parameters,
            prestarted_vms,
            vds_group_id,
            vds_group_name)
      select ppr.vm_pool_id, ppr.assigned_vm_count, ppr.vm_running_count,
  				 p.vm_pool_description, p.vm_pool_name, p.vm_pool_type, p.parameters, p.prestarted_vms,
					 p.vds_group_id, p.vds_group_name
      from tt_VM_POOL_PRERESULT ppr
      inner join vm_pools_view p on ppr.vm_pool_id = p.vm_pool_id;
      RETURN QUERY select *
      from tt_VM_POOL_RESULT;
END; ';


ALTER FUNCTION public.getallfromvm_pools() OWNER TO engine;

--
-- Name: vm_device_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_device_view AS
    SELECT vm_device.device_id, vm_device.vm_id, vm_device.type, vm_device.device, vm_device.address, vm_device.boot_order, vm_device.spec_params, vm_device.is_managed, vm_device.is_plugged, vm_device.is_readonly, vm_device.alias FROM vm_device;


ALTER TABLE public.vm_device_view OWNER TO engine;

--
-- Name: getallfromvmdevice(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvmdevice() RETURNS SETOF vm_device_view
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   vm_device_view;
END; ';


ALTER FUNCTION public.getallfromvmdevice() OWNER TO engine;

--
-- Name: getallfromvmdynamic(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvmdynamic() RETURNS SETOF vm_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_dynamic.*
      FROM vm_dynamic;
END; ';


ALTER FUNCTION public.getallfromvmdynamic() OWNER TO engine;

--
-- Name: getallfromvms(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvms(v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT DISTINCT vms.*
   FROM vms
   WHERE (NOT v_is_filtered OR EXISTS (SELECT 1
                                       FROM user_vm_permissions_view
                                       WHERE user_id = v_user_id AND entity_id = vm_guid))
   ORDER BY vm_guid;
END; ';


ALTER FUNCTION public.getallfromvms(v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallfromvmstatic(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvmstatic() RETURNS SETOF vm_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vm_static.*
   FROM vm_static
   WHERE entity_type = ''VM'';

END; ';


ALTER FUNCTION public.getallfromvmstatic() OWNER TO engine;

--
-- Name: getallfromvmstaticbystoragepoolid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvmstaticbystoragepoolid(v_sp_id uuid) RETURNS SETOF vm_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vm_static.*
   FROM vm_static INNER JOIN
        vm_dynamic ON vm_static.vm_guid = vm_dynamic.vm_guid INNER JOIN
        vds_groups ON vm_static.vds_group_id = vds_groups.vds_group_id LEFT OUTER JOIN
        storage_pool ON vm_static.vds_group_id = vds_groups.vds_group_id
        and vds_groups.storage_pool_id = storage_pool.id
   WHERE v_sp_id = storage_pool.id
   AND   entity_type = ''VM'';

END; ';


ALTER FUNCTION public.getallfromvmstaticbystoragepoolid(v_sp_id uuid) OWNER TO engine;

--
-- Name: getallfromvmstatistics(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvmstatistics() RETURNS SETOF vm_statistics
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_statistics.*
      FROM vm_statistics;
END; ';


ALTER FUNCTION public.getallfromvmstatistics() OWNER TO engine;

--
-- Name: getallfromvmtemplates(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallfromvmtemplates(v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vm_templates_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_templates.*
      FROM vm_templates_view vm_templates
      WHERE (NOT v_is_filtered OR EXISTS (SELECT 1
                                          FROM   user_vm_template_permissions_view
                                          WHERE  user_id = v_user_id AND entity_id = vmt_guid))
      ORDER BY name;
END; ';


ALTER FUNCTION public.getallfromvmtemplates(v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getalljobidsbyentityid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getalljobidsbyentityid(v_entity_id uuid) RETURNS SETOF uuid
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT job_subject_entity.job_id
    FROM job_subject_entity
    WHERE entity_id = v_entity_id;
END; ';


ALTER FUNCTION public.getalljobidsbyentityid(v_entity_id uuid) OWNER TO engine;

--
-- Name: job; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE job (
    job_id uuid NOT NULL,
    action_type character varying(50) NOT NULL,
    description text NOT NULL,
    status character varying(32) NOT NULL,
    owner_id uuid,
    visible boolean DEFAULT true NOT NULL,
    start_time timestamp with time zone NOT NULL,
    end_time timestamp with time zone,
    last_update_time timestamp with time zone,
    correlation_id character varying(50) NOT NULL
);


ALTER TABLE public.job OWNER TO engine;

--
-- Name: getalljobs(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getalljobs() RETURNS SETOF job
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT job.*
    FROM JOB
    where status != ''UNKNOWN'';
END; ';


ALTER FUNCTION public.getalljobs() OWNER TO engine;

--
-- Name: getallnetworkbyclusterid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallnetworkbyclusterid(v_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF networkviewclustertype
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT
    DISTINCT
    network.id,
    network.name,
    network.description,
    network.type,
    network.addr,
    network.subnet,
    network.gateway,
    network.vlan_id,
    network.stp,
    network.storage_pool_id,
    network.mtu,
    network.vm_network,
    network_cluster.network_id,
    network_cluster.cluster_id,
    network_cluster.status,
    network_cluster.is_display,
    network_cluster.required
   FROM network
   INNER JOIN network_cluster
   ON network.id = network_cluster.network_id
   where network_cluster.cluster_id = v_id
  AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                    FROM   user_vds_groups_permissions_view
                                    WHERE  user_id = v_user_id AND entity_id = v_id));



END; ';


ALTER FUNCTION public.getallnetworkbyclusterid(v_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallnetworkbystoragepoolid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallnetworkbystoragepoolid(v_id uuid) RETURNS SETOF network
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT *
   FROM network
   where storage_pool_id = v_id;

END; ';


ALTER FUNCTION public.getallnetworkbystoragepoolid(v_id uuid) OWNER TO engine;

--
-- Name: getallrolesbyadelementid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallrolesbyadelementid(v_ad_element_id uuid) RETURNS SETOF roles
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT roles.*
   FROM roles INNER JOIN
   permissions ON permissions.role_id = roles.id
   WHERE permissions.ad_element_id = v_ad_element_id
   or permissions.ad_element_id in(select id from getUserAndGroupsById(v_ad_element_id));

END; ';


ALTER FUNCTION public.getallrolesbyadelementid(v_ad_element_id uuid) OWNER TO engine;

--
-- Name: getallrolesbyuseridandgroupids(uuid, text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallrolesbyuseridandgroupids(v_user_id uuid, v_group_ids text) RETURNS SETOF roles
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT roles.*
   FROM roles INNER JOIN
   permissions ON permissions.role_id = roles.id
   WHERE permissions.ad_element_id = v_user_id
   or permissions.ad_element_id in(select id from getElementIdsByIdAndGroups(v_user_id, v_group_ids));

END; ';


ALTER FUNCTION public.getallrolesbyuseridandgroupids(v_user_id uuid, v_group_ids text) OWNER TO engine;

--
-- Name: step; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE step (
    step_id uuid NOT NULL,
    parent_step_id uuid,
    job_id uuid NOT NULL,
    step_type character varying(32) NOT NULL,
    description text NOT NULL,
    step_number integer NOT NULL,
    status character varying(32) NOT NULL,
    start_time timestamp with time zone NOT NULL,
    end_time timestamp with time zone,
    correlation_id character varying(50) NOT NULL,
    external_id uuid,
    external_system_type character varying(32)
);


ALTER TABLE public.step OWNER TO engine;

--
-- Name: getallsteps(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallsteps() RETURNS SETOF step
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT step.*
    FROM step;
END; ';


ALTER FUNCTION public.getallsteps() OWNER TO engine;

--
-- Name: quota_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW quota_view AS
    SELECT q.id AS quota_id, q.storage_pool_id, storage_pool.name AS storage_pool_name, q.quota_name, q.description, q.threshold_vds_group_percentage, q.threshold_storage_percentage, q.grace_vds_group_percentage, q.grace_storage_percentage, storage_pool.quota_enforcement_type FROM storage_pool, quota q WHERE (storage_pool.id = q.storage_pool_id);


ALTER TABLE public.quota_view OWNER TO engine;

--
-- Name: getallthinquotasbystorageid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallthinquotasbystorageid(v_storage_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF quota_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT DISTINCT
    quota_id,
    storage_pool_id,
    storage_pool_name,
    quota_name,
    description,
    threshold_vds_group_percentage,
    threshold_storage_percentage,
    grace_vds_group_percentage,
    grace_storage_percentage,
    quota_enforcement_type
   FROM   quota_limitations_view
   WHERE  (storage_id = v_storage_id
   OR     (is_global AND
           NOT is_empty AND
           storage_size_gb IS NOT null AND
           storage_pool_id IN (SELECT storage_pool_id FROM storage_pool_iso_map
               WHERE  storage_id = v_storage_id)))
   AND (NOT v_is_filtered OR
          EXISTS (SELECT 1 FROM permissions p
                  JOIN user_flat_groups u ON
                  u.granted_id = p.ad_element_id WHERE
                  u.user_id = v_user_id AND
                  p.object_type_id = 17 AND -- quota object
                  p.role_id = ''def0000a-0000-0000-0000-def00000000a'' AND -- consume quota
                  quota_id = p.object_id));
END; ';


ALTER FUNCTION public.getallthinquotasbystorageid(v_storage_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getallthinquotasbyvdsgroupid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallthinquotasbyvdsgroupid(v_vds_group_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF quota_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT DISTINCT
    quota_id,
    storage_pool_id,
    storage_pool_name,
    quota_name,
    description,
    threshold_vds_group_percentage,
    threshold_storage_percentage,
    grace_vds_group_percentage,
    grace_storage_percentage,
    quota_enforcement_type
   FROM   quota_limitations_view
   WHERE  (vds_group_id = v_vds_group_id
   OR     (is_global AND
           NOT is_empty AND
           virtual_cpu IS NOT null AND
           storage_pool_id IN (SELECT storage_pool_id FROM vds_groups
               WHERE  vds_group_id = v_vds_group_id)))
   AND (NOT v_is_filtered OR
          EXISTS (SELECT 1 FROM permissions p
                  JOIN user_flat_groups u ON
                  u.granted_id = p.ad_element_id WHERE
                  u.user_id = v_user_id AND
                  p.object_type_id = 17 AND -- quota object
                  p.role_id = ''def0000a-0000-0000-0000-def00000000a'' AND -- consume quota
                  quota_id = p.object_id));
END; ';


ALTER FUNCTION public.getallthinquotasbyvdsgroupid(v_vds_group_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: vm_pools_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_pools_view AS
    SELECT vm_pools.vm_pool_id, vm_pools.vm_pool_name, vm_pools.vm_pool_description, vm_pools.vm_pool_type, vm_pools.parameters, vm_pools.prestarted_vms, vm_pools.vds_group_id, vds_groups.name AS vds_group_name FROM (vm_pools JOIN vds_groups ON ((vm_pools.vds_group_id = vds_groups.vds_group_id)));


ALTER TABLE public.vm_pools_view OWNER TO engine;

--
-- Name: getallvm_poolsbyuser_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallvm_poolsbyuser_id(v_user_id uuid) RETURNS SETOF vm_pools_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT  DISTINCT vm_pools_view.*
      FROM         users_and_groups_to_vm_pool_map_view INNER JOIN
      vm_pools_view ON
      users_and_groups_to_vm_pool_map_view.vm_pool_id = vm_pools_view.vm_pool_id
      WHERE     (users_and_groups_to_vm_pool_map_view.user_id = v_user_id);
END; ';


ALTER FUNCTION public.getallvm_poolsbyuser_id(v_user_id uuid) OWNER TO engine;

--
-- Name: getallvm_poolsbyuser_id_with_groups_and_userroles(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallvm_poolsbyuser_id_with_groups_and_userroles(v_user_id uuid) RETURNS SETOF vm_pools_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT pools.*
	FROM vm_pools_view pools
    INNER JOIN user_vm_pool_permissions_view ON user_id = v_user_id AND entity_id = pools.vm_pool_id;
END; ';


ALTER FUNCTION public.getallvm_poolsbyuser_id_with_groups_and_userroles(v_user_id uuid) OWNER TO engine;

--
-- Name: getallvmsrelatedtoquotaid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallvmsrelatedtoquotaid(v_quota_id uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vms.*
      FROM vms
      WHERE quota_id = v_quota_id
      UNION
      SELECT DISTINCT vms.*
      FROM vms
      INNER JOIN vm_device vd ON vd.vm_id = vms.vm_guid
      INNER JOIN images ON images.image_group_id = vd.device_id AND images.active = TRUE
      WHERE images.quota_id = v_quota_id;
END; ';


ALTER FUNCTION public.getallvmsrelatedtoquotaid(v_quota_id uuid) OWNER TO engine;

--
-- Name: getallvmtemplatesrelatedtoquotaid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getallvmtemplatesrelatedtoquotaid(v_quota_id uuid) RETURNS SETOF vm_templates_view
    LANGUAGE plpgsql
    AS '
BEGIN
	RETURN QUERY SELECT vm_templates.*
      FROM vm_templates_view vm_templates
      WHERE quota_id = v_quota_id
      UNION
      SELECT DISTINCT vm_templates.*
      FROM vm_templates_view vm_templates
      INNER JOIN vm_device vd ON vd.vm_id = vm_templates.vmt_guid
      INNER JOIN images ON images.image_group_id = vd.device_id AND images.active = TRUE
      WHERE images.quota_id = v_quota_id;
END; ';


ALTER FUNCTION public.getallvmtemplatesrelatedtoquotaid(v_quota_id uuid) OWNER TO engine;

--
-- Name: getancestralimagebyimageguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getancestralimagebyimageguid(v_image_guid uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY WITH RECURSIVE ancestor_image(image_guid, parentid) AS (
         SELECT image_guid, parentid 
         FROM images
         WHERE image_guid = v_image_guid
         UNION ALL
         SELECT i.image_guid, i.parentid
         FROM images i, ancestor_image ai
         WHERE i.image_guid = ai.parentid
      )
      SELECT i.*
      FROM ancestor_image ai, images_storage_domain_view i
      WHERE ai.parentid = ''00000000-0000-0000-0000-000000000000''
      AND ai.image_guid = i.image_guid;
END; ';


ALTER FUNCTION public.getancestralimagebyimageguid(v_image_guid uuid) OWNER TO engine;

--
-- Name: getasync_tasksbytask_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getasync_tasksbytask_id(v_task_id uuid) RETURNS SETOF async_tasks
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM async_tasks
   WHERE task_id = v_task_id;

END; ';


ALTER FUNCTION public.getasync_tasksbytask_id(v_task_id uuid) OWNER TO engine;

--
-- Name: getasynctasksbyentityid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getasynctasksbyentityid(v_entity_id uuid) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT async_task_id from async_tasks_entities where entity_id = v_entity_id;
END; ';


ALTER FUNCTION public.getasynctasksbyentityid(v_entity_id uuid) OWNER TO engine;

--
-- Name: getasynctasksbystoragepoolid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getasynctasksbystoragepoolid(v_storage_pool_id uuid) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT task_ent.async_task_id
   FROM  storage_pool_iso_map sd_map
   JOIN async_tasks_entities task_ent ON sd_map.storage_id = task_ent.entity_id
   WHERE storage_pool_id = v_storage_pool_id;
END; ';


ALTER FUNCTION public.getasynctasksbystoragepoolid(v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getauditlogbyauditlogid(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getauditlogbyauditlogid(v_audit_log_id integer) RETURNS SETOF audit_log
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM audit_log
      WHERE audit_log_id = v_audit_log_id;
END; ';


ALTER FUNCTION public.getauditlogbyauditlogid(v_audit_log_id integer) OWNER TO engine;

--
-- Name: getauditlogbyvmname(character varying, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getauditlogbyvmname(v_vm_name character varying, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF audit_log
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM   audit_log
      WHERE  vm_name = v_vm_name
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_vm_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = vm_id));


END; ';


ALTER FUNCTION public.getauditlogbyvmname(v_vm_name character varying, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getauditlogbyvmtemplatename(character varying, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getauditlogbyvmtemplatename(v_vm_template_name character varying, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF audit_log
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM   audit_log
      WHERE  vm_template_name = v_vm_template_name
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_vm_template_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = vm_template_id));


END; ';


ALTER FUNCTION public.getauditlogbyvmtemplatename(v_vm_template_name character varying, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getauditloglaterthendate(timestamp with time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getauditloglaterthendate(v_date timestamp with time zone) RETURNS SETOF audit_log
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM audit_log
      WHERE LOG_TIME >= v_date;
END; ';


ALTER FUNCTION public.getauditloglaterthendate(v_date timestamp with time zone) OWNER TO engine;

--
-- Name: getbasediskbybasediskid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getbasediskbybasediskid(v_disk_id uuid) RETURNS SETOF base_disks
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   base_disks
    WHERE  disk_id = v_disk_id;
END; ';


ALTER FUNCTION public.getbasediskbybasediskid(v_disk_id uuid) OWNER TO engine;

--
-- Name: getbookmarkbybookmark_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getbookmarkbybookmark_id(v_bookmark_id uuid) RETURNS SETOF bookmarks
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM bookmarks
      WHERE bookmark_Id = v_bookmark_id;
END; ';


ALTER FUNCTION public.getbookmarkbybookmark_id(v_bookmark_id uuid) OWNER TO engine;

--
-- Name: getbookmarkbybookmark_name(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getbookmarkbybookmark_name(v_bookmark_name character varying) RETURNS SETOF bookmarks
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM bookmarks
      WHERE bookmark_name = v_bookmark_name;
END; ';


ALTER FUNCTION public.getbookmarkbybookmark_name(v_bookmark_name character varying) OWNER TO engine;

--
-- Name: gluster_volume_bricks; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE gluster_volume_bricks (
    volume_id uuid NOT NULL,
    server_id uuid NOT NULL,
    brick_dir character varying(4096) NOT NULL,
    status character varying(32) NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone NOT NULL,
    _update_date timestamp with time zone,
    id uuid NOT NULL,
    brick_order integer DEFAULT 0
);


ALTER TABLE public.gluster_volume_bricks OWNER TO engine;

--
-- Name: getbricksbyglustervolumeguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getbricksbyglustervolumeguid(v_volume_id uuid) RETURNS SETOF gluster_volume_bricks
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM  gluster_volume_bricks
    WHERE volume_id = v_volume_id
    ORDER BY brick_order;
END; ';


ALTER FUNCTION public.getbricksbyglustervolumeguid(v_volume_id uuid) OWNER TO engine;

--
-- Name: permissions; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE permissions (
    id uuid NOT NULL,
    role_id uuid NOT NULL,
    ad_element_id uuid NOT NULL,
    object_id uuid NOT NULL,
    object_type_id integer NOT NULL
);


ALTER TABLE public.permissions OWNER TO engine;

--
-- Name: permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW permissions_view AS
    SELECT permissions.id, permissions.role_id, permissions.ad_element_id, permissions.object_id, permissions.object_type_id, roles.name AS role_name, roles.role_type, roles.allows_viewing_children, fn_get_entity_name(permissions.object_id, permissions.object_type_id) AS object_name, fn_get_ad_element_name(permissions.ad_element_id) AS owner_name FROM (permissions JOIN roles ON ((permissions.role_id = roles.id)));


ALTER TABLE public.permissions_view OWNER TO engine;

--
-- Name: getconsumedpermissionsforquotaid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getconsumedpermissionsforquotaid(v_quota_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY    SELECT *
   FROM permissions_view
   WHERE role_id in (SELECT role_id FROM ROLES_groups where action_group_id = 901)
     AND object_id in(select id from  fn_get_entity_parents(v_quota_id,17));
END; ';


ALTER FUNCTION public.getconsumedpermissionsforquotaid(v_quota_id uuid) OWNER TO engine;

--
-- Name: getcustom_actionsbyaction_id(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getcustom_actionsbyaction_id(v_action_id integer) RETURNS SETOF custom_actions
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM custom_actions
      WHERE action_id = v_action_id;
END; ';


ALTER FUNCTION public.getcustom_actionsbyaction_id(v_action_id integer) OWNER TO engine;

--
-- Name: getcustom_actionsbynameandtab(character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getcustom_actionsbynameandtab(v_action_name character varying, v_tab integer) RETURNS SETOF custom_actions
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM custom_actions
      WHERE tab = v_tab and action_name = v_action_name;
END; ';


ALTER FUNCTION public.getcustom_actionsbynameandtab(v_action_name character varying, v_tab integer) OWNER TO engine;

--
-- Name: getcustom_actionsbytab_id(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getcustom_actionsbytab_id(v_tab integer) RETURNS SETOF custom_actions
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM custom_actions
      WHERE tab = v_tab;
END; ';


ALTER FUNCTION public.getcustom_actionsbytab_id(v_tab integer) OWNER TO engine;

--
-- Name: getdirectpermissionsbyadelementid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getdirectpermissionsbyadelementid(v_ad_element_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE permissions_view.ad_element_id = v_ad_element_id;

END; ';


ALTER FUNCTION public.getdirectpermissionsbyadelementid(v_ad_element_id uuid) OWNER TO engine;

--
-- Name: getdisk_image_dynamicbyimage_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getdisk_image_dynamicbyimage_id(v_image_id uuid) RETURNS SETOF disk_image_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM disk_image_dynamic
   WHERE image_id = v_image_id;

END; ';


ALTER FUNCTION public.getdisk_image_dynamicbyimage_id(v_image_id uuid) OWNER TO engine;

--
-- Name: getdiskbydiskid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getdiskbydiskid(v_disk_id uuid) RETURNS SETOF all_disks
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   all_disks
    WHERE  image_group_id = v_disk_id;
END; ';


ALTER FUNCTION public.getdiskbydiskid(v_disk_id uuid) OWNER TO engine;

--
-- Name: getdisklunmapbydisklunmapid(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getdisklunmapbydisklunmapid(v_disk_id uuid, v_lun_id character varying) RETURNS SETOF disk_lun_map
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   disk_lun_map
    WHERE  disk_id = v_disk_id
    AND    lun_id = v_lun_id;
END; ';


ALTER FUNCTION public.getdisklunmapbydisklunmapid(v_disk_id uuid, v_lun_id character varying) OWNER TO engine;

--
-- Name: getdisklunmapbylunid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getdisklunmapbylunid(v_lun_id character varying) RETURNS SETOF disk_lun_map
    LANGUAGE plpgsql
    AS '
BEGIN
	RETURN QUERY
    SELECT *
    FROM   disk_lun_map
    WHERE  lun_id = v_lun_id;
END; ';


ALTER FUNCTION public.getdisklunmapbylunid(v_lun_id character varying) OWNER TO engine;

--
-- Name: getdisksvmguid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getdisksvmguid(v_vm_guid uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF all_disks
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT all_disks.*
      FROM all_disks
      LEFT JOIN vm_device on vm_device.device_id = all_disks.image_group_id
      WHERE vm_device.vm_id = v_vm_guid
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_disk_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = all_disks.disk_id));

END; ';


ALTER FUNCTION public.getdisksvmguid(v_vm_guid uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getelementidsbyidandgroups(uuid, text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getelementidsbyidandgroups(v_id uuid, v_group_ids text) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
   DECLARE
   SWV_Rs idUuidType;
BEGIN
   BEGIN
      CREATE GLOBAL TEMPORARY TABLE tt_LDAP_ELEMENT_IDS
      (
         id UUID
      ) WITH OIDS;
      exception when others then
         truncate table tt_LDAP_ELEMENT_IDS;
   END;
   insert INTO tt_LDAP_ELEMENT_IDS
   select ID from fnsplitteruuid(v_group_ids)
   UNION
   select v_id
   UNION
   -- user is also member of ''Everyone''
   select ''EEE00000-0000-0000-0000-123456789EEE'';
   FOR SWV_Rs IN(SELECT * FROM  tt_LDAP_ELEMENT_IDS) LOOP
      RETURN NEXT SWV_Rs;
   END LOOP;
   RETURN;
END; ';


ALTER FUNCTION public.getelementidsbyidandgroups(v_id uuid, v_group_ids text) OWNER TO engine;

--
-- Name: getevent_subscriberbysubscriber_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getevent_subscriberbysubscriber_id(v_subscriber_id uuid) RETURNS SETOF event_subscriber
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM event_subscriber
   WHERE subscriber_id = v_subscriber_id;

END; ';


ALTER FUNCTION public.getevent_subscriberbysubscriber_id(v_subscriber_id uuid) OWNER TO engine;

--
-- Name: geteventmapbyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION geteventmapbyname(v_event_name character varying) RETURNS SETOF event_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      from event_map
      where event_up_name = v_event_name;
END; ';


ALTER FUNCTION public.geteventmapbyname(v_event_name character varying) OWNER TO engine;

--
-- Name: geteventnotificationmethodbyid(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION geteventnotificationmethodbyid(v_method_id integer) RETURNS SETOF event_notification_methods
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      from event_notification_methods
      where method_id = v_method_id;
END; ';


ALTER FUNCTION public.geteventnotificationmethodbyid(v_method_id integer) OWNER TO engine;

--
-- Name: geteventnotificationmethodbytype(character); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION geteventnotificationmethodbytype(v_method_type character) RETURNS SETOF event_notification_methods
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      from event_notification_methods
      where method_type = v_method_type;
END; ';


ALTER FUNCTION public.geteventnotificationmethodbytype(v_method_type character) OWNER TO engine;

--
-- Name: getfailingstorage_domains(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getfailingstorage_domains() RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY
    SELECT * FROM storage_domains WHERE recoverable AND status = 4; --inactive
END; ';


ALTER FUNCTION public.getfailingstorage_domains() OWNER TO engine;

--
-- Name: getfailingvdss(); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getfailingvdss() RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY
    SELECT * FROM vds WHERE recoverable AND status = 10; --non operational
END; ';


ALTER FUNCTION public.getfailingvdss() OWNER TO engine;

--
-- Name: getforroleandadelementandobject_wgroupcheck(uuid, uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getforroleandadelementandobject_wgroupcheck(v_role_id uuid, v_ad_element_id uuid, v_object_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE role_id = v_role_id and object_id = v_object_id and ad_element_id in (
         select id from getUserAndGroupsById(v_ad_element_id));
END; ';


ALTER FUNCTION public.getforroleandadelementandobject_wgroupcheck(v_role_id uuid, v_ad_element_id uuid, v_object_id uuid) OWNER TO engine;

--
-- Name: getglobalids(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getglobalids(v_name character varying) RETURNS uuid
    LANGUAGE plpgsql IMMUTABLE
    AS '
   DECLARE
   v_id  UUID;
BEGIN
   if (v_name = ''system'') then
      v_id := ''AAA00000-0000-0000-0000-123456789AAA'';
   elsif (v_name = ''everyone'') then
      v_id := ''EEE00000-0000-0000-0000-123456789EEE'';
   -- bottom is an object which all the objects in the system are its parents
   -- useful to denote we want all objects when checking for permissions
   elsif (v_name = ''bottom'') then
      v_id := ''BBB00000-0000-0000-0000-123456789BBB'';
   end if;
   return  v_id;
END; ';


ALTER FUNCTION public.getglobalids(v_name character varying) OWNER TO engine;

--
-- Name: getglusterbrickbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getglusterbrickbyid(v_id uuid) RETURNS SETOF gluster_volume_bricks
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM gluster_volume_bricks
    WHERE id = v_id;
END; ';


ALTER FUNCTION public.getglusterbrickbyid(v_id uuid) OWNER TO engine;

--
-- Name: gluster_volume_options; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE gluster_volume_options (
    volume_id uuid NOT NULL,
    option_key character varying(8192) NOT NULL,
    option_val character varying(8192) NOT NULL,
    id uuid NOT NULL
);


ALTER TABLE public.gluster_volume_options OWNER TO engine;

--
-- Name: getglusteroptionbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getglusteroptionbyid(v_id uuid) RETURNS SETOF gluster_volume_options
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM gluster_volume_options
    WHERE id = v_id;
END; ';


ALTER FUNCTION public.getglusteroptionbyid(v_id uuid) OWNER TO engine;

--
-- Name: getglustervolumebricksbyserverguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getglustervolumebricksbyserverguid(v_server_id uuid) RETURNS SETOF gluster_volume_bricks
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT *
FROM  gluster_volume_bricks
WHERE server_id = v_server_id
ORDER BY brick_order;
END; ';


ALTER FUNCTION public.getglustervolumebricksbyserverguid(v_server_id uuid) OWNER TO engine;

--
-- Name: gluster_volumes; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE gluster_volumes (
    id uuid NOT NULL,
    cluster_id uuid NOT NULL,
    vol_name character varying(1000) NOT NULL,
    vol_type character varying(32) NOT NULL,
    status character varying(32) NOT NULL,
    replica_count integer DEFAULT 0 NOT NULL,
    stripe_count integer DEFAULT 0 NOT NULL,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone NOT NULL,
    _update_date timestamp with time zone
);


ALTER TABLE public.gluster_volumes OWNER TO engine;

--
-- Name: getglustervolumebyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getglustervolumebyid(v_volume_id uuid) RETURNS SETOF gluster_volumes
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM gluster_volumes
    WHERE id = v_volume_id;
END; ';


ALTER FUNCTION public.getglustervolumebyid(v_volume_id uuid) OWNER TO engine;

--
-- Name: getglustervolumebyname(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getglustervolumebyname(v_cluster_id uuid, v_vol_name character varying) RETURNS SETOF gluster_volumes
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM gluster_volumes
    WHERE cluster_id = v_cluster_id and vol_name = v_vol_name;
END; ';


ALTER FUNCTION public.getglustervolumebyname(v_cluster_id uuid, v_vol_name character varying) OWNER TO engine;

--
-- Name: getglustervolumesbyclusterguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getglustervolumesbyclusterguid(v_cluster_id uuid) RETURNS SETOF gluster_volumes
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM  gluster_volumes
    WHERE cluster_id = v_cluster_id;
END; ';


ALTER FUNCTION public.getglustervolumesbyclusterguid(v_cluster_id uuid) OWNER TO engine;

--
-- Name: getimage_storage_domain_mapbyimage_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getimage_storage_domain_mapbyimage_id(v_image_id uuid) RETURNS SETOF image_storage_domain_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM image_storage_domain_map
   WHERE image_id = v_image_id;

END; ';


ALTER FUNCTION public.getimage_storage_domain_mapbyimage_id(v_image_id uuid) OWNER TO engine;

--
-- Name: getimage_storage_domain_mapbystorage_domain_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getimage_storage_domain_mapbystorage_domain_id(v_storage_domain_id uuid) RETURNS SETOF image_storage_domain_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM image_storage_domain_map
   WHERE storage_domain_id = v_storage_domain_id;

END; ';


ALTER FUNCTION public.getimage_storage_domain_mapbystorage_domain_id(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: vm_images_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_images_view AS
    SELECT array_to_string(array_agg(images_storage_domain_view.storage_id), ','::text) AS storage_id, array_to_string(array_agg(images_storage_domain_view.storage_path), ','::text) AS storage_path, array_to_string(array_agg(images_storage_domain_view.storage_name), ','::text) AS storage_name, images_storage_domain_view.storage_pool_id, images_storage_domain_view.image_guid, images_storage_domain_view.creation_date, disk_image_dynamic.actual_size, disk_image_dynamic.read_rate, disk_image_dynamic.read_latency_seconds, disk_image_dynamic.write_latency_seconds, disk_image_dynamic.flush_latency_seconds, disk_image_dynamic.write_rate, images_storage_domain_view.size, images_storage_domain_view.it_guid, images_storage_domain_view.description, images_storage_domain_view.parentid, images_storage_domain_view.imagestatus, images_storage_domain_view.lastmodified, images_storage_domain_view.app_list, images_storage_domain_view.vm_snapshot_id, images_storage_domain_view.volume_type, images_storage_domain_view.image_group_id, images_storage_domain_view.active, images_storage_domain_view.volume_format, images_storage_domain_view.disk_interface, images_storage_domain_view.boot, images_storage_domain_view.wipe_after_delete, images_storage_domain_view.propagate_errors, images_storage_domain_view.entity_type, images_storage_domain_view.number_of_vms, images_storage_domain_view.vm_names, images_storage_domain_view.quota_id, images_storage_domain_view.quota_name, images_storage_domain_view.quota_enforcement_type, images_storage_domain_view.disk_id, images_storage_domain_view.disk_alias, images_storage_domain_view.disk_description, images_storage_domain_view.shareable FROM (images_storage_domain_view JOIN disk_image_dynamic ON ((images_storage_domain_view.image_guid = disk_image_dynamic.image_id))) WHERE (images_storage_domain_view.active = true) GROUP BY images_storage_domain_view.storage_pool_id, images_storage_domain_view.image_guid, images_storage_domain_view.creation_date, disk_image_dynamic.actual_size, disk_image_dynamic.read_rate, disk_image_dynamic.read_latency_seconds, disk_image_dynamic.write_latency_seconds, disk_image_dynamic.flush_latency_seconds, disk_image_dynamic.write_rate, images_storage_domain_view.size, images_storage_domain_view.it_guid, images_storage_domain_view.description, images_storage_domain_view.parentid, images_storage_domain_view.imagestatus, images_storage_domain_view.lastmodified, images_storage_domain_view.app_list, images_storage_domain_view.vm_snapshot_id, images_storage_domain_view.volume_type, images_storage_domain_view.image_group_id, images_storage_domain_view.active, images_storage_domain_view.volume_format, images_storage_domain_view.disk_interface, images_storage_domain_view.boot, images_storage_domain_view.wipe_after_delete, images_storage_domain_view.propagate_errors, images_storage_domain_view.number_of_vms, images_storage_domain_view.entity_type, images_storage_domain_view.vm_names, images_storage_domain_view.quota_id, images_storage_domain_view.quota_name, images_storage_domain_view.quota_enforcement_type, images_storage_domain_view.disk_id, images_storage_domain_view.disk_alias, images_storage_domain_view.disk_description, images_storage_domain_view.shareable;


ALTER TABLE public.vm_images_view OWNER TO engine;

--
-- Name: getimagebyimageguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getimagebyimageguid(v_image_guid uuid) RETURNS SETOF vm_images_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM vm_images_view
      WHERE image_guid = v_image_guid;
END; ';


ALTER FUNCTION public.getimagebyimageguid(v_image_guid uuid) OWNER TO engine;

--
-- Name: getimagebyimageid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getimagebyimageid(v_image_guid uuid) RETURNS SETOF images
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   images
    WHERE  image_guid = v_image_guid;
END; ';


ALTER FUNCTION public.getimagebyimageid(v_image_guid uuid) OWNER TO engine;

--
-- Name: getimagebystorageidandtemplateid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getimagebystorageidandtemplateid(v_storage_id uuid, v_template_id uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
	  IF v_template_id IS NULL then
           RETURN QUERY SELECT images_storage_domain_view.*
           FROM images_storage_domain_view 
           WHERE images_storage_domain_view.storage_id = v_storage_id AND images_storage_domain_view.entity_type::text = ''TEMPLATE''::text;
      ELSE
           RETURN QUERY SELECT images_storage_domain_view.*
           FROM images_storage_domain_view
           JOIN vm_device ON vm_device.device_id = images_storage_domain_view.disk_id
           WHERE images_storage_domain_view.storage_id = v_storage_id
             AND vm_device.vm_id = v_template_id
             AND images_storage_domain_view.entity_type::text = ''TEMPLATE''::text;
      END IF;     
END; ';


ALTER FUNCTION public.getimagebystorageidandtemplateid(v_storage_id uuid, v_template_id uuid) OWNER TO engine;

--
-- Name: getimagesbyquotaid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getimagesbyquotaid(v_quota_id uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM images_storage_domain_view
      WHERE quota_id = v_quota_id;

END; ';


ALTER FUNCTION public.getimagesbyquotaid(v_quota_id uuid) OWNER TO engine;

--
-- Name: getimageswhichhavenodisk(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getimageswhichhavenodisk(v_vm_id uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT i.*
      FROM   images_storage_domain_view i
      JOIN   snapshots s ON (i.vm_snapshot_id = s.snapshot_id)
      WHERE  s.vm_id = v_vm_id
      AND    NOT EXISTS (
          SELECT 1
          FROM   base_disks d
          WHERE  d.disk_id = i.image_group_id);
END; ';


ALTER FUNCTION public.getimageswhichhavenodisk(v_vm_id uuid) OWNER TO engine;

--
-- Name: vds_interface; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vds_interface (
    id uuid NOT NULL,
    name character varying(50) NOT NULL,
    network_name character varying(50),
    vds_id uuid,
    mac_addr character varying(59),
    is_bond boolean DEFAULT false,
    bond_name character varying(50),
    bond_type integer,
    bond_opts character varying(4000),
    vlan_id integer,
    speed integer,
    addr character varying(20),
    subnet character varying(20),
    gateway character varying(20),
    boot_protocol integer,
    type integer DEFAULT 0,
    _create_date timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    _update_date timestamp with time zone,
    mtu integer,
    bridged boolean DEFAULT true NOT NULL
);


ALTER TABLE public.vds_interface OWNER TO engine;

--
-- Name: vds_interface_statistics; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vds_interface_statistics (
    id uuid NOT NULL,
    vds_id uuid,
    rx_rate numeric(18,0),
    tx_rate numeric(18,0),
    rx_drop numeric(18,0),
    tx_drop numeric(18,0),
    iface_status integer
);


ALTER TABLE public.vds_interface_statistics OWNER TO engine;

--
-- Name: vds_interface_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vds_interface_view AS
    SELECT vds_interface_statistics.rx_rate, vds_interface_statistics.tx_rate, vds_interface_statistics.rx_drop, vds_interface_statistics.tx_drop, vds_interface_statistics.iface_status, vds_interface.type, vds_interface.gateway, vds_interface.subnet, vds_interface.addr, vds_interface.speed, vds_interface.vlan_id, vds_interface.bond_type, vds_interface.bond_name, vds_interface.is_bond, vds_interface.bond_opts, vds_interface.mac_addr, vds_interface.network_name, vds_interface.name, vds_static.vds_id, vds_static.vds_name, vds_interface.id, vds_interface.boot_protocol, vds_interface.mtu, vds_interface.bridged, 1 AS is_vds FROM ((vds_interface_statistics JOIN vds_interface ON ((vds_interface_statistics.id = vds_interface.id))) JOIN vds_static ON ((vds_interface.vds_id = vds_static.vds_id)));


ALTER TABLE public.vds_interface_view OWNER TO engine;

--
-- Name: getinterface_viewbyvds_id(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getinterface_viewbyvds_id(v_vds_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds_interface_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM vds_interface_view
   WHERE vds_id = v_vds_id
   AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                     FROM   user_vds_permissions_view
                                     WHERE  user_id = v_user_id AND entity_id = v_vds_id));

END; ';


ALTER FUNCTION public.getinterface_viewbyvds_id(v_vds_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getjobbyjobid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getjobbyjobid(v_job_id uuid) RETURNS SETOF job
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT job.*
    FROM JOB
    WHERE job_id = v_job_id;
END; ';


ALTER FUNCTION public.getjobbyjobid(v_job_id uuid) OWNER TO engine;

--
-- Name: getjobsbycorrelationid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getjobsbycorrelationid(v_correlation_id character varying) RETURNS SETOF job
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT job.*
    FROM JOB
    WHERE correlation_id = v_correlation_id;
END; ';


ALTER FUNCTION public.getjobsbycorrelationid(v_correlation_id character varying) OWNER TO engine;

--
-- Name: getjobsbyoffsetandpagesize(integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getjobsbyoffsetandpagesize(v_position integer, v_page_size integer) RETURNS SETOF job
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    (SELECT job.*
    FROM JOB
    WHERE status = ''STARTED''
    ORDER BY last_update_time desc)
    UNION ALL
    (SELECT job.*
    FROM JOB
    WHERE status not in (''STARTED'',''UNKNOWN'')
    ORDER BY last_update_time desc)
    OFFSET v_position LIMIT v_page_size;
END; ';


ALTER FUNCTION public.getjobsbyoffsetandpagesize(v_position integer, v_page_size integer) OWNER TO engine;

--
-- Name: job_subject_entity; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE job_subject_entity (
    job_id uuid NOT NULL,
    entity_id uuid NOT NULL,
    entity_type character varying(32) NOT NULL
);


ALTER TABLE public.job_subject_entity OWNER TO engine;

--
-- Name: getjobsubjectentitybyjobid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getjobsubjectentitybyjobid(v_job_id uuid) RETURNS SETOF job_subject_entity
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT job_subject_entity.*
    FROM job_subject_entity
    WHERE job_id = v_job_id;
END; ';


ALTER FUNCTION public.getjobsubjectentitybyjobid(v_job_id uuid) OWNER TO engine;

--
-- Name: getlun_storage_server_connection_mapbylunbystorage_server_conn(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getlun_storage_server_connection_mapbylunbystorage_server_conn(v_lun_id character varying, v_storage_server_connection character varying) RETURNS SETOF lun_storage_server_connection_map
    LANGUAGE plpgsql
    AS '
BEGIN
	
   RETURN QUERY SELECT *
   FROM LUN_storage_server_connection_map lUN_storage_server_connection_map
   WHERE LUN_id = v_LUN_id AND storage_server_connection = v_storage_server_connection;

END; ';


ALTER FUNCTION public.getlun_storage_server_connection_mapbylunbystorage_server_conn(v_lun_id character varying, v_storage_server_connection character varying) OWNER TO engine;

--
-- Name: getlunbylunid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getlunbylunid(v_lun_id character varying) RETURNS SETOF luns_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM luns_view
   WHERE LUN_id = v_LUN_id; 

END; ';


ALTER FUNCTION public.getlunbylunid(v_lun_id character varying) OWNER TO engine;

--
-- Name: getlunsbystorage_server_connection(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getlunsbystorage_server_connection(v_storage_server_connection character varying) RETURNS SETOF luns_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT luns_view.*
   FROM luns_view INNER JOIN
   LUN_storage_server_connection_map
   ON LUN_storage_server_connection_map.LUN_id = luns_view.LUN_id
   WHERE LUN_storage_server_connection_map.storage_server_connection = v_storage_server_connection;

END; ';


ALTER FUNCTION public.getlunsbystorage_server_connection(v_storage_server_connection character varying) OWNER TO engine;

--
-- Name: getlunsbyvolumegroupid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getlunsbyvolumegroupid(v_volume_group_id character varying) RETURNS SETOF luns_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM luns_view
   WHERE volume_group_id = v_volume_group_id; 

END; ';


ALTER FUNCTION public.getlunsbyvolumegroupid(v_volume_group_id character varying) OWNER TO engine;

--
-- Name: getnamesofvmstaticdedicatedtovds(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getnamesofvmstaticdedicatedtovds(v_vds_id uuid) RETURNS SETOF getnamesofvmstaticdedicatedtovds_rs
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY
      SELECT vm_name
      FROM vm_static
      WHERE dedicated_vm_for_vds = v_vds_id
      AND   migration_support = 2
      AND   entity_type = ''VM'';

END; ';


ALTER FUNCTION public.getnamesofvmstaticdedicatedtovds(v_vds_id uuid) OWNER TO engine;

--
-- Name: getnetwork_clusterbycluster_idandbynetwork_id(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getnetwork_clusterbycluster_idandbynetwork_id(v_cluster_id uuid, v_network_id uuid) RETURNS SETOF network_cluster
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM network_cluster
   WHERE cluster_id = v_cluster_id AND network_id = v_network_id;

END; ';


ALTER FUNCTION public.getnetwork_clusterbycluster_idandbynetwork_id(v_cluster_id uuid, v_network_id uuid) OWNER TO engine;

--
-- Name: getnetworkbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getnetworkbyid(v_id uuid) RETURNS SETOF network
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT *
   FROM network
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getnetworkbyid(v_id uuid) OWNER TO engine;

--
-- Name: getnetworkbyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getnetworkbyname(v_networkname character varying) RETURNS SETOF network
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM network
   WHERE name = v_networkName;

END; ';


ALTER FUNCTION public.getnetworkbyname(v_networkname character varying) OWNER TO engine;

--
-- Name: getnfsstorage_server_connectionsbystoragepoolid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getnfsstorage_server_connectionsbystoragepoolid(v_storage_pool_id uuid) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT distinct storage_server_connections.*
   FROM    storage_server_connections storage_server_connections
   INNER JOIN
   storage_domain_static_view ON
   storage_server_connections.id = storage_domain_static_view.storage
   WHERE     (storage_domain_static_view.storage_pool_id = v_storage_pool_id);
END; ';


ALTER FUNCTION public.getnfsstorage_server_connectionsbystoragepoolid(v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getnvmtagsbyvmid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getnvmtagsbyvmid(v_vm_id uuid) RETURNS SETOF tags_vm_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY select * from tags_vm_map
      where tags_vm_map.vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.getnvmtagsbyvmid(v_vm_id uuid) OWNER TO engine;

--
-- Name: getnvmtagsbyvmidanddefaulttag(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getnvmtagsbyvmidanddefaulttag(v_vm_id uuid) RETURNS SETOF tags_vm_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY select tags_vm_map.* from tags_vm_map
      inner join tags on tags.tag_id = tags_vm_map.tag_id
      where tags_vm_map.vm_id = v_vm_id
      and tags.type = 1;
END; ';


ALTER FUNCTION public.getnvmtagsbyvmidanddefaulttag(v_vm_id uuid) OWNER TO engine;

--
-- Name: getoptionsbyglustervolumeguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getoptionsbyglustervolumeguid(v_volume_id uuid) RETURNS SETOF gluster_volume_options
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM  gluster_volume_options
    WHERE volume_id = v_volume_id;
END; ';


ALTER FUNCTION public.getoptionsbyglustervolumeguid(v_volume_id uuid) OWNER TO engine;

--
-- Name: getorderedvmguidsforrunmultipleactions(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getorderedvmguidsforrunmultipleactions(v_vm_guids character varying) RETURNS SETOF getorderedvmguidsforrunmultipleactions_rs
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_ordered_guids GetOrderedVmGuidsForRunMultipleActions_rs;
BEGIN
   FOR v_ordered_guids IN EXECUTE ''SELECT vm_guid from vm_static where vm_guid in( '' || v_vm_guids || '' ) AND entity_type = ''''VM''''  order by auto_startup desc,priority desc, migration_support desc'' LOOP
      RETURN NEXT v_ordered_guids;
   END LOOP;
	
END; ';


ALTER FUNCTION public.getorderedvmguidsforrunmultipleactions(v_vm_guids character varying) OWNER TO engine;

--
-- Name: getpermissionbyroleid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionbyroleid(v_role_id uuid) RETURNS SETOF permissions
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   from permissions
   where role_id = v_role_id;
END; ';


ALTER FUNCTION public.getpermissionbyroleid(v_role_id uuid) OWNER TO engine;

--
-- Name: getpermissionsbyadelementid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionsbyadelementid(v_ad_element_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE 
   (permissions_view.ad_element_id = v_ad_element_id
    OR    ad_element_id IN (SELECT id FROM getUserAndGroupsById(v_ad_element_id)))
   AND (NOT v_is_filtered OR EXISTS (SELECT 1 FROM user_permissions_permissions_view WHERE user_id = v_user_id));

END; ';


ALTER FUNCTION public.getpermissionsbyadelementid(v_ad_element_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getpermissionsbyentityid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionsbyentityid(v_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE object_id = v_id
   AND   (NOT v_is_filtered OR EXISTS (SELECT 1
                                       FROM   GetUserPermissionsByEntityId(v_id, v_user_id, v_is_filtered)));
END; ';


ALTER FUNCTION public.getpermissionsbyentityid(v_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getpermissionsbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionsbyid(v_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getpermissionsbyid(v_id uuid) OWNER TO engine;

--
-- Name: getpermissionsbyroleid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionsbyroleid(v_role_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE role_id = v_role_id;

END; ';


ALTER FUNCTION public.getpermissionsbyroleid(v_role_id uuid) OWNER TO engine;

--
-- Name: getpermissionsbyroleidandadelementid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionsbyroleidandadelementid(v_role_id uuid, v_ad_element_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE role_id = v_role_id and ad_element_id = v_ad_element_id;

END; ';


ALTER FUNCTION public.getpermissionsbyroleidandadelementid(v_role_id uuid, v_ad_element_id uuid) OWNER TO engine;

--
-- Name: getpermissionsbyroleidandadelementidandobjectid(uuid, uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionsbyroleidandadelementidandobjectid(v_role_id uuid, v_ad_element_id uuid, v_object_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE role_id = v_role_id and ad_element_id = v_ad_element_id and object_id = v_object_id;

END; ';


ALTER FUNCTION public.getpermissionsbyroleidandadelementidandobjectid(v_role_id uuid, v_ad_element_id uuid, v_object_id uuid) OWNER TO engine;

--
-- Name: getpermissionsbyroleidandobjectid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionsbyroleidandobjectid(v_role_id uuid, v_object_id uuid) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view
   WHERE role_id = v_role_id and object_id = v_object_id;

END; ';


ALTER FUNCTION public.getpermissionsbyroleidandobjectid(v_role_id uuid, v_object_id uuid) OWNER TO engine;

--
-- Name: getpermissionstreebyentityid(uuid, integer, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getpermissionstreebyentityid(v_id uuid, v_object_type_id integer, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM   permissions_view p
   WHERE  object_id in(select id from  fn_get_entity_parents(v_id,v_object_type_id))
   AND    (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_flat_groups u
                                        WHERE  p.ad_element_id = u.granted_id
                                        AND    u.user_id       = v_user_id));

END; ';


ALTER FUNCTION public.getpermissionstreebyentityid(v_id uuid, v_object_type_id integer, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getquotabyadelementid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotabyadelementid(v_ad_element_id uuid, v_storage_pool_id uuid) RETURNS SETOF quota_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT * FROM quota_view WHERE quota_view.quota_id IN
   (SELECT object_id
    FROM PERMISSIONS
    WHERE object_type_id = 17
    AND role_id in (SELECT role_id FROM ROLES_groups where action_group_id = 901)
    AND ad_element_id = v_ad_element_id)
    AND (v_storage_pool_id = quota_view.storage_pool_id or v_storage_pool_id IS NULL);
  END; ';


ALTER FUNCTION public.getquotabyadelementid(v_ad_element_id uuid, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: quota_limitation; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE quota_limitation (
    id uuid NOT NULL,
    quota_id uuid NOT NULL,
    storage_id uuid,
    vds_group_id uuid,
    virtual_cpu integer,
    mem_size_mb bigint,
    storage_size_gb bigint
);


ALTER TABLE public.quota_limitation OWNER TO engine;

--
-- Name: quota_global_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW quota_global_view AS
    SELECT q_limit.quota_id, q.storage_pool_id, storage_pool.name AS storage_pool_name, q.quota_name, q.description, q.threshold_vds_group_percentage, q.threshold_storage_percentage, q.grace_vds_group_percentage, q.grace_storage_percentage, q_limit.virtual_cpu, (calculatevdsgroupusage(q_limit.quota_id, NULL::uuid)).virtual_cpu_usage AS virtual_cpu_usage, q_limit.mem_size_mb, (calculatevdsgroupusage(q_limit.quota_id, NULL::uuid)).mem_size_mb_usage AS mem_size_mb_usage, q_limit.storage_size_gb, calculatestorageusage(q_limit.quota_id, NULL::uuid) AS storage_size_gb_usage, storage_pool.quota_enforcement_type FROM storage_pool, (quota q LEFT JOIN quota_limitation q_limit ON ((q_limit.quota_id = q.id))) WHERE (((storage_pool.id = q.storage_pool_id) AND (q_limit.vds_group_id IS NULL)) AND (q_limit.storage_id IS NULL));


ALTER TABLE public.quota_global_view OWNER TO engine;

--
-- Name: getquotabyquotaguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotabyquotaguid(v_id uuid) RETURNS SETOF quota_global_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM quota_global_view
   WHERE quota_id = v_id;
END; ';


ALTER FUNCTION public.getquotabyquotaguid(v_id uuid) OWNER TO engine;

--
-- Name: getquotabyquotaname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotabyquotaname(v_quota_name character varying) RETURNS SETOF quota_global_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM quota_global_view
   WHERE quota_name = v_quota_name;
END; ';


ALTER FUNCTION public.getquotabyquotaname(v_quota_name character varying) OWNER TO engine;

--
-- Name: getquotabystoragepoolguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotabystoragepoolguid(v_storage_pool_id uuid) RETURNS SETOF quota_global_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM  quota_global_view
   WHERE (storage_pool_id = v_storage_pool_id or v_storage_pool_id IS NULL);
END; ';


ALTER FUNCTION public.getquotabystoragepoolguid(v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: quota_storage_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW quota_storage_view AS
    SELECT q_limit.id AS quota_storage_id, q_limit.quota_id, q_limit.storage_id, storage_domain_static.storage_name, q_limit.storage_size_gb, calculatestorageusage(q_limit.quota_id, q_limit.storage_id) AS storage_size_gb_usage FROM quota_limitation q_limit, quota q, storage_domain_static WHERE ((((q_limit.quota_id = q.id) AND (q_limit.vds_group_id IS NULL)) AND (q_limit.storage_id IS NOT NULL)) AND (storage_domain_static.id = q_limit.storage_id));


ALTER TABLE public.quota_storage_view OWNER TO engine;

--
-- Name: getquotastoragebyquotaguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotastoragebyquotaguid(v_id uuid) RETURNS SETOF quota_storage_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM  quota_storage_view
   WHERE quota_id = v_id;
END; ';


ALTER FUNCTION public.getquotastoragebyquotaguid(v_id uuid) OWNER TO engine;

--
-- Name: getquotastoragebystorageguid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotastoragebystorageguid(v_storage_id uuid, v_id uuid, v_allow_empty boolean) RETURNS SETOF quota_storage_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM
   (SELECT  COALESCE(q_storage_view.quota_storage_id, q_g_view.quota_id) as quota_storage_id,
            q_g_view.quota_id as quota_id,
            q_storage_view.storage_id,
            q_storage_view.storage_name,
            COALESCE(q_storage_view.storage_size_gb, q_g_view.storage_size_gb) as storage_size_gb,
            COALESCE(q_storage_view.storage_size_gb_usage, q_g_view.storage_size_gb_usage) as storage_size_gb_usage
    FROM  quota_global_view q_g_view 
    LEFT OUTER JOIN quota_storage_view q_storage_view ON q_g_view.quota_id = q_storage_view.quota_id
    AND  (v_storage_id = q_storage_view.storage_id OR v_storage_id IS NULL)
   WHERE q_g_view.quota_id = v_id) sub
   WHERE (v_allow_empty OR storage_size_gb IS NOT NULL);
END; ';


ALTER FUNCTION public.getquotastoragebystorageguid(v_storage_id uuid, v_id uuid, v_allow_empty boolean) OWNER TO engine;

--
-- Name: quota_vds_group_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW quota_vds_group_view AS
    SELECT q_limit.id AS quota_vds_group_id, q_limit.quota_id, q_limit.vds_group_id, vds_groups.name AS vds_group_name, q_limit.virtual_cpu, (calculatevdsgroupusage(q_limit.quota_id, q_limit.vds_group_id)).virtual_cpu_usage AS virtual_cpu_usage, q_limit.mem_size_mb, (calculatevdsgroupusage(q_limit.quota_id, q_limit.vds_group_id)).mem_size_mb_usage AS mem_size_mb_usage FROM quota_limitation q_limit, quota q, vds_groups WHERE ((((q_limit.quota_id = q.id) AND (q_limit.vds_group_id IS NOT NULL)) AND (q_limit.storage_id IS NULL)) AND (vds_groups.vds_group_id = q_limit.vds_group_id));


ALTER TABLE public.quota_vds_group_view OWNER TO engine;

--
-- Name: getquotavdsgroupbyquotaguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotavdsgroupbyquotaguid(v_id uuid) RETURNS SETOF quota_vds_group_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT quota_vds_group_view.*
   FROM  quota_vds_group_view
   WHERE quota_id = v_id;
END; ';


ALTER FUNCTION public.getquotavdsgroupbyquotaguid(v_id uuid) OWNER TO engine;

--
-- Name: getquotavdsgroupbyvdsgroupguid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getquotavdsgroupbyvdsgroupguid(v_vds_group_id uuid, v_id uuid, v_allow_empty boolean) RETURNS SETOF quota_vds_group_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM (SELECT COALESCE(q_vds_view.quota_vds_group_id, q_g_view.quota_id) as quota_vds_group_id,
                q_g_view.quota_id as quota_id,
                q_vds_view.vds_group_id as vds_group_id,
                q_vds_view.vds_group_name as vds_group_name,
                COALESCE(q_vds_view.virtual_cpu,q_g_view.virtual_cpu) as virtual_cpu,
                COALESCE(q_vds_view.virtual_cpu_usage, q_g_view.virtual_cpu_usage) as virtual_cpu_usage,
                COALESCE(q_vds_view.mem_size_mb,q_g_view.mem_size_mb) as mem_size_mb,
                COALESCE(q_vds_view.mem_size_mb_usage, q_g_view.mem_size_mb_usage) as mem_size_mb_usage
         FROM   quota_global_view q_g_view 
         LEFT OUTER JOIN quota_vds_group_view q_vds_view ON q_g_view.quota_id = q_vds_view.quota_id
         AND   (v_vds_group_id = q_vds_view.vds_group_id OR v_vds_group_id IS NULL)
         WHERE q_g_view.quota_id = v_id) sub
   WHERE v_allow_empty OR virtual_cpu IS NOT NULL OR mem_size_mb IS NOT NULL;
END; ';


ALTER FUNCTION public.getquotavdsgroupbyvdsgroupguid(v_vds_group_id uuid, v_id uuid, v_allow_empty boolean) OWNER TO engine;

--
-- Name: repo_file_meta_data; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE repo_file_meta_data (
    repo_domain_id uuid NOT NULL,
    repo_file_name character varying(256) NOT NULL,
    size bigint DEFAULT 0,
    date_created timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone,
    last_refreshed bigint DEFAULT 0,
    file_type integer DEFAULT 0
);


ALTER TABLE public.repo_file_meta_data OWNER TO engine;

--
-- Name: getrepo_files_by_storage_domain(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getrepo_files_by_storage_domain(v_storage_domain_id uuid, v_file_type integer) RETURNS SETOF repo_file_meta_data
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT repo_file_meta_data.*
   FROM repo_file_meta_data
   WHERE repo_domain_id = v_storage_domain_id
   AND repo_file_meta_data.file_type = v_file_type
   ORDER BY repo_file_meta_data.last_refreshed;
END; ';


ALTER FUNCTION public.getrepo_files_by_storage_domain(v_storage_domain_id uuid, v_file_type integer) OWNER TO engine;

--
-- Name: storage_domain_file_repos; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW storage_domain_file_repos AS
    SELECT storage_domain_static.id AS storage_domain_id, storage_domain_static.storage_domain_type, storage_pool_iso_map.storage_pool_id, storage_pool_iso_map.status AS storage_domain_status, repo_file_meta_data.repo_file_name, repo_file_meta_data.size, repo_file_meta_data.date_created, repo_file_meta_data.last_refreshed, repo_file_meta_data.file_type, vds_dynamic.status AS vds_status, storage_pool.status AS storage_pool_status FROM ((((storage_domain_static JOIN storage_pool_iso_map ON ((storage_domain_static.id = storage_pool_iso_map.storage_id))) JOIN storage_pool ON ((storage_pool.id = storage_pool_iso_map.storage_pool_id))) JOIN vds_dynamic ON ((vds_dynamic.vds_id = storage_pool.spm_vds_id))) LEFT JOIN repo_file_meta_data ON ((storage_pool_iso_map.storage_id = repo_file_meta_data.repo_domain_id)));


ALTER TABLE public.storage_domain_file_repos OWNER TO engine;

--
-- Name: getrepo_files_by_storage_domain_and_storage_pool(uuid, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getrepo_files_by_storage_domain_and_storage_pool(v_storage_pool_id uuid, v_storage_domain_id uuid, v_file_type integer) RETURNS SETOF storage_domain_file_repos
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT storage_domain_file_repos.*
   FROM storage_domain_file_repos
   WHERE storage_domain_id = v_storage_domain_id
   AND storage_pool_id = v_storage_pool_id
   AND storage_domain_file_repos.file_type = v_file_type
   ORDER BY storage_domain_file_repos.last_refreshed;
END; ';


ALTER FUNCTION public.getrepo_files_by_storage_domain_and_storage_pool(v_storage_pool_id uuid, v_storage_domain_id uuid, v_file_type integer) OWNER TO engine;

--
-- Name: getrepo_files_in_all_storage_pools(integer, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getrepo_files_in_all_storage_pools(v_storage_domain_type integer, v_storage_pool_status integer, v_vds_status integer, v_storage_domain_status integer) RETURNS SETOF getrepo_files_in_all_storage_pools_rs
    LANGUAGE plpgsql
    AS '
BEGIN
 RETURN QUERY SELECT distinct b.storage_domain_id,c.last_refreshed,b.file_type
   FROM storage_domain_file_repos b  
   LEFT OUTER JOIN 
   (SELECT storage_domain_id,file_type,min(last_refreshed) as last_refreshed
      FROM storage_domain_file_repos a
   	  Group by storage_domain_id,file_type) as c ON b.storage_domain_id = c.storage_domain_id
                                                 AND b.file_type = c.file_type
   WHERE b.storage_domain_type = v_storage_domain_type
     and b.storage_pool_status = v_storage_pool_status
     and b.storage_domain_status = v_storage_domain_status
	 and b.vds_status = v_vds_status;
END; ';


ALTER FUNCTION public.getrepo_files_in_all_storage_pools(v_storage_domain_type integer, v_storage_pool_status integer, v_vds_status integer, v_storage_domain_status integer) OWNER TO engine;

--
-- Name: getrole_children(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getrole_children(v_role_id uuid) RETURNS SETOF roles_relations
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles_relations
   WHERE role_container_id = v_role_id;

END; ';


ALTER FUNCTION public.getrole_children(v_role_id uuid) OWNER TO engine;

--
-- Name: getroleactiongroupsbyroleid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getroleactiongroupsbyroleid(v_id uuid) RETURNS SETOF roles_groups
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles_groups
   WHERE role_id = v_id;
END; ';


ALTER FUNCTION public.getroleactiongroupsbyroleid(v_id uuid) OWNER TO engine;

--
-- Name: getrolebyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getrolebyname(v_name character varying) RETURNS SETOF roles
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles
   WHERE name = v_name;

END; ';


ALTER FUNCTION public.getrolebyname(v_name character varying) OWNER TO engine;

--
-- Name: getroles_relationsbyrole_container_idandbyrole_id(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getroles_relationsbyrole_container_idandbyrole_id(v_role_container_id uuid, v_role_id uuid) RETURNS SETOF roles_relations
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles_relations
   WHERE role_container_id = v_role_container_id AND role_id = v_role_id;

END; ';


ALTER FUNCTION public.getroles_relationsbyrole_container_idandbyrole_id(v_role_container_id uuid, v_role_id uuid) OWNER TO engine;

--
-- Name: getrolesbyadelementid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getrolesbyadelementid(v_ad_element_id uuid) RETURNS SETOF roles
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT roles.*
   FROM roles
   inner join permissions permissions on roles.id = permissions.role_id
   WHERE ad_element_id = v_ad_element_id;
END; ';


ALTER FUNCTION public.getrolesbyadelementid(v_ad_element_id uuid) OWNER TO engine;

--
-- Name: getrolsbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getrolsbyid(v_id uuid) RETURNS SETOF roles
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM roles
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getrolsbyid(v_id uuid) OWNER TO engine;

--
-- Name: getsnapshotbyguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotbyguid(v_image_guid uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM images_storage_domain_view images_storage_domain_view
      WHERE image_guid = v_image_guid;
END; ';


ALTER FUNCTION public.getsnapshotbyguid(v_image_guid uuid) OWNER TO engine;

--
-- Name: getsnapshotbyparentguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotbyparentguid(v_parent_guid uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM images_storage_domain_view images_storage_domain_view
      WHERE ParentId = v_parent_guid;
END; ';


ALTER FUNCTION public.getsnapshotbyparentguid(v_parent_guid uuid) OWNER TO engine;

--
-- Name: getsnapshotbysnapshotid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotbysnapshotid(v_snapshot_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF snapshots
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   snapshots
    WHERE  snapshot_id = v_snapshot_id AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_vm_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = (SELECT vm_id
                                        FROM snapshots where snapshot_id = v_snapshot_id)));
END; ';


ALTER FUNCTION public.getsnapshotbysnapshotid(v_snapshot_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getsnapshotbyvmidandtype(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotbyvmidandtype(v_vm_id uuid, v_snapshot_type character varying) RETURNS SETOF snapshots
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   snapshots
    WHERE  vm_id = v_vm_id
    AND    snapshot_type = v_snapshot_type
    ORDER BY creation_date ASC
    LIMIT 1;
END; ';


ALTER FUNCTION public.getsnapshotbyvmidandtype(v_vm_id uuid, v_snapshot_type character varying) OWNER TO engine;

--
-- Name: getsnapshotidsbyvmidandtype(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotidsbyvmidandtype(v_vm_id uuid, v_snapshot_type character varying) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT snapshot_id
    FROM   snapshots
    WHERE  vm_id = v_vm_id
    AND    snapshot_type = v_snapshot_type
    ORDER BY creation_date ASC;
END; ';


ALTER FUNCTION public.getsnapshotidsbyvmidandtype(v_vm_id uuid, v_snapshot_type character varying) OWNER TO engine;

--
-- Name: getsnapshotidsbyvmidandtypeandstatus(uuid, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotidsbyvmidandtypeandstatus(v_vm_id uuid, v_snapshot_type character varying, v_status character varying) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT snapshot_id
    FROM   snapshots
    WHERE  vm_id = v_vm_id
    AND    snapshot_type = v_snapshot_type
    AND    status = v_status
    ORDER BY creation_date ASC;
END; ';


ALTER FUNCTION public.getsnapshotidsbyvmidandtypeandstatus(v_vm_id uuid, v_snapshot_type character varying, v_status character varying) OWNER TO engine;

--
-- Name: getsnapshotsbyimagegroupid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotsbyimagegroupid(v_image_group_id uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM images_storage_domain_view images_storage_domain_view
      WHERE image_group_id = v_image_group_id;
END; ';


ALTER FUNCTION public.getsnapshotsbyimagegroupid(v_image_group_id uuid) OWNER TO engine;

--
-- Name: getsnapshotsbystoragedomainid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotsbystoragedomainid(v_storage_domain_id uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM images_storage_domain_view images_storage_domain_view
      WHERE storage_id = v_storage_domain_id;
END; ';


ALTER FUNCTION public.getsnapshotsbystoragedomainid(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: getsnapshotsbyvmsnapshotid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsnapshotsbyvmsnapshotid(v_vm_snapshot_id uuid) RETURNS SETOF images_storage_domain_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM images_storage_domain_view images_storage_domain_view
      WHERE vm_snapshot_id = v_vm_snapshot_id;
END; ';


ALTER FUNCTION public.getsnapshotsbyvmsnapshotid(v_vm_snapshot_id uuid) OWNER TO engine;

--
-- Name: getstepbystepid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstepbystepid(v_step_id uuid) RETURNS SETOF step
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT step.*
    FROM step
    WHERE step_id = v_step_id;
END; ';


ALTER FUNCTION public.getstepbystepid(v_step_id uuid) OWNER TO engine;

--
-- Name: getstepsbyjobid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstepsbyjobid(v_job_id uuid) RETURNS SETOF step
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT step.*
    FROM step
    WHERE job_id = v_job_id
    ORDER BY parent_step_id nulls first, step_number;
END; ';


ALTER FUNCTION public.getstepsbyjobid(v_job_id uuid) OWNER TO engine;

--
-- Name: getstepsbyparentstepid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstepsbyparentstepid(v_parent_step_id uuid) RETURNS SETOF step
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT step.*
    FROM step
    WHERE parent_step_id = v_parent_step_id
    ORDER BY step_number;
END; ';


ALTER FUNCTION public.getstepsbyparentstepid(v_parent_step_id uuid) OWNER TO engine;

--
-- Name: getstorage_domain_by_id_with_permitted_action(uuid, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domain_by_id_with_permitted_action(v_user_id uuid, v_action_group_id integer, v_storage_id uuid) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE id = v_storage_id
   AND (SELECT get_entity_permissions(v_user_id, v_action_group_id, id, 11)) IS NOT NULL;

END; ';


ALTER FUNCTION public.getstorage_domain_by_id_with_permitted_action(v_user_id uuid, v_action_group_id integer, v_storage_id uuid) OWNER TO engine;

--
-- Name: getstorage_domain_dynamicbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domain_dynamicbyid(v_id uuid) RETURNS SETOF storage_domain_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domain_dynamic
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getstorage_domain_dynamicbyid(v_id uuid) OWNER TO engine;

--
-- Name: getstorage_domain_staticbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domain_staticbyid(v_id uuid) RETURNS SETOF storage_domain_static
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domain_static
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getstorage_domain_staticbyid(v_id uuid) OWNER TO engine;

--
-- Name: getstorage_domain_staticbyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domain_staticbyname(v_name character varying) RETURNS SETOF storage_domain_static
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domain_static
   WHERE storage_name = v_name;

END; ';


ALTER FUNCTION public.getstorage_domain_staticbyname(v_name character varying) OWNER TO engine;

--
-- Name: getstorage_domain_staticbystorage_pool_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domain_staticbystorage_pool_id(v_storage_pool_id uuid) RETURNS SETOF storage_domain_static_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domain_static_view
   WHERE storage_pool_id = v_storage_pool_id;

END; ';


ALTER FUNCTION public.getstorage_domain_staticbystorage_pool_id(v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getstorage_domain_staticbystorage_pool_type(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domain_staticbystorage_pool_type(v_storage_pool_type integer) RETURNS SETOF storage_domain_static
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domain_static
   WHERE storage_type = v_storage_pool_type;

END; ';


ALTER FUNCTION public.getstorage_domain_staticbystorage_pool_type(v_storage_pool_type integer) OWNER TO engine;

--
-- Name: getstorage_domain_staticbystorage_type_and_storage_pool_id(integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domain_staticbystorage_type_and_storage_pool_id(v_storage_type integer, v_storage_pool_id uuid) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE storage_pool_id = v_storage_pool_id and storage_type = v_storage_type;

END; ';


ALTER FUNCTION public.getstorage_domain_staticbystorage_type_and_storage_pool_id(v_storage_type integer, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getstorage_domains_by_connection(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_by_connection(v_connection character varying) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE storage IN (
      SELECT id
      FROM storage_server_connections
      WHERE connection = v_connection);

END; ';


ALTER FUNCTION public.getstorage_domains_by_connection(v_connection character varying) OWNER TO engine;

--
-- Name: storage_domains_without_storage_pools; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW storage_domains_without_storage_pools AS
    SELECT storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_name, storage_domain_static.storage_type, storage_domain_static.storage_domain_type, storage_domain_static.storage_domain_format_type, storage_domain_static.last_time_used_as_master, NULL::unknown AS status, NULL::unknown AS owner, NULL::unknown AS storage_pool_id, NULL::unknown AS storage_pool_name, storage_domain_dynamic.available_disk_size, storage_domain_dynamic.used_disk_size, fn_get_disk_commited_value_by_storage(storage_domain_static.id) AS commited_disk_size, fn_get_storage_domain_shared_status_by_domain_id(storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_type) AS storage_domain_shared_status, storage_domain_static.recoverable FROM (storage_domain_static JOIN storage_domain_dynamic ON ((storage_domain_static.id = storage_domain_dynamic.id)));


ALTER TABLE public.storage_domains_without_storage_pools OWNER TO engine;

--
-- Name: getstorage_domains_by_id(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_by_id(v_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF storage_domains_without_storage_pools
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains_without_storage_pools
   WHERE id = v_id
   AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                     FROM   user_storage_domain_permissions_view
                                     WHERE  user_id = v_user_id AND entity_id = v_id));

END; ';


ALTER FUNCTION public.getstorage_domains_by_id(v_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getstorage_domains_by_id_and_by_storage_pool_id(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_by_id_and_by_storage_pool_id(v_id uuid, v_storage_pool_id uuid) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE id = v_id and storage_pool_id = v_storage_pool_id;

END; ';


ALTER FUNCTION public.getstorage_domains_by_id_and_by_storage_pool_id(v_id uuid, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getstorage_domains_by_storage_pool_id_and_connection(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_by_storage_pool_id_and_connection(v_storage_pool_id uuid, v_connection character varying) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE storage_pool_id = v_storage_pool_id
   AND storage IN (
      SELECT id
      FROM storage_server_connections
      WHERE connection = v_connection);
END; ';


ALTER FUNCTION public.getstorage_domains_by_storage_pool_id_and_connection(v_storage_pool_id uuid, v_connection character varying) OWNER TO engine;

--
-- Name: getstorage_domains_by_storage_pool_id_with_permitted_action(uuid, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_by_storage_pool_id_with_permitted_action(v_user_id uuid, v_action_group_id integer, v_storage_pool_id uuid) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE storage_pool_id = v_storage_pool_id
   AND (SELECT get_entity_permissions(v_user_id, v_action_group_id, id, 11)) IS NOT NULL;

END; ';


ALTER FUNCTION public.getstorage_domains_by_storage_pool_id_with_permitted_action(v_user_id uuid, v_action_group_id integer, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getstorage_domains_by_storagepoolid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_by_storagepoolid(v_storage_pool_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE storage_pool_id = v_storage_pool_id
   AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                     FROM   user_storage_domain_permissions_view
                                     WHERE  user_id = v_user_id AND entity_id = id));



END; ';


ALTER FUNCTION public.getstorage_domains_by_storagepoolid(v_storage_pool_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getstorage_domains_list_by_imageid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_list_by_imageid(v_image_id uuid) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY SELECT *
    FROM storage_domains
    WHERE id in (SELECT storage_domain_id
                 FROM image_storage_domain_map
                 WHERE image_id = v_image_id);
END; ';


ALTER FUNCTION public.getstorage_domains_list_by_imageid(v_image_id uuid) OWNER TO engine;

--
-- Name: getstorage_domains_list_by_storagedomainid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_domains_list_by_storagedomainid(v_storage_domain_id uuid) RETURNS SETOF storage_domains
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_domains
   WHERE storage_domains.id = v_storage_domain_id;

END; ';


ALTER FUNCTION public.getstorage_domains_list_by_storagedomainid(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: getstorage_pool_iso_mapbystorage_idandbystorage_pool_id(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_pool_iso_mapbystorage_idandbystorage_pool_id(v_storage_id uuid, v_storage_pool_id uuid) RETURNS SETOF storage_pool_iso_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool_iso_map
   WHERE storage_id = v_storage_id AND storage_pool_id = v_storage_pool_id;

END; ';


ALTER FUNCTION public.getstorage_pool_iso_mapbystorage_idandbystorage_pool_id(v_storage_id uuid, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getstorage_pool_iso_mapsbybystorage_pool_id(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_pool_iso_mapsbybystorage_pool_id(v_storage_id uuid, v_storage_pool_id uuid) RETURNS SETOF storage_pool_iso_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool_iso_map
   WHERE storage_pool_id = v_storage_pool_id;

END; ';


ALTER FUNCTION public.getstorage_pool_iso_mapsbybystorage_pool_id(v_storage_id uuid, v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getstorage_pool_iso_mapsbystorage_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_pool_iso_mapsbystorage_id(v_storage_id uuid) RETURNS SETOF storage_pool_iso_map
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool_iso_map
   WHERE storage_id = v_storage_id;

END; ';


ALTER FUNCTION public.getstorage_pool_iso_mapsbystorage_id(v_storage_id uuid) OWNER TO engine;

--
-- Name: getstorage_poolbyid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_poolbyid(v_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool
   WHERE id = v_id
   AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                     FROM   user_storage_pool_permissions_view
                                     WHERE  user_id = v_user_id AND entity_id = v_id));



END; ';


ALTER FUNCTION public.getstorage_poolbyid(v_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getstorage_poolbyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_poolbyname(v_name character varying) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool
   WHERE name = v_name;
END; ';


ALTER FUNCTION public.getstorage_poolbyname(v_name character varying) OWNER TO engine;

--
-- Name: getstorage_poolsbystoragedomainid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_poolsbystoragedomainid(v_storage_domain_id uuid) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT storage_pool.*
   FROM storage_pool
   inner join storage_pool_iso_map on storage_pool.id = storage_pool_iso_map.storage_pool_id
   WHERE storage_pool_iso_map.storage_id = v_storage_domain_id;

END; ';


ALTER FUNCTION public.getstorage_poolsbystoragedomainid(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: getstorage_poolsbytype(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_poolsbytype(v_storage_pool_type integer) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool
   WHERE storage_pool_type = v_storage_pool_type;
END; ';


ALTER FUNCTION public.getstorage_poolsbytype(v_storage_pool_type integer) OWNER TO engine;

--
-- Name: getstorage_poolsbyvdsgroupid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_poolsbyvdsgroupid(v_clusterid uuid) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_pool
   WHERE storage_pool.id in(select storage_pool_id
      FROM vds_groups
      WHERE vds_group_id = v_clusterId);

END; ';


ALTER FUNCTION public.getstorage_poolsbyvdsgroupid(v_clusterid uuid) OWNER TO engine;

--
-- Name: getstorage_poolsbyvdsid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_poolsbyvdsid(v_vdsid uuid) RETURNS SETOF storage_pool
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_clusterId  UUID;
BEGIN
select   vds_group_id INTO v_clusterId FROM Vds_static WHERE vds_id = v_vdsId; 
   RETURN QUERY SELECT *
   FROM storage_pool
   WHERE storage_pool.id in(select storage_pool_id
      FROM vds_groups
      WHERE vds_group_id = v_clusterId);

END; ';


ALTER FUNCTION public.getstorage_poolsbyvdsid(v_vdsid uuid) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbyconnection(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbyconnection(v_connection character varying) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_server_connections
   WHERE connection = v_connection;

END; ';


ALTER FUNCTION public.getstorage_server_connectionsbyconnection(v_connection character varying) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbyid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbyid(v_id character varying) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_server_connections
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getstorage_server_connectionsbyid(v_id character varying) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbyiqn(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbyiqn(v_iqn character varying) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_server_connections
   WHERE iqn = v_iqn;

END; ';


ALTER FUNCTION public.getstorage_server_connectionsbyiqn(v_iqn character varying) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbyiqnandconnection(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbyiqnandconnection(v_iqn character varying, v_connection character varying) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_server_connections
   WHERE iqn = v_iqn and (connection = v_connection or connection is NULL);

END; ';


ALTER FUNCTION public.getstorage_server_connectionsbyiqnandconnection(v_iqn character varying, v_connection character varying) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbykey(character varying, character varying, character varying, character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbykey(v_iqn character varying, v_connection character varying, v_port character varying, v_portal character varying, v_username character varying, v_password character varying) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_server_connections
   WHERE (iqn = v_iqn or iqn is NULL) and
			(connection = v_connection) and
			(port = v_port or port is NULL) and
			(portal = v_portal or portal is NULL) and
			(user_name = v_username or user_name is NULL) and
			(password = v_password or password is NULL);

END; ';


ALTER FUNCTION public.getstorage_server_connectionsbykey(v_iqn character varying, v_connection character varying, v_port character varying, v_portal character varying, v_username character varying, v_password character varying) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbylunid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbylunid(v_lunid character varying) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT storage_server_connections.*
   FROM  storage_server_connections storage_server_connections
   INNER JOIN lun_storage_server_connection_map ON
   lun_storage_server_connection_map.storage_server_connection = storage_server_connections.id
   WHERE     (lun_storage_server_connection_map.lun_id = v_lunId);
END; ';


ALTER FUNCTION public.getstorage_server_connectionsbylunid(v_lunid character varying) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbystoragepoolid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbystoragepoolid(v_storage_pool_id uuid) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT distinct storage_server_connections.*
   FROM
   LUN_storage_server_connection_map LUN_storage_server_connection_map
   INNER JOIN  LUNs ON LUN_storage_server_connection_map.LUN_id = LUNs.LUN_id
   INNER JOIN  storage_domains ON LUNs.volume_group_id = storage_domains.storage
   INNER JOIN  storage_server_connections ON LUN_storage_server_connection_map.storage_server_connection = storage_server_connections.id
   WHERE     (storage_domains.storage_pool_id = v_storage_pool_id  and storage_domains.status in(0,3))
   UNION
   SELECT distinct storage_server_connections.*
   FROM         storage_server_connections
   INNER JOIN  storage_domains ON storage_server_connections.id = storage_domains.storage
   WHERE     (storage_domains.storage_pool_id = v_storage_pool_id and storage_domains.status in(0,3));
END; ';


ALTER FUNCTION public.getstorage_server_connectionsbystoragepoolid(v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbystoragetype(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbystoragetype(v_storage_type integer) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM storage_server_connections
   WHERE storage_type = v_storage_type;

END; ';


ALTER FUNCTION public.getstorage_server_connectionsbystoragetype(v_storage_type integer) OWNER TO engine;

--
-- Name: getstorage_server_connectionsbyvolumegroupid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstorage_server_connectionsbyvolumegroupid(v_volume_group_id character varying) RETURNS SETOF storage_server_connections
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT storage_server_connections.*
   FROM
   LUN_storage_server_connection_map  LUN_storage_server_connection_map 
   INNER JOIN
   LUNs ON LUN_storage_server_connection_map.LUN_id = LUNs.LUN_id INNER JOIN
   storage_domain_static ON LUNs.volume_group_id = storage_domain_static.storage INNER JOIN
   storage_server_connections ON
   LUN_storage_server_connection_map.storage_server_connection = storage_server_connections.id
   WHERE     (storage_domain_static.storage = v_volume_group_id);
END; ';


ALTER FUNCTION public.getstorage_server_connectionsbyvolumegroupid(v_volume_group_id character varying) OWNER TO engine;

--
-- Name: getstoragedomainidsbystoragepoolidandstatus(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getstoragedomainidsbystoragepoolidandstatus(v_storage_pool_id uuid, v_status integer) RETURNS SETOF getstoragedomainidsbystoragepoolidandstatus_rs
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY
   SELECT storage_id
   FROM   storage_pool_iso_map
   WHERE  storage_pool_id = v_storage_pool_id
   AND    status = v_status;

END; ';


ALTER FUNCTION public.getstoragedomainidsbystoragepoolidandstatus(v_storage_pool_id uuid, v_status integer) OWNER TO engine;

--
-- Name: getsystem_statistics(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getsystem_statistics(v_entity character varying, v_status character varying) RETURNS getsystem_statistics_rs
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_i Getsystem_statistics_rs;
   v_sql  VARCHAR(4000);
   v_sys_entity VARCHAR(10);
BEGIN
   v_sys_entity := v_entity;
   v_sql := NULL;

   v_sys_entity := upper(v_sys_entity);
   if (v_sys_entity = ''VM'') then
      v_sql := ''select count(vm_guid) from vm_dynamic'';
   else 
      if (v_sys_entity = ''HOST'') then
         v_sql := ''select count(vds_id)  from vds_dynamic'';
      else 
         if (v_sys_entity = ''USER'') then
            v_sql := ''select count(user_id) from users'';
         else 
            if (v_sys_entity = ''TSD'') then
               v_sql := ''select count(id) from storage_domain_static'';
            else 
               if (v_sys_entity = ''ASD'') then
                  v_sql := ''select count(storage_id) from storage_pool_iso_map'';
               end if;
            end if;
         end if;
      end if;
   end if;

   if (v_status != '''' and v_sys_entity != ''TSD'') then
      v_sql := coalesce(v_sql,'''') || '' where status in ('' || coalesce(v_status,'''') || '')'';
   end if;
   EXECUTE v_sql INTO v_i;
   RETURN v_i;
END; ';


ALTER FUNCTION public.getsystem_statistics(v_entity character varying, v_status character varying) OWNER TO engine;

--
-- Name: tags_user_group_map_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW tags_user_group_map_view AS
    SELECT tags.tag_id, tags.tag_name, tags.parent_id, tags.readonly, tags.type, tags_user_group_map.group_id FROM (tags_user_group_map JOIN tags ON ((tags_user_group_map.tag_id = tags.tag_id)));


ALTER TABLE public.tags_user_group_map_view OWNER TO engine;

--
-- Name: gettags_user_group_mapbytagname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettags_user_group_mapbytagname(v_tag_name character varying) RETURNS SETOF tags_user_group_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_user_group_map_view.*
      FROM tags_user_group_map_view
      WHERE tag_name = v_tag_name;
END; ';


ALTER FUNCTION public.gettags_user_group_mapbytagname(v_tag_name character varying) OWNER TO engine;

--
-- Name: tags_user_map_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW tags_user_map_view AS
    SELECT tags.tag_id, tags.tag_name, tags.parent_id, tags.readonly, tags.type, tags_user_map.user_id FROM (tags JOIN tags_user_map ON ((tags.tag_id = tags_user_map.tag_id)));


ALTER TABLE public.tags_user_map_view OWNER TO engine;

--
-- Name: gettags_user_mapbytagname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettags_user_mapbytagname(v_tag_name character varying) RETURNS SETOF tags_user_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_user_map_view.*
      FROM tags_user_map_view
      WHERE tag_name = v_tag_name;
END; ';


ALTER FUNCTION public.gettags_user_mapbytagname(v_tag_name character varying) OWNER TO engine;

--
-- Name: tags_vds_map_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW tags_vds_map_view AS
    SELECT tags.tag_id, tags.tag_name, tags.parent_id, tags.readonly, tags.type, tags_vds_map.vds_id FROM (tags JOIN tags_vds_map ON ((tags.tag_id = tags_vds_map.tag_id)));


ALTER TABLE public.tags_vds_map_view OWNER TO engine;

--
-- Name: gettags_vds_mapbytagname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettags_vds_mapbytagname(v_tag_name character varying) RETURNS SETOF tags_vds_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_vds_map_view.*
      FROM tags_vds_map_view
      WHERE tag_name = v_tag_name;
END; ';


ALTER FUNCTION public.gettags_vds_mapbytagname(v_tag_name character varying) OWNER TO engine;

--
-- Name: tags_vm_map_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW tags_vm_map_view AS
    SELECT tags.tag_id, tags.tag_name, tags.parent_id, tags.readonly, tags.type, tags_vm_map.vm_id FROM (tags JOIN tags_vm_map ON ((tags.tag_id = tags_vm_map.tag_id)));


ALTER TABLE public.tags_vm_map_view OWNER TO engine;

--
-- Name: gettags_vm_mapbytagname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettags_vm_mapbytagname(v_tag_name character varying) RETURNS SETOF tags_vm_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_vm_map_view.*
      FROM tags_vm_map_view
      WHERE tag_name = v_tag_name;
END; ';


ALTER FUNCTION public.gettags_vm_mapbytagname(v_tag_name character varying) OWNER TO engine;

--
-- Name: gettags_vm_pool_mapbytag_idandbyvm_pool_id(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettags_vm_pool_mapbytag_idandbyvm_pool_id(v_tag_id uuid, v_vm_pool_id uuid) RETURNS SETOF tags_vm_pool_map
    LANGUAGE plpgsql
    AS '
BEGIN
	
   RETURN QUERY SELECT tags_vm_pool_map.*
   FROM tags_vm_pool_map
   WHERE tag_id = v_tag_id AND vm_pool_id = v_vm_pool_id;

END; ';


ALTER FUNCTION public.gettags_vm_pool_mapbytag_idandbyvm_pool_id(v_tag_id uuid, v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: gettagsbyparent_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbyparent_id(v_parent_id uuid) RETURNS SETOF tags
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags.*
      FROM tags
      WHERE parent_id = v_parent_id;
END; ';


ALTER FUNCTION public.gettagsbyparent_id(v_parent_id uuid) OWNER TO engine;

--
-- Name: gettagsbytag_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbytag_id(v_tag_id uuid) RETURNS SETOF tags
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags.*
      FROM tags
      WHERE tag_id = v_tag_id;
END; ';


ALTER FUNCTION public.gettagsbytag_id(v_tag_id uuid) OWNER TO engine;

--
-- Name: gettagsbytag_name(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbytag_name(v_tag_name character varying) RETURNS SETOF tags
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags.*
      FROM tags
      WHERE tag_name = v_tag_name;
END; ';


ALTER FUNCTION public.gettagsbytag_name(v_tag_name character varying) OWNER TO engine;

--
-- Name: gettagsbyusergroupid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbyusergroupid(v_group_ids character varying) RETURNS SETOF tags_user_group_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_user_group_map_view.*
      FROM tags_user_group_map_view
      WHERE group_id in(select id from fnSplitterUuid(v_group_ids));
END; ';


ALTER FUNCTION public.gettagsbyusergroupid(v_group_ids character varying) OWNER TO engine;

--
-- Name: gettagsbyuserid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbyuserid(v_user_ids character varying) RETURNS SETOF tags_user_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_user_map_view.*
      FROM tags_user_map_view
      WHERE user_id in(select id from fnSplitterUuid(v_user_ids));
END; ';


ALTER FUNCTION public.gettagsbyuserid(v_user_ids character varying) OWNER TO engine;

--
-- Name: gettagsbyvdsid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbyvdsid(v_vds_ids character varying) RETURNS SETOF tags_vds_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_vds_map_view.*
      FROM tags_vds_map_view
      WHERE vds_id in(select id from fnSplitterUuid(v_vds_ids));
END; ';


ALTER FUNCTION public.gettagsbyvdsid(v_vds_ids character varying) OWNER TO engine;

--
-- Name: gettagsbyvmid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbyvmid(v_vm_ids character varying) RETURNS SETOF tags_vm_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_vm_map_view.*
      FROM tags_vm_map_view
      WHERE vm_id in(select id from fnSplitterUuid(v_vm_ids));
END; ';


ALTER FUNCTION public.gettagsbyvmid(v_vm_ids character varying) OWNER TO engine;

--
-- Name: tags_vm_pool_map_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW tags_vm_pool_map_view AS
    SELECT tags.tag_id, tags.tag_name, tags.parent_id, tags.readonly, tags.type, tags_vm_pool_map.vm_pool_id FROM (tags JOIN tags_vm_pool_map ON ((tags.tag_id = tags_vm_pool_map.tag_id)));


ALTER TABLE public.tags_vm_pool_map_view OWNER TO engine;

--
-- Name: gettagsbyvmpoolid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagsbyvmpoolid(v_vm_pool_ids character varying) RETURNS SETOF tags_vm_pool_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_vm_pool_map_view.*
      FROM tags_vm_pool_map_view
      WHERE vm_pool_id in(select id from fnSplitterUuid(v_vm_pool_ids));
END; ';


ALTER FUNCTION public.gettagsbyvmpoolid(v_vm_pool_ids character varying) OWNER TO engine;

--
-- Name: gettaguserbytagidandbyuserid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettaguserbytagidandbyuserid(v_tag_id uuid, v_user_id uuid) RETURNS SETOF tags_user_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_user_map.*
      FROM tags_user_map
      WHERE tag_id = v_tag_id AND user_id = v_user_id;
END; ';


ALTER FUNCTION public.gettaguserbytagidandbyuserid(v_tag_id uuid, v_user_id uuid) OWNER TO engine;

--
-- Name: gettagusergroupbygroupidandbytagid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagusergroupbygroupidandbytagid(v_group_id uuid, v_tag_id uuid) RETURNS SETOF tags_user_group_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_user_group_map.*
      FROM tags_user_group_map
      WHERE group_id = v_group_id AND tag_id = v_tag_id;
END; ';


ALTER FUNCTION public.gettagusergroupbygroupidandbytagid(v_group_id uuid, v_tag_id uuid) OWNER TO engine;

--
-- Name: gettagvdsbytagidandbyvdsid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagvdsbytagidandbyvdsid(v_tag_id uuid, v_vds_id uuid) RETURNS SETOF tags_vds_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_vds_map.*
      FROM tags_vds_map
      WHERE tag_id = v_tag_id AND vds_id = v_vds_id;
END; ';


ALTER FUNCTION public.gettagvdsbytagidandbyvdsid(v_tag_id uuid, v_vds_id uuid) OWNER TO engine;

--
-- Name: gettagvmbytagidandbyvmid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettagvmbytagidandbyvmid(v_tag_id uuid, v_vm_id uuid) RETURNS SETOF tags_vm_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT tags_vm_map.*
      FROM tags_vm_map
      WHERE tag_id = v_tag_id AND vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.gettagvmbytagidandbyvmid(v_tag_id uuid, v_vm_id uuid) OWNER TO engine;

--
-- Name: gettimeleasedusersvmsbygroupidandpoolid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettimeleasedusersvmsbygroupidandpoolid(v_groupid uuid, v_vm_pool_id uuid) RETURNS SETOF tags_vm_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY select tags_vm_map.* from tags_vm_map
      inner join vm_pool_map on vm_pool_map.vm_guid = tags_vm_map.vm_id
      inner join tags_permissions_map on tags_permissions_map.tag_id = tags_vm_map.tag_id
      inner join permissions on permissions.id = tags_permissions_map.permission_id
      where permissions.ad_element_id
      in(select users.user_id from users
         where (users.groups LIKE ''%'' ||(select ad_groups.name from ad_groups where ad_groups.id = v_groupId)
         || ''%''))
      and
      vm_pool_map.vm_pool_id = v_vm_pool_id;
END; ';


ALTER FUNCTION public.gettimeleasedusersvmsbygroupidandpoolid(v_groupid uuid, v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: gluster_volume_transport_types; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE gluster_volume_transport_types (
    volume_id uuid NOT NULL,
    transport_type character varying(32) NOT NULL
);


ALTER TABLE public.gluster_volume_transport_types OWNER TO engine;

--
-- Name: gettransporttypesbyglustervolumeguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION gettransporttypesbyglustervolumeguid(v_volume_id uuid) RETURNS SETOF gluster_volume_transport_types
    LANGUAGE plpgsql
    AS '
BEGIN
       RETURN QUERY SELECT *
       FROM  gluster_volume_transport_types
       WHERE volume_id = v_volume_id;
END; ';


ALTER FUNCTION public.gettransporttypesbyglustervolumeguid(v_volume_id uuid) OWNER TO engine;

--
-- Name: getupandprioritizedvds(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getupandprioritizedvds(v_storage_pool_id uuid) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '

BEGIN
BEGIN
      RETURN QUERY SELECT vds.*
      FROM vds
      WHERE (status = 3) AND (storage_pool_id = v_storage_pool_id) AND (vds_spm_priority IS NULL OR vds_spm_priority > (-1))
      ORDER BY vds_spm_priority DESC, RANDOM();
   END;
   RETURN;
END; ';


ALTER FUNCTION public.getupandprioritizedvds(v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getuser_sessionsbysession_idandbyuser_id(character, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getuser_sessionsbysession_idandbyuser_id(v_session_id character, v_user_id uuid) RETURNS SETOF user_sessions
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT user_sessions.*
      FROM user_sessions
      WHERE session_id = v_session_id AND user_id = v_user_id;
END; ';


ALTER FUNCTION public.getuser_sessionsbysession_idandbyuser_id(v_session_id character, v_user_id uuid) OWNER TO engine;

--
-- Name: getuserandgroupsbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getuserandgroupsbyid(v_id uuid) RETURNS SETOF iduuidtype
    LANGUAGE plpgsql
    AS '
   DECLARE
   SWV_Rs idUuidType;
BEGIN
   BEGIN
      CREATE GLOBAL TEMPORARY TABLE tt_TEMP3
      (
         id UUID
      ) WITH OIDS;
      exception when others then
         truncate table tt_TEMP3;
   END;
   insert INTO tt_TEMP3
   select ID from ad_groups,users where users.user_id = v_id
   and ad_groups.id in(select ID from fnsplitteruuid(users.group_ids))
   UNION
   select v_id
   UNION
   -- user is also member of ''Everyone''
   select ''EEE00000-0000-0000-0000-123456789EEE'';
   FOR SWV_Rs IN(SELECT * FROM  tt_TEMP3) LOOP
      RETURN NEXT SWV_Rs;
   END LOOP;
   RETURN;
END; ';


ALTER FUNCTION public.getuserandgroupsbyid(v_id uuid) OWNER TO engine;

--
-- Name: getuserbyuserid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getuserbyuserid(v_user_id uuid) RETURNS SETOF users
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT users.*
      FROM users
      WHERE user_id = v_user_id;
END; ';


ALTER FUNCTION public.getuserbyuserid(v_user_id uuid) OWNER TO engine;

--
-- Name: getuserbyusername(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getuserbyusername(v_username character varying) RETURNS SETOF users
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT users.*
      FROM users
      WHERE username = v_username;
END; ';


ALTER FUNCTION public.getuserbyusername(v_username character varying) OWNER TO engine;

--
-- Name: getusergrouptagsbytagids(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getusergrouptagsbytagids(v_tag_ids character varying) RETURNS SETOF tags_user_group_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_user_group_map_view.*
      FROM tags_user_group_map_view
      WHERE tag_id in(select id from fnSplitterUuid(v_tag_ids));
END; ';


ALTER FUNCTION public.getusergrouptagsbytagids(v_tag_ids character varying) OWNER TO engine;

--
-- Name: getuserpermissionsbyentityid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getuserpermissionsbyentityid(v_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF permissions_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM permissions_view p
   WHERE object_id = v_id
   AND   (NOT v_is_filtered OR EXISTS (SELECT 1
                                       FROM   user_flat_groups u
                                       WHERE  p.ad_element_id = u.granted_id
                                       AND    u.user_id       = v_user_id));
END; ';


ALTER FUNCTION public.getuserpermissionsbyentityid(v_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getusersbyvmguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getusersbyvmguid(v_vm_guid uuid) RETURNS SETOF users
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT users.*
      FROM users
      inner join permissions
      on users.user_id = permissions.ad_element_id
      WHERE permissions.object_type_id = 2
      and	permissions.object_id = v_vm_guid;
END; ';


ALTER FUNCTION public.getusersbyvmguid(v_vm_guid uuid) OWNER TO engine;

--
-- Name: getusertagsbytagids(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getusertagsbytagids(v_tag_ids character varying) RETURNS SETOF tags_user_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_user_map_view.*
      FROM tags_user_map_view
      WHERE tag_id in(select id from fnSplitterUuid(v_tag_ids));
END; ';


ALTER FUNCTION public.getusertagsbytagids(v_tag_ids character varying) OWNER TO engine;

--
-- Name: getvdcoptionbyid(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdcoptionbyid(v_option_id integer) RETURNS SETOF vdc_options
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vdc_options.*
      FROM vdc_options
      WHERE option_id = v_option_id;
END; ';


ALTER FUNCTION public.getvdcoptionbyid(v_option_id integer) OWNER TO engine;

--
-- Name: getvdcoptionbyname(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdcoptionbyname(v_option_name character varying, v_version character varying) RETURNS SETOF vdc_options
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vdc_options.*
      FROM vdc_options
      WHERE OPTION_NAME = v_option_name and version = v_version;
END; ';


ALTER FUNCTION public.getvdcoptionbyname(v_option_name character varying, v_version character varying) OWNER TO engine;

--
-- Name: getvds_spm_id_mapbystorage_pool_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvds_spm_id_mapbystorage_pool_id(v_storage_pool_id uuid) RETURNS SETOF vds_spm_id_map
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vds_spm_id_map.*
   FROM vds_spm_id_map
   WHERE storage_pool_id = v_storage_pool_id;

END; ';


ALTER FUNCTION public.getvds_spm_id_mapbystorage_pool_id(v_storage_pool_id uuid) OWNER TO engine;

--
-- Name: getvds_spm_id_mapbystorage_pool_idandbyvds_spm_id(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvds_spm_id_mapbystorage_pool_idandbyvds_spm_id(v_storage_pool_id uuid, v_vds_spm_id integer) RETURNS SETOF vds_spm_id_map
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vds_spm_id_map.*
   FROM vds_spm_id_map
   WHERE storage_pool_id = v_storage_pool_id AND vds_spm_id = v_vds_spm_id;

END; ';


ALTER FUNCTION public.getvds_spm_id_mapbystorage_pool_idandbyvds_spm_id(v_storage_pool_id uuid, v_vds_spm_id integer) OWNER TO engine;

--
-- Name: getvds_spm_id_mapbyvds_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvds_spm_id_mapbyvds_id(v_vds_id uuid) RETURNS SETOF vds_spm_id_map
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vds_spm_id_map.*
   FROM vds_spm_id_map
   WHERE vds_id = v_vds_id;

END; ';


ALTER FUNCTION public.getvds_spm_id_mapbyvds_id(v_vds_id uuid) OWNER TO engine;

--
-- Name: getvdsbyhostname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbyhostname(v_host_name character varying) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM vds
      WHERE host_name = v_host_name;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsbyhostname(v_host_name character varying) OWNER TO engine;

--
-- Name: getvdsbyip(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbyip(v_ip character varying) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM vds
      WHERE ip = v_ip;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsbyip(v_ip character varying) OWNER TO engine;

--
-- Name: getvdsbyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbyname(v_vds_name character varying) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM vds
      WHERE vds_name = v_vds_name;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsbyname(v_vds_name character varying) OWNER TO engine;

--
-- Name: getvdsbystoragepoolid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbystoragepoolid(v_storage_pool_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
   BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM   vds
      WHERE  storage_pool_id = v_storage_pool_id
      AND    (NOT v_is_filtered OR EXISTS (SELECT 1
                                           FROM   user_vds_permissions_view
                                           WHERE  user_id = v_user_id AND entity_id = vds_id));
   END;
   RETURN;
END; ';


ALTER FUNCTION public.getvdsbystoragepoolid(v_storage_pool_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvdsbytype(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbytype(v_vds_type integer) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM vds
      WHERE vds_type = v_vds_type;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsbytype(v_vds_type integer) OWNER TO engine;

--
-- Name: getvdsbyuniqueid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbyuniqueid(v_vds_unique_id character varying) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM vds
      WHERE vds_unique_id = v_vds_unique_id;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsbyuniqueid(v_vds_unique_id character varying) OWNER TO engine;

--
-- Name: getvdsbyvdsgroupid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbyvdsgroupid(v_vds_group_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
	-- this sp returns all vds for a given cluster
   BEGIN
      if (v_is_filtered) then
          RETURN QUERY SELECT DISTINCT (rec).*
          FROM fn_db_mask_object(''vds'') as q (rec vds)
          WHERE (rec).vds_group_id = v_vds_group_id
          AND EXISTS (SELECT 1
              FROM   user_vds_permissions_view
              WHERE  user_id = v_user_id AND entity_id = (rec).vds_id);
      else
          RETURN QUERY SELECT DISTINCT vds.*
          FROM vds
          WHERE vds_group_id = v_vds_group_id;
      end if;
    END;
    RETURN;
END; ';


ALTER FUNCTION public.getvdsbyvdsgroupid(v_vds_group_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvdsbyvdsid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsbyvdsid(v_vds_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
DECLARE
v_columns text[];
BEGIN
    BEGIN
      if (v_is_filtered) then
          RETURN QUERY SELECT DISTINCT (rec).*
          FROM fn_db_mask_object(''vds'') as q (rec vds)
          WHERE (rec).vds_id = v_vds_id
          AND EXISTS (SELECT 1
              FROM   user_vds_permissions_view
              WHERE  user_id = v_user_id AND entity_id = v_vds_id);
      else
          RETURN QUERY SELECT DISTINCT vds.*
          FROM vds
          WHERE vds_id = v_vds_id;
      end if;
    END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsbyvdsid(v_vds_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvdsdynamicbyvdsid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsdynamicbyvdsid(v_vds_id uuid) RETURNS SETOF vds_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_dynamic.*
      FROM vds_dynamic
      WHERE vds_id = v_vds_id;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsdynamicbyvdsid(v_vds_id uuid) OWNER TO engine;

--
-- Name: getvdsforvdsgroupwithstatus(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsforvdsgroupwithstatus(v_vds_group_id uuid, v_status integer) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN
    BEGIN
        RETURN QUERY SELECT vds.*
        FROM vds
        WHERE (status = v_status) AND (vds_group_id = v_vds_group_id);
    END;
    RETURN;
END; ';


ALTER FUNCTION public.getvdsforvdsgroupwithstatus(v_vds_group_id uuid, v_status integer) OWNER TO engine;

--
-- Name: getvdsgroupbyvdsgroupid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsgroupbyvdsgroupid(v_vds_group_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vds_groups.*
      FROM vds_groups
      WHERE vds_group_id = v_vds_group_id
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_vds_groups_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = v_vds_group_id));

END; ';


ALTER FUNCTION public.getvdsgroupbyvdsgroupid(v_vds_group_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvdsgroupbyvdsgroupname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsgroupbyvdsgroupname(v_vds_group_name character varying) RETURNS SETOF vds_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vds_groups.*
      FROM vds_groups
      WHERE name = v_vds_group_name;
END; ';


ALTER FUNCTION public.getvdsgroupbyvdsgroupname(v_vds_group_name character varying) OWNER TO engine;

--
-- Name: getvdsgroupsbystoragepoolid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsgroupsbystoragepoolid(v_storage_pool_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vds_groups.*
      FROM vds_groups
      WHERE storage_pool_id = v_storage_pool_id
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_vds_groups_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = vds_group_id));
END; ';


ALTER FUNCTION public.getvdsgroupsbystoragepoolid(v_storage_pool_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvdsgroupwithrunningvms(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsgroupwithrunningvms(v_vds_group_id uuid) RETURNS SETOF vds_groups
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vds_groups.*
      FROM vds_groups
      WHERE vds_group_id = v_vds_group_id and vds_group_id in(select vds_group_id from vms where vms.status NOT IN(0,13,14));
END; ';


ALTER FUNCTION public.getvdsgroupwithrunningvms(v_vds_group_id uuid) OWNER TO engine;

--
-- Name: getvdsmanagedinterfacebyvdsid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsmanagedinterfacebyvdsid(v_vds_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vds_interface_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM vds_interface_view
   -- Checking if the 2nd bit in the type column is set, meaning that the interface is managed
   WHERE vds_id = v_vds_id AND (type & 2) = 2
   AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                     FROM   user_vds_permissions_view
                                     WHERE  user_id = v_user_id AND entity_id = v_vds_id));

END; ';


ALTER FUNCTION public.getvdsmanagedinterfacebyvdsid(v_vds_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvdsstaticbyhostname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsstaticbyhostname(v_host_name character varying) RETURNS SETOF vds_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vds_static.*
   FROM vds_static
   WHERE host_name = v_host_name;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsstaticbyhostname(v_host_name character varying) OWNER TO engine;

--
-- Name: getvdsstaticbyip(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsstaticbyip(v_ip character varying) RETURNS SETOF vds_static
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_static.*
      FROM vds_static
      WHERE ip = v_ip;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsstaticbyip(v_ip character varying) OWNER TO engine;

--
-- Name: getvdsstaticbyvdsgroupid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsstaticbyvdsgroupid(v_vds_group_id uuid) RETURNS SETOF vds_static
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_static.*
      FROM vds_static vds_static
      WHERE vds_group_id = v_vds_group_id;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsstaticbyvdsgroupid(v_vds_group_id uuid) OWNER TO engine;

--
-- Name: getvdsstaticbyvdsid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsstaticbyvdsid(v_vds_id uuid) RETURNS SETOF vds_static
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_static.*
      FROM vds_static
      WHERE vds_id = v_vds_id;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsstaticbyvdsid(v_vds_id uuid) OWNER TO engine;

--
-- Name: getvdsstaticbyvdsname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsstaticbyvdsname(v_vds_name character varying) RETURNS SETOF vds_static
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_static.*
      FROM vds_static
      WHERE vds_name = v_vds_name;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsstaticbyvdsname(v_vds_name character varying) OWNER TO engine;

--
-- Name: getvdsstatisticsbyvdsid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdsstatisticsbyvdsid(v_vds_id uuid) RETURNS SETOF vds_statistics
    LANGUAGE plpgsql
    AS '
BEGIN
BEGIN
      RETURN QUERY SELECT vds_statistics.*
      FROM vds_statistics
      WHERE vds_id = v_vds_id;
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdsstatisticsbyvdsid(v_vds_id uuid) OWNER TO engine;

--
-- Name: getvdstagsbytagids(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdstagsbytagids(v_tag_ids character varying) RETURNS SETOF tags_vds_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_vds_map_view.*
      FROM tags_vds_map_view
      WHERE tag_id in(select id from fnSplitterUuid(v_tag_ids));
END; ';


ALTER FUNCTION public.getvdstagsbytagids(v_tag_ids character varying) OWNER TO engine;

--
-- Name: getvdswithoutmigratingvmsbyvdsgroupid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvdswithoutmigratingvmsbyvdsgroupid(v_vds_group_id uuid) RETURNS SETOF vds
    LANGUAGE plpgsql
    AS '
BEGIN

	
	-- this sp returns all vds in given cluster that have no pending vms and no vms in migration states
	BEGIN
      RETURN QUERY SELECT DISTINCT vds.*
      FROM vds
      WHERE vds_group_id = v_vds_group_id and
      pending_vcpus_count = 0
      and	vds.status = 3
      and	vds_id not in(select distinct RUN_ON_VDS from vm_dynamic
         where status in(5,6,11,12));
   END;

   RETURN;
END; ';


ALTER FUNCTION public.getvdswithoutmigratingvmsbyvdsgroupid(v_vds_group_id uuid) OWNER TO engine;

--
-- Name: vm_interface_statistics; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vm_interface_statistics (
    id uuid NOT NULL,
    vm_id uuid,
    rx_rate numeric(18,0),
    tx_rate numeric(18,0),
    rx_drop numeric(18,0),
    tx_drop numeric(18,0),
    iface_status integer
);


ALTER TABLE public.vm_interface_statistics OWNER TO engine;

--
-- Name: getvm_interface_statisticsbyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_interface_statisticsbyid(v_id uuid) RETURNS SETOF vm_interface_statistics
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT *
   FROM vm_interface_statistics
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getvm_interface_statisticsbyid(v_id uuid) OWNER TO engine;

--
-- Name: vm_interface_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_interface_view AS
    SELECT vm_interface_statistics.rx_rate, vm_interface_statistics.tx_rate, vm_interface_statistics.rx_drop, vm_interface_statistics.tx_drop, vm_interface_statistics.iface_status, vm_interface.type, vm_interface.speed, vm_interface.mac_addr, vm_interface.network_name, vm_interface.name, vm_static.vm_guid, vm_interface.vmt_guid, vm_static.vm_name, vm_interface.id, 0 AS boot_protocol, 0 AS is_vds, vm_device.is_plugged, vm_interface.port_mirroring FROM (((vm_interface_statistics JOIN vm_interface ON ((vm_interface_statistics.id = vm_interface.id))) JOIN vm_static ON ((vm_interface.vm_guid = vm_static.vm_guid))) JOIN vm_device ON (((vm_interface.vm_guid = vm_device.vm_id) AND (vm_interface.id = vm_device.device_id)))) UNION SELECT vm_interface_statistics.rx_rate, vm_interface_statistics.tx_rate, vm_interface_statistics.rx_drop, vm_interface_statistics.tx_drop, vm_interface_statistics.iface_status, vm_interface.type, vm_interface.speed, vm_interface.mac_addr, vm_interface.network_name, vm_interface.name, NULL::uuid AS vm_guid, vm_interface.vmt_guid, vm_templates.vm_name, vm_interface.id, 0 AS boot_protocol, 0 AS is_vds, vm_device.is_plugged, vm_interface.port_mirroring FROM (((vm_interface_statistics RIGHT JOIN vm_interface ON ((vm_interface_statistics.id = vm_interface.id))) JOIN vm_static vm_templates ON ((vm_interface.vmt_guid = vm_templates.vm_guid))) JOIN vm_device ON (((vm_interface.vmt_guid = vm_device.vm_id) AND (vm_interface.id = vm_device.device_id))));


ALTER TABLE public.vm_interface_view OWNER TO engine;

--
-- Name: getvm_interfacebyid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_interfacebyid(v_id uuid) RETURNS SETOF vm_interface_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM vm_interface_view
   WHERE id = v_id;

END; ';


ALTER FUNCTION public.getvm_interfacebyid(v_id uuid) OWNER TO engine;

--
-- Name: getvm_interfacebytemplate_id(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_interfacebytemplate_id(v_template_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vm_interface_view
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM vm_interface_view
   WHERE vmt_guid = v_template_id
   AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                     FROM   user_vm_template_permissions_view
                                     WHERE  user_id = v_user_id AND entity_id = v_template_id));

END; ';


ALTER FUNCTION public.getvm_interfacebytemplate_id(v_template_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvm_interfacebyvm_guidandbyvmt_guid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_interfacebyvm_guidandbyvmt_guid(v_vm_guid uuid, v_vmt_guid uuid) RETURNS SETOF vm_interface
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT *
   FROM vm_interface
   WHERE VM_GUID = v_vm_guid AND VMT_GUID = v_vmt_guid;

END; ';


ALTER FUNCTION public.getvm_interfacebyvm_guidandbyvmt_guid(v_vm_guid uuid, v_vmt_guid uuid) OWNER TO engine;

--
-- Name: getvm_interfacebyvm_id(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_interfacebyvm_id(v_vm_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vm_interface_view
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT *
   FROM vm_interface_view
   WHERE vm_guid = v_vm_id
   AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                     FROM   user_vm_permissions_view
                                     WHERE  user_id = v_user_id AND entity_id = v_vm_id));

END; ';


ALTER FUNCTION public.getvm_interfacebyvm_id(v_vm_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvm_pool_mapbyvm_guid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_pool_mapbyvm_guid(v_vm_guid uuid) RETURNS SETOF vm_pool_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_pool_map.*
      FROM vm_pool_map
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.getvm_pool_mapbyvm_guid(v_vm_guid uuid) OWNER TO engine;

--
-- Name: getvm_pool_mapbyvm_pool_id(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_pool_mapbyvm_pool_id(v_vm_pool_id uuid) RETURNS SETOF vm_pool_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_pool_map.*
      FROM vm_pool_map INNER JOIN vm_static
      ON vm_pool_map.vm_guid = vm_static.vm_guid
      WHERE vm_pool_id = v_vm_pool_id
      ORDER BY vm_static.VM_NAME;
END; ';


ALTER FUNCTION public.getvm_pool_mapbyvm_pool_id(v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: getvm_poolsbyadgroup_names(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_poolsbyadgroup_names(v_ad_group_names character varying) RETURNS SETOF vm_pools_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT vm_pools_view.*
      FROM         ad_groups INNER JOIN
      users_and_groups_to_vm_pool_map_view ON
      ad_groups.id = users_and_groups_to_vm_pool_map_view.user_id INNER JOIN
      vm_pools_view ON users_and_groups_to_vm_pool_map_view.vm_pool_id = vm_pools_view.vm_pool_id
      WHERE     (ad_groups.name in(select Id from fnSplitter(v_ad_group_names)));
END; ';


ALTER FUNCTION public.getvm_poolsbyadgroup_names(v_ad_group_names character varying) OWNER TO engine;

--
-- Name: vm_pools_full_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_pools_full_view AS
    SELECT vmp.vm_pool_id, vmp.vm_pool_name, vmp.vm_pool_description, vmp.vm_pool_type, vmp.parameters, vmp.prestarted_vms, vmp.vds_group_id, vmp.vds_group_name, (SELECT count(vm_pool_map.vm_pool_id) AS expr1 FROM (vm_pools_view v1 LEFT JOIN vm_pool_map ON (((v1.vm_pool_id = vm_pool_map.vm_pool_id) AND (v1.vm_pool_id = vmp.vm_pool_id))))) AS assigned_vm_count, (SELECT count(v2.vm_pool_id) AS expr1 FROM ((vm_pools v2 LEFT JOIN vm_pool_map vm_pool_map_1 ON (((v2.vm_pool_id = vm_pool_map_1.vm_pool_id) AND (v2.vm_pool_id = vmp.vm_pool_id)))) LEFT JOIN vm_dynamic ON ((vm_pool_map_1.vm_guid = vm_dynamic.vm_guid))) WHERE (vm_dynamic.status <> ALL (ARRAY[0, 15])) GROUP BY v2.vm_pool_id) AS vm_running_count FROM vm_pools_view vmp;


ALTER TABLE public.vm_pools_full_view OWNER TO engine;

--
-- Name: getvm_poolsbyvm_pool_id(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_poolsbyvm_pool_id(v_vm_pool_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vm_pools_full_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_pools_full_view.*
      FROM vm_pools_full_view
      WHERE vm_pool_id = v_vm_pool_id
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_vm_pool_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = v_vm_pool_id));
END; ';


ALTER FUNCTION public.getvm_poolsbyvm_pool_id(v_vm_pool_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvm_poolsbyvm_pool_name(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvm_poolsbyvm_pool_name(v_vm_pool_name character varying) RETURNS SETOF vm_pools_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_pools_view.*
      FROM vm_pools_view
      WHERE vm_pool_name = v_vm_pool_name;
END; ';


ALTER FUNCTION public.getvm_poolsbyvm_pool_name(v_vm_pool_name character varying) OWNER TO engine;

--
-- Name: getvmbyhibernationimageid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmbyhibernationimageid(v_image_id character varying) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT vms.*
      FROM vms
      WHERE hibernation_vol_handle like ''%'' || coalesce(v_image_id,'''') || ''%'';
END; ';


ALTER FUNCTION public.getvmbyhibernationimageid(v_image_id character varying) OWNER TO engine;

--
-- Name: getvmbyvmguid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmbyvmguid(v_vm_guid uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT DISTINCT vms.*
   FROM vms
   WHERE vm_guid = v_vm_guid
   AND   (NOT v_is_filtered OR EXISTS (SELECT 1
                                       FROM   user_vm_permissions_view
                                       WHERE  user_id = v_user_id AND entity_id = v_vm_guid));
END; ';


ALTER FUNCTION public.getvmbyvmguid(v_vm_guid uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvmdatafrompoolbypoolid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmdatafrompoolbypoolid(v_pool_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
     RETURN QUERY SELECT vms.*
     FROM vms WHERE vm_pool_id = v_pool_id
     AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                       FROM   user_vm_pool_permissions_view
                                       WHERE  user_id = v_user_id AND entity_id = v_pool_id))
     -- Limiting results to 1 since we only need a single VM from the pool to retrieve the pool data
     LIMIT 1;
END; ';


ALTER FUNCTION public.getvmdatafrompoolbypoolid(v_pool_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvmdevicebydeviceid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmdevicebydeviceid(v_device_id uuid, v_vm_id uuid) RETURNS SETOF vm_device_view
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   vm_device_view
    WHERE  device_id = v_device_id
    AND (v_vm_id IS NULL OR vm_id = v_vm_id);
END; ';


ALTER FUNCTION public.getvmdevicebydeviceid(v_device_id uuid, v_vm_id uuid) OWNER TO engine;

--
-- Name: getvmdevicebyvmid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmdevicebyvmid(v_vm_id uuid) RETURNS SETOF vm_device_view
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   vm_device_view
    WHERE  vm_id = v_vm_id order by device_id;
END; ';


ALTER FUNCTION public.getvmdevicebyvmid(v_vm_id uuid) OWNER TO engine;

--
-- Name: getvmdevicebyvmidandtype(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmdevicebyvmidandtype(v_vm_id uuid, v_type character varying) RETURNS SETOF vm_device_view
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   vm_device_view
    WHERE  vm_id = v_vm_id and type = v_type
    ORDER BY NULLIF(alias,'''') NULLS LAST;
END; ';


ALTER FUNCTION public.getvmdevicebyvmidandtype(v_vm_id uuid, v_type character varying) OWNER TO engine;

--
-- Name: getvmdevicebyvmidtypeanddevice(uuid, character varying, character varying, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmdevicebyvmidtypeanddevice(v_vm_id uuid, v_type character varying, v_device character varying, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vm_device_view
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    SELECT *
    FROM   vm_device_view
    WHERE  vm_id = v_vm_id and type = v_type and device = v_device
    AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                      FROM   user_vm_permissions_view
                                      WHERE  user_id = v_user_id AND entity_id = v_vm_id))
    ORDER BY NULLIF(alias,'''') NULLS LAST;

END; ';


ALTER FUNCTION public.getvmdevicebyvmidtypeanddevice(v_vm_id uuid, v_type character varying, v_device character varying, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvmdynamicbyvmguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmdynamicbyvmguid(v_vm_guid uuid) RETURNS SETOF vm_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_dynamic.*
      FROM vm_dynamic
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.getvmdynamicbyvmguid(v_vm_guid uuid) OWNER TO engine;

--
-- Name: getvmimagebyimageguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmimagebyimageguid(v_image_guid uuid) RETURNS SETOF vm_images_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT *
      FROM vm_images_view
      WHERE image_guid = v_image_guid;
END; ';


ALTER FUNCTION public.getvmimagebyimageguid(v_image_guid uuid) OWNER TO engine;

--
-- Name: getvmmapsinvmpoolbyvmpoolidandstatus(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmmapsinvmpoolbyvmpoolidandstatus(v_vm_pool_id uuid, v_status integer) RETURNS SETOF vm_pool_map
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_pool_id, vm_pool_map.vm_guid
      FROM vm_pool_map, vm_dynamic
      WHERE vm_pool_map.vm_guid = vm_dynamic.vm_guid
      AND vm_pool_id = v_vm_pool_id
      AND vm_dynamic.status = v_status;
END; ';


ALTER FUNCTION public.getvmmapsinvmpoolbyvmpoolidandstatus(v_vm_pool_id uuid, v_status integer) OWNER TO engine;

--
-- Name: getvmsbyadgroupnames(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsbyadgroupnames(v_ad_group_names character varying) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY select distinct vms.* from vms
   inner join permissions on vms.vm_guid = permissions.object_id
   inner join ad_groups on ad_groups.id = permissions.ad_element_id
   WHERE     (ad_groups.name in(select Id from fnSplitter(v_ad_group_names))); 
END; ';


ALTER FUNCTION public.getvmsbyadgroupnames(v_ad_group_names character varying) OWNER TO engine;

--
-- Name: vms_with_plug_info; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vms_with_plug_info AS
    SELECT vms.vm_name, vms.vm_mem_size_mb, vms.nice_level, vms.vmt_guid, vms.vm_os, vms.vm_description, vms.vds_group_id, vms.vm_domain, vms.vm_creation_date, vms.auto_startup, vms.is_stateless, vms.dedicated_vm_for_vds, vms.fail_back, vms.default_boot_sequence, vms.vm_type, vms.hypervisor_type, vms.operation_mode, vms.vds_group_name, vms.selection_algorithm, vms.transparent_hugepages, vms.storage_pool_id, vms.storage_pool_name, vms.vds_group_description, vms.vmt_name, vms.vmt_mem_size_mb, vms.vmt_os, vms.vmt_creation_date, vms.vmt_child_count, vms.vmt_num_of_sockets, vms.vmt_cpu_per_socket, vms.vmt_num_of_cpus, vms.vmt_description, vms.status, vms.vm_ip, vms.vm_host, vms.vm_pid, vms.last_start_time, vms.guest_cur_user_name, vms.guest_last_login_time, vms.guest_cur_user_id, vms.guest_last_logout_time, vms.guest_os, vms.console_user_id, vms.run_on_vds, vms.migrating_to_vds, vms.app_list, vms.display, vms.hibernation_vol_handle, vms.vm_pool_name, vms.vm_pool_id, vms.vm_guid, vms.num_of_monitors, vms.allow_console_reconnect, vms.is_initialized, vms.is_auto_suspend, vms.num_of_sockets, vms.cpu_per_socket, vms.usb_policy, vms.acpi_enable, vms.session, vms.num_of_cpus, vms.quota_id, vms.quota_name, vms.quota_enforcement_type, vms.display_ip, vms.display_type, vms.kvm_enable, vms.boot_sequence, vms.display_secure_port, vms.utc_diff, vms.last_vds_run_on, vms.client_ip, vms.guest_requested_memory, vms.time_zone, vms.cpu_user, vms.cpu_sys, vms.elapsed_time, vms.usage_network_percent, vms.usage_mem_percent, vms.usage_cpu_percent, vms.run_on_vds_name, vms.vds_group_cpu_name, vms.default_display_type, vms.priority, vms.iso_path, vms.origin, vms.vds_group_compatibility_version, vms.initrd_url, vms.kernel_url, vms.kernel_params, vms.pause_status, vms.exit_message, vms.exit_status, vms.migration_support, vms.predefined_properties, vms.userdefined_properties, vms.min_allocated_mem, vms.hash, vms.cpu_pinning, vd.device_id, vd.is_plugged FROM (vms JOIN vm_device vd ON ((vd.vm_id = vms.vm_guid)));


ALTER TABLE public.vms_with_plug_info OWNER TO engine;

--
-- Name: getvmsbydiskid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsbydiskid(v_disk_guid uuid) RETURNS SETOF vms_with_plug_info
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT vms_with_plug_info.*
      FROM vms_with_plug_info
      WHERE device_id = v_disk_guid;
END; ';


ALTER FUNCTION public.getvmsbydiskid(v_disk_guid uuid) OWNER TO engine;

--
-- Name: getvmsbystoragedomainid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsbystoragedomainid(v_storage_domain_id uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT vms.*
      FROM vms
      INNER JOIN vm_device vd ON vd.vm_id = vms.vm_guid
      INNER JOIN images ON images.image_group_id = vd.device_id AND images.active = TRUE
      inner join image_storage_domain_map on images.image_guid = image_storage_domain_map.image_id
      where image_storage_domain_map.storage_domain_id = v_storage_domain_id;
END; ';


ALTER FUNCTION public.getvmsbystoragedomainid(v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: getvmsbyuserid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsbyuserid(v_user_id uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY select vms.* from vms
   inner join permissions on vms.vm_guid = permissions.object_id
   WHERE permissions.ad_element_id = v_user_id;
END; ';


ALTER FUNCTION public.getvmsbyuserid(v_user_id uuid) OWNER TO engine;

--
-- Name: getvmsbyuseridwithgroupsanduserroles(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsbyuseridwithgroupsanduserroles(v_user_id uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT DISTINCT vms.*
   from vms
   inner join permissions_view as perms on vms.vm_guid = perms.object_id
   WHERE (perms.ad_element_id = v_user_id
   or perms.ad_element_id in(select id from getUserAndGroupsById(v_user_id)))
   and perms.role_type = 2;

END; ';


ALTER FUNCTION public.getvmsbyuseridwithgroupsanduserroles(v_user_id uuid) OWNER TO engine;

--
-- Name: getvmsbyvmtguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsbyvmtguid(v_vmt_guid uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT DISTINCT vms.*
   FROM vms
   WHERE vmt_guid = v_vmt_guid;
END; ';


ALTER FUNCTION public.getvmsbyvmtguid(v_vmt_guid uuid) OWNER TO engine;

--
-- Name: getvmsdedicatedtopowerclientbyvdsid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsdedicatedtopowerclientbyvdsid(v_dedicated_vm_for_vds uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT DISTINCT vms.*
   FROM vms inner join
   vds_static on vms.dedicated_vm_for_vds = vds_static.vds_id
   WHERE vms.dedicated_vm_for_vds = v_dedicated_vm_for_vds
   and vds_static.vds_type = 1;
END; ';


ALTER FUNCTION public.getvmsdedicatedtopowerclientbyvdsid(v_dedicated_vm_for_vds uuid) OWNER TO engine;

--
-- Name: getvmsdynamicrunningonvds(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsdynamicrunningonvds(v_vds_id uuid) RETURNS SETOF vm_dynamic
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_dynamic.*
      FROM vm_dynamic
      WHERE RUN_ON_VDS = v_vds_id;
END; ';


ALTER FUNCTION public.getvmsdynamicrunningonvds(v_vds_id uuid) OWNER TO engine;

--
-- Name: getvmsrunningonvds(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmsrunningonvds(v_vds_id uuid) RETURNS SETOF vms
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT DISTINCT vms.*
   FROM vms
   WHERE run_on_vds = v_vds_id;

END; ';


ALTER FUNCTION public.getvmsrunningonvds(v_vds_id uuid) OWNER TO engine;

--
-- Name: getvmstaticbygroupidandnetwork(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmstaticbygroupidandnetwork(v_groupid uuid, v_networkname character varying) RETURNS SETOF vm_static
    LANGUAGE plpgsql
    AS '
BEGIN
   RETURN QUERY SELECT
   vm_static.* from vm_static
   inner join vm_interface_view
   on vm_static.vm_guid = vm_interface_view.vm_guid
   and network_name = v_networkName
   and vm_static.vds_group_id = v_groupId;

    
END; ';


ALTER FUNCTION public.getvmstaticbygroupidandnetwork(v_groupid uuid, v_networkname character varying) OWNER TO engine;

--
-- Name: getvmstaticbyname(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmstaticbyname(v_vm_name character varying) RETURNS SETOF vm_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vm_static.*
   FROM vm_static
   WHERE VM_NAME = v_vm_name
   AND   entity_type = ''VM'';

END; ';


ALTER FUNCTION public.getvmstaticbyname(v_vm_name character varying) OWNER TO engine;

--
-- Name: getvmstaticbyvdsgroup(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmstaticbyvdsgroup(v_vds_group_id uuid) RETURNS SETOF vm_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vm_static.*
   FROM vm_static
   WHERE vds_group_id = v_vds_group_id
   AND   entity_type = ''VM'';

END; ';


ALTER FUNCTION public.getvmstaticbyvdsgroup(v_vds_group_id uuid) OWNER TO engine;

--
-- Name: getvmstaticbyvmguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmstaticbyvmguid(v_vm_guid uuid) RETURNS SETOF vm_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vm_static.*
   FROM vm_static
   WHERE vm_guid = v_vm_guid
   AND   entity_type = ''VM'';

END; ';


ALTER FUNCTION public.getvmstaticbyvmguid(v_vm_guid uuid) OWNER TO engine;

--
-- Name: getvmstaticwithfailbackbyvdsid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmstaticwithfailbackbyvdsid(v_vds_id uuid) RETURNS SETOF vm_static
    LANGUAGE plpgsql
    AS '
BEGIN
RETURN QUERY SELECT vm_static.*
   FROM vm_static
   WHERE dedicated_vm_for_vds = v_vds_id and fail_back = TRUE
   AND   entity_type = ''VM'';

END; ';


ALTER FUNCTION public.getvmstaticwithfailbackbyvdsid(v_vds_id uuid) OWNER TO engine;

--
-- Name: getvmstatisticsbyvmguid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmstatisticsbyvmguid(v_vm_guid uuid) RETURNS SETOF vm_statistics
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_statistics.*
      FROM vm_statistics
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.getvmstatisticsbyvmguid(v_vm_guid uuid) OWNER TO engine;

--
-- Name: getvmtagsbytagid(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmtagsbytagid(v_tag_ids character varying) RETURNS SETOF tags_vm_map_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT tags_vm_map_view.*
      FROM tags_vm_map_view
      WHERE tag_id in(select id from fnSplitterUuid(v_tag_ids));
END; ';


ALTER FUNCTION public.getvmtagsbytagid(v_tag_ids character varying) OWNER TO engine;

--
-- Name: getvmtemplatebyvdsgroupid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmtemplatebyvdsgroupid(v_vds_group_id uuid) RETURNS SETOF vm_templates_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_templates.*
      FROM vm_templates_view vm_templates
      WHERE vds_group_id = v_vds_group_id;
END; ';


ALTER FUNCTION public.getvmtemplatebyvdsgroupid(v_vds_group_id uuid) OWNER TO engine;

--
-- Name: getvmtemplatebyvmtguid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmtemplatebyvmtguid(v_vmt_guid uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vm_templates_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT vm_templates.*
      FROM vm_templates_view vm_templates
      WHERE vmt_guid = v_vmt_guid
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                        FROM   user_vm_template_permissions_view
                                        WHERE  user_id = v_user_id AND entity_id = v_vmt_guid));
END; ';


ALTER FUNCTION public.getvmtemplatebyvmtguid(v_vmt_guid uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: vm_templates_with_plug_info; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_templates_with_plug_info AS
    SELECT vm_templates_view.vmt_guid, vm_templates_view.name, vm_templates_view.mem_size_mb, vm_templates_view.os, vm_templates_view.creation_date, vm_templates_view.child_count, vm_templates_view.num_of_sockets, vm_templates_view.cpu_per_socket, vm_templates_view.num_of_cpus, vm_templates_view.description, vm_templates_view.vds_group_id, vm_templates_view.domain, vm_templates_view.num_of_monitors, vm_templates_view.allow_console_reconnect, vm_templates_view.status, vm_templates_view.usb_policy, vm_templates_view.time_zone, vm_templates_view.is_auto_suspend, vm_templates_view.fail_back, vm_templates_view.vds_group_name, vm_templates_view.vm_type, vm_templates_view.hypervisor_type, vm_templates_view.operation_mode, vm_templates_view.nice_level, vm_templates_view.storage_pool_id, vm_templates_view.storage_pool_name, vm_templates_view.quota_enforcement_type, vm_templates_view.default_boot_sequence, vm_templates_view.default_display_type, vm_templates_view.priority, vm_templates_view.auto_startup, vm_templates_view.is_stateless, vm_templates_view.iso_path, vm_templates_view.origin, vm_templates_view.initrd_url, vm_templates_view.kernel_url, vm_templates_view.kernel_params, vm_templates_view.quota_id, vm_templates_view.quota_name, vm_templates_view.migration_support, vm_templates_view.dedicated_vm_for_vds, images.image_guid, images.image_group_id, vd.is_plugged FROM ((vm_templates_view JOIN vm_device vd ON ((vd.vm_id = vm_templates_view.vmt_guid))) JOIN images ON (((images.image_group_id = vd.device_id) AND (images.active = true))));


ALTER TABLE public.vm_templates_with_plug_info OWNER TO engine;

--
-- Name: getvmtemplatesbyimageid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmtemplatesbyimageid(v_image_guid uuid) RETURNS SETOF vm_templates_with_plug_info
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT * 
      FROM vm_templates_with_plug_info t
      WHERE t.image_guid = v_image_guid;
END; ';


ALTER FUNCTION public.getvmtemplatesbyimageid(v_image_guid uuid) OWNER TO engine;

--
-- Name: getvmtemplatesbystoragedomainid(uuid, uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmtemplatesbystoragedomainid(v_storage_domain_id uuid, v_user_id uuid, v_is_filtered boolean) RETURNS SETOF vm_templates_view
    LANGUAGE plpgsql
    AS '
BEGIN
      RETURN QUERY SELECT DISTINCT vm_templates.*
      FROM vm_templates_view vm_templates
      INNER JOIN vm_device vd ON vd.vm_id = vm_templates.vmt_guid
      INNER JOIN images i ON i.image_group_id = vd.device_id AND i.active = TRUE
      where i.image_guid in(select image_id from image_storage_domain_map where storage_domain_id = v_storage_domain_id)
      AND (NOT v_is_filtered OR EXISTS (SELECT 1
                                      FROM   user_vm_template_permissions_view
                                      WHERE  user_id = v_user_id AND entity_id = vm_templates.vmt_guid));
END; ';


ALTER FUNCTION public.getvmtemplatesbystoragedomainid(v_storage_domain_id uuid, v_user_id uuid, v_is_filtered boolean) OWNER TO engine;

--
-- Name: getvmunmanageddevicesbyvmid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION getvmunmanageddevicesbyvmid(v_vm_id uuid) RETURNS SETOF vm_device_view
    LANGUAGE plpgsql
    AS '
BEGIN
    RETURN QUERY
    select vm_device_view.* from vm_device_view
    where vm_id = v_vm_id and
          is_managed = false;
END; ';


ALTER FUNCTION public.getvmunmanageddevicesbyvmid(v_vm_id uuid) OWNER TO engine;

--
-- Name: insert_entity_snapshot(uuid, character varying, character varying, character varying, text, character varying, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insert_entity_snapshot(v_command_id uuid, v_command_type character varying, v_entity_id character varying, v_entity_type character varying, v_entity_snapshot text, v_snapshot_class character varying, v_snapshot_type integer, v_insertion_order integer) RETURNS void
    LANGUAGE plpgsql
    AS '
declare v_id uuid;
BEGIN
	BEGIN 	 
		INSERT INTO business_entity_snapshot(id, command_id, command_type, entity_id,entity_type,entity_snapshot, snapshot_class, snapshot_type,insertion_order)
				VALUES(uuid_generate_v1(), v_command_id, v_command_type, v_entity_id,v_entity_type,v_entity_snapshot, v_snapshot_class, v_snapshot_type,v_insertion_order);
	END;
    
   RETURN;
END; ';


ALTER FUNCTION public.insert_entity_snapshot(v_command_id uuid, v_command_type character varying, v_entity_id character varying, v_entity_type character varying, v_entity_snapshot text, v_snapshot_class character varying, v_snapshot_type integer, v_insertion_order integer) OWNER TO engine;

--
-- Name: insert_roles_groups(integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insert_roles_groups(v_action_group_id integer, v_role_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO roles_groups(action_group_id, role_id)
	VALUES(v_action_group_id, v_role_id);
END; ';


ALTER FUNCTION public.insert_roles_groups(v_action_group_id integer, v_role_id uuid) OWNER TO engine;

--
-- Name: insertaction_version_map(integer, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertaction_version_map(v_action_type integer, v_cluster_minimal_version character varying, v_storage_pool_minimal_version character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO action_version_map(action_type, cluster_minimal_version, storage_pool_minimal_version)
	VALUES(v_action_type, v_cluster_minimal_version, v_storage_pool_minimal_version);
END; ';


ALTER FUNCTION public.insertaction_version_map(v_action_type integer, v_cluster_minimal_version character varying, v_storage_pool_minimal_version character varying) OWNER TO engine;

--
-- Name: insertad_groups(uuid, character varying, integer, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertad_groups(v_id uuid, v_name character varying, v_status integer, v_domain character varying, v_distinguishedname character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO ad_groups(id, name,status,domain,distinguishedname)
	VALUES(v_id, v_name,v_status,v_domain,v_distinguishedname);
END; ';


ALTER FUNCTION public.insertad_groups(v_id uuid, v_name character varying, v_status integer, v_domain character varying, v_distinguishedname character varying) OWNER TO engine;

--
-- Name: insertasync_tasks(integer, integer, integer, uuid, text, character varying, uuid, uuid, character varying, timestamp without time zone, uuid, integer, text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertasync_tasks(v_action_type integer, v_result integer, v_status integer, v_task_id uuid, v_action_parameters text, v_action_params_class character varying, v_step_id uuid, v_command_id uuid, v_entity_type character varying, v_started_at timestamp without time zone, v_storage_pool_id uuid, v_async_task_type integer, v_entity_ids text) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO async_tasks(action_type, result, status, task_id, action_parameters,action_params_class, step_id, command_id, started_at,storage_pool_id, task_type)
	VALUES(v_action_type, v_result, v_status, v_task_id, v_action_parameters,v_action_params_class, v_step_id, v_command_id, v_started_at, v_storage_pool_id, v_async_task_type);
INSERT INTO async_tasks_entities (async_task_id,entity_id,entity_type)
	SELECT v_task_id,id,v_entity_type from fnsplitteruuid(v_entity_ids);
END; ';


ALTER FUNCTION public.insertasync_tasks(v_action_type integer, v_result integer, v_status integer, v_task_id uuid, v_action_parameters text, v_action_params_class character varying, v_step_id uuid, v_command_id uuid, v_entity_type character varying, v_started_at timestamp without time zone, v_storage_pool_id uuid, v_async_task_type integer, v_entity_ids text) OWNER TO engine;

--
-- Name: insertauditlog(integer, timestamp with time zone, integer, character varying, integer, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, character varying, uuid, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertauditlog(INOUT v_audit_log_id integer, v_log_time timestamp with time zone, v_log_type integer, v_log_type_name character varying, v_severity integer, v_message character varying, v_user_id uuid, v_user_name character varying, v_vds_id uuid, v_vds_name character varying, v_vm_id uuid, v_vm_name character varying, v_vm_template_id uuid, v_vm_template_name character varying, v_storage_pool_id uuid, v_storage_pool_name character varying, v_storage_domain_id uuid, v_storage_domain_name character varying, v_vds_group_id uuid, v_vds_group_name character varying, v_quota_id uuid, v_quota_name character varying, v_correlation_id character varying, v_job_id uuid, v_gluster_volume_id uuid, v_gluster_volume_name character varying) RETURNS integer
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_min_alret_severity  INTEGER;
BEGIN
      v_min_alret_severity := 10;
	-- insert regular log messages (non alerts)
      if (v_severity < v_min_alret_severity) then
	 
INSERT INTO audit_log(LOG_TIME, log_type, log_type_name, severity,message, user_id, USER_NAME, vds_id, VDS_NAME, vm_id, VM_NAME,vm_template_id,VM_TEMPLATE_NAME,storage_pool_id,STORAGE_POOL_NAME,storage_domain_id,STORAGE_DOMAIN_NAME,vds_group_id,vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name)
		VALUES(v_log_time, v_log_type, v_log_type_name, v_severity, v_message, v_user_id, v_user_name, v_vds_id, v_vds_name, v_vm_id, v_vm_name,v_vm_template_id,v_vm_template_name,v_storage_pool_id,v_storage_pool_name,v_storage_domain_id,v_storage_domain_name,v_vds_group_id,v_vds_group_name, v_correlation_id, v_job_id, v_quota_id, v_quota_name, v_gluster_volume_id, v_gluster_volume_name);
		
         v_audit_log_id := CURRVAL(''audit_log_seq'');
      else
         if (not exists(select audit_log_id from audit_log where vds_name = v_vds_name and log_type = v_log_type)) then
		 
INSERT INTO audit_log(LOG_TIME, log_type, log_type_name, severity,message, user_id, USER_NAME, vds_id, VDS_NAME, vm_id, VM_NAME,vm_template_id,VM_TEMPLATE_NAME,storage_pool_id,STORAGE_POOL_NAME,storage_domain_id,STORAGE_DOMAIN_NAME,vds_group_id,vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name)
			VALUES(v_log_time, v_log_type, v_log_type_name, v_severity, v_message, v_user_id, v_user_name, v_vds_id, v_vds_name, v_vm_id, v_vm_name,v_vm_template_id,v_vm_template_name,v_storage_pool_id,v_storage_pool_name,v_storage_domain_id,v_storage_domain_name,v_vds_group_id,v_vds_group_name, v_correlation_id, v_job_id, v_quota_id, v_quota_name, v_gluster_volume_id, v_gluster_volume_name);
			
            v_audit_log_id := CURRVAL(''audit_log_seq'');
         else
            select   audit_log_id INTO v_audit_log_id from audit_log where vds_name = v_vds_name and log_type = v_log_type;
         end if;
      end if;
END; ';


ALTER FUNCTION public.insertauditlog(INOUT v_audit_log_id integer, v_log_time timestamp with time zone, v_log_type integer, v_log_type_name character varying, v_severity integer, v_message character varying, v_user_id uuid, v_user_name character varying, v_vds_id uuid, v_vds_name character varying, v_vm_id uuid, v_vm_name character varying, v_vm_template_id uuid, v_vm_template_name character varying, v_storage_pool_id uuid, v_storage_pool_name character varying, v_storage_domain_id uuid, v_storage_domain_name character varying, v_vds_group_id uuid, v_vds_group_name character varying, v_quota_id uuid, v_quota_name character varying, v_correlation_id character varying, v_job_id uuid, v_gluster_volume_id uuid, v_gluster_volume_name character varying) OWNER TO engine;

--
-- Name: insertbasedisk(uuid, character varying, boolean, character varying, character varying, character varying, boolean, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertbasedisk(v_disk_id uuid, v_disk_interface character varying, v_wipe_after_delete boolean, v_propagate_errors character varying, v_disk_alias character varying, v_disk_description character varying, v_shareable boolean, v_boot boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO base_disks(
        disk_id,
        disk_interface,
        wipe_after_delete,
        propagate_errors,
        disk_alias,
        disk_description,
        shareable,
        boot)
    VALUES(
        v_disk_id,
        v_disk_interface,
        v_wipe_after_delete,
        v_propagate_errors,
        v_disk_alias,
        v_disk_description,
        v_shareable,
        v_boot);
END; ';


ALTER FUNCTION public.insertbasedisk(v_disk_id uuid, v_disk_interface character varying, v_wipe_after_delete boolean, v_propagate_errors character varying, v_disk_alias character varying, v_disk_description character varying, v_shareable boolean, v_boot boolean) OWNER TO engine;

--
-- Name: insertbookmark(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertbookmark(v_bookmark_name character varying, v_bookmark_value character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO bookmarks(bookmark_Id,bookmark_name, bookmark_value)
	VALUES(uuid_generate_v1(),v_bookmark_name, v_bookmark_value);
END; ';


ALTER FUNCTION public.insertbookmark(v_bookmark_name character varying, v_bookmark_value character varying) OWNER TO engine;

--
-- Name: insertcustom_actions(integer, character varying, character varying, integer, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertcustom_actions(INOUT v_action_id integer, v_action_name character varying, v_path character varying, v_tab integer, v_description character varying) RETURNS integer
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO custom_actions(action_name, path, tab, description)
	VALUES(v_action_name, v_path, v_tab, v_description);
    
      v_action_id := CURRVAL(''custom_actions_seq'');
END; ';


ALTER FUNCTION public.insertcustom_actions(INOUT v_action_id integer, v_action_name character varying, v_path character varying, v_tab integer, v_description character varying) OWNER TO engine;

--
-- Name: insertdisk_image_dynamic(uuid, integer, integer, bigint, numeric, numeric, numeric); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertdisk_image_dynamic(v_image_id uuid, v_read_rate integer, v_write_rate integer, v_actual_size bigint, v_read_latency_seconds numeric, v_write_latency_seconds numeric, v_flush_latency_seconds numeric) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO disk_image_dynamic(image_id, read_rate, write_rate, actual_size, read_latency_seconds, write_latency_seconds, flush_latency_seconds)
	VALUES(v_image_id, v_read_rate, v_write_rate, v_actual_size, v_read_latency_seconds, v_write_latency_seconds, v_flush_latency_seconds);
END; ';


ALTER FUNCTION public.insertdisk_image_dynamic(v_image_id uuid, v_read_rate integer, v_write_rate integer, v_actual_size bigint, v_read_latency_seconds numeric, v_write_latency_seconds numeric, v_flush_latency_seconds numeric) OWNER TO engine;

--
-- Name: insertdisklunmap(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertdisklunmap(v_disk_id uuid, v_lun_id character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO disk_lun_map(
        disk_id,
        lun_id)
    VALUES(
        v_disk_id,
        v_lun_id);
END; ';


ALTER FUNCTION public.insertdisklunmap(v_disk_id uuid, v_lun_id character varying) OWNER TO engine;

--
-- Name: insertevent_notification_hist(bigint, character varying, character, character, timestamp with time zone, boolean, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertevent_notification_hist(v_audit_log_id bigint, v_event_name character varying, v_method_type character, v_reason character, v_sent_at timestamp with time zone, v_status boolean, v_subscriber_id character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO event_notification_hist(audit_log_id, event_name, method_type, reason, sent_at, status, subscriber_id)
	VALUES(v_audit_log_id, v_event_name, v_method_type, v_reason, v_sent_at, v_status, v_subscriber_id::uuid);
END; ';


ALTER FUNCTION public.insertevent_notification_hist(v_audit_log_id bigint, v_event_name character varying, v_method_type character, v_reason character, v_sent_at timestamp with time zone, v_status boolean, v_subscriber_id character varying) OWNER TO engine;

--
-- Name: insertevent_subscriber(character varying, integer, character varying, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertevent_subscriber(v_event_up_name character varying, v_method_id integer, v_method_address character varying, v_subscriber_id uuid, v_tag_name character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      if not exists(select * from  event_subscriber where
      subscriber_id = v_subscriber_id and
      event_up_name = v_event_up_name and
      method_id = v_method_id and
      tag_name = v_tag_name) then
		 
INSERT INTO event_subscriber(event_up_name, method_id, method_address, subscriber_id, tag_name)
			VALUES(v_event_up_name, v_method_id, v_method_address, v_subscriber_id,v_tag_name);
      end if;
END; ';


ALTER FUNCTION public.insertevent_subscriber(v_event_up_name character varying, v_method_id integer, v_method_address character varying, v_subscriber_id uuid, v_tag_name character varying) OWNER TO engine;

--
-- Name: insertglustervolume(uuid, uuid, character varying, character varying, character varying, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertglustervolume(v_id uuid, v_cluster_id uuid, v_vol_name character varying, v_vol_type character varying, v_status character varying, v_replica_count integer, v_stripe_count integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO gluster_volumes (id, cluster_id, vol_name, vol_type,
        status, replica_count, stripe_count)
    VALUES (v_id,  v_cluster_id, v_vol_name, v_vol_type,
        v_status, v_replica_count,  v_stripe_count);
END; ';


ALTER FUNCTION public.insertglustervolume(v_id uuid, v_cluster_id uuid, v_vol_name character varying, v_vol_type character varying, v_status character varying, v_replica_count integer, v_stripe_count integer) OWNER TO engine;

--
-- Name: insertglustervolumeaccessprotocol(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertglustervolumeaccessprotocol(v_volume_id uuid, v_access_protocol character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO gluster_volume_access_protocols (volume_id, access_protocol)
    VALUES (v_volume_id, v_access_protocol);
END; ';


ALTER FUNCTION public.insertglustervolumeaccessprotocol(v_volume_id uuid, v_access_protocol character varying) OWNER TO engine;

--
-- Name: insertglustervolumebrick(uuid, uuid, uuid, character varying, integer, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertglustervolumebrick(v_id uuid, v_volume_id uuid, v_server_id uuid, v_brick_dir character varying, v_brick_order integer, v_status character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO gluster_volume_bricks (id, volume_id, server_id, brick_dir, brick_order, status)
    VALUES (v_id, v_volume_id, v_server_id, v_brick_dir, v_brick_order, v_status);
END; ';


ALTER FUNCTION public.insertglustervolumebrick(v_id uuid, v_volume_id uuid, v_server_id uuid, v_brick_dir character varying, v_brick_order integer, v_status character varying) OWNER TO engine;

--
-- Name: insertglustervolumeoption(uuid, uuid, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertglustervolumeoption(v_id uuid, v_volume_id uuid, v_option_key character varying, v_option_val character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO gluster_volume_options (id, volume_id, option_key, option_val)
    VALUES (v_id, v_volume_id, v_option_key, v_option_val);
END; ';


ALTER FUNCTION public.insertglustervolumeoption(v_id uuid, v_volume_id uuid, v_option_key character varying, v_option_val character varying) OWNER TO engine;

--
-- Name: insertglustervolumetransporttype(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertglustervolumetransporttype(v_volume_id uuid, v_transport_type character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO gluster_volume_transport_types (volume_id, transport_type)
    VALUES (v_volume_id, v_transport_type);
END; ';


ALTER FUNCTION public.insertglustervolumetransporttype(v_volume_id uuid, v_transport_type character varying) OWNER TO engine;

--
-- Name: insertimage(timestamp with time zone, uuid, uuid, bigint, uuid, integer, timestamp with time zone, uuid, integer, integer, uuid, boolean, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertimage(v_creation_date timestamp with time zone, v_image_guid uuid, v_it_guid uuid, v_size bigint, v_parentid uuid, v_imagestatus integer, v_lastmodified timestamp with time zone, v_vm_snapshot_id uuid, v_volume_type integer, v_volume_format integer, v_image_group_id uuid, v_active boolean, v_quota_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO images(
        creation_date,
        image_guid,
        it_guid,
        size,
        ParentId,
        imageStatus,
        lastModified,
        vm_snapshot_id,
        volume_type,
        image_group_id,
        volume_format,
        active,
        quota_id)
    VALUES(
        v_creation_date,
        v_image_guid,
        v_it_guid,
        v_size,
        v_ParentId,
        v_imageStatus,
        v_lastModified,
        v_vm_snapshot_id,
        v_volume_type,
        v_image_group_id,
        v_volume_format,
        v_active,
        v_quota_id);
END; ';


ALTER FUNCTION public.insertimage(v_creation_date timestamp with time zone, v_image_guid uuid, v_it_guid uuid, v_size bigint, v_parentid uuid, v_imagestatus integer, v_lastmodified timestamp with time zone, v_vm_snapshot_id uuid, v_volume_type integer, v_volume_format integer, v_image_group_id uuid, v_active boolean, v_quota_id uuid) OWNER TO engine;

--
-- Name: insertimage_storage_domain_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertimage_storage_domain_map(v_image_id uuid, v_storage_domain_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO image_storage_domain_map(image_id, storage_domain_id)
	VALUES(v_image_id, v_storage_domain_id);
END; ';


ALTER FUNCTION public.insertimage_storage_domain_map(v_image_id uuid, v_storage_domain_id uuid) OWNER TO engine;

--
-- Name: insertjob(uuid, character varying, text, character varying, uuid, boolean, timestamp with time zone, timestamp with time zone, timestamp with time zone, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertjob(v_job_id uuid, v_action_type character varying, v_description text, v_status character varying, v_owner_id uuid, v_visible boolean, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_last_update_time timestamp with time zone, v_correlation_id character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO job(
        job_id,
        action_type,
        description,
        status,
        owner_id,
        visible,
        start_time,
        end_time,
        last_update_time,
        correlation_id)
    VALUES (
        v_job_id,
        v_action_type,
        v_description,
        v_status,
        v_owner_id,
        v_visible,
        v_start_time,
        v_end_time,
        v_last_update_time,
        v_correlation_id);
END; ';


ALTER FUNCTION public.insertjob(v_job_id uuid, v_action_type character varying, v_description text, v_status character varying, v_owner_id uuid, v_visible boolean, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_last_update_time timestamp with time zone, v_correlation_id character varying) OWNER TO engine;

--
-- Name: insertjobsubjectentity(uuid, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertjobsubjectentity(v_job_id uuid, v_entity_id uuid, v_entity_type character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO job_subject_entity(
        job_id,
        entity_id,
        entity_type)
    VALUES (
        v_job_id,
        v_entity_id,
        v_entity_type);
END; ';


ALTER FUNCTION public.insertjobsubjectentity(v_job_id uuid, v_entity_id uuid, v_entity_type character varying) OWNER TO engine;

--
-- Name: insertlun_storage_server_connection_map(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertlun_storage_server_connection_map(v_lun_id character varying, v_storage_server_connection character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO LUN_storage_server_connection_map(LUN_id, storage_server_connection)
	VALUES(v_LUN_id, v_storage_server_connection);
END; ';


ALTER FUNCTION public.insertlun_storage_server_connection_map(v_lun_id character varying, v_storage_server_connection character varying) OWNER TO engine;

--
-- Name: insertluns(character varying, character varying, character varying, character varying, integer, character varying, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertluns(v_lun_id character varying, v_physical_volume_id character varying, v_volume_group_id character varying, v_serial character varying, v_lun_mapping integer, v_vendor_id character varying, v_product_id character varying, v_device_size integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO LUNs(LUN_id, physical_volume_id, volume_group_id, serial, lun_mapping, vendor_id, product_id, device_size)
	VALUES(v_LUN_id, v_physical_volume_id, v_volume_group_id, v_serial, v_lun_mapping, v_vendor_id, v_product_id, v_device_size);
END; ';


ALTER FUNCTION public.insertluns(v_lun_id character varying, v_physical_volume_id character varying, v_volume_group_id character varying, v_serial character varying, v_lun_mapping integer, v_vendor_id character varying, v_product_id character varying, v_device_size integer) OWNER TO engine;

--
-- Name: insertnetwork(character varying, character varying, uuid, character varying, character varying, character varying, integer, integer, boolean, uuid, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertnetwork(v_addr character varying, v_description character varying, v_id uuid, v_name character varying, v_subnet character varying, v_gateway character varying, v_type integer, v_vlan_id integer, v_stp boolean, v_storage_pool_id uuid, v_mtu integer, v_vm_network boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO network(addr, description, id, name, subnet, gateway, type, vlan_id, stp, storage_pool_id, mtu, vm_network)
	VALUES(v_addr, v_description, v_id, v_name, v_subnet, v_gateway, v_type, v_vlan_id, v_stp, v_storage_pool_id, v_mtu, v_vm_network );
END; ';


ALTER FUNCTION public.insertnetwork(v_addr character varying, v_description character varying, v_id uuid, v_name character varying, v_subnet character varying, v_gateway character varying, v_type integer, v_vlan_id integer, v_stp boolean, v_storage_pool_id uuid, v_mtu integer, v_vm_network boolean) OWNER TO engine;

--
-- Name: insertnetwork_cluster(uuid, uuid, integer, boolean, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertnetwork_cluster(v_cluster_id uuid, v_network_id uuid, v_status integer, v_is_display boolean, v_required boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO network_cluster(cluster_id, network_id, status, is_display, required)
	VALUES(v_cluster_id, v_network_id, v_status, v_is_display, v_required);
END; ';


ALTER FUNCTION public.insertnetwork_cluster(v_cluster_id uuid, v_network_id uuid, v_status integer, v_is_display boolean, v_required boolean) OWNER TO engine;

--
-- Name: insertpermission(uuid, uuid, uuid, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertpermission(v_ad_element_id uuid, v_id uuid, v_role_id uuid, v_object_id uuid, v_object_type_id integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO permissions(ad_element_id, id, role_id, object_id, object_type_id)
	VALUES(v_ad_element_id, v_id, v_role_id, v_object_id, v_object_type_id);
END; ';


ALTER FUNCTION public.insertpermission(v_ad_element_id uuid, v_id uuid, v_role_id uuid, v_object_id uuid, v_object_type_id integer) OWNER TO engine;

--
-- Name: insertquota(uuid, uuid, character varying, character varying, integer, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertquota(v_id uuid, v_storage_pool_id uuid, v_quota_name character varying, v_description character varying, v_threshold_vds_group_percentage integer, v_threshold_storage_percentage integer, v_grace_vds_group_percentage integer, v_grace_storage_percentage integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO quota(id, storage_pool_id, quota_name, description, threshold_vds_group_percentage, threshold_storage_percentage, grace_vds_group_percentage, grace_storage_percentage)
   VALUES(v_id,  v_storage_pool_id, v_quota_name,  v_description,  v_threshold_vds_group_percentage ,  v_threshold_storage_percentage,  v_grace_vds_group_percentage,  v_grace_storage_percentage);
END; ';


ALTER FUNCTION public.insertquota(v_id uuid, v_storage_pool_id uuid, v_quota_name character varying, v_description character varying, v_threshold_vds_group_percentage integer, v_threshold_storage_percentage integer, v_grace_vds_group_percentage integer, v_grace_storage_percentage integer) OWNER TO engine;

--
-- Name: insertquotalimitation(uuid, uuid, uuid, uuid, integer, bigint, bigint); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertquotalimitation(v_id uuid, v_quota_id uuid, v_storage_id uuid, v_vds_group_id uuid, v_virtual_cpu integer, v_mem_size_mb bigint, v_storage_size_gb bigint) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO quota_limitation(id, quota_id, storage_id, vds_group_id, virtual_cpu, mem_size_mb, storage_size_gb)
   VALUES(v_id, v_quota_id, v_storage_id, v_vds_group_id, v_virtual_cpu, v_mem_size_mb, v_storage_size_gb);

END; ';


ALTER FUNCTION public.insertquotalimitation(v_id uuid, v_quota_id uuid, v_storage_id uuid, v_vds_group_id uuid, v_virtual_cpu integer, v_mem_size_mb bigint, v_storage_size_gb bigint) OWNER TO engine;

--
-- Name: insertrepo_domain_file_meta_data(uuid, character varying, bigint, timestamp with time zone, bigint, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertrepo_domain_file_meta_data(v_repo_domain_id uuid, v_repo_file_name character varying, v_size bigint, v_date_created timestamp with time zone, v_last_refreshed bigint, v_file_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

INSERT INTO repo_file_meta_data(repo_domain_id, repo_file_name, size, date_created, last_refreshed, file_type)
    VALUES(v_repo_domain_id, v_repo_file_name, v_size, v_date_created, v_last_refreshed, v_file_type);

END; ';


ALTER FUNCTION public.insertrepo_domain_file_meta_data(v_repo_domain_id uuid, v_repo_file_name character varying, v_size bigint, v_date_created timestamp with time zone, v_last_refreshed bigint, v_file_type integer) OWNER TO engine;

--
-- Name: insertrole(character varying, uuid, character varying, boolean, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertrole(v_description character varying, v_id uuid, v_name character varying, v_is_readonly boolean, v_role_type integer, v_allows_viewing_children boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO roles(description, id, name, is_readonly, role_type, allows_viewing_children)
	VALUES(v_description, v_id, v_name, v_is_readonly, v_role_type, v_allows_viewing_children);
END; ';


ALTER FUNCTION public.insertrole(v_description character varying, v_id uuid, v_name character varying, v_is_readonly boolean, v_role_type integer, v_allows_viewing_children boolean) OWNER TO engine;

--
-- Name: insertroles_relations(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertroles_relations(v_role_container_id uuid, v_role_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO roles_relations(role_container_id, role_id)
	VALUES(v_role_container_id, v_role_id);
END; ';


ALTER FUNCTION public.insertroles_relations(v_role_container_id uuid, v_role_id uuid) OWNER TO engine;

--
-- Name: insertsnapshot(uuid, uuid, character varying, character varying, character varying, timestamp with time zone, text, text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertsnapshot(v_snapshot_id uuid, v_vm_id uuid, v_snapshot_type character varying, v_status character varying, v_description character varying, v_creation_date timestamp with time zone, v_app_list text, v_vm_configuration text) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO snapshots(
        snapshot_id,
        status,
        vm_id,
        snapshot_type,
        description,
        creation_date,
        app_list,
        vm_configuration)
    VALUES(
        v_snapshot_id,
        v_status,
        v_vm_id,
        v_snapshot_type,
        v_description,
        v_creation_date,
        v_app_list,
        v_vm_configuration);
END; ';


ALTER FUNCTION public.insertsnapshot(v_snapshot_id uuid, v_vm_id uuid, v_snapshot_type character varying, v_status character varying, v_description character varying, v_creation_date timestamp with time zone, v_app_list text, v_vm_configuration text) OWNER TO engine;

--
-- Name: insertstep(uuid, uuid, uuid, character varying, text, integer, character varying, timestamp with time zone, timestamp with time zone, character varying, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertstep(v_step_id uuid, v_parent_step_id uuid, v_job_id uuid, v_step_type character varying, v_description text, v_step_number integer, v_status character varying, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_correlation_id character varying, v_external_id uuid, v_external_system_type character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO step(
        step_id,
        parent_step_id,
        job_id,
        step_type,
        description,
        step_number,
        status,
        start_time,
        end_time,
        correlation_id,
        external_id,
        external_system_type)
    VALUES (
        v_step_id,
        v_parent_step_id,
        v_job_id,
        v_step_type,
        v_description,
        v_step_number,
        v_status,
        v_start_time,
        v_end_time,
        v_correlation_id,
        v_external_id,
        v_external_system_type);
END; ';


ALTER FUNCTION public.insertstep(v_step_id uuid, v_parent_step_id uuid, v_job_id uuid, v_step_type character varying, v_description text, v_step_number integer, v_status character varying, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_correlation_id character varying, v_external_id uuid, v_external_system_type character varying) OWNER TO engine;

--
-- Name: insertstorage_domain_dynamic(integer, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertstorage_domain_dynamic(v_available_disk_size integer, v_id uuid, v_used_disk_size integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO storage_domain_dynamic(available_disk_size, id, used_disk_size)
	VALUES(v_available_disk_size, v_id, v_used_disk_size);
END; ';


ALTER FUNCTION public.insertstorage_domain_dynamic(v_available_disk_size integer, v_id uuid, v_used_disk_size integer) OWNER TO engine;

--
-- Name: insertstorage_domain_static(uuid, character varying, character varying, integer, integer, character varying, bigint); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertstorage_domain_static(v_id uuid, v_storage character varying, v_storage_name character varying, v_storage_type integer, v_storage_domain_type integer, v_storage_domain_format_type character varying, v_last_time_used_as_master bigint) RETURNS void
    LANGUAGE plpgsql
    AS '
   BEGIN
INSERT INTO storage_domain_static(id, storage,storage_name, storage_type, storage_domain_type, storage_domain_format_type, last_time_used_as_master)
	VALUES(v_id, v_storage, v_storage_name, v_storage_type, v_storage_domain_type, v_storage_domain_format_type, v_last_time_used_as_master);
END; ';


ALTER FUNCTION public.insertstorage_domain_static(v_id uuid, v_storage character varying, v_storage_name character varying, v_storage_type integer, v_storage_domain_type integer, v_storage_domain_format_type character varying, v_last_time_used_as_master bigint) OWNER TO engine;

--
-- Name: insertstorage_pool(character varying, uuid, character varying, integer, integer, integer, uuid, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertstorage_pool(v_description character varying, v_id uuid, v_name character varying, v_storage_pool_type integer, v_status integer, v_master_domain_version integer, v_spm_vds_id uuid, v_compatibility_version character varying, v_quota_enforcement_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO storage_pool(description, id, name, storage_pool_type,status,master_domain_version,spm_vds_id,compatibility_version,quota_enforcement_type)
	VALUES(v_description, v_id, v_name, v_storage_pool_type,v_status,v_master_domain_version,v_spm_vds_id,v_compatibility_version,v_quota_enforcement_type);
END; ';


ALTER FUNCTION public.insertstorage_pool(v_description character varying, v_id uuid, v_name character varying, v_storage_pool_type integer, v_status integer, v_master_domain_version integer, v_spm_vds_id uuid, v_compatibility_version character varying, v_quota_enforcement_type integer) OWNER TO engine;

--
-- Name: insertstorage_pool_iso_map(uuid, uuid, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertstorage_pool_iso_map(v_storage_id uuid, v_storage_pool_id uuid, v_status integer, v_owner integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO storage_pool_iso_map(storage_id, storage_pool_id, status, owner)
	VALUES(v_storage_id, v_storage_pool_id, v_status, v_owner);
END; ';


ALTER FUNCTION public.insertstorage_pool_iso_map(v_storage_id uuid, v_storage_pool_id uuid, v_status integer, v_owner integer) OWNER TO engine;

--
-- Name: insertstorage_server_connections(character varying, character varying, character varying, character varying, character varying, text, integer, character varying, character varying, character varying, character varying, smallint, smallint); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertstorage_server_connections(v_connection character varying, v_id character varying, v_iqn character varying, v_port character varying, v_portal character varying, v_password text, v_storage_type integer, v_user_name character varying, v_mount_options character varying, v_vfs_type character varying, v_nfs_version character varying, v_nfs_timeo smallint, v_nfs_retrans smallint) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO storage_server_connections(connection, id, iqn, port,portal,
	password, storage_type, user_name,mount_options,vfs_type,nfs_version,nfs_timeo,nfs_retrans)
	VALUES(v_connection, v_id, v_iqn,v_port,v_portal, v_password, v_storage_type, v_user_name,v_mount_options,v_vfs_type,v_nfs_version,v_nfs_timeo,v_nfs_retrans);
END; ';


ALTER FUNCTION public.insertstorage_server_connections(v_connection character varying, v_id character varying, v_iqn character varying, v_port character varying, v_portal character varying, v_password text, v_storage_type integer, v_user_name character varying, v_mount_options character varying, v_vfs_type character varying, v_nfs_version character varying, v_nfs_timeo smallint, v_nfs_retrans smallint) OWNER TO engine;

--
-- Name: inserttags(character varying, uuid, character varying, uuid, boolean, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inserttags(v_description character varying, INOUT v_tag_id uuid, v_tag_name character varying, v_parent_id uuid, v_readonly boolean, v_type integer) RETURNS uuid
    LANGUAGE plpgsql
    AS '
BEGIN
      v_tag_id := uuid_generate_v1();
      INSERT INTO tags(tag_id,description, tag_name,parent_id,readonly,type)
	VALUES(v_tag_id,v_description, v_tag_name,v_parent_id,v_readonly,v_type);
END; ';


ALTER FUNCTION public.inserttags(v_description character varying, INOUT v_tag_id uuid, v_tag_name character varying, v_parent_id uuid, v_readonly boolean, v_type integer) OWNER TO engine;

--
-- Name: inserttags_user_group_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inserttags_user_group_map(v_group_id uuid, v_tag_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO tags_user_group_map(group_id, tag_id)
	VALUES(v_group_id, v_tag_id);
END; ';


ALTER FUNCTION public.inserttags_user_group_map(v_group_id uuid, v_tag_id uuid) OWNER TO engine;

--
-- Name: inserttags_user_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inserttags_user_map(v_tag_id uuid, v_user_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO tags_user_map(tag_id, user_id)
	VALUES(v_tag_id, v_user_id);
END; ';


ALTER FUNCTION public.inserttags_user_map(v_tag_id uuid, v_user_id uuid) OWNER TO engine;

--
-- Name: inserttags_vds_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inserttags_vds_map(v_tag_id uuid, v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO tags_vds_map(tag_id, vds_id)
	VALUES(v_tag_id, v_vds_id);
END; ';


ALTER FUNCTION public.inserttags_vds_map(v_tag_id uuid, v_vds_id uuid) OWNER TO engine;

--
-- Name: inserttags_vm_map(uuid, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inserttags_vm_map(v_tag_id uuid, v_vm_id uuid, v_defaultdisplaytype integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO tags_vm_map(tag_id, vm_id, DefaultDisplayType)
	VALUES(v_tag_id, v_vm_id, v_DefaultDisplayType);
END; ';


ALTER FUNCTION public.inserttags_vm_map(v_tag_id uuid, v_vm_id uuid, v_defaultdisplaytype integer) OWNER TO engine;

--
-- Name: inserttags_vm_pool_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inserttags_vm_pool_map(v_tag_id uuid, v_vm_pool_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO tags_vm_pool_map(tag_id, vm_pool_id)
	VALUES(v_tag_id, v_vm_pool_id);
END; ';


ALTER FUNCTION public.inserttags_vm_pool_map(v_tag_id uuid, v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: insertuser(character varying, character varying, character varying, character varying, character varying, character varying, character varying, character varying, integer, character varying, character varying, uuid, integer, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertuser(v_department character varying, v_desktop_device character varying, v_domain character varying, v_email character varying, v_groups character varying, v_name character varying, v_note character varying, v_role character varying, v_status integer, v_surname character varying, v_user_icon_path character varying, v_user_id uuid, v_session_count integer, v_username character varying, v_group_ids character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO users(department, desktop_device, domain, email, groups, name, note, role, status, surname, user_icon_path, user_id, session_count, username, group_ids)
	VALUES(v_department, v_desktop_device, v_domain, v_email, v_groups, v_name, v_note, v_role, v_status, v_surname, v_user_icon_path, v_user_id, v_session_count, v_username, v_group_ids);
END; ';


ALTER FUNCTION public.insertuser(v_department character varying, v_desktop_device character varying, v_domain character varying, v_email character varying, v_groups character varying, v_name character varying, v_note character varying, v_role character varying, v_status integer, v_surname character varying, v_user_icon_path character varying, v_user_id uuid, v_session_count integer, v_username character varying, v_group_ids character varying) OWNER TO engine;

--
-- Name: insertuser_sessions(character, character, timestamp with time zone, character, character, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertuser_sessions(v_browser character, v_client_type character, v_login_time timestamp with time zone, v_os character, v_session_id character, v_user_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      if (not exists(select session_id from user_sessions
      where session_id = v_session_id and user_id = v_user_id)) then
		 
INSERT INTO user_sessions(browser, client_type, login_time, os, session_id, user_id)
				VALUES(v_browser, v_client_type, v_login_time, v_os, v_session_id, v_user_id);
				
         UPDATE users
         SET session_count = session_count+1
         WHERE
         user_id = v_user_id;
      end if;
END; ';


ALTER FUNCTION public.insertuser_sessions(v_browser character, v_client_type character, v_login_time timestamp with time zone, v_os character, v_session_id character, v_user_id uuid) OWNER TO engine;

--
-- Name: insertvdcoption(character varying, character varying, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvdcoption(v_option_name character varying, v_option_value character varying, v_version character varying, INOUT v_option_id integer) RETURNS integer
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vdc_options(OPTION_NAME, option_value, version)
	VALUES(v_option_name, v_option_value, v_version);
    
      v_option_id := CURRVAL(''vdc_options_seq'');
END; ';


ALTER FUNCTION public.insertvdcoption(v_option_name character varying, v_option_value character varying, v_version character varying, INOUT v_option_id integer) OWNER TO engine;

--
-- Name: insertvds(character varying, character varying, character varying, integer, uuid, uuid, character varying, boolean, integer, integer, character varying, character varying, character varying, integer, character varying, boolean, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvds(v_host_name character varying, v_ip character varying, v_vds_unique_id character varying, v_port integer, v_vds_group_id uuid, INOUT v_vds_id uuid, v_vds_name character varying, v_server_ssl_enabled boolean, v_vds_type integer, v_vds_strength integer, v_pm_type character varying, v_pm_user character varying, v_pm_password character varying, v_pm_port integer, v_pm_options character varying, v_pm_enabled boolean, v_vds_spm_priority integer) RETURNS uuid
    LANGUAGE plpgsql
    AS '
BEGIN
	
   BEGIN
      v_vds_id := uuid_generate_v1();
      INSERT INTO vds_static(vds_id,host_name, ip, vds_unique_id, port, vds_group_id, vds_name, server_SSL_enabled,vds_type,vds_strength,pm_type,pm_user,pm_password, pm_port, pm_options, pm_enabled, vds_spm_priority)
	VALUES(v_vds_id,v_host_name, v_ip, v_vds_unique_id, v_port, v_vds_group_id, v_vds_name, v_server_SSL_enabled,v_vds_type, v_vds_strength,v_pm_type,v_pm_user,v_pm_password,v_pm_port, v_pm_options, v_pm_enabled, v_vds_spm_priority);
    
      INSERT INTO vds_dynamic(vds_id, status) VALUES(v_vds_id, 0);
    
      INSERT INTO vds_statistics(vds_id) VALUES(v_vds_id);
   END;
    
   RETURN;
END; ';


ALTER FUNCTION public.insertvds(v_host_name character varying, v_ip character varying, v_vds_unique_id character varying, v_port integer, v_vds_group_id uuid, INOUT v_vds_id uuid, v_vds_name character varying, v_server_ssl_enabled boolean, v_vds_type integer, v_vds_strength integer, v_pm_type character varying, v_pm_user character varying, v_pm_password character varying, v_pm_port integer, v_pm_options character varying, v_pm_enabled boolean, v_vds_spm_priority integer) OWNER TO engine;

--
-- Name: insertvds_interface(character varying, character varying, integer, character varying, uuid, boolean, character varying, character varying, character varying, character varying, integer, character varying, integer, integer, uuid, integer, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvds_interface(v_addr character varying, v_bond_name character varying, v_bond_type integer, v_gateway character varying, v_id uuid, v_is_bond boolean, v_bond_opts character varying, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_subnet character varying, v_boot_protocol integer, v_type integer, v_vds_id uuid, v_vlan_id integer, v_mtu integer, v_bridged boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vds_interface(addr, bond_name, bond_type, gateway, id, is_bond, bond_opts, mac_addr, name, network_name, speed, subnet, boot_protocol, type, VDS_ID, vlan_id, mtu, bridged)
	VALUES(v_addr, v_bond_name, v_bond_type, v_gateway, v_id, v_is_bond, v_bond_opts, v_mac_addr, v_name, v_network_name, v_speed, v_subnet, v_boot_protocol, v_type, v_vds_id, v_vlan_id, v_mtu, v_bridged);
END; ';


ALTER FUNCTION public.insertvds_interface(v_addr character varying, v_bond_name character varying, v_bond_type integer, v_gateway character varying, v_id uuid, v_is_bond boolean, v_bond_opts character varying, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_subnet character varying, v_boot_protocol integer, v_type integer, v_vds_id uuid, v_vlan_id integer, v_mtu integer, v_bridged boolean) OWNER TO engine;

--
-- Name: insertvds_interface_statistics(uuid, numeric, numeric, numeric, numeric, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvds_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vds_interface_statistics(id, rx_drop, rx_rate, tx_drop, tx_rate, vds_id, iface_status)
	VALUES(v_id, v_rx_drop, v_rx_rate, v_tx_drop, v_tx_rate, v_vds_id,v_iface_status);
END; ';


ALTER FUNCTION public.insertvds_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vds_id uuid) OWNER TO engine;

--
-- Name: insertvds_spm_id_map(uuid, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvds_spm_id_map(v_storage_pool_id uuid, v_vds_id uuid, v_vds_spm_id integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vds_spm_id_map(storage_pool_id, vds_id, vds_spm_id)
	VALUES(v_storage_pool_id, v_vds_id, v_vds_spm_id);
END; ';


ALTER FUNCTION public.insertvds_spm_id_map(v_storage_pool_id uuid, v_vds_id uuid, v_vds_spm_id integer) OWNER TO engine;

--
-- Name: insertvdsdynamic(integer, character varying, numeric, character varying, boolean, integer, integer, integer, uuid, integer, integer, integer, integer, integer, integer, character varying, character varying, character varying, character varying, integer, character varying, timestamp with time zone, integer, integer, integer, integer, boolean, character varying, character varying, character varying, character varying, character varying, character varying, character varying, integer, integer, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvdsdynamic(v_cpu_cores integer, v_cpu_model character varying, v_cpu_speed_mh numeric, v_if_total_speed character varying, v_kvm_enabled boolean, v_mem_commited integer, v_physical_mem_mb integer, v_status integer, v_vds_id uuid, v_vm_active integer, v_vm_count integer, v_vms_cores_count integer, v_vm_migrating integer, v_reserved_mem integer, v_guest_overhead integer, v_rpm_version character varying, v_software_version character varying, v_version_name character varying, v_build_name character varying, v_previous_status integer, v_cpu_flags character varying, v_cpu_over_commit_time_stamp timestamp with time zone, v_hypervisor_type integer, v_pending_vcpus_count integer, v_pending_vmem_size integer, v_cpu_sockets integer, v_net_config_dirty boolean, v_supported_cluster_levels character varying, v_supported_engines character varying, v_host_os character varying, v_kvm_version character varying, v_spice_version character varying, v_kernel_version character varying, v_iscsi_initiator_name character varying, v_transparent_hugepages_state integer, v_anonymous_hugepages integer, v_hooks character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   BEGIN
INSERT INTO vds_dynamic(cpu_cores, cpu_model, cpu_speed_mh, if_total_speed, kvm_enabled, mem_commited, physical_mem_mb,	status, vds_id, vm_active, vm_count, vm_migrating, reserved_mem, guest_overhead, rpm_version, software_version, version_name, build_name, previous_status, cpu_flags, cpu_over_commit_time_stamp, hypervisor_type, vms_cores_count, pending_vcpus_count, pending_vmem_size, cpu_sockets,net_config_dirty, supported_cluster_levels, supported_engines, host_os, kvm_version, spice_version, kernel_version, iscsi_initiator_name, transparent_hugepages_state, anonymous_hugepages,hooks)
	VALUES(v_cpu_cores,	v_cpu_model,	v_cpu_speed_mh,	v_if_total_speed, v_kvm_enabled, v_mem_commited, v_physical_mem_mb,	v_status, v_vds_id, v_vm_active, v_vm_count, v_vm_migrating,	v_reserved_mem, v_guest_overhead, v_rpm_version, v_software_version, v_version_name, v_build_name, v_previous_status, v_cpu_flags, v_cpu_over_commit_time_stamp, v_hypervisor_type, v_vms_cores_count,v_pending_vcpus_count, v_pending_vmem_size, v_cpu_sockets, v_net_config_dirty, v_supported_cluster_levels, v_supported_engines, v_host_os, v_kvm_version, v_spice_version, v_kernel_version, v_iscsi_initiator_name, v_transparent_hugepages_state, v_anonymous_hugepages,v_hooks);
   END;
    
   RETURN;
END; ';


ALTER FUNCTION public.insertvdsdynamic(v_cpu_cores integer, v_cpu_model character varying, v_cpu_speed_mh numeric, v_if_total_speed character varying, v_kvm_enabled boolean, v_mem_commited integer, v_physical_mem_mb integer, v_status integer, v_vds_id uuid, v_vm_active integer, v_vm_count integer, v_vms_cores_count integer, v_vm_migrating integer, v_reserved_mem integer, v_guest_overhead integer, v_rpm_version character varying, v_software_version character varying, v_version_name character varying, v_build_name character varying, v_previous_status integer, v_cpu_flags character varying, v_cpu_over_commit_time_stamp timestamp with time zone, v_hypervisor_type integer, v_pending_vcpus_count integer, v_pending_vmem_size integer, v_cpu_sockets integer, v_net_config_dirty boolean, v_supported_cluster_levels character varying, v_supported_engines character varying, v_host_os character varying, v_kvm_version character varying, v_spice_version character varying, v_kernel_version character varying, v_iscsi_initiator_name character varying, v_transparent_hugepages_state integer, v_anonymous_hugepages integer, v_hooks character varying) OWNER TO engine;

--
-- Name: insertvdsgroups(character varying, character varying, character varying, integer, integer, integer, integer, integer, uuid, integer, character varying, boolean, integer, uuid, boolean, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvdsgroups(v_description character varying, v_name character varying, v_cpu_name character varying, v_selection_algorithm integer, v_high_utilization integer, v_low_utilization integer, v_cpu_over_commit_duration_minutes integer, v_hypervisor_type integer, v_storage_pool_id uuid, v_max_vds_memory_over_commit integer, v_compatibility_version character varying, v_transparent_hugepages boolean, v_migrate_on_error integer, INOUT v_vds_group_id uuid, v_virt_service boolean, v_gluster_service boolean) RETURNS uuid
    LANGUAGE plpgsql
    AS '
BEGIN
      v_vds_group_id := uuid_generate_v1();
      INSERT INTO vds_groups(vds_group_id,description, name, cpu_name, selection_algorithm, high_utilization, low_utilization,
	cpu_over_commit_duration_minutes, hypervisor_type, storage_pool_id,  max_vds_memory_over_commit, compatibility_version, transparent_hugepages, migrate_on_error,
	virt_service, gluster_service)
	VALUES(v_vds_group_id,v_description, v_name, v_cpu_name, v_selection_algorithm, v_high_utilization, v_low_utilization,
	v_cpu_over_commit_duration_minutes, v_hypervisor_type, v_storage_pool_id,  v_max_vds_memory_over_commit, v_compatibility_version, v_transparent_hugepages, v_migrate_on_error,
	v_virt_service, v_gluster_service);
END; ';


ALTER FUNCTION public.insertvdsgroups(v_description character varying, v_name character varying, v_cpu_name character varying, v_selection_algorithm integer, v_high_utilization integer, v_low_utilization integer, v_cpu_over_commit_duration_minutes integer, v_hypervisor_type integer, v_storage_pool_id uuid, v_max_vds_memory_over_commit integer, v_compatibility_version character varying, v_transparent_hugepages boolean, v_migrate_on_error integer, INOUT v_vds_group_id uuid, v_virt_service boolean, v_gluster_service boolean) OWNER TO engine;

--
-- Name: insertvdsstatic(character varying, character varying, character varying, integer, uuid, uuid, character varying, boolean, integer, integer, character varying, character varying, character varying, integer, character varying, boolean, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvdsstatic(v_host_name character varying, v_ip character varying, v_vds_unique_id character varying, v_port integer, v_vds_group_id uuid, INOUT v_vds_id uuid, v_vds_name character varying, v_server_ssl_enabled boolean, v_vds_type integer, v_vds_strength integer, v_pm_type character varying, v_pm_user character varying, v_pm_password character varying, v_pm_port integer, v_pm_options character varying, v_pm_enabled boolean, v_vds_spm_priority integer) RETURNS uuid
    LANGUAGE plpgsql
    AS '
BEGIN
   IF v_vds_unique_id IS NULL OR NOT EXISTS(SELECT vds_name FROM vds_static WHERE vds_unique_id = v_vds_unique_id) then
      BEGIN
         v_vds_id := uuid_generate_v1();
         INSERT INTO vds_static(vds_id,host_name, ip, vds_unique_id, port, vds_group_id, vds_name, server_SSL_enabled,vds_type,vds_strength,pm_type,pm_user,pm_password,pm_port,pm_options,pm_enabled, vds_spm_priority)
			VALUES(v_vds_id,v_host_name, v_ip, v_vds_unique_id, v_port, v_vds_group_id, v_vds_name, v_server_SSL_enabled,v_vds_type,v_vds_strength,v_pm_type,v_pm_user,v_pm_password,v_pm_port,v_pm_options,v_pm_enabled, v_vds_spm_priority);
      END;
   end if;
   RETURN;
END; ';


ALTER FUNCTION public.insertvdsstatic(v_host_name character varying, v_ip character varying, v_vds_unique_id character varying, v_port integer, v_vds_group_id uuid, INOUT v_vds_id uuid, v_vds_name character varying, v_server_ssl_enabled boolean, v_vds_type integer, v_vds_strength integer, v_pm_type character varying, v_pm_user character varying, v_pm_password character varying, v_pm_port integer, v_pm_options character varying, v_pm_enabled boolean, v_vds_spm_priority integer) OWNER TO engine;

--
-- Name: insertvdsstatistics(numeric, numeric, numeric, numeric, integer, integer, integer, uuid, bigint, bigint, bigint, bigint, integer, bigint, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvdsstatistics(v_cpu_idle numeric, v_cpu_load numeric, v_cpu_sys numeric, v_cpu_user numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_vds_id uuid, v_mem_available bigint, v_mem_shared bigint, v_swap_free bigint, v_swap_total bigint, v_ksm_cpu_percent integer, v_ksm_pages bigint, v_ksm_state boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
	
   BEGIN
INSERT INTO vds_statistics(cpu_idle, cpu_load, cpu_sys, cpu_user, usage_cpu_percent, usage_mem_percent, usage_network_percent, vds_id, mem_available, mem_shared,swap_free,swap_total,ksm_cpu_percent,ksm_pages,ksm_state)
	VALUES(v_cpu_idle, v_cpu_load, v_cpu_sys, v_cpu_user, v_usage_cpu_percent, v_usage_mem_percent, v_usage_network_percent, v_vds_id, v_mem_available, v_mem_shared,v_swap_free,v_swap_total,v_ksm_cpu_percent,v_ksm_pages,v_ksm_state);
   END;
    
   RETURN;
END; ';


ALTER FUNCTION public.insertvdsstatistics(v_cpu_idle numeric, v_cpu_load numeric, v_cpu_sys numeric, v_cpu_user numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_vds_id uuid, v_mem_available bigint, v_mem_shared bigint, v_swap_free bigint, v_swap_total bigint, v_ksm_cpu_percent integer, v_ksm_pages bigint, v_ksm_state boolean) OWNER TO engine;

--
-- Name: insertvm(character varying, integer, integer, uuid, uuid, character varying, uuid, integer, boolean, boolean, boolean, integer, integer, integer, character varying, boolean, boolean, uuid, boolean, integer, integer, integer, integer, integer, integer, integer, character varying, integer, character varying, character varying, character varying, integer, character varying, character varying, integer, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvm(v_description character varying, v_mem_size_mb integer, v_os integer, v_vds_group_id uuid, v_vm_guid uuid, v_vm_name character varying, v_vmt_guid uuid, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_is_initialized boolean, v_is_auto_suspend boolean, v_num_of_sockets integer, v_cpu_per_socket integer, v_usb_policy integer, v_time_zone character varying, v_auto_startup boolean, v_is_stateless boolean, v_dedicated_vm_for_vds uuid, v_fail_back boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_migration_support integer, v_predefined_properties character varying, v_userdefined_properties character varying, v_min_allocated_mem integer, v_cpu_pinning character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vm_static(description, mem_size_mb, os, vds_group_id, vm_guid, VM_NAME, vmt_guid, num_of_monitors, allow_console_reconnect, is_initialized, is_auto_suspend, num_of_sockets, cpu_per_socket, usb_policy, time_zone,auto_startup,is_stateless,dedicated_vm_for_vds,fail_back,vm_type,hypervisor_type,operation_mode,nice_level,default_boot_sequence,default_display_type,priority,iso_path,origin,initrd_url,kernel_url,kernel_params,migration_support,predefined_properties,userdefined_properties,min_allocated_mem,cpu_pinning)
	VALUES(v_description, v_mem_size_mb, v_os, v_vds_group_id, v_vm_guid, v_vm_name, v_vmt_guid, v_num_of_monitors, v_num_of_monitors, v_is_initialized, v_is_auto_suspend, v_num_of_sockets, v_cpu_per_socket, v_usb_policy, v_time_zone,v_auto_startup,v_is_stateless,v_dedicated_vm_for_vds,v_fail_back,v_vm_type,v_hypervisor_type,v_operation_mode,v_nice_level,v_default_boot_sequence,v_default_display_type,v_priority,v_iso_path,v_origin,v_initrd_url,v_kernel_url,v_kernel_params,v_migration_support,v_predefined_properties,v_userdefined_properties,v_min_allocated_mem,v_cpu_pinning);
	
      INSERT INTO vm_dynamic(vm_guid, status) VALUES(v_vm_guid, 0);
	
      INSERT INTO vm_statistics(vm_guid) VALUES(v_vm_guid);
	
      UPDATE vm_static
      SET child_count =(SELECT COUNT(*) FROM vm_static WHERE vmt_guid = v_vmt_guid)
      WHERE vm_guid = v_vmt_guid;
END; ';


ALTER FUNCTION public.insertvm(v_description character varying, v_mem_size_mb integer, v_os integer, v_vds_group_id uuid, v_vm_guid uuid, v_vm_name character varying, v_vmt_guid uuid, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_is_initialized boolean, v_is_auto_suspend boolean, v_num_of_sockets integer, v_cpu_per_socket integer, v_usb_policy integer, v_time_zone character varying, v_auto_startup boolean, v_is_stateless boolean, v_dedicated_vm_for_vds uuid, v_fail_back boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_migration_support integer, v_predefined_properties character varying, v_userdefined_properties character varying, v_min_allocated_mem integer, v_cpu_pinning character varying) OWNER TO engine;

--
-- Name: insertvm_interface(uuid, character varying, character varying, character varying, integer, uuid, uuid, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvm_interface(v_id uuid, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_vm_guid uuid, v_vmt_guid uuid, v_type integer, v_port_mirroring boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vm_interface(id, mac_addr, name, network_name, speed, VM_GUID, VMT_GUID, type, port_mirroring)
	VALUES(v_id, v_mac_addr, v_name, v_network_name, v_speed, v_vm_guid, v_vmt_guid, v_type, v_port_mirroring);
END; ';


ALTER FUNCTION public.insertvm_interface(v_id uuid, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_vm_guid uuid, v_vmt_guid uuid, v_type integer, v_port_mirroring boolean) OWNER TO engine;

--
-- Name: insertvm_interface_statistics(uuid, numeric, numeric, numeric, numeric, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvm_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vm_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vm_interface_statistics(id, rx_drop, rx_rate, tx_drop, tx_rate, vm_id, iface_status)
	VALUES(v_id, v_rx_drop, v_rx_rate, v_tx_drop, v_tx_rate, v_vm_id,v_iface_status);
END; ';


ALTER FUNCTION public.insertvm_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vm_id uuid) OWNER TO engine;

--
-- Name: insertvm_pool_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvm_pool_map(v_vm_guid uuid, v_vm_pool_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vm_pool_map(vm_guid, vm_pool_id)
	VALUES(v_vm_guid, v_vm_pool_id);
END; ';


ALTER FUNCTION public.insertvm_pool_map(v_vm_guid uuid, v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: insertvm_pools(character varying, uuid, character varying, integer, character varying, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvm_pools(v_vm_pool_description character varying, INOUT v_vm_pool_id uuid, v_vm_pool_name character varying, v_vm_pool_type integer, v_parameters character varying, v_prestarted_vms integer, v_vds_group_id uuid) RETURNS uuid
    LANGUAGE plpgsql
    AS '
BEGIN
      v_vm_pool_id := uuid_generate_v1();
      INSERT INTO vm_pools(vm_pool_id,vm_pool_description, vm_pool_name, vm_pool_type,parameters, prestarted_vms, vds_group_id)
      VALUES(v_vm_pool_id,v_vm_pool_description, v_vm_pool_name,v_vm_pool_type,v_parameters, v_prestarted_vms, v_vds_group_id);
END; ';


ALTER FUNCTION public.insertvm_pools(v_vm_pool_description character varying, INOUT v_vm_pool_id uuid, v_vm_pool_name character varying, v_vm_pool_type integer, v_parameters character varying, v_prestarted_vms integer, v_vds_group_id uuid) OWNER TO engine;

--
-- Name: insertvmdevice(uuid, uuid, character varying, character varying, character varying, integer, text, boolean, boolean, boolean, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvmdevice(v_device_id uuid, v_vm_id uuid, v_device character varying, v_type character varying, v_address character varying, v_boot_order integer, v_spec_params text, v_is_managed boolean, v_is_plugged boolean, v_is_readonly boolean, v_alias character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    INSERT INTO vm_device(
        device_id,
        vm_id ,
        device ,
        type,
        address ,
        boot_order ,
        spec_params,
        is_managed,
        is_plugged,
        is_readonly,
        alias)
    VALUES(
        v_device_id ,
        v_vm_id ,
        v_device ,
        v_type ,
        v_address ,
        v_boot_order ,
        v_spec_params,
        v_is_managed,
        v_is_plugged,
        v_is_readonly,
        v_alias);
END; ';


ALTER FUNCTION public.insertvmdevice(v_device_id uuid, v_vm_id uuid, v_device character varying, v_type character varying, v_address character varying, v_boot_order integer, v_spec_params text, v_is_managed boolean, v_is_plugged boolean, v_is_readonly boolean, v_alias character varying) OWNER TO engine;

--
-- Name: insertvmdynamic(character varying, uuid, character varying, timestamp with time zone, timestamp with time zone, uuid, character varying, uuid, uuid, integer, uuid, character varying, character varying, timestamp with time zone, integer, integer, boolean, integer, character varying, integer, boolean, integer, integer, integer, uuid, character varying, integer, character varying, integer, integer, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvmdynamic(v_app_list character varying, v_guest_cur_user_id uuid, v_guest_cur_user_name character varying, v_guest_last_login_time timestamp with time zone, v_guest_last_logout_time timestamp with time zone, v_console_user_id uuid, v_guest_os character varying, v_migrating_to_vds uuid, v_run_on_vds uuid, v_status integer, v_vm_guid uuid, v_vm_host character varying, v_vm_ip character varying, v_last_start_time timestamp with time zone, v_vm_pid integer, v_display integer, v_acpi_enable boolean, v_session integer, v_display_ip character varying, v_display_type integer, v_kvm_enable boolean, v_boot_sequence integer, v_display_secure_port integer, v_utc_diff integer, v_last_vds_run_on uuid, v_client_ip character varying, v_guest_requested_memory integer, v_hibernation_vol_handle character varying, v_exit_status integer, v_pause_status integer, v_exit_message character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vm_dynamic(app_list,	guest_cur_user_id, guest_cur_user_name, guest_last_login_time, guest_last_logout_time, console_user_id, guest_os, migrating_to_vds, RUN_ON_VDS, status, vm_guid, vm_host, vm_ip, last_start_time, vm_pid, display, acpi_enable, session, display_ip, display_type, kvm_enable, boot_sequence, display_secure_port, utc_diff, last_vds_run_on, client_ip, guest_requested_memory, hibernation_vol_handle,exit_status,pause_status,exit_message)
	VALUES(v_app_list, v_guest_cur_user_id, v_guest_cur_user_name, v_guest_last_login_time, v_guest_last_logout_time, v_console_user_id, v_guest_os, v_migrating_to_vds, v_run_on_vds, v_status, v_vm_guid, v_vm_host, v_vm_ip, v_last_start_time, v_vm_pid, v_display, v_acpi_enable, v_session, v_display_ip, v_display_type, v_kvm_enable, v_boot_sequence, v_display_secure_port, v_utc_diff, v_last_vds_run_on, v_client_ip, v_guest_requested_memory, v_hibernation_vol_handle, v_exit_status, v_pause_status, v_exit_message);
END; ';


ALTER FUNCTION public.insertvmdynamic(v_app_list character varying, v_guest_cur_user_id uuid, v_guest_cur_user_name character varying, v_guest_last_login_time timestamp with time zone, v_guest_last_logout_time timestamp with time zone, v_console_user_id uuid, v_guest_os character varying, v_migrating_to_vds uuid, v_run_on_vds uuid, v_status integer, v_vm_guid uuid, v_vm_host character varying, v_vm_ip character varying, v_last_start_time timestamp with time zone, v_vm_pid integer, v_display integer, v_acpi_enable boolean, v_session integer, v_display_ip character varying, v_display_type integer, v_kvm_enable boolean, v_boot_sequence integer, v_display_secure_port integer, v_utc_diff integer, v_last_vds_run_on uuid, v_client_ip character varying, v_guest_requested_memory integer, v_hibernation_vol_handle character varying, v_exit_status integer, v_pause_status integer, v_exit_message character varying) OWNER TO engine;

--
-- Name: insertvmstatic(character varying, integer, integer, uuid, uuid, character varying, uuid, character varying, timestamp with time zone, integer, boolean, boolean, boolean, integer, integer, integer, character varying, boolean, boolean, uuid, boolean, integer, integer, integer, integer, integer, integer, integer, character varying, integer, character varying, character varying, character varying, integer, character varying, character varying, integer, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvmstatic(v_description character varying, v_mem_size_mb integer, v_os integer, v_vds_group_id uuid, v_vm_guid uuid, v_vm_name character varying, v_vmt_guid uuid, v_domain character varying, v_creation_date timestamp with time zone, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_is_initialized boolean, v_is_auto_suspend boolean, v_num_of_sockets integer, v_cpu_per_socket integer, v_usb_policy integer, v_time_zone character varying, v_auto_startup boolean, v_is_stateless boolean, v_dedicated_vm_for_vds uuid, v_fail_back boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_migration_support integer, v_predefined_properties character varying, v_userdefined_properties character varying, v_min_allocated_mem integer, v_quota_id uuid, v_cpu_pinning character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vm_static(description, mem_size_mb, os, vds_group_id, vm_guid, VM_NAME, vmt_guid,domain,creation_date,num_of_monitors,allow_console_reconnect,is_initialized,is_auto_suspend,num_of_sockets,cpu_per_socket,usb_policy, time_zone,auto_startup,is_stateless,dedicated_vm_for_vds, fail_back, default_boot_sequence, vm_type, hypervisor_type, operation_mode, nice_level, default_display_type, priority,iso_path,origin,initrd_url,kernel_url,kernel_params,migration_support,predefined_properties,userdefined_properties,min_allocated_mem, entity_type, quota_id, cpu_pinning)
	VALUES(v_description,  v_mem_size_mb, v_os, v_vds_group_id, v_vm_guid, v_vm_name, v_vmt_guid, v_domain, v_creation_date, v_num_of_monitors, v_allow_console_reconnect, v_is_initialized, v_is_auto_suspend, v_num_of_sockets, v_cpu_per_socket, v_usb_policy, v_time_zone, v_auto_startup,v_is_stateless,v_dedicated_vm_for_vds,v_fail_back, v_default_boot_sequence, v_vm_type, v_hypervisor_type, v_operation_mode, v_nice_level, v_default_display_type, v_priority,v_iso_path,v_origin,v_initrd_url,v_kernel_url,v_kernel_params,v_migration_support,v_predefined_properties,v_userdefined_properties,v_min_allocated_mem, ''VM'', v_quota_id, v_cpu_pinning);
END; ';


ALTER FUNCTION public.insertvmstatic(v_description character varying, v_mem_size_mb integer, v_os integer, v_vds_group_id uuid, v_vm_guid uuid, v_vm_name character varying, v_vmt_guid uuid, v_domain character varying, v_creation_date timestamp with time zone, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_is_initialized boolean, v_is_auto_suspend boolean, v_num_of_sockets integer, v_cpu_per_socket integer, v_usb_policy integer, v_time_zone character varying, v_auto_startup boolean, v_is_stateless boolean, v_dedicated_vm_for_vds uuid, v_fail_back boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_migration_support integer, v_predefined_properties character varying, v_userdefined_properties character varying, v_min_allocated_mem integer, v_quota_id uuid, v_cpu_pinning character varying) OWNER TO engine;

--
-- Name: insertvmstatistics(numeric, numeric, numeric, integer, integer, integer, text, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvmstatistics(v_cpu_sys numeric, v_cpu_user numeric, v_elapsed_time numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_disks_usage text, v_vm_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT INTO vm_statistics(cpu_sys, cpu_user, elapsed_time, usage_cpu_percent, usage_mem_percent, usage_network_percent, disks_usage, vm_guid)
	VALUES(v_cpu_sys, v_cpu_user, v_elapsed_time, v_usage_cpu_percent, v_usage_mem_percent, v_usage_network_percent, v_disks_usage, v_vm_guid);
END; ';


ALTER FUNCTION public.insertvmstatistics(v_cpu_sys numeric, v_cpu_user numeric, v_elapsed_time numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_disks_usage text, v_vm_guid uuid) OWNER TO engine;

--
-- Name: insertvmtemplate(integer, timestamp with time zone, character varying, integer, character varying, integer, integer, integer, uuid, uuid, character varying, integer, boolean, integer, integer, character varying, boolean, boolean, integer, integer, integer, integer, integer, integer, integer, boolean, boolean, character varying, integer, character varying, character varying, character varying, uuid, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION insertvmtemplate(v_child_count integer, v_creation_date timestamp with time zone, v_description character varying, v_mem_size_mb integer, v_name character varying, v_num_of_sockets integer, v_cpu_per_socket integer, v_os integer, v_vmt_guid uuid, v_vds_group_id uuid, v_domain character varying, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_status integer, v_usb_policy integer, v_time_zone character varying, v_fail_back boolean, v_is_auto_suspend boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_auto_startup boolean, v_is_stateless boolean, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_quota_id uuid, v_migration_support integer, v_dedicated_vm_for_vds uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
INSERT
INTO vm_static(
    vmt_guid,
    child_count,
    creation_date,
    description,
    mem_size_mb,
    vm_name,
    num_of_sockets,
    cpu_per_socket,
    os,
    vm_guid,
    vds_group_id,
    domain,
    num_of_monitors,
    allow_console_reconnect,
    template_status,
    usb_policy,
    time_zone,
    fail_back,
    is_auto_suspend,
    vm_type,
    hypervisor_type,
    operation_mode,
    nice_level,
    default_boot_sequence,
    default_display_type,
    priority,
    auto_startup,
    is_stateless,
    iso_path,
    origin,
    initrd_url,
    kernel_url,
    kernel_params,
    entity_type,
    quota_id,
    migration_support,
    dedicated_vm_for_vds)
VALUES(
    -- This field is meaningless for templates for the time being, however we want to keep it not null for VMs.
    -- Thus, since templates are top level elements they "point" to the ''Blank'' template.
    ''00000000-0000-0000-0000-000000000000'',
    v_child_count,
    v_creation_date,
    v_description,
    v_mem_size_mb,
    v_name,
    v_num_of_sockets,
    v_cpu_per_socket,
    v_os,
    v_vmt_guid,
    v_vds_group_id,
    v_domain,
    v_num_of_monitors,
    v_allow_console_reconnect,
    v_status,
    v_usb_policy,
    v_time_zone,
    v_fail_back,
    v_is_auto_suspend,
    v_vm_type,
    v_hypervisor_type,
    v_operation_mode,
    v_nice_level,
    v_default_boot_sequence,
    v_default_display_type,
    v_priority,
    v_auto_startup,
    v_is_stateless,
    v_iso_path,
    v_origin,
    v_initrd_url,
    v_kernel_url,
    v_kernel_params,
    ''TEMPLATE'',
    v_quota_id,
    v_migration_support,
    v_dedicated_vm_for_vds);
END; ';


ALTER FUNCTION public.insertvmtemplate(v_child_count integer, v_creation_date timestamp with time zone, v_description character varying, v_mem_size_mb integer, v_name character varying, v_num_of_sockets integer, v_cpu_per_socket integer, v_os integer, v_vmt_guid uuid, v_vds_group_id uuid, v_domain character varying, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_status integer, v_usb_policy integer, v_time_zone character varying, v_fail_back boolean, v_is_auto_suspend boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_auto_startup boolean, v_is_stateless boolean, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_quota_id uuid, v_migration_support integer, v_dedicated_vm_for_vds uuid) OWNER TO engine;

--
-- Name: inst_add_iso_storage_domain(uuid, character varying, character varying, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inst_add_iso_storage_domain(v_storage_domain_id uuid, v_name character varying, v_connection character varying, v_available integer, v_used integer) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_connection_id UUID;
BEGIN        
    v_connection_id := uuid_generate_v1();
    if not exists (select 1 from storage_server_connections where connection = v_connection) then
        -- Insert storage server connection info
        perform Insertstorage_server_connections(v_connection,cast(v_connection_id as varchar(250)),NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,NULL);
        -- Insert storage domain static info
        perform Insertstorage_domain_static(v_storage_domain_id,cast(v_connection_id as varchar(250)),v_name,1,2,''0'',0);
        -- Insert storage domain dynamic  info
        perform Insertstorage_domain_dynamic(v_available,v_storage_domain_id,v_used);
    end if;
    exception 
        when others then
	    RAISE EXCEPTION ''NUM:%, DETAILS:%'', SQLSTATE, SQLERRM;        
END; ';


ALTER FUNCTION public.inst_add_iso_storage_domain(v_storage_domain_id uuid, v_name character varying, v_connection character varying, v_available integer, v_used integer) OWNER TO engine;

--
-- Name: inst_update_default_storage_pool_type(integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION inst_update_default_storage_pool_type(v_storage_pool_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      if (v_storage_pool_type > 0 and v_storage_pool_type < 7) then
         UPDATE storage_pool
         SET storage_pool_type = v_storage_pool_type, _update_date = LOCALTIMESTAMP
         WHERE storage_pool.name = ''Default'' and not exists
         (select 1 from storage_domains where storage_domains.storage_pool_name = ''Default'');
      end if;
END; ';


ALTER FUNCTION public.inst_update_default_storage_pool_type(v_storage_pool_type integer) OWNER TO engine;

--
-- Name: isloggingenabled(text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION isloggingenabled(errorcode text) RETURNS boolean
    LANGUAGE plpgsql
    AS '
-- determine if logging errors is enabled.
-- define in your postgresql.conf:
-- custom_variable_classes = ''engine''
-- set engine.logging = ''true'';
-- or this could be in a config table

-- NOTE: We should look at checking error codes as not all are suitable for exceptions some are just notice or info
declare
    result boolean := false;
    prop text;
begin
    -- check for log setting in postgresql.conf
    select current_setting(''engine.logging'') into prop;
    if prop = ''true'' then
result = true;
    end if;
    return result;
exception
    when others then
result = true;  -- default to log if not specified
return result;
end;
';


ALTER FUNCTION public.isloggingenabled(errorcode text) OWNER TO engine;

--
-- Name: ismemballoonenabled(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION ismemballoonenabled(v_vm_id uuid) RETURNS boolean
    LANGUAGE plpgsql
    AS '
declare
    result boolean := false;
begin
    if exists (select 1 from vm_device where vm_id = v_vm_id and type = ''balloon'' and device = ''memballoon'') then
        result := true;
    end if;
    return result;
end;
';


ALTER FUNCTION public.ismemballoonenabled(v_vm_id uuid) OWNER TO engine;

--
-- Name: isquotainuse(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION isquotainuse(v_quota_id uuid) RETURNS boolean
    LANGUAGE plpgsql
    AS '
DECLARE
    result boolean := FALSE;
BEGIN
    if EXISTS (SELECT quota_id
                    FROM images
                    WHERE quota_id = v_quota_id
    UNION SELECT quota_id
              FROM vm_static
              WHERE quota_id = v_quota_id) then
        result := TRUE;
    END if;
    return result;
END; ';


ALTER FUNCTION public.isquotainuse(v_quota_id uuid) OWNER TO engine;

--
-- Name: removeallvmtagsbyvmid(uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION removeallvmtagsbyvmid(v_vm_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      delete FROM tags_vm_map
      where vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.removeallvmtagsbyvmid(v_vm_id uuid) OWNER TO engine;

--
-- Name: set_network_exclusively_as_display(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION set_network_exclusively_as_display(v_cluster_id uuid, v_network_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

   UPDATE network_cluster
   SET is_display = true
   WHERE cluster_id = v_cluster_id AND network_id = v_network_id;

   IF FOUND THEN
       UPDATE network_cluster
       SET is_display = false
       WHERE cluster_id = v_cluster_id AND network_id != v_network_id;
   END IF;

END; ';


ALTER FUNCTION public.set_network_exclusively_as_display(v_cluster_id uuid, v_network_id uuid) OWNER TO engine;

--
-- Name: updatead_groups(uuid, character varying, integer, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatead_groups(v_id uuid, v_name character varying, v_status integer, v_domain character varying, v_distinguishedname character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE ad_groups
      SET name = v_name,status = v_status,domain = v_domain,distinguishedname =v_distinguishedname
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatead_groups(v_id uuid, v_name character varying, v_status integer, v_domain character varying, v_distinguishedname character varying) OWNER TO engine;

--
-- Name: updateasync_tasks(integer, integer, integer, uuid, text, character varying, uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateasync_tasks(v_action_type integer, v_result integer, v_status integer, v_task_id uuid, v_action_parameters text, v_action_params_class character varying, v_step_id uuid, v_command_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE async_tasks
      SET action_type = v_action_type,
          result = v_result,
          status = v_status,
          action_parameters = v_action_parameters,
          action_params_class = v_action_params_class,
          step_id = v_step_id,
          command_id = v_command_id
      WHERE task_id = v_task_id;
END; ';


ALTER FUNCTION public.updateasync_tasks(v_action_type integer, v_result integer, v_status integer, v_task_id uuid, v_action_parameters text, v_action_params_class character varying, v_step_id uuid, v_command_id uuid) OWNER TO engine;

--
-- Name: updateauditlog(integer, timestamp with time zone, integer, integer, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, uuid, character varying, character varying, uuid, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateauditlog(v_audit_log_id integer, v_log_time timestamp with time zone, v_log_type integer, v_severity integer, v_message character varying, v_user_id uuid, v_user_name character varying, v_vds_id uuid, v_vds_name character varying, v_vm_id uuid, v_vm_name character varying, v_vm_template_id uuid, v_vm_template_name character varying, v_storage_pool_id uuid, v_storage_pool_name character varying, v_storage_domain_id uuid, v_storage_domain_name character varying, v_vds_group_id uuid, v_vds_group_name character varying, v_quota_id uuid, v_quota_name character varying, v_correlation_id character varying, v_job_id uuid, v_gluster_volume_id uuid, v_gluster_volume_name character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE audit_log
      SET LOG_TIME = v_log_time,log_type = v_log_type,severity = v_severity,message = v_message, 
      user_id = v_user_id,USER_NAME = v_user_name,vds_id = v_vds_id, 
      VDS_NAME = v_vds_name,vm_id = v_vm_id,VM_NAME = v_vm_name,
      vm_template_id = v_vm_template_id,VM_TEMPLATE_NAME = v_vm_template_name,
      storage_pool_id = v_storage_pool_id,STORAGE_POOL_NAME = v_storage_pool_name, 
      storage_domain_id = v_storage_domain_id,STORAGE_DOMAIN_NAME = v_storage_domain_name,
      vds_group_id = v_vds_group_id,vds_group_name = v_vds_group_name, correlation_id = v_correlation_id, job_id = v_job_id, quota_id = v_quota_id, quota_name = v_quota_name,
      gluster_volume_id = v_gluster_volume_id, gluster_volume_name = v_gluster_volume_name
      WHERE audit_log_id = v_audit_log_id;
END; ';


ALTER FUNCTION public.updateauditlog(v_audit_log_id integer, v_log_time timestamp with time zone, v_log_type integer, v_severity integer, v_message character varying, v_user_id uuid, v_user_name character varying, v_vds_id uuid, v_vds_name character varying, v_vm_id uuid, v_vm_name character varying, v_vm_template_id uuid, v_vm_template_name character varying, v_storage_pool_id uuid, v_storage_pool_name character varying, v_storage_domain_id uuid, v_storage_domain_name character varying, v_vds_group_id uuid, v_vds_group_name character varying, v_quota_id uuid, v_quota_name character varying, v_correlation_id character varying, v_job_id uuid, v_gluster_volume_id uuid, v_gluster_volume_name character varying) OWNER TO engine;

--
-- Name: updatebasedisk(uuid, character varying, boolean, character varying, character varying, character varying, boolean, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatebasedisk(v_disk_id uuid, v_disk_interface character varying, v_wipe_after_delete boolean, v_propagate_errors character varying, v_disk_alias character varying, v_disk_description character varying, v_shareable boolean, v_boot boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE base_disks
    SET    disk_interface = v_disk_interface,
           wipe_after_delete = v_wipe_after_delete,
           propagate_errors = v_propagate_errors,
           disk_alias = v_disk_alias,
           disk_description = v_disk_description,
           shareable = v_shareable,
           boot = v_boot
    WHERE  disk_id = v_disk_id;
END; ';


ALTER FUNCTION public.updatebasedisk(v_disk_id uuid, v_disk_interface character varying, v_wipe_after_delete boolean, v_propagate_errors character varying, v_disk_alias character varying, v_disk_description character varying, v_shareable boolean, v_boot boolean) OWNER TO engine;

--
-- Name: updatebookmark(uuid, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatebookmark(v_bookmark_id uuid, v_bookmark_name character varying, v_bookmark_value character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE bookmarks
      SET bookmark_name = v_bookmark_name,bookmark_value = v_bookmark_value
      WHERE bookmark_Id = v_bookmark_id;
END; ';


ALTER FUNCTION public.updatebookmark(v_bookmark_id uuid, v_bookmark_name character varying, v_bookmark_value character varying) OWNER TO engine;

--
-- Name: updateconsoleuserwithoptimisticlocking(uuid, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateconsoleuserwithoptimisticlocking(v_vm_guid uuid, v_console_user_id uuid, v_guest_cur_user_name character varying, OUT v_updated boolean) RETURNS boolean
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE vm_dynamic SET
        console_user_id = v_console_user_id,
        guest_cur_user_name = v_guest_cur_user_name
    WHERE
        vm_guid = v_vm_guid AND
        (console_user_id = v_console_user_id OR console_user_id IS NULL);
    v_updated := FOUND;
END; ';


ALTER FUNCTION public.updateconsoleuserwithoptimisticlocking(v_vm_guid uuid, v_console_user_id uuid, v_guest_cur_user_name character varying, OUT v_updated boolean) OWNER TO engine;

--
-- Name: updatecustom_actions(integer, character varying, character varying, integer, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatecustom_actions(v_action_id integer, v_action_name character varying, v_path character varying, v_tab integer, v_description character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE custom_actions
      SET action_name = v_action_name,path = v_path,tab = v_tab,description = v_description
      WHERE action_id = v_action_id;
END; ';


ALTER FUNCTION public.updatecustom_actions(v_action_id integer, v_action_name character varying, v_path character varying, v_tab integer, v_description character varying) OWNER TO engine;

--
-- Name: updatedisk_image_dynamic(uuid, integer, integer, bigint, numeric, numeric, numeric); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatedisk_image_dynamic(v_image_id uuid, v_read_rate integer, v_write_rate integer, v_actual_size bigint, v_read_latency_seconds numeric, v_write_latency_seconds numeric, v_flush_latency_seconds numeric) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE disk_image_dynamic
      SET read_rate = v_read_rate,write_rate = v_write_rate,actual_size = v_actual_size,read_latency_seconds = v_read_latency_seconds,write_latency_seconds = v_write_latency_seconds,flush_latency_seconds = v_flush_latency_seconds
      WHERE image_id = v_image_id;
END; ';


ALTER FUNCTION public.updatedisk_image_dynamic(v_image_id uuid, v_read_rate integer, v_write_rate integer, v_actual_size bigint, v_read_latency_seconds numeric, v_write_latency_seconds numeric, v_flush_latency_seconds numeric) OWNER TO engine;

--
-- Name: updateevent_subscriber(character varying, integer, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateevent_subscriber(v_event_up_name character varying, v_old_method_id integer, v_new_method_id integer, v_subscriber_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      update event_subscriber set method_id = v_new_method_id
      where event_up_name = v_event_up_name
      and method_id = v_old_method_id
      and subscriber_id = v_subscriber_id;
END; ';


ALTER FUNCTION public.updateevent_subscriber(v_event_up_name character varying, v_old_method_id integer, v_new_method_id integer, v_subscriber_id uuid) OWNER TO engine;

--
-- Name: updateglustervolume(uuid, uuid, character varying, character varying, character varying, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateglustervolume(v_id uuid, v_cluster_id uuid, v_vol_name character varying, v_vol_type character varying, v_status character varying, v_replica_count integer, v_stripe_count integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE gluster_volumes
    SET cluster_id = v_cluster_id,
        vol_name = v_vol_name,
        vol_type = v_vol_type,
        status = v_status,
        replica_count = v_replica_count,
        stripe_count = v_stripe_count,
        _update_date = LOCALTIMESTAMP
    WHERE id = v_id;
END; ';


ALTER FUNCTION public.updateglustervolume(v_id uuid, v_cluster_id uuid, v_vol_name character varying, v_vol_type character varying, v_status character varying, v_replica_count integer, v_stripe_count integer) OWNER TO engine;

--
-- Name: updateglustervolumebrick(uuid, uuid, uuid, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateglustervolumebrick(v_id uuid, v_new_id uuid, v_new_server_id uuid, v_new_brick_dir character varying, v_new_status character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE gluster_volume_bricks
    SET    id = v_new_id,
           server_id = v_new_server_id,
           brick_dir = v_new_brick_dir,
           status = v_new_status,
           _update_date = LOCALTIMESTAMP
    WHERE  id = v_id;
END; ';


ALTER FUNCTION public.updateglustervolumebrick(v_id uuid, v_new_id uuid, v_new_server_id uuid, v_new_brick_dir character varying, v_new_status character varying) OWNER TO engine;

--
-- Name: updateglustervolumebrickorder(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateglustervolumebrickorder(v_id uuid, v_brick_order integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE  gluster_volume_bricks
    SET     brick_order = v_brick_order,
            _update_date = LOCALTIMESTAMP
    WHERE   id = v_id;
END; ';


ALTER FUNCTION public.updateglustervolumebrickorder(v_id uuid, v_brick_order integer) OWNER TO engine;

--
-- Name: updateglustervolumebrickstatus(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateglustervolumebrickstatus(v_id uuid, v_status character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE  gluster_volume_bricks
    SET     status = v_status,
            _update_date = LOCALTIMESTAMP
    WHERE   id = v_id;
END; ';


ALTER FUNCTION public.updateglustervolumebrickstatus(v_id uuid, v_status character varying) OWNER TO engine;

--
-- Name: updateglustervolumeoption(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateglustervolumeoption(v_id uuid, v_option_val character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE gluster_volume_options
    SET option_val = v_option_val
    WHERE id = v_id;
END; ';


ALTER FUNCTION public.updateglustervolumeoption(v_id uuid, v_option_val character varying) OWNER TO engine;

--
-- Name: updateglustervolumestatus(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateglustervolumestatus(v_volume_id uuid, v_status character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE gluster_volumes
    SET
        status = v_status,
        _update_date = LOCALTIMESTAMP
    WHERE id = v_volume_id;
END; ';


ALTER FUNCTION public.updateglustervolumestatus(v_volume_id uuid, v_status character varying) OWNER TO engine;

--
-- Name: updateglustervolumestatusbyname(uuid, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateglustervolumestatusbyname(v_cluster_id uuid, v_vol_name character varying, v_status character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE gluster_volumes
    SET
        status = v_status,
        _update_date = LOCALTIMESTAMP
    WHERE cluster_id = v_cluster_id
    AND   vol_name = v_vol_name;
END; ';


ALTER FUNCTION public.updateglustervolumestatusbyname(v_cluster_id uuid, v_vol_name character varying, v_status character varying) OWNER TO engine;

--
-- Name: updateimage(timestamp with time zone, uuid, uuid, bigint, uuid, integer, timestamp with time zone, uuid, integer, integer, uuid, boolean, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateimage(v_creation_date timestamp with time zone, v_image_guid uuid, v_it_guid uuid, v_size bigint, v_parentid uuid, v_imagestatus integer, v_lastmodified timestamp with time zone, v_vm_snapshot_id uuid, v_volume_type integer, v_volume_format integer, v_image_group_id uuid, v_active boolean, v_quota_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE images
    SET    creation_date = v_creation_date,
           it_guid = v_it_guid,
           size = v_size,
           ParentId = v_ParentId,
           imageStatus = v_imageStatus,
           lastModified = v_lastModified,
           vm_snapshot_id = v_vm_snapshot_id,
           volume_type = v_volume_type,
           image_group_id = v_image_group_id,
           volume_format = v_volume_format,
           active = v_active,
           quota_id = v_quota_id,
           _update_date = LOCALTIMESTAMP
    WHERE  image_guid = v_image_guid;
END; ';


ALTER FUNCTION public.updateimage(v_creation_date timestamp with time zone, v_image_guid uuid, v_it_guid uuid, v_size bigint, v_parentid uuid, v_imagestatus integer, v_lastmodified timestamp with time zone, v_vm_snapshot_id uuid, v_volume_type integer, v_volume_format integer, v_image_group_id uuid, v_active boolean, v_quota_id uuid) OWNER TO engine;

--
-- Name: updateimagestatus(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateimagestatus(v_image_id uuid, v_status integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE images
    SET    imageStatus = v_status
    WHERE  image_guid = v_image_id;
END; ';


ALTER FUNCTION public.updateimagestatus(v_image_id uuid, v_status integer) OWNER TO engine;

--
-- Name: updateimagevmsnapshotid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateimagevmsnapshotid(v_image_id uuid, v_vm_snapshot_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE images
    SET    vm_snapshot_id = v_vm_snapshot_id
    WHERE  image_guid = v_image_id;
END; ';


ALTER FUNCTION public.updateimagevmsnapshotid(v_image_id uuid, v_vm_snapshot_id uuid) OWNER TO engine;

--
-- Name: updateisinitialized(uuid, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateisinitialized(v_vm_guid uuid, v_is_initialized boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_static
      SET is_initialized = v_is_initialized
      WHERE vm_guid = v_vm_guid
      AND   entity_type = ''VM'';
END; ';


ALTER FUNCTION public.updateisinitialized(v_vm_guid uuid, v_is_initialized boolean) OWNER TO engine;

--
-- Name: updatejob(uuid, character varying, text, character varying, uuid, boolean, timestamp with time zone, timestamp with time zone, timestamp with time zone, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatejob(v_job_id uuid, v_action_type character varying, v_description text, v_status character varying, v_owner_id uuid, v_visible boolean, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_last_update_time timestamp with time zone, v_correlation_id character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    update job
    SET action_type = v_action_type,
        description = v_description,
        status = v_status,
        owner_id = v_owner_id,
        visible = v_visible,
        start_time = v_start_time,
        end_time = v_end_time,
        last_update_time = v_last_update_time,
        correlation_id = v_correlation_id
    WHERE job_id = v_job_id;
END; ';


ALTER FUNCTION public.updatejob(v_job_id uuid, v_action_type character varying, v_description text, v_status character varying, v_owner_id uuid, v_visible boolean, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_last_update_time timestamp with time zone, v_correlation_id character varying) OWNER TO engine;

--
-- Name: updatejoblastupdatetime(uuid, timestamp with time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatejoblastupdatetime(v_job_id uuid, v_last_update_time timestamp with time zone) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    update job
    SET last_update_time = v_last_update_time
    WHERE job_id = v_job_id;
END; ';


ALTER FUNCTION public.updatejoblastupdatetime(v_job_id uuid, v_last_update_time timestamp with time zone) OWNER TO engine;

--
-- Name: updatejobstepscompleted(uuid, character varying, timestamp with time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatejobstepscompleted(v_job_id uuid, v_status character varying, v_end_time timestamp with time zone) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE step
    SET status = v_status,
        end_time = v_end_time
    WHERE job_id = v_job_id
    AND   status = ''STARTED''
    AND   STATUS != v_status;
END; ';


ALTER FUNCTION public.updatejobstepscompleted(v_job_id uuid, v_status character varying, v_end_time timestamp with time zone) OWNER TO engine;

--
-- Name: updatelastadmincheckstatus(character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatelastadmincheckstatus(v_userids character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
   DECLARE
   v_id  UUID;
   v_tempId  VARCHAR(4000);
   myCursor cursor for select id from fnSplitter(v_userIds);
   v_result  INTEGER;
BEGIN	
	-- get users and its groups
	-- get their permission based on ad_element_id.
	-- if one permissions role''s type is ADMIN(1) then set the user last_admin_check_status to 1
   OPEN myCursor;
   FETCH myCursor into v_tempId;
   WHILE FOUND LOOP
      v_id := CAST(v_tempId AS UUID);
      select   count(*) INTO v_result from users where user_id in(select ad_element_id as user_id from permissions,roles
         where permissions.role_id = roles.id
         and ad_element_id in((select id from ad_groups,users where users.user_id = v_id
               and ad_groups.id in(select id from fnsplitteruuid(users.group_ids))
               union
               select v_id))
         and (roles.role_type = 1 or permissions.role_id = ''00000000-0000-0000-0000-000000000001''));
      update users set last_admin_check_status =
      case
      when v_result = 0 then FALSE
      else TRUE
      end
      where user_id = v_id;
      FETCH myCursor into v_tempId;
   END LOOP;
   CLOSE myCursor;  
END; ';


ALTER FUNCTION public.updatelastadmincheckstatus(v_userids character varying) OWNER TO engine;

--
-- Name: updatelun_storage_server_connection_map(character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatelun_storage_server_connection_map(v_lun_id character varying, v_storage_server_connection character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
END; ';


ALTER FUNCTION public.updatelun_storage_server_connection_map(v_lun_id character varying, v_storage_server_connection character varying) OWNER TO engine;

--
-- Name: updatenetwork(character varying, character varying, uuid, character varying, character varying, character varying, integer, integer, boolean, uuid, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatenetwork(v_addr character varying, v_description character varying, v_id uuid, v_name character varying, v_subnet character varying, v_gateway character varying, v_type integer, v_vlan_id integer, v_stp boolean, v_storage_pool_id uuid, v_mtu integer, v_vm_network boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE network
      SET addr = v_addr,description = v_description,name = v_name,subnet = v_subnet,
      gateway = v_gateway,type = v_type,vlan_id = v_vlan_id,
      stp = v_stp,storage_pool_id = v_storage_pool_id, mtu = v_mtu,
      vm_network = v_vm_network
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatenetwork(v_addr character varying, v_description character varying, v_id uuid, v_name character varying, v_subnet character varying, v_gateway character varying, v_type integer, v_vlan_id integer, v_stp boolean, v_storage_pool_id uuid, v_mtu integer, v_vm_network boolean) OWNER TO engine;

--
-- Name: updatenetwork_cluster(uuid, uuid, integer, boolean, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatenetwork_cluster(v_cluster_id uuid, v_network_id uuid, v_status integer, v_is_display boolean, v_required boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   UPDATE network_cluster
   SET status = v_status,is_display = v_is_display, required = v_required
   WHERE cluster_id = v_cluster_id AND network_id = v_network_id;
END; ';


ALTER FUNCTION public.updatenetwork_cluster(v_cluster_id uuid, v_network_id uuid, v_status integer, v_is_display boolean, v_required boolean) OWNER TO engine;

--
-- Name: updatenetwork_cluster_status(uuid, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatenetwork_cluster_status(v_cluster_id uuid, v_network_id uuid, v_status integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   UPDATE network_cluster
   SET status = v_status
   WHERE cluster_id = v_cluster_id AND network_id = v_network_id;
END; ';


ALTER FUNCTION public.updatenetwork_cluster_status(v_cluster_id uuid, v_network_id uuid, v_status integer) OWNER TO engine;

--
-- Name: updatequotaforimageandsnapshots(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatequotaforimageandsnapshots(v_image_group_id uuid, v_quota_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
UPDATE images
    SET quota_id = v_quota_id
    WHERE image_group_id = v_image_group_id;
END; ';


ALTER FUNCTION public.updatequotaforimageandsnapshots(v_image_group_id uuid, v_quota_id uuid) OWNER TO engine;

--
-- Name: updatequotametadata(uuid, uuid, character varying, character varying, integer, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatequotametadata(v_id uuid, v_storage_pool_id uuid, v_quota_name character varying, v_description character varying, v_threshold_vds_group_percentage integer, v_threshold_storage_percentage integer, v_grace_vds_group_percentage integer, v_grace_storage_percentage integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
UPDATE quota
   SET storage_pool_id = v_storage_pool_id,
   quota_name = v_quota_name,
   description = v_description,
   _update_date = LOCALTIMESTAMP,
   threshold_vds_group_percentage = v_threshold_vds_group_percentage,
   threshold_storage_percentage = v_threshold_storage_percentage,
   grace_vds_group_percentage = v_grace_vds_group_percentage,
   grace_storage_percentage = v_grace_storage_percentage
   WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatequotametadata(v_id uuid, v_storage_pool_id uuid, v_quota_name character varying, v_description character varying, v_threshold_vds_group_percentage integer, v_threshold_storage_percentage integer, v_grace_vds_group_percentage integer, v_grace_storage_percentage integer) OWNER TO engine;

--
-- Name: updatereplicacount(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatereplicacount(v_volume_id uuid, v_replica_count integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
UPDATE gluster_volumes
SET
replica_count = v_replica_count,
_update_date = LOCALTIMESTAMP
WHERE id = v_volume_id;
END; ';


ALTER FUNCTION public.updatereplicacount(v_volume_id uuid, v_replica_count integer) OWNER TO engine;

--
-- Name: updaterole(character varying, uuid, character varying, boolean, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updaterole(v_description character varying, v_id uuid, v_name character varying, v_is_readonly boolean, v_role_type integer, v_allows_viewing_children boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE roles
      SET description    = v_description,
          name           = v_name,
          is_readonly    = v_is_readonly,
          role_type      = v_role_type,
          allows_viewing_children = v_allows_viewing_children
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updaterole(v_description character varying, v_id uuid, v_name character varying, v_is_readonly boolean, v_role_type integer, v_allows_viewing_children boolean) OWNER TO engine;

--
-- Name: updateroles_relations(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateroles_relations(v_role_container_id uuid, v_role_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
END; ';


ALTER FUNCTION public.updateroles_relations(v_role_container_id uuid, v_role_id uuid) OWNER TO engine;

--
-- Name: updatesnapshot(uuid, uuid, character varying, character varying, character varying, timestamp with time zone, text, text); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatesnapshot(v_snapshot_id uuid, v_vm_id uuid, v_snapshot_type character varying, v_status character varying, v_description character varying, v_creation_date timestamp with time zone, v_app_list text, v_vm_configuration text) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE snapshots
    SET    status = v_status,
           vm_id = v_vm_id,
           snapshot_type = v_snapshot_type,
           description = v_description,
           creation_date = v_creation_date,
           app_list = v_app_list,
           vm_configuration = v_vm_configuration,
           _update_date = NOW()
    WHERE  snapshot_id = v_snapshot_id;
END; ';


ALTER FUNCTION public.updatesnapshot(v_snapshot_id uuid, v_vm_id uuid, v_snapshot_type character varying, v_status character varying, v_description character varying, v_creation_date timestamp with time zone, v_app_list text, v_vm_configuration text) OWNER TO engine;

--
-- Name: updatesnapshotid(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatesnapshotid(v_snapshot_id uuid, v_new_snapshot_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE snapshots
    SET    snapshot_id = v_new_snapshot_id
    WHERE  snapshot_id = v_snapshot_id;
END; ';


ALTER FUNCTION public.updatesnapshotid(v_snapshot_id uuid, v_new_snapshot_id uuid) OWNER TO engine;

--
-- Name: updatesnapshotstatus(uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatesnapshotstatus(v_snapshot_id uuid, v_status character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE snapshots
    SET    status = v_status
    WHERE  snapshot_id = v_snapshot_id;
END; ';


ALTER FUNCTION public.updatesnapshotstatus(v_snapshot_id uuid, v_status character varying) OWNER TO engine;

--
-- Name: updatestartedexecutionentitiestounknown(timestamp with time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestartedexecutionentitiestounknown(v_end_time timestamp with time zone) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

update job
set status = ''UNKNOWN'',
    end_time = v_end_time,
    last_update_time = v_end_time
where job.status = ''STARTED''
and job_id not in (select job_id
                   from step
                   where external_id is not null);

update step
set status = ''UNKNOWN'',
    end_time = v_end_time
where status = ''STARTED''
and job_id not in (select step.job_id
                   from step step
                   where step.external_id is not null);

END; ';


ALTER FUNCTION public.updatestartedexecutionentitiestounknown(v_end_time timestamp with time zone) OWNER TO engine;

--
-- Name: updatestep(uuid, uuid, uuid, character varying, text, integer, character varying, timestamp with time zone, timestamp with time zone, character varying, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestep(v_step_id uuid, v_parent_step_id uuid, v_job_id uuid, v_step_type character varying, v_description text, v_step_number integer, v_status character varying, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_correlation_id character varying, v_external_id uuid, v_external_system_type character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE step
    SET parent_step_id = v_parent_step_id,
        job_id = v_job_id,
        step_type = v_step_type,
        description = v_description,
        step_number = v_step_number,
        status = v_status,
        start_time = v_start_time,
        end_time = v_end_time,
        correlation_id = v_correlation_id,
        external_id = v_external_id,
        external_system_type = v_external_system_type
    WHERE step_id = v_step_id;
END; ';


ALTER FUNCTION public.updatestep(v_step_id uuid, v_parent_step_id uuid, v_job_id uuid, v_step_type character varying, v_description text, v_step_number integer, v_status character varying, v_start_time timestamp with time zone, v_end_time timestamp with time zone, v_correlation_id character varying, v_external_id uuid, v_external_system_type character varying) OWNER TO engine;

--
-- Name: updatestepexternalidandtype(uuid, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestepexternalidandtype(v_step_id uuid, v_external_id uuid, v_external_system_type character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE step
    SET external_id = v_external_id,
        external_system_type = v_external_system_type
    WHERE step_id = v_step_id;
END; ';


ALTER FUNCTION public.updatestepexternalidandtype(v_step_id uuid, v_external_id uuid, v_external_system_type character varying) OWNER TO engine;

--
-- Name: updatestepstatusandendtime(uuid, character varying, timestamp with time zone); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestepstatusandendtime(v_step_id uuid, v_status character varying, v_end_time timestamp with time zone) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE step
    SET status = v_status,
        end_time = v_end_time
    WHERE step_id = v_step_id;
END; ';


ALTER FUNCTION public.updatestepstatusandendtime(v_step_id uuid, v_status character varying, v_end_time timestamp with time zone) OWNER TO engine;

--
-- Name: updatestorage_domain_dynamic(integer, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_domain_dynamic(v_available_disk_size integer, v_id uuid, v_used_disk_size integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE storage_domain_dynamic
      SET available_disk_size = v_available_disk_size,used_disk_size = v_used_disk_size
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatestorage_domain_dynamic(v_available_disk_size integer, v_id uuid, v_used_disk_size integer) OWNER TO engine;

--
-- Name: updatestorage_domain_static(uuid, character varying, character varying, integer, integer, integer, bigint); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_domain_static(v_id uuid, v_storage character varying, v_storage_name character varying, v_storage_type integer, v_storage_domain_type integer, v_storage_domain_format_type integer, v_last_time_used_as_master bigint) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE storage_domain_static
      SET storage = v_storage, storage_name = v_storage_name, storage_type = v_storage_type,
      storage_domain_type = v_storage_domain_type, _update_date = LOCALTIMESTAMP,
      storage_domain_format_type = v_storage_domain_format_type,
      last_time_used_as_master = v_last_time_used_as_master
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatestorage_domain_static(v_id uuid, v_storage character varying, v_storage_name character varying, v_storage_type integer, v_storage_domain_type integer, v_storage_domain_format_type integer, v_last_time_used_as_master bigint) OWNER TO engine;

--
-- Name: updatestorage_pool(character varying, uuid, character varying, integer, integer, character varying, integer, uuid, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_pool(v_description character varying, v_id uuid, v_name character varying, v_storage_pool_type integer, v_status integer, v_storage_pool_format_type character varying, v_master_domain_version integer, v_spm_vds_id uuid, v_compatibility_version character varying, v_quota_enforcement_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE storage_pool
      SET description = v_description,name = v_name,storage_pool_type = v_storage_pool_type, 
      status = v_status,storage_pool_format_type = v_storage_pool_format_type,master_domain_version = v_master_domain_version, 
      spm_vds_id = v_spm_vds_id,compatibility_version = v_compatibility_version, 
      _update_date = LOCALTIMESTAMP,quota_enforcement_type=v_quota_enforcement_type
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatestorage_pool(v_description character varying, v_id uuid, v_name character varying, v_storage_pool_type integer, v_status integer, v_storage_pool_format_type character varying, v_master_domain_version integer, v_spm_vds_id uuid, v_compatibility_version character varying, v_quota_enforcement_type integer) OWNER TO engine;

--
-- Name: updatestorage_pool_iso_map(uuid, uuid, integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_pool_iso_map(v_storage_id uuid, v_storage_pool_id uuid, v_status integer, v_owner integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE storage_pool_iso_map
      SET status = v_status,owner = v_owner
      WHERE storage_id = v_storage_id and storage_pool_id = v_storage_pool_id;
END; ';


ALTER FUNCTION public.updatestorage_pool_iso_map(v_storage_id uuid, v_storage_pool_id uuid, v_status integer, v_owner integer) OWNER TO engine;

--
-- Name: updatestorage_pool_iso_map_status(uuid, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_pool_iso_map_status(v_storage_id uuid, v_storage_pool_id uuid, v_status integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
   UPDATE storage_pool_iso_map
   SET status = v_status
   WHERE storage_pool_id = v_storage_pool_id AND storage_id = v_storage_id;
END; ';


ALTER FUNCTION public.updatestorage_pool_iso_map_status(v_storage_id uuid, v_storage_pool_id uuid, v_status integer) OWNER TO engine;

--
-- Name: updatestorage_pool_partial(character varying, uuid, character varying, integer, character varying, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_pool_partial(v_description character varying, v_id uuid, v_name character varying, v_storage_pool_type integer, v_storage_pool_format_type character varying, v_compatibility_version character varying, v_quota_enforcement_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE storage_pool
      SET description = v_description,name = v_name,storage_pool_type = v_storage_pool_type,
      storage_pool_format_type = v_storage_pool_format_type,compatibility_version = v_compatibility_version,
      _update_date = LOCALTIMESTAMP,quota_enforcement_type = v_quota_enforcement_type
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatestorage_pool_partial(v_description character varying, v_id uuid, v_name character varying, v_storage_pool_type integer, v_storage_pool_format_type character varying, v_compatibility_version character varying, v_quota_enforcement_type integer) OWNER TO engine;

--
-- Name: updatestorage_pool_status(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_pool_status(v_id uuid, v_status integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE storage_pool
      SET 
      status = v_status,
      _update_date = LOCALTIMESTAMP
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatestorage_pool_status(v_id uuid, v_status integer) OWNER TO engine;

--
-- Name: updatestorage_server_connections(character varying, character varying, character varying, text, integer, character varying, character varying, character varying, character varying, character varying, smallint, smallint, smallint); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestorage_server_connections(v_connection character varying, v_id character varying, v_iqn character varying, v_password text, v_storage_type integer, v_port character varying, v_portal character varying, v_user_name character varying, v_mount_options character varying, v_vfs_type character varying, v_nfs_version smallint, v_nfs_timeo smallint, v_nfs_retrans smallint) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE storage_server_connections
      SET connection = v_connection,iqn = v_iqn,password = v_password,port = v_port, 
      portal = v_portal,storage_type = v_storage_type,user_name = v_user_name,mount_options = v_mount_options, vfs_type = v_vfs_type, nfs_version = v_nfs_version, nfs_timeo = v_nfs_timeo, nfs_retrans = v_nfs_retrans
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatestorage_server_connections(v_connection character varying, v_id character varying, v_iqn character varying, v_password text, v_storage_type integer, v_port character varying, v_portal character varying, v_user_name character varying, v_mount_options character varying, v_vfs_type character varying, v_nfs_version smallint, v_nfs_timeo smallint, v_nfs_retrans smallint) OWNER TO engine;

--
-- Name: updatestripecount(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatestripecount(v_volume_id uuid, v_stripe_count integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
UPDATE gluster_volumes
SET
stripe_count = v_stripe_count,
_update_date = LOCALTIMESTAMP
WHERE id = v_volume_id;
END; ';


ALTER FUNCTION public.updatestripecount(v_volume_id uuid, v_stripe_count integer) OWNER TO engine;

--
-- Name: updatetags(character varying, uuid, character varying, uuid, boolean, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatetags(v_description character varying, v_tag_id uuid, v_tag_name character varying, v_parent_id uuid, v_readonly boolean, v_type integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE tags
      SET description = v_description,tag_name = v_tag_name,parent_id = v_parent_id,
      readonly	= v_readonly,type = v_type,_update_date = LOCALTIMESTAMP
      WHERE tag_id = v_tag_id;
END; ';


ALTER FUNCTION public.updatetags(v_description character varying, v_tag_id uuid, v_tag_name character varying, v_parent_id uuid, v_readonly boolean, v_type integer) OWNER TO engine;

--
-- Name: updatetags_vm_pool_map(integer, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatetags_vm_pool_map(v_tag_id integer, v_vm_pool_id integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
END; ';


ALTER FUNCTION public.updatetags_vm_pool_map(v_tag_id integer, v_vm_pool_id integer) OWNER TO engine;

--
-- Name: updateuser(character varying, character varying, character varying, character varying, character varying, character varying, character varying, character varying, integer, character varying, character varying, uuid, integer, character varying, boolean, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updateuser(v_department character varying, v_desktop_device character varying, v_domain character varying, v_email character varying, v_groups character varying, v_name character varying, v_note character varying, v_role character varying, v_status integer, v_surname character varying, v_user_icon_path character varying, v_user_id uuid, v_session_count integer, v_username character varying, v_last_admin_check_status boolean, v_group_ids character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE users
      SET department = v_department,desktop_device = v_desktop_device,domain = v_domain, 
      email = v_email,groups = v_groups,name = v_name,note = v_note, 
      role = v_role,status = v_status,surname = v_surname,user_icon_path = v_user_icon_path, 
      username = v_username,session_count = v_session_count, 
      last_admin_check_status = v_last_admin_check_status,
      group_ids = v_group_ids
      WHERE user_id = v_user_id;
END; ';


ALTER FUNCTION public.updateuser(v_department character varying, v_desktop_device character varying, v_domain character varying, v_email character varying, v_groups character varying, v_name character varying, v_note character varying, v_role character varying, v_status integer, v_surname character varying, v_user_icon_path character varying, v_user_id uuid, v_session_count integer, v_username character varying, v_last_admin_check_status boolean, v_group_ids character varying) OWNER TO engine;

--
-- Name: updatevdcoption(character varying, character varying, integer, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevdcoption(v_option_name character varying, v_option_value character varying, v_option_id integer, v_version character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vdc_options
      SET OPTION_NAME = v_option_name,option_value = v_option_value,version = v_version
      WHERE option_id = v_option_id;
END; ';


ALTER FUNCTION public.updatevdcoption(v_option_name character varying, v_option_value character varying, v_option_id integer, v_version character varying) OWNER TO engine;

--
-- Name: updatevds_interface(character varying, character varying, integer, character varying, uuid, boolean, character varying, character varying, character varying, character varying, integer, character varying, integer, integer, uuid, integer, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevds_interface(v_addr character varying, v_bond_name character varying, v_bond_type integer, v_gateway character varying, v_id uuid, v_is_bond boolean, v_bond_opts character varying, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_subnet character varying, v_boot_protocol integer, v_type integer, v_vds_id uuid, v_vlan_id integer, v_mtu integer, v_bridged boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vds_interface
      SET addr = v_addr,bond_name = v_bond_name,bond_type = v_bond_type,gateway = v_gateway, 
      is_bond = v_is_bond,bond_opts = v_bond_opts,mac_addr = v_mac_addr, 
      name = v_name,network_name = v_network_name,speed = v_speed, 
      subnet = v_subnet,boot_protocol = v_boot_protocol, 
      type = v_type,VDS_ID = v_vds_id,vlan_id = v_vlan_id,_update_date = LOCALTIMESTAMP, mtu = v_mtu,
      bridged = v_bridged
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatevds_interface(v_addr character varying, v_bond_name character varying, v_bond_type integer, v_gateway character varying, v_id uuid, v_is_bond boolean, v_bond_opts character varying, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_subnet character varying, v_boot_protocol integer, v_type integer, v_vds_id uuid, v_vlan_id integer, v_mtu integer, v_bridged boolean) OWNER TO engine;

--
-- Name: updatevds_interface_statistics(uuid, numeric, numeric, numeric, numeric, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevds_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vds_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vds_interface_statistics
      SET rx_drop = v_rx_drop,rx_rate = v_rx_rate,tx_drop = v_tx_drop,tx_rate = v_tx_rate, 
      vds_id = v_vds_id,iface_status = v_iface_status
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatevds_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vds_id uuid) OWNER TO engine;

--
-- Name: updatevdsdynamic(integer, character varying, numeric, character varying, boolean, integer, integer, integer, uuid, integer, integer, integer, integer, integer, integer, character varying, character varying, character varying, character varying, integer, character varying, timestamp with time zone, integer, integer, integer, integer, boolean, character varying, character varying, character varying, character varying, character varying, character varying, character varying, integer, integer, character varying, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevdsdynamic(v_cpu_cores integer, v_cpu_model character varying, v_cpu_speed_mh numeric, v_if_total_speed character varying, v_kvm_enabled boolean, v_mem_commited integer, v_physical_mem_mb integer, v_status integer, v_vds_id uuid, v_vm_active integer, v_vm_count integer, v_vms_cores_count integer, v_vm_migrating integer, v_reserved_mem integer, v_guest_overhead integer, v_rpm_version character varying, v_software_version character varying, v_version_name character varying, v_build_name character varying, v_previous_status integer, v_cpu_flags character varying, v_cpu_over_commit_time_stamp timestamp with time zone, v_hypervisor_type integer, v_pending_vcpus_count integer, v_pending_vmem_size integer, v_cpu_sockets integer, v_net_config_dirty boolean, v_supported_cluster_levels character varying, v_supported_engines character varying, v_host_os character varying, v_kvm_version character varying, v_spice_version character varying, v_kernel_version character varying, v_iscsi_initiator_name character varying, v_transparent_hugepages_state integer, v_anonymous_hugepages integer, v_hooks character varying, v_non_operational_reason integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

   BEGIN
      UPDATE vds_dynamic
      SET cpu_cores = v_cpu_cores,cpu_model = v_cpu_model,cpu_speed_mh = v_cpu_speed_mh, 
      if_total_speed = v_if_total_speed,kvm_enabled = v_kvm_enabled, 
      mem_commited = v_mem_commited,physical_mem_mb = v_physical_mem_mb, 
      status = v_status,vm_active = v_vm_active,vm_count = v_vm_count, 
      vm_migrating = v_vm_migrating,reserved_mem = v_reserved_mem, 
      guest_overhead = v_guest_overhead,rpm_version = v_rpm_version, software_version = v_software_version,
      version_name = v_version_name,build_name = v_build_name,previous_status = v_previous_status, 
      cpu_flags = v_cpu_flags,cpu_over_commit_time_stamp = v_cpu_over_commit_time_stamp, 
      hypervisor_type = v_hypervisor_type, 
      vms_cores_count = v_vms_cores_count,pending_vcpus_count = v_pending_vcpus_count, 
      pending_vmem_size = v_pending_vmem_size, 
      cpu_sockets = v_cpu_sockets,net_config_dirty = v_net_config_dirty, 
      supported_cluster_levels = v_supported_cluster_levels, 
      supported_engines = v_supported_engines,host_os = v_host_os, 
      kvm_version = v_kvm_version,spice_version = v_spice_version, 
      kernel_version = v_kernel_version,iscsi_initiator_name = v_iscsi_initiator_name, 
      transparent_hugepages_state = v_transparent_hugepages_state, 
      anonymous_hugepages = v_anonymous_hugepages,hooks = v_hooks,
      _update_date = LOCALTIMESTAMP,non_operational_reason = v_non_operational_reason
      WHERE vds_id = v_vds_id;
   END;	

   RETURN;
END; ';


ALTER FUNCTION public.updatevdsdynamic(v_cpu_cores integer, v_cpu_model character varying, v_cpu_speed_mh numeric, v_if_total_speed character varying, v_kvm_enabled boolean, v_mem_commited integer, v_physical_mem_mb integer, v_status integer, v_vds_id uuid, v_vm_active integer, v_vm_count integer, v_vms_cores_count integer, v_vm_migrating integer, v_reserved_mem integer, v_guest_overhead integer, v_rpm_version character varying, v_software_version character varying, v_version_name character varying, v_build_name character varying, v_previous_status integer, v_cpu_flags character varying, v_cpu_over_commit_time_stamp timestamp with time zone, v_hypervisor_type integer, v_pending_vcpus_count integer, v_pending_vmem_size integer, v_cpu_sockets integer, v_net_config_dirty boolean, v_supported_cluster_levels character varying, v_supported_engines character varying, v_host_os character varying, v_kvm_version character varying, v_spice_version character varying, v_kernel_version character varying, v_iscsi_initiator_name character varying, v_transparent_hugepages_state integer, v_anonymous_hugepages integer, v_hooks character varying, v_non_operational_reason integer) OWNER TO engine;

--
-- Name: updatevdsdynamicstatus(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevdsdynamicstatus(v_vds_guid uuid, v_status integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vds_dynamic
      SET
      status = v_status
      WHERE vds_id = v_vds_guid;
END; ';


ALTER FUNCTION public.updatevdsdynamicstatus(v_vds_guid uuid, v_status integer) OWNER TO engine;

--
-- Name: updatevdsgroup(character varying, character varying, uuid, character varying, integer, integer, integer, integer, integer, uuid, integer, character varying, boolean, integer, boolean, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevdsgroup(v_description character varying, v_name character varying, v_vds_group_id uuid, v_cpu_name character varying, v_selection_algorithm integer, v_high_utilization integer, v_low_utilization integer, v_cpu_over_commit_duration_minutes integer, v_hypervisor_type integer, v_storage_pool_id uuid, v_max_vds_memory_over_commit integer, v_compatibility_version character varying, v_transparent_hugepages boolean, v_migrate_on_error integer, v_virt_service boolean, v_gluster_service boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vds_groups
      SET description = v_description,name = v_name,cpu_name = v_cpu_name,selection_algorithm = v_selection_algorithm, 
      high_utilization = v_high_utilization, 
      low_utilization = v_low_utilization,cpu_over_commit_duration_minutes = v_cpu_over_commit_duration_minutes, 
      hypervisor_type = v_hypervisor_type, 
      storage_pool_id = v_storage_pool_id,_update_date = LOCALTIMESTAMP,
      max_vds_memory_over_commit = v_max_vds_memory_over_commit, 
      compatibility_version = v_compatibility_version,transparent_hugepages = v_transparent_hugepages, 
      migrate_on_error = v_migrate_on_error,
      virt_service = v_virt_service, gluster_service = v_gluster_service
      WHERE vds_group_id = v_vds_group_id;
END; ';


ALTER FUNCTION public.updatevdsgroup(v_description character varying, v_name character varying, v_vds_group_id uuid, v_cpu_name character varying, v_selection_algorithm integer, v_high_utilization integer, v_low_utilization integer, v_cpu_over_commit_duration_minutes integer, v_hypervisor_type integer, v_storage_pool_id uuid, v_max_vds_memory_over_commit integer, v_compatibility_version character varying, v_transparent_hugepages boolean, v_migrate_on_error integer, v_virt_service boolean, v_gluster_service boolean) OWNER TO engine;

--
-- Name: updatevdsstatic(character varying, character varying, character varying, integer, uuid, uuid, character varying, boolean, integer, integer, character varying, character varying, character varying, integer, character varying, boolean, bigint, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevdsstatic(v_host_name character varying, v_ip character varying, v_vds_unique_id character varying, v_port integer, v_vds_group_id uuid, v_vds_id uuid, v_vds_name character varying, v_server_ssl_enabled boolean, v_vds_type integer, v_vds_strength integer, v_pm_type character varying, v_pm_user character varying, v_pm_password character varying, v_pm_port integer, v_pm_options character varying, v_pm_enabled boolean, v_otp_validity bigint, v_vds_spm_priority integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

   BEGIN
      UPDATE vds_static
      SET host_name = v_host_name,ip = v_ip,vds_unique_id = v_vds_unique_id, 
      port = v_port,vds_group_id = v_vds_group_id,vds_name = v_vds_name,server_SSL_enabled = v_server_SSL_enabled, 
      vds_type = v_vds_type, 
      _update_date = LOCALTIMESTAMP,vds_strength = v_vds_strength, 
      pm_type = v_pm_type,pm_user = v_pm_user,pm_password = v_pm_password, 
      pm_port = v_pm_port,pm_options = v_pm_options,pm_enabled = v_pm_enabled, otp_validity = v_otp_validity, vds_spm_priority = v_vds_spm_priority
      WHERE vds_id = v_vds_id;
   END;	

   RETURN;
END; ';


ALTER FUNCTION public.updatevdsstatic(v_host_name character varying, v_ip character varying, v_vds_unique_id character varying, v_port integer, v_vds_group_id uuid, v_vds_id uuid, v_vds_name character varying, v_server_ssl_enabled boolean, v_vds_type integer, v_vds_strength integer, v_pm_type character varying, v_pm_user character varying, v_pm_password character varying, v_pm_port integer, v_pm_options character varying, v_pm_enabled boolean, v_otp_validity bigint, v_vds_spm_priority integer) OWNER TO engine;

--
-- Name: updatevdsstatistics(numeric, numeric, numeric, numeric, integer, integer, integer, uuid, bigint, bigint, bigint, bigint, integer, bigint, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevdsstatistics(v_cpu_idle numeric, v_cpu_load numeric, v_cpu_sys numeric, v_cpu_user numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_vds_id uuid, v_mem_available bigint, v_mem_shared bigint, v_swap_free bigint, v_swap_total bigint, v_ksm_cpu_percent integer, v_ksm_pages bigint, v_ksm_state boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN

   BEGIN
      UPDATE vds_statistics
      SET cpu_idle = v_cpu_idle,cpu_load = v_cpu_load,cpu_sys = v_cpu_sys, 
      cpu_user = v_cpu_user,usage_cpu_percent = v_usage_cpu_percent,usage_mem_percent = v_usage_mem_percent, 
      usage_network_percent = v_usage_network_percent, 
      mem_available = v_mem_available,mem_shared = v_mem_shared,
      swap_free = v_swap_free,swap_total = v_swap_total,ksm_cpu_percent = v_ksm_cpu_percent, 
      ksm_pages = v_ksm_pages,ksm_state = v_ksm_state
      WHERE vds_id = v_vds_id;
   END;	

   RETURN;
END; ';


ALTER FUNCTION public.updatevdsstatistics(v_cpu_idle numeric, v_cpu_load numeric, v_cpu_sys numeric, v_cpu_user numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_vds_id uuid, v_mem_available bigint, v_mem_shared bigint, v_swap_free bigint, v_swap_total bigint, v_ksm_cpu_percent integer, v_ksm_pages bigint, v_ksm_state boolean) OWNER TO engine;

--
-- Name: updatevm_interface(uuid, character varying, character varying, character varying, integer, uuid, uuid, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevm_interface(v_id uuid, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_vm_guid uuid, v_vmt_guid uuid, v_type integer, v_port_mirroring boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_interface
      SET mac_addr = v_mac_addr,name = v_name,network_name = v_network_name, 
      speed = v_speed,VM_GUID = v_vm_guid,VMT_GUID = v_vmt_guid,type = v_type, 
      _update_date = LOCALTIMESTAMP, port_mirroring = v_port_mirroring
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatevm_interface(v_id uuid, v_mac_addr character varying, v_name character varying, v_network_name character varying, v_speed integer, v_vm_guid uuid, v_vmt_guid uuid, v_type integer, v_port_mirroring boolean) OWNER TO engine;

--
-- Name: updatevm_interface_statistics(uuid, numeric, numeric, numeric, numeric, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevm_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vm_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_interface_statistics
      SET rx_drop = v_rx_drop,rx_rate = v_rx_rate,tx_drop = v_tx_drop,tx_rate = v_tx_rate, 
      vm_id = v_vm_id,iface_status = v_iface_status
      WHERE id = v_id;
END; ';


ALTER FUNCTION public.updatevm_interface_statistics(v_id uuid, v_rx_drop numeric, v_rx_rate numeric, v_tx_drop numeric, v_tx_rate numeric, v_iface_status integer, v_vm_id uuid) OWNER TO engine;

--
-- Name: updatevm_pool_map(uuid, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevm_pool_map(v_vm_guid uuid, v_vm_pool_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_pool_map
      SET vm_pool_id = v_vm_pool_id
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.updatevm_pool_map(v_vm_guid uuid, v_vm_pool_id uuid) OWNER TO engine;

--
-- Name: updatevm_pools(character varying, uuid, character varying, integer, character varying, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevm_pools(v_vm_pool_description character varying, v_vm_pool_id uuid, v_vm_pool_name character varying, v_vm_pool_type integer, v_parameters character varying, v_prestarted_vms integer, v_vds_group_id uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_pools
      SET vm_pool_description = v_vm_pool_description,vm_pool_name = v_vm_pool_name,
      vm_pool_type = v_vm_pool_type,parameters = v_parameters, prestarted_vms = v_prestarted_vms, vds_group_id = v_vds_group_id
      WHERE vm_pool_id = v_vm_pool_id;
END; ';


ALTER FUNCTION public.updatevm_pools(v_vm_pool_description character varying, v_vm_pool_id uuid, v_vm_pool_name character varying, v_vm_pool_type integer, v_parameters character varying, v_prestarted_vms integer, v_vds_group_id uuid) OWNER TO engine;

--
-- Name: updatevmdevice(uuid, uuid, character varying, character varying, character varying, integer, text, boolean, boolean, boolean, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmdevice(v_device_id uuid, v_vm_id uuid, v_device character varying, v_type character varying, v_address character varying, v_boot_order integer, v_spec_params text, v_is_managed boolean, v_is_plugged boolean, v_is_readonly boolean, v_alias character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE vm_device
    SET
           device = v_device,
           type = v_type,
           address = v_address,
           boot_order = v_boot_order,
           spec_params = v_spec_params,
           is_managed = v_is_managed,
           is_plugged = v_is_plugged,
           is_readonly = v_is_readonly,
           alias = v_alias,
           _update_date = current_timestamp
    WHERE  device_id = v_device_id and vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.updatevmdevice(v_device_id uuid, v_vm_id uuid, v_device character varying, v_type character varying, v_address character varying, v_boot_order integer, v_spec_params text, v_is_managed boolean, v_is_plugged boolean, v_is_readonly boolean, v_alias character varying) OWNER TO engine;

--
-- Name: updatevmdeviceforhotplugdisk(uuid, uuid, integer, boolean); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmdeviceforhotplugdisk(v_device_id uuid, v_vm_id uuid, v_boot_order integer, v_is_plugged boolean) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE vm_device
    SET
           boot_order = v_boot_order,
           is_plugged = v_is_plugged,
           _update_date = current_timestamp
    WHERE  device_id = v_device_id and vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.updatevmdeviceforhotplugdisk(v_device_id uuid, v_vm_id uuid, v_boot_order integer, v_is_plugged boolean) OWNER TO engine;

--
-- Name: updatevmdeviceruntimeinfo(uuid, uuid, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmdeviceruntimeinfo(v_device_id uuid, v_vm_id uuid, v_address character varying, v_alias character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
    UPDATE vm_device
    SET
           address = v_address,
           alias = v_alias,
           _update_date = current_timestamp
    WHERE  device_id = v_device_id and vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.updatevmdeviceruntimeinfo(v_device_id uuid, v_vm_id uuid, v_address character varying, v_alias character varying) OWNER TO engine;

--
-- Name: updatevmdynamic(character varying, uuid, character varying, timestamp with time zone, timestamp with time zone, uuid, character varying, uuid, uuid, integer, uuid, character varying, character varying, timestamp with time zone, integer, integer, boolean, integer, character varying, integer, boolean, integer, integer, integer, uuid, character varying, integer, character varying, integer, integer, character varying, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmdynamic(v_app_list character varying, v_guest_cur_user_id uuid, v_guest_cur_user_name character varying, v_guest_last_login_time timestamp with time zone, v_guest_last_logout_time timestamp with time zone, v_console_user_id uuid, v_guest_os character varying, v_migrating_to_vds uuid, v_run_on_vds uuid, v_status integer, v_vm_guid uuid, v_vm_host character varying, v_vm_ip character varying, v_last_start_time timestamp with time zone, v_vm_pid integer, v_display integer, v_acpi_enable boolean, v_session integer, v_display_ip character varying, v_display_type integer, v_kvm_enable boolean, v_boot_sequence integer, v_display_secure_port integer, v_utc_diff integer, v_last_vds_run_on uuid, v_client_ip character varying, v_guest_requested_memory integer, v_hibernation_vol_handle character varying, v_exit_status integer, v_pause_status integer, v_exit_message character varying, v_hash character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_dynamic
      SET app_list = v_app_list,guest_cur_user_id = v_guest_cur_user_id,guest_cur_user_name = v_guest_cur_user_name, 
      guest_last_login_time = v_guest_last_login_time, 
      guest_last_logout_time = v_guest_last_logout_time, 
      console_user_id = v_console_user_id,
      guest_os = v_guest_os,migrating_to_vds = v_migrating_to_vds,RUN_ON_VDS = v_run_on_vds, 
      status = v_status,vm_host = v_vm_host,vm_ip = v_vm_ip, 
      last_start_time = v_last_start_time, 
      vm_pid = v_vm_pid,display = v_display,acpi_enable = v_acpi_enable, 
      session = v_session,display_ip = v_display_ip, 
      display_type = v_display_type,kvm_enable = v_kvm_enable,boot_sequence = v_boot_sequence, 
      display_secure_port = v_display_secure_port, 
      utc_diff = v_utc_diff,last_vds_run_on = v_last_vds_run_on,client_ip = v_client_ip, 
      guest_requested_memory = v_guest_requested_memory, 
      hibernation_vol_handle = v_hibernation_vol_handle,exit_status = v_exit_status, 
      pause_status = v_pause_status,exit_message = v_exit_message, hash=v_hash
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.updatevmdynamic(v_app_list character varying, v_guest_cur_user_id uuid, v_guest_cur_user_name character varying, v_guest_last_login_time timestamp with time zone, v_guest_last_logout_time timestamp with time zone, v_console_user_id uuid, v_guest_os character varying, v_migrating_to_vds uuid, v_run_on_vds uuid, v_status integer, v_vm_guid uuid, v_vm_host character varying, v_vm_ip character varying, v_last_start_time timestamp with time zone, v_vm_pid integer, v_display integer, v_acpi_enable boolean, v_session integer, v_display_ip character varying, v_display_type integer, v_kvm_enable boolean, v_boot_sequence integer, v_display_secure_port integer, v_utc_diff integer, v_last_vds_run_on uuid, v_client_ip character varying, v_guest_requested_memory integer, v_hibernation_vol_handle character varying, v_exit_status integer, v_pause_status integer, v_exit_message character varying, v_hash character varying) OWNER TO engine;

--
-- Name: updatevmdynamicstatus(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmdynamicstatus(v_vm_guid uuid, v_status integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_dynamic
      SET  
      status = v_status 
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.updatevmdynamicstatus(v_vm_guid uuid, v_status integer) OWNER TO engine;

--
-- Name: updatevmstatic(character varying, integer, integer, uuid, uuid, character varying, uuid, character varying, timestamp with time zone, integer, boolean, boolean, boolean, integer, integer, integer, character varying, boolean, boolean, uuid, boolean, integer, integer, integer, integer, integer, integer, integer, character varying, integer, character varying, character varying, character varying, integer, character varying, character varying, integer, uuid, character varying); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmstatic(v_description character varying, v_mem_size_mb integer, v_os integer, v_vds_group_id uuid, v_vm_guid uuid, v_vm_name character varying, v_vmt_guid uuid, v_domain character varying, v_creation_date timestamp with time zone, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_is_initialized boolean, v_is_auto_suspend boolean, v_num_of_sockets integer, v_cpu_per_socket integer, v_usb_policy integer, v_time_zone character varying, v_auto_startup boolean, v_is_stateless boolean, v_dedicated_vm_for_vds uuid, v_fail_back boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_migration_support integer, v_predefined_properties character varying, v_userdefined_properties character varying, v_min_allocated_mem integer, v_quota_id uuid, v_cpu_pinning character varying) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_static
      SET description = v_description,mem_size_mb = v_mem_size_mb,os = v_os,vds_group_id = v_vds_group_id, 
      VM_NAME = v_vm_name,vmt_guid = v_vmt_guid, 
      domain = v_domain,creation_date = v_creation_date,num_of_monitors = v_num_of_monitors, 
      allow_console_reconnect = v_allow_console_reconnect,
      is_initialized = v_is_initialized,is_auto_suspend = v_is_auto_suspend, 
      num_of_sockets = v_num_of_sockets,cpu_per_socket = v_cpu_per_socket, 
      usb_policy = v_usb_policy,time_zone = v_time_zone,auto_startup = v_auto_startup, 
      is_stateless = v_is_stateless,dedicated_vm_for_vds = v_dedicated_vm_for_vds, 
      fail_back = v_fail_back,vm_type = v_vm_type, 
      hypervisor_type = v_hypervisor_type,nice_level = v_nice_level,operation_mode = v_operation_mode, 
      _update_date = LOCALTIMESTAMP,default_boot_sequence = v_default_boot_sequence, 
      default_display_type = v_default_display_type, 
      priority = v_priority,iso_path = v_iso_path,origin = v_origin, 
      initrd_url = v_initrd_url,kernel_url = v_kernel_url, 
      kernel_params = v_kernel_params,migration_support = v_migration_support,
      predefined_properties = v_predefined_properties,userdefined_properties = v_userdefined_properties,
      min_allocated_mem = v_min_allocated_mem, quota_id = v_quota_id, cpu_pinning = v_cpu_pinning
      WHERE vm_guid = v_vm_guid
      AND   entity_type = ''VM'';
END; ';


ALTER FUNCTION public.updatevmstatic(v_description character varying, v_mem_size_mb integer, v_os integer, v_vds_group_id uuid, v_vm_guid uuid, v_vm_name character varying, v_vmt_guid uuid, v_domain character varying, v_creation_date timestamp with time zone, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_is_initialized boolean, v_is_auto_suspend boolean, v_num_of_sockets integer, v_cpu_per_socket integer, v_usb_policy integer, v_time_zone character varying, v_auto_startup boolean, v_is_stateless boolean, v_dedicated_vm_for_vds uuid, v_fail_back boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_migration_support integer, v_predefined_properties character varying, v_userdefined_properties character varying, v_min_allocated_mem integer, v_quota_id uuid, v_cpu_pinning character varying) OWNER TO engine;

--
-- Name: updatevmstatistics(numeric, numeric, numeric, integer, integer, integer, text, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmstatistics(v_cpu_sys numeric, v_cpu_user numeric, v_elapsed_time numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_disks_usage text, v_vm_guid uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_statistics
      SET cpu_sys = v_cpu_sys,cpu_user = v_cpu_user,elapsed_time = v_elapsed_time, 
      usage_cpu_percent = v_usage_cpu_percent,usage_mem_percent = v_usage_mem_percent, 
      usage_network_percent = v_usage_network_percent,disks_usage = v_disks_usage
      WHERE vm_guid = v_vm_guid;
END; ';


ALTER FUNCTION public.updatevmstatistics(v_cpu_sys numeric, v_cpu_user numeric, v_elapsed_time numeric, v_usage_cpu_percent integer, v_usage_mem_percent integer, v_usage_network_percent integer, v_disks_usage text, v_vm_guid uuid) OWNER TO engine;

--
-- Name: updatevmtagsdefaultdisplaytype(uuid, uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmtagsdefaultdisplaytype(v_tag_id uuid, v_vm_id uuid, v_defaultdisplaytype integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      update tags_vm_map
      set DefaultDisplayType = v_DefaultDisplayType
      where tags_vm_map.tag_id = v_tag_id
      and tags_vm_map.vm_id = v_vm_id;
END; ';


ALTER FUNCTION public.updatevmtagsdefaultdisplaytype(v_tag_id uuid, v_vm_id uuid, v_defaultdisplaytype integer) OWNER TO engine;

--
-- Name: updatevmtemplate(integer, timestamp with time zone, character varying, integer, character varying, integer, integer, integer, uuid, uuid, character varying, integer, boolean, integer, integer, character varying, boolean, boolean, integer, integer, integer, integer, integer, integer, integer, boolean, boolean, character varying, integer, character varying, character varying, character varying, uuid, integer, uuid); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmtemplate(v_child_count integer, v_creation_date timestamp with time zone, v_description character varying, v_mem_size_mb integer, v_name character varying, v_num_of_sockets integer, v_cpu_per_socket integer, v_os integer, v_vmt_guid uuid, v_vds_group_id uuid, v_domain character varying, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_status integer, v_usb_policy integer, v_time_zone character varying, v_fail_back boolean, v_is_auto_suspend boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_auto_startup boolean, v_is_stateless boolean, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_quota_id uuid, v_migration_support integer, v_dedicated_vm_for_vds uuid) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_static
      SET child_count = v_child_count,creation_date = v_creation_date,description = v_description, 
      mem_size_mb = v_mem_size_mb,vm_name = v_name,num_of_sockets = v_num_of_sockets,
      cpu_per_socket = v_cpu_per_socket,os = v_os, 
      vds_group_id = v_vds_group_id,domain = v_domain,num_of_monitors = v_num_of_monitors,
      allow_console_reconnect = v_allow_console_reconnect,
      template_status = v_status,usb_policy = v_usb_policy,time_zone = v_time_zone,
      fail_back = v_fail_back,is_auto_suspend = v_is_auto_suspend,
      vm_type = v_vm_type,hypervisor_type = v_hypervisor_type,operation_mode = v_operation_mode, 
      nice_level = v_nice_level,default_boot_sequence = v_default_boot_sequence, 
      default_display_type = v_default_display_type, 
      priority = v_priority,auto_startup = v_auto_startup,is_stateless = v_is_stateless, 
      iso_path = v_iso_path,origin = v_origin,initrd_url = v_initrd_url, 
      kernel_url = v_kernel_url,kernel_params = v_kernel_params, _update_date = CURRENT_TIMESTAMP, quota_id = v_quota_id,
      migration_support = v_migration_support, dedicated_vm_for_vds = v_dedicated_vm_for_vds
      WHERE vm_guid = v_vmt_guid
      AND   entity_type = ''TEMPLATE'';
END; ';


ALTER FUNCTION public.updatevmtemplate(v_child_count integer, v_creation_date timestamp with time zone, v_description character varying, v_mem_size_mb integer, v_name character varying, v_num_of_sockets integer, v_cpu_per_socket integer, v_os integer, v_vmt_guid uuid, v_vds_group_id uuid, v_domain character varying, v_num_of_monitors integer, v_allow_console_reconnect boolean, v_status integer, v_usb_policy integer, v_time_zone character varying, v_fail_back boolean, v_is_auto_suspend boolean, v_vm_type integer, v_hypervisor_type integer, v_operation_mode integer, v_nice_level integer, v_default_boot_sequence integer, v_default_display_type integer, v_priority integer, v_auto_startup boolean, v_is_stateless boolean, v_iso_path character varying, v_origin integer, v_initrd_url character varying, v_kernel_url character varying, v_kernel_params character varying, v_quota_id uuid, v_migration_support integer, v_dedicated_vm_for_vds uuid) OWNER TO engine;

--
-- Name: updatevmtemplatestatus(uuid, integer); Type: FUNCTION; Schema: public; Owner: engine
--

CREATE FUNCTION updatevmtemplatestatus(v_vmt_guid uuid, v_status integer) RETURNS void
    LANGUAGE plpgsql
    AS '
BEGIN
      UPDATE vm_static
      SET    template_status = v_status
      WHERE  vm_guid = v_vmt_guid
      AND    entity_type = ''TEMPLATE'';
END; ';


ALTER FUNCTION public.updatevmtemplatestatus(v_vmt_guid uuid, v_status integer) OWNER TO engine;

--
-- Name: uuid_generate_v1(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_generate_v1() RETURNS uuid
    LANGUAGE c STRICT
    AS '$libdir/uuid-ossp', 'uuid_generate_v1';


ALTER FUNCTION public.uuid_generate_v1() OWNER TO postgres;

--
-- Name: uuid_generate_v1mc(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_generate_v1mc() RETURNS uuid
    LANGUAGE c STRICT
    AS '$libdir/uuid-ossp', 'uuid_generate_v1mc';


ALTER FUNCTION public.uuid_generate_v1mc() OWNER TO postgres;

--
-- Name: uuid_generate_v3(uuid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_generate_v3(namespace uuid, name text) RETURNS uuid
    LANGUAGE c IMMUTABLE STRICT
    AS '$libdir/uuid-ossp', 'uuid_generate_v3';


ALTER FUNCTION public.uuid_generate_v3(namespace uuid, name text) OWNER TO postgres;

--
-- Name: uuid_generate_v4(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_generate_v4() RETURNS uuid
    LANGUAGE c STRICT
    AS '$libdir/uuid-ossp', 'uuid_generate_v4';


ALTER FUNCTION public.uuid_generate_v4() OWNER TO postgres;

--
-- Name: uuid_generate_v5(uuid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_generate_v5(namespace uuid, name text) RETURNS uuid
    LANGUAGE c IMMUTABLE STRICT
    AS '$libdir/uuid-ossp', 'uuid_generate_v5';


ALTER FUNCTION public.uuid_generate_v5(namespace uuid, name text) OWNER TO postgres;

--
-- Name: uuid_nil(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_nil() RETURNS uuid
    LANGUAGE c IMMUTABLE STRICT
    AS '$libdir/uuid-ossp', 'uuid_nil';


ALTER FUNCTION public.uuid_nil() OWNER TO postgres;

--
-- Name: uuid_ns_dns(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_ns_dns() RETURNS uuid
    LANGUAGE c IMMUTABLE STRICT
    AS '$libdir/uuid-ossp', 'uuid_ns_dns';


ALTER FUNCTION public.uuid_ns_dns() OWNER TO postgres;

--
-- Name: uuid_ns_oid(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_ns_oid() RETURNS uuid
    LANGUAGE c IMMUTABLE STRICT
    AS '$libdir/uuid-ossp', 'uuid_ns_oid';


ALTER FUNCTION public.uuid_ns_oid() OWNER TO postgres;

--
-- Name: uuid_ns_url(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_ns_url() RETURNS uuid
    LANGUAGE c IMMUTABLE STRICT
    AS '$libdir/uuid-ossp', 'uuid_ns_url';


ALTER FUNCTION public.uuid_ns_url() OWNER TO postgres;

--
-- Name: uuid_ns_x500(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uuid_ns_x500() RETURNS uuid
    LANGUAGE c IMMUTABLE STRICT
    AS '$libdir/uuid-ossp', 'uuid_ns_x500';


ALTER FUNCTION public.uuid_ns_x500() OWNER TO postgres;

--
-- Name: async_tasks_entities; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE async_tasks_entities (
    async_task_id uuid NOT NULL,
    entity_id uuid NOT NULL,
    entity_type character varying(128)
);


ALTER TABLE public.async_tasks_entities OWNER TO engine;

--
-- Name: desktop_vms; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW desktop_vms AS
    SELECT vms.vm_name, vms.vm_mem_size_mb, vms.nice_level, vms.vmt_guid, vms.vm_os, vms.vm_description, vms.vds_group_id, vms.vm_domain, vms.vm_creation_date, vms.auto_startup, vms.is_stateless, vms.dedicated_vm_for_vds, vms.fail_back, vms.default_boot_sequence, vms.vm_type, vms.hypervisor_type, vms.operation_mode, vms.vds_group_name, vms.selection_algorithm, vms.transparent_hugepages, vms.storage_pool_id, vms.storage_pool_name, vms.vds_group_description, vms.vmt_name, vms.vmt_mem_size_mb, vms.vmt_os, vms.vmt_creation_date, vms.vmt_child_count, vms.vmt_num_of_sockets, vms.vmt_cpu_per_socket, vms.vmt_num_of_cpus, vms.vmt_description, vms.status, vms.vm_ip, vms.vm_host, vms.vm_pid, vms.last_start_time, vms.guest_cur_user_name, vms.guest_last_login_time, vms.guest_cur_user_id, vms.guest_last_logout_time, vms.guest_os, vms.console_user_id, vms.run_on_vds, vms.migrating_to_vds, vms.app_list, vms.display, vms.hibernation_vol_handle, vms.vm_pool_name, vms.vm_pool_id, vms.vm_guid, vms.num_of_monitors, vms.allow_console_reconnect, vms.is_initialized, vms.is_auto_suspend, vms.num_of_sockets, vms.cpu_per_socket, vms.usb_policy, vms.acpi_enable, vms.session, vms.num_of_cpus, vms.quota_id, vms.quota_name, vms.quota_enforcement_type, vms.display_ip, vms.display_type, vms.kvm_enable, vms.boot_sequence, vms.display_secure_port, vms.utc_diff, vms.last_vds_run_on, vms.client_ip, vms.guest_requested_memory, vms.time_zone, vms.cpu_user, vms.cpu_sys, vms.elapsed_time, vms.usage_network_percent, vms.usage_mem_percent, vms.usage_cpu_percent, vms.run_on_vds_name, vms.vds_group_cpu_name, vms.default_display_type, vms.priority, vms.iso_path, vms.origin, vms.vds_group_compatibility_version, vms.initrd_url, vms.kernel_url, vms.kernel_params, vms.pause_status, vms.exit_message, vms.exit_status, vms.migration_support, vms.predefined_properties, vms.userdefined_properties, vms.min_allocated_mem, vms.hash, vms.cpu_pinning FROM vms WHERE (vms.vm_type = 0);


ALTER TABLE public.desktop_vms OWNER TO engine;

--
-- Name: dwh_history_timekeeping; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE dwh_history_timekeeping (
    var_name character varying(50) NOT NULL,
    var_value character varying(255),
    var_datetime timestamp with time zone
);


ALTER TABLE public.dwh_history_timekeeping OWNER TO engine;

--
-- Name: dwh_add_tags_relations_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_add_tags_relations_history_view AS
    ((((SELECT tags.tag_id AS entity_id, tags.parent_id, (18)::smallint AS entity_type, tags._create_date AS attach_date, tags._update_date AS move_date FROM tags WHERE ((tags._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (tags._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text)))) UNION ALL SELECT tags_vds_map.vds_id AS entity_id, tags_vds_map.tag_id AS parent_id, (3)::smallint AS entity_type, tags_vds_map._create_date AS attach_date, NULL::unknown AS move_date FROM tags_vds_map WHERE (tags_vds_map._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text)))) UNION ALL SELECT tags_vm_pool_map.vm_pool_id AS entity_id, tags_vm_pool_map.tag_id AS parent_id, (5)::smallint AS entity_type, tags_vm_pool_map._create_date AS attach_date, NULL::unknown AS move_date FROM tags_vm_pool_map WHERE (tags_vm_pool_map._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text)))) UNION ALL SELECT tags_vm_map.vm_id AS entity_id, tags_vm_map.tag_id AS parent_id, (2)::smallint AS entity_type, tags_vm_map._create_date AS attach_date, NULL::unknown AS move_date FROM tags_vm_map WHERE (tags_vm_map._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text)))) UNION ALL SELECT tags_user_map.user_id AS entity_id, tags_user_map.tag_id AS parent_id, (15)::smallint AS entity_type, tags_user_map._create_date AS attach_date, NULL::unknown AS move_date FROM tags_user_map WHERE (tags_user_map._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text)))) UNION ALL SELECT tags_user_group_map.group_id AS entity_id, tags_user_group_map.tag_id AS parent_id, (17)::smallint AS entity_type, tags_user_group_map._create_date AS attach_date, NULL::unknown AS move_date FROM tags_user_group_map WHERE (tags_user_group_map._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text)));


ALTER TABLE public.dwh_add_tags_relations_history_view OWNER TO engine;

--
-- Name: dwh_cluster_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_cluster_configuration_history_view AS
    SELECT vds_groups.vds_group_id AS cluster_id, vds_groups.name AS cluster_name, vds_groups.description AS cluster_description, vds_groups.storage_pool_id AS datacenter_id, vds_groups.cpu_name, vds_groups.compatibility_version, vds_groups._create_date AS create_date, vds_groups._update_date AS update_date FROM vds_groups WHERE ((vds_groups._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (vds_groups._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text))));


ALTER TABLE public.dwh_cluster_configuration_history_view OWNER TO engine;

--
-- Name: dwh_datacenter_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_datacenter_configuration_history_view AS
    SELECT storage_pool.id AS datacenter_id, storage_pool.name AS datacenter_name, storage_pool.description AS datacenter_description, (storage_pool.storage_pool_type)::smallint AS storage_type, storage_pool._create_date AS create_date, storage_pool._update_date AS update_date FROM storage_pool WHERE ((storage_pool._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (storage_pool._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text))));


ALTER TABLE public.dwh_datacenter_configuration_history_view OWNER TO engine;

--
-- Name: dwh_datacenter_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_datacenter_history_view AS
    SELECT storage_pool.id AS datacenter_id, (storage_pool.status)::smallint AS datacenter_status FROM storage_pool;


ALTER TABLE public.dwh_datacenter_history_view OWNER TO engine;

--
-- Name: dwh_datacenter_storage_map_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_datacenter_storage_map_history_view AS
    SELECT storage_pool_iso_map.storage_pool_id AS datacenter_id, storage_pool_iso_map.storage_id AS storage_domain_id FROM storage_pool_iso_map;


ALTER TABLE public.dwh_datacenter_storage_map_history_view OWNER TO engine;

--
-- Name: dwh_disk_vm_map_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_disk_vm_map_history_view AS
    SELECT images.image_guid AS vm_disk_id, vm_device.vm_id FROM (vm_device JOIN images ON ((vm_device.device_id = images.image_group_id))) WHERE (images.active = true);


ALTER TABLE public.dwh_disk_vm_map_history_view OWNER TO engine;

--
-- Name: dwh_host_configuration_full_check_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_host_configuration_full_check_view AS
    SELECT a.vds_id AS host_id, a.vds_unique_id AS host_unique_id, a.vds_name AS host_name, a.vds_group_id AS cluster_id, (a.vds_type)::smallint AS host_type, a.host_name AS fqdn_or_ip, b.physical_mem_mb AS memory_size_mb, (c.swap_total)::integer AS swap_size_mb, b.cpu_model, (b.cpu_cores)::smallint AS number_of_cores, (b.cpu_sockets)::smallint AS number_of_sockets, b.cpu_speed_mh, b.host_os, a.ip AS pm_ip_address, b.kernel_version, b.kvm_version, CASE substr((b.software_version)::text, 1, 3) WHEN '4.4'::text THEN (('2.1'::text || substr((b.software_version)::text, 4, length((b.software_version)::text))))::character varying WHEN '4.5'::text THEN (('2.2'::text || substr((b.software_version)::text, 4, length((b.software_version)::text))))::character varying WHEN '4.9'::text THEN (('2.3'::text || substr((b.software_version)::text, 4, length((b.software_version)::text))))::character varying ELSE b.software_version END AS vdsm_version, a.port AS vdsm_port, a._create_date AS create_date, a._update_date AS update_date FROM ((vds_static a JOIN vds_dynamic b ON ((a.vds_id = b.vds_id))) JOIN vds_statistics c ON ((c.vds_id = a.vds_id)));


ALTER TABLE public.dwh_host_configuration_full_check_view OWNER TO engine;

--
-- Name: dwh_host_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_host_configuration_history_view AS
    SELECT a.vds_id AS host_id, a.vds_unique_id AS host_unique_id, a.vds_name AS host_name, a.vds_group_id AS cluster_id, (a.vds_type)::smallint AS host_type, a.host_name AS fqdn_or_ip, b.physical_mem_mb AS memory_size_mb, (c.swap_total)::integer AS swap_size_mb, b.cpu_model, (b.cpu_cores)::smallint AS number_of_cores, (b.cpu_sockets)::smallint AS number_of_sockets, b.cpu_speed_mh, b.host_os, a.ip AS pm_ip_address, b.kernel_version, b.kvm_version, b.software_version AS vdsm_version, a.port AS vdsm_port, a._create_date AS create_date, a._update_date AS update_date FROM ((vds_static a JOIN vds_dynamic b ON ((a.vds_id = b.vds_id))) JOIN vds_statistics c ON ((c.vds_id = a.vds_id))) WHERE ((a._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (a._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text))));


ALTER TABLE public.dwh_host_configuration_history_view OWNER TO engine;

--
-- Name: dwh_host_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_host_history_view AS
    SELECT b.vds_id AS host_id, (b.status)::smallint AS host_status, (c.usage_mem_percent)::smallint AS memory_usage_percent, (c.usage_cpu_percent)::smallint AS cpu_usage_percent, (c.ksm_cpu_percent)::smallint AS ksm_cpu_percent, (c.cpu_load)::integer AS cpu_load, (c.cpu_sys)::smallint AS system_cpu_usage_percent, (c.cpu_user)::smallint AS user_cpu_usage_percent, ((c.swap_total - c.swap_free))::integer AS swap_used_mb, (b.vm_active)::smallint AS vm_active, (b.vm_count)::smallint AS total_vms, b.vms_cores_count AS total_vms_vcpus FROM vds_dynamic b, vds_statistics c WHERE (b.vds_id = c.vds_id);


ALTER TABLE public.dwh_host_history_view OWNER TO engine;

--
-- Name: dwh_host_interface_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_host_interface_configuration_history_view AS
    SELECT a.id AS host_interface_id, a.name AS host_interface_name, a.vds_id AS host_id, (a.type)::smallint AS host_interface_type, a.speed AS host_interface_speed_bps, a.mac_addr AS mac_address, a.network_name, a.addr AS ip_address, a.gateway, a.is_bond AS bond, a.bond_name, a.vlan_id, a._create_date AS create_date, a._update_date AS update_date FROM vds_interface a WHERE (((a._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (a._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text)))) AND ((a.is_bond IS NULL) OR ((a.is_bond = true) AND ((a.name)::text IN (SELECT b.bond_name FROM vds_interface b WHERE ((b.is_bond IS NULL) AND (b.vds_id = a.vds_id)))))));


ALTER TABLE public.dwh_host_interface_configuration_history_view OWNER TO engine;

--
-- Name: dwh_host_interface_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_host_interface_history_view AS
    SELECT vds_interface_statistics.id AS host_interface_id, (vds_interface_statistics.rx_rate)::smallint AS receive_rate_percent, (vds_interface_statistics.tx_rate)::smallint AS transmit_rate_percent FROM vds_interface_statistics;


ALTER TABLE public.dwh_host_interface_history_view OWNER TO engine;

--
-- Name: dwh_remove_tags_relations_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_remove_tags_relations_history_view AS
    ((((SELECT tags.tag_id AS entity_id, tags.parent_id FROM tags UNION ALL SELECT tags_vds_map.vds_id AS entity_id, tags_vds_map.tag_id AS parent_id FROM tags_vds_map) UNION ALL SELECT tags_vm_pool_map.vm_pool_id AS entity_id, tags_vm_pool_map.tag_id AS parent_id FROM tags_vm_pool_map) UNION ALL SELECT tags_vm_map.vm_id AS entity_id, tags_vm_map.tag_id AS parent_id FROM tags_vm_map) UNION ALL SELECT tags_user_map.user_id AS entity_id, tags_user_map.tag_id AS parent_id FROM tags_user_map) UNION ALL SELECT tags_user_group_map.group_id AS entity_id, tags_user_group_map.tag_id AS parent_id FROM tags_user_group_map;


ALTER TABLE public.dwh_remove_tags_relations_history_view OWNER TO engine;

--
-- Name: dwh_storage_domain_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_storage_domain_configuration_history_view AS
    SELECT storage_domain_static.id AS storage_domain_id, storage_domain_static.storage_name AS storage_domain_name, (storage_domain_static.storage_domain_type)::smallint AS storage_domain_type, (storage_domain_static.storage_type)::smallint AS storage_type, storage_domain_static._create_date AS create_date, storage_domain_static._update_date AS update_date FROM storage_domain_static WHERE ((storage_domain_static._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (storage_domain_static._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text))));


ALTER TABLE public.dwh_storage_domain_configuration_history_view OWNER TO engine;

--
-- Name: dwh_storage_domain_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_storage_domain_history_view AS
    SELECT storage_domain_dynamic.id AS storage_domain_id, storage_domain_dynamic.available_disk_size AS available_disk_size_gb, storage_domain_dynamic.used_disk_size AS used_disk_size_gb FROM storage_domain_dynamic;


ALTER TABLE public.dwh_storage_domain_history_view OWNER TO engine;

--
-- Name: dwh_tags_details_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_tags_details_history_view AS
    SELECT tags.tag_id, tags.tag_name, tags.description AS tag_description, tags._create_date AS create_date, tags._update_date AS update_date FROM tags WHERE ((tags._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (tags._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text))));


ALTER TABLE public.dwh_tags_details_history_view OWNER TO engine;

--
-- Name: dwh_vm_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_vm_configuration_history_view AS
    SELECT a.vm_guid AS vm_id, a.vm_name, a.description AS vm_description, (a.vm_type)::smallint AS vm_type, a.vds_group_id AS cluster_id, a.vmt_guid AS template_id, b.vm_name AS template_name, (a.cpu_per_socket)::smallint AS cpu_per_socket, (a.num_of_sockets)::smallint AS number_of_sockets, a.mem_size_mb AS memory_size_mb, (a.os)::smallint AS operating_system, a.domain AS ad_domain, a.dedicated_vm_for_vds AS default_host, a.auto_startup AS high_availability, a.is_initialized AS initialized, a.is_stateless AS stateless, a.fail_back, a.is_auto_suspend AS auto_suspend, (a.usb_policy)::smallint AS usb_policy, a.time_zone, a._create_date AS create_date, a._update_date AS update_date FROM (vm_static a JOIN vm_static b ON ((a.vmt_guid = b.vm_guid))) WHERE ((((a.entity_type)::text = 'VM'::text) AND ((b.entity_type)::text = 'TEMPLATE'::text)) AND (((a._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (a._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text)))) OR (b._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text)))));


ALTER TABLE public.dwh_vm_configuration_history_view OWNER TO engine;

--
-- Name: dwh_vm_device_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_vm_device_history_view AS
    SELECT vm_device.device_id, vm_device.vm_id, vm_device.type, vm_device.address, vm_device.is_managed, vm_device.is_plugged, vm_device.is_readonly, vm_device._create_date AS create_date, vm_device._update_date AS update_date FROM vm_device WHERE (((((vm_device.type)::text = 'disk'::text) AND ((vm_device.device)::text = 'disk'::text)) OR ((vm_device.type)::text = 'interface'::text)) AND ((vm_device._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (vm_device._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text)))));


ALTER TABLE public.dwh_vm_device_history_view OWNER TO engine;

--
-- Name: dwh_vm_disk_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_vm_disk_configuration_history_view AS
    SELECT d.disk_id AS vm_disk_id, d.disk_alias AS vm_disk_name, d.disk_description AS vm_disk_description, i.image_guid AS image_id, image_storage_domain_map.storage_domain_id, ((i.size / 1048576))::integer AS vm_disk_size_mb, (i.volume_type)::smallint AS vm_disk_type, (i.volume_format)::smallint AS vm_disk_format, CASE WHEN ((d.disk_interface)::text = 'IDE'::text) THEN (0)::smallint WHEN ((d.disk_interface)::text = 'SCSI'::text) THEN (1)::smallint WHEN ((d.disk_interface)::text = 'VirtIO'::text) THEN (2)::smallint ELSE NULL::smallint END AS vm_disk_interface, d.shareable AS is_shared, i._create_date AS create_date, i._update_date AS update_date FROM ((((images i JOIN base_disks d ON ((i.image_group_id = d.disk_id))) JOIN image_storage_domain_map ON ((image_storage_domain_map.image_id = i.image_guid))) LEFT JOIN vm_device ON ((vm_device.device_id = i.image_group_id))) LEFT JOIN vm_static ON ((vm_static.vm_guid = vm_device.vm_id))) WHERE (((i.active = true) AND (((vm_static.entity_type)::text = 'VM'::text) OR (vm_static.entity_type IS NULL))) AND ((i._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (i._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text)))));


ALTER TABLE public.dwh_vm_disk_configuration_history_view OWNER TO engine;

--
-- Name: dwh_vm_disks_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_vm_disks_history_view AS
    SELECT d.disk_id AS vm_disk_id, images.image_guid AS image_id, (images.imagestatus)::smallint AS vm_disk_status, ((disk_image_dynamic.actual_size / 1048576))::integer AS vm_disk_actual_size_mb, disk_image_dynamic.read_rate AS read_rate_bytes_per_second, disk_image_dynamic.read_latency_seconds, disk_image_dynamic.write_rate AS write_rate_bytes_per_second, disk_image_dynamic.write_latency_seconds, disk_image_dynamic.flush_latency_seconds FROM ((((images JOIN disk_image_dynamic ON ((images.image_guid = disk_image_dynamic.image_id))) JOIN base_disks d ON ((images.image_group_id = d.disk_id))) LEFT JOIN vm_device ON ((vm_device.device_id = images.image_group_id))) LEFT JOIN vm_static ON ((vm_static.vm_guid = vm_device.vm_id))) WHERE ((images.active = true) AND (((vm_static.entity_type)::text = 'VM'::text) OR (vm_static.entity_type IS NULL)));


ALTER TABLE public.dwh_vm_disks_history_view OWNER TO engine;

--
-- Name: dwh_vm_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_vm_history_view AS
    SELECT c.vm_guid AS vm_id, (b.status)::smallint AS vm_status, (c.usage_cpu_percent)::smallint AS cpu_usage_percent, (c.usage_mem_percent)::smallint AS memory_usage_percent, (c.cpu_sys)::smallint AS system_cpu_usage_percent, (c.cpu_user)::smallint AS user_cpu_usage_percent, c.disks_usage, b.last_start_time, b.vm_ip, b.guest_cur_user_name AS current_user_name, b.run_on_vds AS currently_running_on_host FROM vm_dynamic b, vm_statistics c WHERE (c.vm_guid = b.vm_guid);


ALTER TABLE public.dwh_vm_history_view OWNER TO engine;

--
-- Name: dwh_vm_interface_configuration_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_vm_interface_configuration_history_view AS
    SELECT vm_interface.id AS vm_interface_id, vm_interface.name AS vm_interface_name, vm_interface.vm_guid AS vm_id, (vm_interface.type)::smallint AS vm_interface_type, vm_interface.speed AS vm_interface_speed_bps, vm_interface.mac_addr AS mac_address, vm_interface.network_name, vm_interface._create_date AS create_date, vm_interface._update_date AS update_date FROM vm_interface WHERE ((vm_interface.vmt_guid IS NULL) AND ((vm_interface._create_date > (SELECT dwh_history_timekeeping.var_datetime FROM dwh_history_timekeeping WHERE ((dwh_history_timekeeping.var_name)::text = 'lastSync'::text))) OR (vm_interface._update_date > (SELECT history_timekeeping_1.var_datetime FROM dwh_history_timekeeping history_timekeeping_1 WHERE ((history_timekeeping_1.var_name)::text = 'lastSync'::text)))));


ALTER TABLE public.dwh_vm_interface_configuration_history_view OWNER TO engine;

--
-- Name: dwh_vm_interface_history_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW dwh_vm_interface_history_view AS
    SELECT vm_interface_statistics.id AS vm_interface_id, (vm_interface_statistics.rx_rate)::smallint AS receive_rate_percent, (vm_interface_statistics.tx_rate)::smallint AS transmit_rate_percent FROM vm_interface_statistics;


ALTER TABLE public.dwh_vm_interface_history_view OWNER TO engine;

--
-- Name: object_column_white_list; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE object_column_white_list (
    object_name character varying(128) NOT NULL,
    column_name character varying(128) NOT NULL
);


ALTER TABLE public.object_column_white_list OWNER TO engine;

--
-- Name: object_column_white_list_sql; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE object_column_white_list_sql (
    object_name character varying(128) NOT NULL,
    sql text NOT NULL
);


ALTER TABLE public.object_column_white_list_sql OWNER TO engine;

--
-- Name: quota_limitations_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW quota_limitations_view AS
    SELECT q_limit.quota_id, q.storage_pool_id, storage_pool.name AS storage_pool_name, q.quota_name, q.description, q.threshold_vds_group_percentage, q.threshold_storage_percentage, q.grace_vds_group_percentage, q.grace_storage_percentage, q_limit.virtual_cpu, q_limit.mem_size_mb, q_limit.storage_size_gb, storage_pool.quota_enforcement_type, q_limit.vds_group_id, q_limit.storage_id, (COALESCE(q_limit.vds_group_id, q_limit.storage_id) IS NULL) AS is_global, (COALESCE((q_limit.virtual_cpu)::bigint, q_limit.mem_size_mb, q_limit.storage_size_gb) IS NULL) AS is_empty FROM ((quota q JOIN storage_pool ON ((storage_pool.id = q.storage_pool_id))) LEFT JOIN quota_limitation q_limit ON ((q_limit.quota_id = q.id)));


ALTER TABLE public.quota_limitations_view OWNER TO engine;

--
-- Name: schema_version_seq; Type: SEQUENCE; Schema: public; Owner: engine
--

CREATE SEQUENCE schema_version_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.schema_version_seq OWNER TO engine;

--
-- Name: schema_version_seq; Type: SEQUENCE SET; Schema: public; Owner: engine
--

SELECT pg_catalog.setval('schema_version_seq', 144, true);


SET default_with_oids = false;

--
-- Name: schema_version; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE schema_version (
    id integer DEFAULT nextval('schema_version_seq'::regclass) NOT NULL,
    version character varying(10) NOT NULL,
    script character varying(255) NOT NULL,
    checksum character varying(128),
    installed_by character varying(30) NOT NULL,
    started_at timestamp without time zone DEFAULT now(),
    ended_at timestamp without time zone,
    state character varying(15) NOT NULL,
    current boolean NOT NULL,
    comment text DEFAULT ''::text
);


ALTER TABLE public.schema_version OWNER TO engine;

--
-- Name: server_vms; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW server_vms AS
    SELECT vms.vm_name, vms.vm_mem_size_mb, vms.nice_level, vms.vmt_guid, vms.vm_os, vms.vm_description, vms.vds_group_id, vms.vm_domain, vms.vm_creation_date, vms.auto_startup, vms.is_stateless, vms.dedicated_vm_for_vds, vms.fail_back, vms.default_boot_sequence, vms.vm_type, vms.hypervisor_type, vms.operation_mode, vms.vds_group_name, vms.selection_algorithm, vms.transparent_hugepages, vms.storage_pool_id, vms.storage_pool_name, vms.vds_group_description, vms.vmt_name, vms.vmt_mem_size_mb, vms.vmt_os, vms.vmt_creation_date, vms.vmt_child_count, vms.vmt_num_of_sockets, vms.vmt_cpu_per_socket, vms.vmt_num_of_cpus, vms.vmt_description, vms.status, vms.vm_ip, vms.vm_host, vms.vm_pid, vms.last_start_time, vms.guest_cur_user_name, vms.guest_last_login_time, vms.guest_cur_user_id, vms.guest_last_logout_time, vms.guest_os, vms.console_user_id, vms.run_on_vds, vms.migrating_to_vds, vms.app_list, vms.display, vms.hibernation_vol_handle, vms.vm_pool_name, vms.vm_pool_id, vms.vm_guid, vms.num_of_monitors, vms.allow_console_reconnect, vms.is_initialized, vms.is_auto_suspend, vms.num_of_sockets, vms.cpu_per_socket, vms.usb_policy, vms.acpi_enable, vms.session, vms.num_of_cpus, vms.quota_id, vms.quota_name, vms.quota_enforcement_type, vms.display_ip, vms.display_type, vms.kvm_enable, vms.boot_sequence, vms.display_secure_port, vms.utc_diff, vms.last_vds_run_on, vms.client_ip, vms.guest_requested_memory, vms.time_zone, vms.cpu_user, vms.cpu_sys, vms.elapsed_time, vms.usage_network_percent, vms.usage_mem_percent, vms.usage_cpu_percent, vms.run_on_vds_name, vms.vds_group_cpu_name, vms.default_display_type, vms.priority, vms.iso_path, vms.origin, vms.vds_group_compatibility_version, vms.initrd_url, vms.kernel_url, vms.kernel_params, vms.pause_status, vms.exit_message, vms.exit_status, vms.migration_support, vms.predefined_properties, vms.userdefined_properties, vms.min_allocated_mem, vms.hash, vms.cpu_pinning FROM vms WHERE (vms.vm_type = 1);


ALTER TABLE public.server_vms OWNER TO engine;

--
-- Name: storage_domains_for_search; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW storage_domains_for_search AS
    SELECT storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_name, storage_domain_static.storage_type, storage_domain_static.storage_domain_type, storage_domain_static.storage_domain_format_type, storage_domain_static.last_time_used_as_master, CASE WHEN status_table.is_multi_domain THEN NULL::integer WHEN (status_table.status IS NULL) THEN 2 ELSE status_table.status END AS status, NULL::unknown AS owner, NULL::unknown AS storage_pool_id, NULL::unknown AS storage_pool_name, storage_domain_dynamic.available_disk_size, storage_domain_dynamic.used_disk_size, fn_get_disk_commited_value_by_storage(storage_domain_static.id) AS commited_disk_size, fn_get_storage_domain_shared_status_by_domain_id(storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_type) AS storage_domain_shared_status, storage_domain_static.recoverable FROM ((storage_domain_static JOIN storage_domain_dynamic ON ((storage_domain_static.id = storage_domain_dynamic.id))) LEFT JOIN (SELECT storage_pool_iso_map.storage_id, (count(storage_pool_iso_map.storage_id) > 1) AS is_multi_domain, max(storage_pool_iso_map.status) AS status FROM storage_pool_iso_map GROUP BY storage_pool_iso_map.storage_id) status_table ON ((storage_domain_static.id = status_table.storage_id)));


ALTER TABLE public.storage_domains_for_search OWNER TO engine;

--
-- Name: storage_domains_with_hosts_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW storage_domains_with_hosts_view AS
    SELECT storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_name, storage_domain_dynamic.available_disk_size, storage_domain_dynamic.used_disk_size, fn_get_disk_commited_value_by_storage(storage_domain_static.id) AS commited_disk_size, storage_pool.name AS storage_pool_name, storage_domain_static.storage_type, storage_domain_static.storage_domain_type, storage_domain_static.storage_domain_format_type, storage_domain_static.last_time_used_as_master, fn_get_storage_domain_shared_status_by_domain_id(storage_domain_static.id, storage_domain_static.storage, storage_domain_static.storage_type) AS storage_domain_shared_status, vds_groups.vds_group_id, vds_static.vds_id, storage_pool_iso_map.storage_pool_id, vds_static.recoverable FROM (((((storage_domain_static JOIN storage_domain_dynamic ON ((storage_domain_static.id = storage_domain_dynamic.id))) LEFT JOIN storage_pool_iso_map ON ((storage_domain_static.id = storage_pool_iso_map.storage_id))) LEFT JOIN storage_pool ON ((storage_pool_iso_map.storage_pool_id = storage_pool.id))) LEFT JOIN vds_groups ON ((storage_pool_iso_map.storage_pool_id = vds_groups.storage_pool_id))) LEFT JOIN vds_static ON ((vds_groups.vds_group_id = vds_static.vds_group_id)));


ALTER TABLE public.storage_domains_with_hosts_view OWNER TO engine;

--
-- Name: storage_pool_with_storage_domain; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW storage_pool_with_storage_domain AS
    SELECT storage_pool.id, storage_pool.name, storage_pool.description, storage_pool.storage_pool_type, storage_pool.status, storage_pool.master_domain_version, storage_pool.spm_vds_id, storage_pool.compatibility_version, storage_pool._create_date, storage_pool._update_date, storage_pool_iso_map.storage_id, storage_pool_iso_map.storage_pool_id, storage_pool_iso_map.owner, storage_domain_static.storage_type, storage_domain_static.storage_domain_type, storage_domain_static.storage_domain_format_type, storage_domain_static.storage_name, storage_domain_static.storage, storage_domain_static.last_time_used_as_master FROM ((storage_pool LEFT JOIN storage_pool_iso_map ON ((storage_pool.id = storage_pool_iso_map.storage_pool_id))) LEFT JOIN storage_domain_static ON ((storage_pool_iso_map.storage_id = storage_domain_static.id)));


ALTER TABLE public.storage_pool_with_storage_domain OWNER TO engine;

--
-- Name: user_flat_groups; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_flat_groups AS
    (SELECT users.user_id, ad_groups.id AS granted_id FROM ad_groups, users WHERE (ad_groups.id IN (SELECT fnsplitteruuid.id FROM fnsplitteruuid(users.group_ids) fnsplitteruuid(id))) UNION ALL SELECT users.user_id, users.user_id AS granted_id FROM users) UNION ALL SELECT users.user_id, 'EEE00000-0000-0000-0000-123456789EEE' AS granted_id FROM users;


ALTER TABLE public.user_flat_groups OWNER TO engine;

--
-- Name: user_vm_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vm_permissions_view_base AS
    ((SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 2) AND (permissions_view.role_type = 2)) UNION ALL SELECT vm_static.vm_guid AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vm_static JOIN permissions_view ON (((((permissions_view.object_id = vm_static.vds_group_id) AND (permissions_view.object_type_id = 9)) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_static.vm_guid AS entity_id, permissions_view.ad_element_id AS granted_id FROM ((vm_static JOIN vds_groups ON ((vds_groups.vds_group_id = vm_static.vds_group_id))) JOIN permissions_view ON (((((permissions_view.object_id = vds_groups.storage_pool_id) AND (permissions_view.object_type_id = 14)) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_static.vm_guid AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN vm_static) WHERE (((permissions_view.object_type_id = 1) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2));


ALTER TABLE public.user_vm_permissions_view_base OWNER TO engine;

--
-- Name: user_vm_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vm_permissions_view AS
    SELECT DISTINCT user_vm_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_vm_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_vm_permissions_view OWNER TO engine;

--
-- Name: user_vm_template_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vm_template_permissions_view_base AS
    ((SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 4) AND (permissions_view.role_type = 2)) UNION ALL SELECT vm_static.vmt_guid AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vm_static JOIN permissions_view ON ((((permissions_view.object_id = vm_static.vm_guid) AND (permissions_view.object_type_id = 2)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_static.vmt_guid AS entity_id, permissions_view.ad_element_id AS granted_id FROM ((vm_static JOIN vds_groups ON ((vds_groups.vds_group_id = vm_static.vds_group_id))) JOIN permissions_view ON (((((permissions_view.object_id = vds_groups.storage_pool_id) AND (permissions_view.object_type_id = 14)) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_static.vm_guid AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN vm_static) WHERE ((((permissions_view.object_type_id = 1) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2)) AND ((vm_static.entity_type)::text = 'TEMPLATE'::text));


ALTER TABLE public.user_vm_template_permissions_view_base OWNER TO engine;

--
-- Name: user_vm_template_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vm_template_permissions_view AS
    SELECT DISTINCT user_vm_template_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_vm_template_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_vm_template_permissions_view OWNER TO engine;

--
-- Name: user_disk_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_disk_permissions_view_base AS
    ((((SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 19) AND (permissions_view.role_type = 2)) UNION ALL SELECT vm_device.device_id AS entity_id, user_vm_permissions_view.user_id AS granted_id FROM (vm_device JOIN user_vm_permissions_view ON ((user_vm_permissions_view.entity_id = vm_device.vm_id))) WHERE (((vm_device.type)::text = 'disk'::text) AND ((vm_device.device)::text = 'disk'::text))) UNION ALL SELECT vm_device.device_id AS entity_id, user_vm_template_permissions_view.user_id AS granted_id FROM (vm_device JOIN user_vm_template_permissions_view ON ((user_vm_template_permissions_view.entity_id = vm_device.vm_id))) WHERE (((vm_device.type)::text = 'disk'::text) AND ((vm_device.device)::text = 'disk'::text))) UNION ALL SELECT images.image_group_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM ((image_storage_domain_map JOIN images ON ((images.image_guid = image_storage_domain_map.image_id))) JOIN permissions_view ON (((((permissions_view.object_id = image_storage_domain_map.storage_domain_id) AND (permissions_view.object_type_id = 11)) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2))))) UNION ALL SELECT images.image_group_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (((image_storage_domain_map JOIN storage_pool_iso_map ON ((image_storage_domain_map.storage_domain_id = storage_pool_iso_map.storage_id))) JOIN images ON ((images.image_guid = image_storage_domain_map.image_id))) JOIN permissions_view ON (((((permissions_view.object_id = storage_pool_iso_map.storage_pool_id) AND (permissions_view.object_type_id = 14)) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_device.device_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN vm_device) WHERE (((permissions_view.object_type_id = 1) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2));


ALTER TABLE public.user_disk_permissions_view_base OWNER TO engine;

--
-- Name: user_disk_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_disk_permissions_view AS
    SELECT DISTINCT user_disk_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_disk_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_disk_permissions_view OWNER TO engine;

--
-- Name: user_permissions_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_permissions_permissions_view AS
    SELECT DISTINCT permissions_view.id AS entity_id, user_flat_groups.user_id FROM (permissions_view JOIN user_flat_groups ON ((user_flat_groups.granted_id = permissions_view.ad_element_id)));


ALTER TABLE public.user_permissions_permissions_view OWNER TO engine;

--
-- Name: vm_templates_storage_domain; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_templates_storage_domain AS
    SELECT vm_templates.vm_guid AS vmt_guid, vm_templates.vm_name AS name, vm_templates.mem_size_mb, vm_templates.os, vm_templates.creation_date, vm_templates.child_count, vm_templates.num_of_sockets, vm_templates.cpu_per_socket, (vm_templates.num_of_sockets * vm_templates.cpu_per_socket) AS num_of_cpus, vm_templates.description, vm_templates.vds_group_id, vm_templates.domain, vm_templates.num_of_monitors, vm_templates.allow_console_reconnect, vm_templates.template_status AS status, vm_templates.usb_policy, vm_templates.time_zone, vm_templates.is_auto_suspend, vm_templates.fail_back, vds_groups.name AS vds_group_name, vm_templates.vm_type, vm_templates.hypervisor_type, vm_templates.operation_mode, vm_templates.nice_level, storage_pool.id AS storage_pool_id, storage_pool.name AS storage_pool_name, vm_templates.default_boot_sequence, vm_templates.default_display_type, vm_templates.priority, vm_templates.auto_startup, vm_templates.is_stateless, vm_templates.iso_path, vm_templates.origin, vm_templates.initrd_url, vm_templates.kernel_url, vm_templates.kernel_params, image_storage_domain_map.storage_domain_id AS storage_id, quota.quota_name FROM ((((((vm_static vm_templates JOIN vds_groups ON ((vm_templates.vds_group_id = vds_groups.vds_group_id))) LEFT JOIN storage_pool ON ((storage_pool.id = vds_groups.storage_pool_id))) JOIN vm_device ON ((vm_device.vm_id = vm_templates.vm_guid))) LEFT JOIN images ON ((images.image_group_id = vm_device.device_id))) LEFT JOIN image_storage_domain_map ON ((image_storage_domain_map.image_id = images.image_guid))) LEFT JOIN quota quota ON ((quota.id = vm_templates.quota_id))) WHERE ((vm_templates.entity_type)::text = 'TEMPLATE'::text) UNION SELECT vm_templates_1.vm_guid AS vmt_guid, vm_templates_1.vm_name AS name, vm_templates_1.mem_size_mb, vm_templates_1.os, vm_templates_1.creation_date, vm_templates_1.child_count, vm_templates_1.num_of_sockets, vm_templates_1.cpu_per_socket, (vm_templates_1.num_of_sockets * vm_templates_1.cpu_per_socket) AS num_of_cpus, vm_templates_1.description, vm_templates_1.vds_group_id, vm_templates_1.domain, vm_templates_1.num_of_monitors, vm_templates_1.allow_console_reconnect, vm_templates_1.template_status AS status, vm_templates_1.usb_policy, vm_templates_1.time_zone, vm_templates_1.is_auto_suspend, vm_templates_1.fail_back, vds_groups_1.name AS vds_group_name, vm_templates_1.vm_type, vm_templates_1.hypervisor_type, vm_templates_1.operation_mode, vm_templates_1.nice_level, storage_pool_1.id AS storage_pool_id, storage_pool_1.name AS storage_pool_name, vm_templates_1.default_boot_sequence, vm_templates_1.default_display_type, vm_templates_1.priority, vm_templates_1.auto_startup, vm_templates_1.is_stateless, vm_templates_1.iso_path, vm_templates_1.origin, vm_templates_1.initrd_url, vm_templates_1.kernel_url, vm_templates_1.kernel_params, image_storage_domain_map.storage_domain_id AS storage_id, quota.quota_name FROM ((((((vm_static vm_templates_1 JOIN vds_groups vds_groups_1 ON ((vm_templates_1.vds_group_id = vds_groups_1.vds_group_id))) LEFT JOIN storage_pool storage_pool_1 ON ((storage_pool_1.id = vds_groups_1.storage_pool_id))) JOIN vm_device vm_device_1 ON ((vm_device_1.vm_id = vm_templates_1.vm_guid))) JOIN images images_1 ON ((images_1.image_group_id = vm_device_1.device_id))) JOIN image_storage_domain_map ON ((image_storage_domain_map.image_id = images_1.image_guid))) LEFT JOIN quota quota ON ((quota.id = vm_templates_1.quota_id))) WHERE ((vm_templates_1.entity_type)::text = 'TEMPLATE'::text);


ALTER TABLE public.vm_templates_storage_domain OWNER TO engine;

--
-- Name: user_storage_domain_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_storage_domain_permissions_view_base AS
    ((((SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 11) AND (permissions_view.role_type = 2)) UNION ALL SELECT storage_domains.id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (((storage_domains JOIN vds_groups ON ((vds_groups.storage_pool_id = storage_domains.storage_pool_id))) JOIN vm_static ON ((vds_groups.vds_group_id = vm_static.vds_group_id))) JOIN permissions_view ON ((((permissions_view.object_id = vm_static.vm_guid) AND (permissions_view.object_type_id = 2)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_templates_storage_domain.storage_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vm_templates_storage_domain JOIN permissions_view ON ((((vm_templates_storage_domain.vmt_guid = permissions_view.object_id) AND (permissions_view.object_type_id = 4)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_templates_storage_domain.storage_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM ((vm_static JOIN vm_templates_storage_domain ON ((vm_static.vmt_guid = vm_templates_storage_domain.vmt_guid))) JOIN permissions_view ON ((((vm_static.vm_guid = permissions_view.object_id) AND (permissions_view.object_type_id = 2)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT storage_domains.id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (storage_domains JOIN permissions_view ON ((((permissions_view.object_id = storage_domains.storage_pool_id) AND (permissions_view.object_type_id = 14)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT storage_domains.id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN storage_domains) WHERE ((permissions_view.object_type_id = 1) AND (permissions_view.role_type = 2));


ALTER TABLE public.user_storage_domain_permissions_view_base OWNER TO engine;

--
-- Name: user_storage_domain_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_storage_domain_permissions_view AS
    SELECT DISTINCT user_storage_domain_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_storage_domain_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_storage_domain_permissions_view OWNER TO engine;

--
-- Name: user_storage_pool_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_storage_pool_permissions_view_base AS
    (((SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 14) AND (permissions_view.role_type = 2)) UNION ALL SELECT vds_groups.storage_pool_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vds_groups JOIN permissions_view ON ((((permissions_view.object_id = vds_groups.vds_group_id) AND (permissions_view.object_type_id = 9)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vds_groups.storage_pool_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM ((vds_groups JOIN vm_pools ON ((vds_groups.vds_group_id = vm_pools.vds_group_id))) JOIN permissions_view ON ((((permissions_view.object_id = vm_pools.vm_pool_id) AND (permissions_view.object_type_id = 5)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vds_groups.storage_pool_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM ((vm_static JOIN vds_groups ON ((vds_groups.vds_group_id = vm_static.vds_group_id))) JOIN permissions_view ON ((((permissions_view.object_id = vm_static.vm_guid) AND (permissions_view.object_type_id = 2)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT storage_pool.id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN storage_pool) WHERE ((permissions_view.object_type_id = 1) AND (permissions_view.role_type = 2));


ALTER TABLE public.user_storage_pool_permissions_view_base OWNER TO engine;

--
-- Name: user_storage_pool_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_storage_pool_permissions_view AS
    SELECT DISTINCT user_storage_pool_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_storage_pool_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_storage_pool_permissions_view OWNER TO engine;

--
-- Name: user_vds_groups_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vds_groups_permissions_view_base AS
    ((SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 9) AND (permissions_view.role_type = 2)) UNION ALL SELECT vm_static.vds_group_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vm_static JOIN permissions_view ON ((((permissions_view.object_id = vm_static.vm_guid) AND (permissions_view.object_type_id = 2)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vds_groups.vds_group_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vds_groups JOIN permissions_view ON ((((permissions_view.object_id = vds_groups.storage_pool_id) AND (permissions_view.object_type_id = 14)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vds_groups.vds_group_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN vds_groups) WHERE ((permissions_view.object_type_id = 1) AND (permissions_view.role_type = 2));


ALTER TABLE public.user_vds_groups_permissions_view_base OWNER TO engine;

--
-- Name: user_vds_groups_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vds_groups_permissions_view AS
    SELECT DISTINCT user_vds_groups_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_vds_groups_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_vds_groups_permissions_view OWNER TO engine;

--
-- Name: user_vds_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vds_permissions_view_base AS
    (SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 3) AND (permissions_view.role_type = 2)) UNION ALL SELECT vds.vds_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vds JOIN permissions_view ON ((((permissions_view.object_id = vds.vds_group_id) AND (permissions_view.object_type_id = 9)) OR (((permissions_view.object_id = vds.storage_pool_id) AND (permissions_view.object_type_id = 14)) AND (permissions_view.role_type = 2)))))) UNION ALL SELECT vds.vds_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN vds) WHERE ((permissions_view.object_type_id = 1) AND (permissions_view.role_type = 2));


ALTER TABLE public.user_vds_permissions_view_base OWNER TO engine;

--
-- Name: user_vds_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vds_permissions_view AS
    SELECT DISTINCT user_vds_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_vds_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_vds_permissions_view OWNER TO engine;

--
-- Name: user_vm_pool_permissions_view_base; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vm_pool_permissions_view_base AS
    (((SELECT permissions_view.object_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM permissions_view WHERE ((permissions_view.object_type_id = 5) AND (permissions_view.role_type = 2)) UNION ALL SELECT vm_pool_map.vm_pool_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vm_pool_map JOIN permissions_view ON ((((permissions_view.object_id = vm_pool_map.vm_guid) AND (permissions_view.object_type_id = 2)) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_pools.vm_pool_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (vm_pools JOIN permissions_view ON (((((permissions_view.object_id = vm_pools.vds_group_id) AND (permissions_view.object_type_id = 9)) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_pools.vm_pool_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM ((vm_pools JOIN vds_groups ON ((vm_pools.vds_group_id = vds_groups.vds_group_id))) JOIN permissions_view ON (((((permissions_view.object_id = vds_groups.storage_pool_id) AND (permissions_view.object_type_id = 14)) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2))))) UNION ALL SELECT vm_pools.vm_pool_id AS entity_id, permissions_view.ad_element_id AS granted_id FROM (permissions_view CROSS JOIN vm_pools) WHERE (((permissions_view.object_type_id = 1) AND permissions_view.allows_viewing_children) AND (permissions_view.role_type = 2));


ALTER TABLE public.user_vm_pool_permissions_view_base OWNER TO engine;

--
-- Name: user_vm_pool_permissions_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW user_vm_pool_permissions_view AS
    SELECT DISTINCT user_vm_pool_permissions_view_base.entity_id, user_flat_groups.user_id FROM (user_vm_pool_permissions_view_base NATURAL JOIN user_flat_groups);


ALTER TABLE public.user_vm_pool_permissions_view OWNER TO engine;

--
-- Name: users_and_groups_to_vm_pool_map_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW users_and_groups_to_vm_pool_map_view AS
    SELECT p.vm_pool_id, p.vm_pool_name, per.ad_element_id AS user_id FROM (vm_pools p JOIN permissions per ON ((per.object_id = p.vm_pool_id)));


ALTER TABLE public.users_and_groups_to_vm_pool_map_view OWNER TO engine;

--
-- Name: vdc_db_log_seq; Type: SEQUENCE; Schema: public; Owner: engine
--

CREATE SEQUENCE vdc_db_log_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.vdc_db_log_seq OWNER TO engine;

--
-- Name: vdc_db_log_seq; Type: SEQUENCE SET; Schema: public; Owner: engine
--

SELECT pg_catalog.setval('vdc_db_log_seq', 1, false);


SET default_with_oids = true;

--
-- Name: vdc_db_log; Type: TABLE; Schema: public; Owner: engine; Tablespace: 
--

CREATE TABLE vdc_db_log (
    error_id bigint DEFAULT nextval('vdc_db_log_seq'::regclass) NOT NULL,
    occured_at timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone NOT NULL,
    error_code character varying(16) NOT NULL,
    error_message character varying(2048),
    error_proc character varying(126),
    error_line integer
);


ALTER TABLE public.vdc_db_log OWNER TO engine;

--
-- Name: vdc_users; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vdc_users AS
    SELECT 'user' AS user_group, users_1.name, users_1.user_id, users_1.surname, users_1.domain, users_1.username, users_1.groups, users_1.department, users_1.role, users_1.user_icon_path, users_1.desktop_device, users_1.email, users_1.note, users_1.status, 0 AS vm_admin, users_1.session_count, users_1.last_admin_check_status, users_1.group_ids FROM users users_1 UNION SELECT 'group' AS user_group, ad_groups.name, ad_groups.id AS user_id, '' AS surname, ad_groups.domain, '' AS username, '' AS groups, '' AS department, '' AS role, '' AS user_icon_path, '' AS desktop_device, '' AS email, '' AS note, ad_groups.status, 1 AS vm_admin, 0 AS session_count, NULL::unknown AS last_admin_check_status, '' AS group_ids FROM ad_groups;


ALTER TABLE public.vdc_users OWNER TO engine;

--
-- Name: vdc_users_with_tags; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vdc_users_with_tags AS
    SELECT users_1.user_group, users_1.name, permissions.object_id AS vm_guid, users_1.user_id, users_1.surname, users_1.domain, users_1.username, users_1.groups, users_1.department, users_1.role, roles1.name AS mla_role, users_1.user_icon_path, users_1.desktop_device, users_1.email, users_1.note, users_1.status, users_1.vm_admin, tags_user_map_view_1.tag_name, tags_user_map_view_1.tag_id, users_1.session_count, users_1.last_admin_check_status, users_1.group_ids, pools.vm_pool_name FROM (((((vdc_users users_1 LEFT JOIN users_and_groups_to_vm_pool_map_view pools ON ((users_1.user_id = pools.user_id))) LEFT JOIN permissions ON ((users_1.user_id = permissions.ad_element_id))) LEFT JOIN tags ON ((tags.type = 1))) LEFT JOIN tags_user_map_view tags_user_map_view_1 ON ((users_1.user_id = tags_user_map_view_1.user_id))) LEFT JOIN roles roles1 ON ((roles1.id = permissions.role_id))) WHERE (users_1.user_group = 'user'::text) UNION SELECT users_2.user_group, users_2.name, permissions_1.object_id AS vm_guid, users_2.user_id, users_2.surname, users_2.domain, users_2.username, users_2.groups, users_2.department, users_2.role, roles2.name AS mla_role, users_2.user_icon_path, users_2.desktop_device, users_2.email, users_2.note, users_2.status, users_2.vm_admin, tags_user_group_map_view.tag_name, tags_user_group_map_view.tag_id, users_2.session_count, users_2.last_admin_check_status, users_2.group_ids, pools1.vm_pool_name FROM (((((vdc_users users_2 LEFT JOIN users_and_groups_to_vm_pool_map_view pools1 ON ((users_2.user_id = pools1.user_id))) LEFT JOIN permissions permissions_1 ON ((users_2.user_id = permissions_1.ad_element_id))) LEFT JOIN tags tags_1 ON ((tags_1.type = 1))) LEFT JOIN tags_user_group_map_view ON ((users_2.user_id = tags_user_group_map_view.group_id))) LEFT JOIN roles roles2 ON ((roles2.id = permissions_1.role_id))) WHERE (users_2.user_group = 'group'::text);


ALTER TABLE public.vdc_users_with_tags OWNER TO engine;

--
-- Name: vds_groups_storage_domain; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vds_groups_storage_domain AS
    SELECT vds_groups.vds_group_id, vds_groups.name, vds_groups.description, vds_groups.cpu_name, vds_groups._create_date, vds_groups._update_date, vds_groups.selection_algorithm, vds_groups.high_utilization, vds_groups.low_utilization, vds_groups.cpu_over_commit_duration_minutes, vds_groups.hypervisor_type, vds_groups.storage_pool_id, vds_groups.max_vds_memory_over_commit, vds_groups.compatibility_version, vds_groups.transparent_hugepages, vds_groups.migrate_on_error, storage_pool_iso_map.storage_id FROM (vds_groups LEFT JOIN storage_pool_iso_map ON ((vds_groups.storage_pool_id = storage_pool_iso_map.storage_pool_id)));


ALTER TABLE public.vds_groups_storage_domain OWNER TO engine;

--
-- Name: vds_with_tags; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vds_with_tags AS
    SELECT vds_groups.vds_group_id, vds_groups.name AS vds_group_name, vds_groups.description AS vds_group_description, vds_groups.selection_algorithm, vds_static.vds_id, vds_static.vds_name, vds_static.ip, vds_static.vds_unique_id, vds_static.host_name, vds_static.port, vds_static.vds_strength, vds_static.server_ssl_enabled, vds_static.vds_type, vds_static.pm_type, vds_static.pm_user, vds_static.pm_password, vds_static.pm_port, vds_static.pm_options, vds_static.pm_enabled, vds_dynamic.hooks, vds_dynamic.status, vds_dynamic.cpu_cores, vds_dynamic.cpu_model, vds_dynamic.cpu_speed_mh, vds_dynamic.if_total_speed, vds_dynamic.kvm_enabled, vds_dynamic.physical_mem_mb, vds_dynamic.pending_vcpus_count, vds_dynamic.pending_vmem_size, vds_dynamic.mem_commited, vds_dynamic.vm_active, vds_dynamic.vm_count, vds_dynamic.vm_migrating, vds_dynamic.vms_cores_count, vds_dynamic.cpu_over_commit_time_stamp, vds_dynamic.hypervisor_type, vds_dynamic.net_config_dirty, vds_groups.high_utilization, vds_groups.low_utilization, vds_groups.max_vds_memory_over_commit, vds_groups.cpu_over_commit_duration_minutes, storage_pool.id AS storage_pool_id, storage_pool.name AS storage_pool_name, tags_vds_map_view.tag_name, tags_vds_map_view.tag_id, vds_dynamic.reserved_mem, vds_dynamic.guest_overhead, vds_dynamic.rpm_version, vds_dynamic.software_version, vds_dynamic.version_name, vds_dynamic.build_name, vds_dynamic.previous_status, vds_statistics.cpu_idle, vds_statistics.cpu_load, vds_statistics.cpu_sys, vds_statistics.cpu_user, vds_statistics.usage_mem_percent, vds_statistics.usage_cpu_percent, vds_statistics.usage_network_percent, vds_statistics.mem_available, vds_statistics.mem_shared, vds_statistics.swap_free, vds_statistics.swap_total, vds_statistics.ksm_cpu_percent, vds_statistics.ksm_pages, vds_statistics.ksm_state, vds_dynamic.cpu_flags, vds_groups.cpu_name AS vds_group_cpu_name, vds_dynamic.cpu_sockets, vds_spm_id_map.vds_spm_id, vds_static.otp_validity, CASE WHEN (storage_pool.spm_vds_id = vds_static.vds_id) THEN CASE WHEN (storage_pool.status = 5) THEN 1 ELSE 2 END ELSE 0 END AS spm_status, vds_dynamic.supported_cluster_levels, vds_dynamic.supported_engines, vds_groups.compatibility_version AS vds_group_compatibility_version, vds_dynamic.host_os, vds_dynamic.kvm_version, vds_dynamic.spice_version, vds_dynamic.kernel_version, vds_dynamic.iscsi_initiator_name, vds_dynamic.transparent_hugepages_state, vds_dynamic.anonymous_hugepages, vds_dynamic.non_operational_reason, storage_pool_iso_map.storage_id FROM (((((((vds_groups JOIN vds_static ON ((vds_groups.vds_group_id = vds_static.vds_group_id))) JOIN vds_dynamic ON ((vds_static.vds_id = vds_dynamic.vds_id))) JOIN vds_statistics ON ((vds_static.vds_id = vds_statistics.vds_id))) LEFT JOIN storage_pool ON ((vds_groups.storage_pool_id = storage_pool.id))) LEFT JOIN tags_vds_map_view ON ((vds_static.vds_id = tags_vds_map_view.vds_id))) LEFT JOIN vds_spm_id_map ON ((vds_static.vds_id = vds_spm_id_map.vds_id))) LEFT JOIN storage_pool_iso_map ON ((storage_pool_iso_map.storage_pool_id = storage_pool.id)));


ALTER TABLE public.vds_with_tags OWNER TO engine;

--
-- Name: vm_images_storage_domains_view; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vm_images_storage_domains_view AS
    SELECT vm_images_view.storage_id, vm_images_view.storage_path, vm_images_view.storage_pool_id, vm_images_view.image_guid, vm_images_view.creation_date, vm_images_view.actual_size, vm_images_view.read_rate, vm_images_view.write_rate, vm_images_view.size, vm_images_view.it_guid, vm_images_view.description, vm_images_view.parentid, vm_images_view.imagestatus, vm_images_view.lastmodified, vm_images_view.app_list, vm_images_view.vm_snapshot_id, vm_images_view.volume_type, vm_images_view.image_group_id, vm_images_view.active, vm_images_view.volume_format, vm_images_view.disk_interface, vm_images_view.boot, vm_images_view.wipe_after_delete, vm_images_view.propagate_errors, vm_images_view.entity_type, vm_images_view.number_of_vms, vm_images_view.vm_names, vm_images_view.quota_id, vm_images_view.quota_name, vm_images_view.disk_alias, vm_images_view.disk_description, storage_domains_with_hosts_view.id, storage_domains_with_hosts_view.storage, storage_domains_with_hosts_view.storage_name, storage_domains_with_hosts_view.available_disk_size, storage_domains_with_hosts_view.used_disk_size, storage_domains_with_hosts_view.commited_disk_size, storage_domains_with_hosts_view.storage_type, storage_domains_with_hosts_view.storage_domain_type, storage_domains_with_hosts_view.storage_domain_format_type, storage_domains_with_hosts_view.storage_domain_shared_status, storage_domains_with_hosts_view.vds_group_id, storage_domains_with_hosts_view.vds_id, storage_domains_with_hosts_view.recoverable, storage_domains_with_hosts_view.storage_pool_name, storage_domains_with_hosts_view.storage_name AS name FROM ((vm_images_view JOIN images_storage_domain_view ON ((vm_images_view.image_guid = images_storage_domain_view.image_guid))) JOIN storage_domains_with_hosts_view ON ((storage_domains_with_hosts_view.id = images_storage_domain_view.storage_id)));


ALTER TABLE public.vm_images_storage_domains_view OWNER TO engine;

--
-- Name: vms_with_tags; Type: VIEW; Schema: public; Owner: engine
--

CREATE VIEW vms_with_tags AS
    SELECT vms.vm_name, vms.vm_mem_size_mb, vms.nice_level, vms.vmt_guid, vms.vm_os, vms.vm_description, vms.vds_group_id, vms.vm_domain, vms.vm_creation_date, vms.auto_startup, vms.is_stateless, vms.dedicated_vm_for_vds, vms.fail_back, vms.default_boot_sequence, vms.vm_type, vms.hypervisor_type, vms.operation_mode, vms.vds_group_name, vms.selection_algorithm, vms.storage_pool_id, vms.storage_pool_name, vms.vds_group_description, vms.vmt_name, vms.vmt_mem_size_mb, vms.vmt_os, vms.vmt_creation_date, vms.vmt_child_count, vms.vmt_num_of_sockets, vms.vmt_cpu_per_socket, vms.vmt_description, vms.status, vms.vm_ip, vms.vm_host, (vms.vmt_num_of_sockets * vms.vmt_cpu_per_socket) AS vmt_num_of_cpus, vms.vm_pid, vms.last_start_time, vms.guest_cur_user_name, vms.guest_last_login_time, vms.guest_cur_user_id, vms.console_user_id, vms.guest_last_logout_time, vms.guest_os, vms.run_on_vds, vms.migrating_to_vds, vms.app_list, vms.display, vms.hibernation_vol_handle, vms.vm_pool_name, vms.vm_pool_id, vms.vm_guid, vms.num_of_monitors, vms.allow_console_reconnect, vms.is_initialized, vms.is_auto_suspend, vms.num_of_sockets, vms.cpu_per_socket, vms.usb_policy, vms.acpi_enable, vms.session, (vms.num_of_sockets * vms.cpu_per_socket) AS num_of_cpus, vms.display_ip, vms.display_type, vms.kvm_enable, vms.boot_sequence, vms.display_secure_port, vms.utc_diff, vms.last_vds_run_on, vms.client_ip, vms.guest_requested_memory, vms.time_zone, vms.cpu_user, vms.cpu_sys, vms.elapsed_time, vms.usage_network_percent, vms.usage_mem_percent, vms.usage_cpu_percent, vms.run_on_vds_name, vms.vds_group_cpu_name, tags_vm_map_view.tag_name, tags_vm_map_view.tag_id, vms.default_display_type, vms.priority, vms.vds_group_compatibility_version, vms.initrd_url, vms.kernel_url, vms.kernel_params, vms.pause_status, vms.exit_status, vms.exit_message, vms.min_allocated_mem, storage_domain_static.id AS storage_id, vms.quota_id, vms.quota_name FROM (((((vms LEFT JOIN tags_vm_map_view ON ((vms.vm_guid = tags_vm_map_view.vm_id))) LEFT JOIN vm_device ON ((vm_device.vm_id = vms.vm_guid))) LEFT JOIN images ON ((images.image_group_id = vm_device.device_id))) LEFT JOIN image_storage_domain_map ON ((image_storage_domain_map.image_id = images.image_guid))) LEFT JOIN storage_domain_static ON ((storage_domain_static.id = image_storage_domain_map.storage_domain_id))) WHERE ((images.active IS NULL) OR (images.active = true));


ALTER TABLE public.vms_with_tags OWNER TO engine;

--
-- Data for Name: action_version_map; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (2, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (33, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (36, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (23, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (39, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (24, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (960, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (961, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (915, '2.2', '2.2');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (41, '3.1', '3.1');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (158, '3.1', '3.0');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (52, '3.1', '3.1');
INSERT INTO action_version_map (action_type, cluster_minimal_version, storage_pool_minimal_version) VALUES (1009, '3.1', '*');


--
-- Data for Name: ad_groups; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO ad_groups (id, name, status, domain, distinguishedname) VALUES ('eee00000-0000-0000-0000-123456789eee', 'Everyone', 1, '', '');


--
-- Data for Name: async_tasks; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: async_tasks_entities; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: audit_log; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:34:01.973+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:44:04.838+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:44:25.936+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center POSIX_EXT4 was added by admin@internal', false, NULL, 'POSIX_EXT4', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7447c045', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:44:35.109+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster POSIX_EXT4 was added by admin@internal', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '49720ed7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (5, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:47:08.887+02', 'VDS_ALERT_FENCING_IS_NOT_CONFIGURED', 9000, 10, 'Failed to verify Power Management configuration for Host gold-vdsc.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (6, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:47:08.923+02', 'USER_ADD_VDS', 42, 0, 'Host gold-vdsc was added by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '35cc43cf', 'b4f90315-db76-469e-9e3e-16001efed0be', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (7, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:47:09.854+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: RHEV_INSTALL; Details: Connected to Host gold-vdsc.qa.lab.tlv.redhat.com with SSH key fingerprint: 21:d5:af:17:49:ed:50:9a:9e:1c:1e:d6:4f:a0:5a:b6.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (8, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:47:10.529+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (9, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:47:11.637+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: SET_SYSTEM_TIME; Details: setSystemTime ended successfully.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (10, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.219+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: RHN_REGISTRATION; Details: Host properly registered with RHN/Satellite..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (11, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.418+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDSM_MAJOR_VER; Details: Available VDSM matches requirements.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (12, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.456+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VT_SVM; Details: Server supports virtualization.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (13, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.466+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: OS; Details: Supported platform version.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (14, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.483+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: KERNEL; Details: Supported kernel version: 279.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (15, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.558+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: REQ PACKAGES; Details: SDL-1.2.14-3.el6.x86_64   (SDL.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (16, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.586+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: REQ PACKAGES; Details: bridge-utils-1.2-9.el6.x86_64   (bridge-utils.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (17, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.607+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: REQ PACKAGES; Details: mesa-libGLU-7.11-5.el6.x86_64   (mesa-libGLU.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (18, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.64+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: REQ PACKAGES; Details: openssl-1.0.0-25.el6_3.1.x86_64   (openssl.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (19, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.661+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: REQ PACKAGES; Details: m2crypto-0.20.2-9.el6.x86_64   (m2crypto.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (20, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.7+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: REQ PACKAGES; Details: rsync-3.0.6-9.el6.x86_64   (rsync.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (21, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.711+02', 'VDS_INSTALL_IN_PROGRESS_WARNING', 510, 1, 'Host gold-vdsc installation in progress . Step: VDS PACKAGES; Details: package qemu-kvm is not installed   (qemu-kvm).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (22, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.728+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: vdsm-4.9.6-44.1.el6_3.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (23, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.786+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (24, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.809+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (25, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.828+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (26, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.865+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (27, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.897+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (28, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.929+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (29, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.95+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: sanlock-2.3-4.el6_3.x86_64   (sanlock).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (846, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:46:10.515+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (30, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:21.971+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: sanlock-python-2.3-4.el6_3.x86_64   (sanlock-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (31, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:50.912+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: vdsm-4.9.6-44.2.el6_3.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (32, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:52.977+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (33, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:55.136+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (34, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:57.226+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (35, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:48:59.292+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (36, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:01.458+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (37, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:03.691+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (38, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:05.764+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: sanlock-2.3-4.el6_3.x86_64   (sanlock).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (39, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:07.935+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: sanlock-python-2.3-4.el6_3.x86_64   (sanlock-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (40, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:10.101+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: package qemu-img is not installed   (qemu-img).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (41, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:12.295+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: package qemu-kvm-tools is not installed   (qemu-kvm-tools).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (42, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:14.452+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS PACKAGES; Details: package qemu-kvm is not installed   (qemu-kvm).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (43, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:14.682+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: CreateConf; Details: Basic configuration found, skipping this step.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (44, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:14.785+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: CheckLocalHostname; Details: Local hostname is correct..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (45, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:14.839+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: SetNetworking; Details: Bridge management already exists. Skipping bridge creation..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (46, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:14.879+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: SetSSHAccess; Details: SUCCESS.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (47, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:15.367+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VerifyServices; Details: Needed services set.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (48, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:23.257+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: Encryption setup; Details: Ended successfully.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (49, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:23.311+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (50, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:24.618+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (51, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:25.082+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: instCert.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (52, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:25.109+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: CoreDump.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (53, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:25.13+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: cleanAll.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (54, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:25.215+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: VDS Configuration.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (55, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:25.257+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (56, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:25.295+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsc. Step: Reboot; Details: Rebooting machine.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (57, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:49:25.388+02', 'VDS_INSTALL', 504, 0, 'Host gold-vdsc installed', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '1957e7f2', 'b4f90315-db76-469e-9e3e-16001efed0be', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (59, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:49:56.114+02', 'USER_ADD_VDS', 42, 0, 'Host gold-vdsd was added by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '165f52be', '69987262-960d-43bb-b9e0-be07521bd764', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (60, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:49:56.345+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL; Details: Connected to Host gold-vdsd.qa.lab.tlv.redhat.com with SSH key fingerprint: 00:62:8b:0b:ce:b9:80:2d:7c:ed:0a:bc:44:a7:b9:c9.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (61, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:49:56.993+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (62, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:49:59.104+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SET_SYSTEM_TIME; Details: setSystemTime ended successfully.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (63, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:50:23.423+02', 'VDS_ALERT_FENCING_IS_NOT_CONFIGURED', 9000, 10, 'Failed to verify Power Management configuration for Host camel-vdsb.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (64, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:50:23.486+02', 'USER_ADD_VDS', 42, 0, 'Host camel-vdsb was added by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '57b86f07', '6ae6a362-5a12-4b57-b20e-12c149ca02e3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (65, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:50:23.637+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: RHEV_INSTALL; Details: Connected to Host camel-vdsb.qa.lab.tlv.redhat.com with SSH key fingerprint: 5b:e6:cf:50:87:f5:55:58:df:12:bf:34:16:b0:b4:ec.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (66, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:50:23.909+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (67, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:50:26.004+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: SET_SYSTEM_TIME; Details: setSystemTime ended successfully.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (68, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.348+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: RHN_REGISTRATION; Details: Host properly registered with RHN/Satellite..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (69, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.605+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDSM_MAJOR_VER; Details: Available VDSM matches requirements.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (70, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.625+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VT_SVM; Details: Server supports virtualization.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (71, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.638+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: OS; Details: Supported platform version.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (72, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.655+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: KERNEL; Details: Supported kernel version: 279.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (73, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.681+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: REQ PACKAGES; Details: SDL-1.2.14-3.el6.x86_64   (SDL.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (74, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.693+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: REQ PACKAGES; Details: bridge-utils-1.2-9.el6.x86_64   (bridge-utils.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (75, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.713+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: REQ PACKAGES; Details: mesa-libGLU-7.11-5.el6.x86_64   (mesa-libGLU.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (76, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.74+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: REQ PACKAGES; Details: openssl-1.0.0-25.el6_3.1.x86_64   (openssl.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (77, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.757+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: REQ PACKAGES; Details: m2crypto-0.20.2-9.el6.x86_64   (m2crypto.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (78, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.775+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: REQ PACKAGES; Details: rsync-3.0.6-9.el6.x86_64   (rsync.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (79, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.792+02', 'VDS_INSTALL_IN_PROGRESS_WARNING', 510, 1, 'Host camel-vdsb installation in progress . Step: VDS PACKAGES; Details: package qemu-kvm is not installed   (qemu-kvm).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (80, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.834+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: vdsm-4.9.6-44.1.el6_3.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (81, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.911+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (82, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:52.978+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (83, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:53.011+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (84, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:53.031+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (85, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:53.072+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (86, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:53.087+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (87, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:53.102+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: sanlock-2.3-4.el6_3.x86_64   (sanlock).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (88, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:51:53.167+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: sanlock-python-2.3-4.el6_3.x86_64   (sanlock-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (89, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.242+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHN_REGISTRATION; Details: Host properly registered with RHN/Satellite..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (90, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.459+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDSM_MAJOR_VER; Details: Available VDSM matches requirements.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (91, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.498+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VT_SVM; Details: Server supports virtualization.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (92, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.512+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: OS; Details: Supported platform version.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (93, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.537+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: KERNEL; Details: Supported kernel version: 279.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (94, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.597+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: SDL-1.2.14-3.el6.x86_64   (SDL.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (95, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.626+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: bridge-utils-1.2-9.el6.x86_64   (bridge-utils.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (96, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.643+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: mesa-libGLU-7.11-5.el6.x86_64   (mesa-libGLU.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (97, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.684+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: openssl-1.0.0-25.el6_3.1.x86_64   (openssl.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (98, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.701+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: m2crypto-0.20.2-9.el6.x86_64   (m2crypto.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (99, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.733+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: rsync-3.0.6-9.el6.x86_64   (rsync.x86_64).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (100, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.751+02', 'VDS_INSTALL_IN_PROGRESS_WARNING', 510, 1, 'Host gold-vdsd installation in progress . Step: VDS PACKAGES; Details: package qemu-kvm is not installed   (qemu-kvm).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (101, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.765+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9.6-44.1.el6_3.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (102, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.783+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (103, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.832+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (104, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.863+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (105, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.877+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (106, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.894+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (107, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.922+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (108, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.942+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: sanlock-2.3-4.el6_3.x86_64   (sanlock).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (109, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:51:53.986+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: sanlock-python-2.3-4.el6_3.x86_64   (sanlock-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (110, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:20.884+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: vdsm-4.9.6-44.2.el6_3.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (111, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:21.024+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9.6-44.2.el6_3.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (112, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:23.131+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (113, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:23.482+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (114, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:25.301+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (115, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:26.182+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (116, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:27.411+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (117, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:28.748+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (118, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:29.495+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (119, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:31.318+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (120, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:31.665+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (121, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:33.828+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (122, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:34.039+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (123, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:35.976+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: sanlock-2.3-4.el6_3.x86_64   (sanlock).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (124, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:36.78+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (125, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:38.219+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: sanlock-python-2.3-4.el6_3.x86_64   (sanlock-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (126, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:39.336+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: sanlock-2.3-4.el6_3.x86_64   (sanlock).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (127, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:40.42+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: package qemu-img is not installed   (qemu-img).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (128, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:42.062+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: sanlock-python-2.3-4.el6_3.x86_64   (sanlock-python).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (129, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:42.573+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: package qemu-kvm-tools is not installed   (qemu-kvm-tools).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (130, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:44.73+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: package qemu-kvm is not installed   (qemu-kvm).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (132, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:44.81+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: CreateConf; Details: Basic configuration found, skipping this step.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (133, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:44.955+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: CheckLocalHostname; Details: Local hostname is correct..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (134, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:44.992+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SetNetworking; Details: Bridge management already exists. Skipping bridge creation..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (135, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:45.041+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SetSSHAccess; Details: SUCCESS.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (136, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:52:45.679+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VerifyServices; Details: Needed services set.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (137, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:47.452+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: package qemu-kvm-tools is not installed   (qemu-kvm-tools).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (138, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:50.216+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: package qemu-kvm is not installed   (qemu-kvm).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (139, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:50.231+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: CreateConf; Details: Basic configuration found, skipping this step.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (140, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:50.246+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: CheckLocalHostname; Details: Local hostname is correct..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (141, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:50.284+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: SetNetworking; Details: Bridge management already exists. Skipping bridge creation..', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (142, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:50.413+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: SetSSHAccess; Details: SUCCESS.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (143, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:50.912+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VerifyServices; Details: Needed services set.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (131, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:52:44.763+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS PACKAGES; Details: package qemu-img is not installed   (qemu-img).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (144, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:02.945+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: Encryption setup; Details: Ended successfully.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (145, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:02.973+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (146, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.271+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (147, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.557+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: instCert.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (148, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.6+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: CoreDump.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (149, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.672+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: cleanAll.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (150, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.687+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: VDS Configuration.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (151, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.728+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (152, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.754+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host camel-vdsb. Step: Reboot; Details: Rebooting machine.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (153, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:53:04.849+02', 'VDS_INSTALL', 504, 0, 'Host camel-vdsb installed', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '220f2132', '6ae6a362-5a12-4b57-b20e-12c149ca02e3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (154, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:26.819+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: Encryption setup; Details: Ended successfully.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (155, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:26.838+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (156, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:28.204+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (157, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:28.704+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: instCert.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (158, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:28.775+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: CoreDump.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (159, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:28.906+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: cleanAll.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (160, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:28.983+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS Configuration.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (161, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:29.009+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (162, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:29.645+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: Reboot; Details: Rebooting machine.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (163, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:53:29.916+02', 'VDS_INSTALL', 504, 0, 'Host gold-vdsd installed', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '6e49ee3c', '69987262-960d-43bb-b9e0-be07521bd764', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (164, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 14:54:27.944+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (165, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:57:35.438+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection orion.qa.lab.tlv.redhat.com:/mnt/daffi_ext4 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (166, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:58:27.062+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection orion.qa.lab.tlv.redhat.com:/daffi_ext4 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (167, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 14:58:32.937+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (168, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 14:58:47.496+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (169, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:59:46.52+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection orion.qa.lab.tlv.redhat.com:/mnt/daffi_ext4 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (170, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 14:59:56.676+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection orion.qa.lab.tlv.redhat.com:daffi_ext4 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (171, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:00:32.91+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection orion.qa.lab.tlv.redhat.com/mnt/daffi_ext4 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (172, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:00:37.661+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection orion.qa.lab.tlv.redhat.com:/mnt/daffi_ext4 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (173, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:25:30.772+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov97 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (174, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:25:40.277+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov94 returned by VDSM was following Permission settings on the specified path do not allow access to the storage.
Verify permission settings on the specified storage path.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (296, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:01:38.739+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '13272eb6', 'ebe6fa1c-ab8e-4679-a3f1-8cb245b48efa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (175, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:26:05.482+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov94 returned by VDSM was following Permission settings on the specified path do not allow access to the storage.
Verify permission settings on the specified storage path.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (177, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:27:55.325+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov94 returned by VDSM was following Permission settings on the specified path do not allow access to the storage.
Verify permission settings on the specified storage path.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (178, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:28:22.754+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /mnt returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (176, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:26:44.101+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov94 returned by VDSM was following Permission settings on the specified path do not allow access to the storage.
Verify permission settings on the specified storage path.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (179, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:29:51.445+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/dm-3 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (180, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:30:20.827+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov94 returned by VDSM was following Permission settings on the specified path do not allow access to the storage.
Verify permission settings on the specified storage path.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (181, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:31:08.049+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov94 returned by VDSM was following Permission settings on the specified path do not allow access to the storage.
Verify permission settings on the specified storage path.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (182, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:32:32.784+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection gold-vdsc.qa.lab.tlv.redhat.com:/dev/mapper/1paikov94 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (188, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:39:05.304+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host camel-vdsb was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '19f30016', '57140c9f-6cf8-4d84-90b8-b020380112b4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (189, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 15:39:05.414+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '19f30016', '74b55652-d3da-4279-8238-9404a0036bb4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (190, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-12 15:39:39.708+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', '00000000-0000-0000-0000-000000000000', '', '244431f4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (192, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:40:05.837+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain ext4 (Data Center POSIX_EXT4) was activated by admin@internal', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'ext4', '00000000-0000-0000-0000-000000000000', '', '2db0b107', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (193, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:40:05.853+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center POSIX_EXT4 by admin@internal', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '59924a3a', 'fd475d51-15fd-4b4d-a689-e2dacd4f8f7e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (194, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:40:16.145+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center POSIX_EXT4 (please check your storage infrastructure).', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'ext4', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', 'ff5c1f1', '60aef642-91f6-43a2-91cd-1ba13932c3f5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (195, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:40:27.382+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (196, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:40:29.832+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (197, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:40:49.677+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (198, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:40:51.595+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (200, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:41:13.865+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (201, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:41:34.856+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (202, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:41:36.513+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (203, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:41:57.139+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (204, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:41:58.983+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (205, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:42:19.917+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (206, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:42:20.983+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '16fd2af2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (207, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:42:21.552+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (208, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:42:42.104+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (209, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:42:43.894+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (183, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:38:29.039+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain ext4 was added by admin@internal', false, NULL, '', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'ext4', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '776766fc', '2abc44f6-1020-4e9f-b415-21ac66c40834', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (186, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:38:36.406+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL_FAILED', 1003, 2, 'Failed to attach Storage Domains to Data Center POSIX_EXT4. (User: admin@internal)', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '28254027', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (187, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:38:36.506+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL_FAILED', 963, 2, 'Failed to attach Storage Domain ext4 to Data Center POSIX_EXT4. (User: admin@internal)', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'ext4', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '1d19109e', '442db69f-8f69-474e-8051-9fc0b80758bf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (191, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:40:05.566+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (199, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:41:12.169+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (210, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:43:04.902+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (211, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:43:06.823+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (212, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:43:27.381+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (213, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:43:29.622+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (214, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:43:50.082+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (215, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:43:51.853+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (216, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:44:12.542+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (217, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:44:14.767+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (218, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:44:35.134+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (219, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:44:37.057+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (220, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:44:57.468+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (221, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:45:00.002+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (222, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:45:19.978+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (223, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:45:21.781+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (224, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:45:42.212+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (225, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:45:44.097+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (226, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:46:04.865+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (227, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:46:06.744+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (228, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:46:27.325+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (229, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:46:30.108+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (230, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:46:49.759+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (231, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:46:51.503+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (919, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:26:59.857+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center EDU was added by admin@internal', false, NULL, 'EDU', NULL, '', '00000000-0000-0000-0000-000000000000', '', '21b83476', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (232, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:47:12.081+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (238, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:48:19.766+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (243, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:49:07.227+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (248, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:50:12.497+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (249, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:50:15.103+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (255, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:51:21.762+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (256, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:51:42.13+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (257, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:51:43.832+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (233, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:47:13.665+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (235, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:47:36.413+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (241, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:48:44.026+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (244, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:49:27.63+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (245, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:49:29.713+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (250, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:50:34.962+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (251, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:50:36.908+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (253, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:50:59.567+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (254, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:51:20.02+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (258, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:51:55.104+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (234, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:47:34.148+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (236, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:47:56.962+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (237, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:47:58.751+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (239, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:48:21.6+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (240, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:48:42.332+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (242, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:49:04.889+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (246, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:49:50.16+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (247, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:49:51.815+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (252, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:50:57.624+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (260, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:52:06.581+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (263, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:52:48.044+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', 'e292c0b', '3184e4d2-cf50-4659-967e-bb1cf7d9de4a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (264, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:52:55.806+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center iSCSI was added by admin@internal', false, NULL, 'iSCSI', NULL, '', '00000000-0000-0000-0000-000000000000', '', '9322fb8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (266, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:53:08.314+02', 'USER_UPDATE_VDS', 43, 0, 'Host camel-vdsb parameters were updated by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '7323af16', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (267, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:53:08.444+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '249375db', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (268, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 15:53:08.579+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '4d1e8f9f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (271, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:53:17.65+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '25100c14', 'cc53e665-3ecd-4dc1-b549-7d9fbbbd4c8b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (273, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:53:20.294+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (275, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 15:54:26.883+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain Dafna-si25-01 was added by admin@internal', false, NULL, '', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '58c40971', 'ef42e23e-53cf-4bf1-aa51-d115b2c163de', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (278, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:55:28.451+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (259, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:52:04.576+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (261, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:52:27.161+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (262, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:52:28.944+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (265, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:53:01.227+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster iSCSI was added by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '18ad00f3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (269, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:53:16.536+02', 'VDS_ACTIVATE', 16, 0, 'Host camel-vdsb was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35b7d9d6', 'f4e76727-a2b8-44bd-8d6b-667bdd57262a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (270, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:53:17.609+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (272, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 15:53:18.763+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3bd1d3f0', '27f4a424-858d-487f-a7cb-85887ec7a7e6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (274, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 15:53:20.32+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (276, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:55:00.174+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-si25-01 (LUN 7PrE7S-xk2t-5isG-2xrr-vglV-bwpq-pYLkyu) returned by VDSM was following Failed to setup iSCSI subsystem', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (277, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-12 15:55:00.233+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '00000000-0000-0000-0000-000000000000', '', '34e59144', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (279, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 15:55:33.192+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center iSCSI. Setting Host state to Non-Operational.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2fb0bd0f', '32c29143-99ac-47ae-ae54-998a35d559bb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (280, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:55:33.448+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain Dafna-si25-01 (Data Center iSCSI) was activated by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '00000000-0000-0000-0000-000000000000', '', '4f9ac276', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (281, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:55:33.492+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center iSCSI by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '43861b0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (282, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:55:33.525+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain Dafna-si25-01 was attached to Data Center iSCSI by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '76705a62', 'b04a4670-5f78-4d3f-b290-60456addf908', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (283, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 15:57:50.696+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain Dafna-si25-02 was added by admin@internal', false, NULL, '', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4bf80795', '59e2b2ba-7009-49a8-862a-ab3e7655d763', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (284, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:58:21.488+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain Dafna-si25-02 was attached to Data Center iSCSI by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '21999376', '461d7158-dece-4e4d-a85b-43d7b22ffd80', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (285, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 15:58:25.335+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain Dafna-si25-03 was added by admin@internal', false, NULL, '', '13d2f06b-2c3b-412c-9fa7-771cf8557509', 'Dafna-si25-03', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '41352992', '75952c3c-b82b-4052-8dbb-9edb5c5bf2ce', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (286, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 15:59:00.208+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain Dafna-si25-03 was attached to Data Center iSCSI by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '13d2f06b-2c3b-412c-9fa7-771cf8557509', 'Dafna-si25-03', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1e67fe6e', 'c22025fe-3638-48ec-a5ef-1df11862e51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (287, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:59:35.14+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain Dafna-si25-02 (Data Center iSCSI) was activated by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '00000000-0000-0000-0000-000000000000', '', '201b3d31', '95606bfe-b359-464b-ad21-2bd39a245f8b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (288, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 15:59:35.173+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain Dafna-si25-03 (Data Center iSCSI) was activated by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '13d2f06b-2c3b-412c-9fa7-771cf8557509', 'Dafna-si25-03', '00000000-0000-0000-0000-000000000000', '', '6cbf6c7d', '470fdb54-8187-41e3-83a1-d6dd96bba141', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (289, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:00:00.894+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsc was autorecovered.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5438fc8c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (290, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:00:01.863+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (291, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:00:05.383+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-si25-02 (LUN C8qzHi-fyIN-r1sx-NRfF-LUG8-omqa-hVacQU) returned by VDSM was following Failed to setup iSCSI subsystem', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (292, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:00:05.405+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-si25-03 (LUN C8qzHi-fyIN-r1sx-NRfF-LUG8-omqa-hVacQU) returned by VDSM was following Failed to setup iSCSI subsystem', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (293, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:00:05.636+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center iSCSI. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '751c731b', '7b1d994a-bd00-45ac-8329-9034bc44030c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (294, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:00:05.714+02', 'CONNECT_STORAGE_SERVERS_FAILED', 994, 1, 'Failed to connect Host gold-vdsc to Storage Servers', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '65e54e12', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (295, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:01:10.434+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '19f93675', '097d3f1b-839f-4379-ab55-8260dda5e828', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (297, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:01:40.168+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (298, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:03:10.285+02', 'USER_UPDATE_STORAGE_POOL', 952, 0, 'Data Center iSCSI was updated by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7689ab12', 'c542f86b-4193-4f6b-967d-90669294d181', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (300, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:15:29.108+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection tiger.qa.lab.tlv.redhat.com:/volumes/wolf/Dafna_New_Export_0_nfs_71122241851338 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (303, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 16:25:36.937+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain New_Export was attached to Data Center iSCSI by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '45b82d0e', 'a08ae74b-f523-4196-8593-5066fc3ef5cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (306, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 16:26:32.414+02', 'IMPORTEXPORT_STARTING_IMPORT_TEMPLATE', 1163, 0, 'Starting to import Template XP_iSCSI to Data Center iSCSI, Cluster iSCSI', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5b0133e2', 'fb508db7-9594-434a-8a4f-de590013aaa8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (307, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:26:37.76+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2428705b', 'df5d0fbd-9354-462c-89ea-87a9b23af330', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (308, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:26:47.072+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5d8eb397', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (309, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:26:47.233+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '7db26098', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (299, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:15:10.34+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection tiger.qa.lab.tlv.redhat.com:/volumes/wolf/Dafna_New_Export_0_nfs_71122241851338 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (301, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:16:35.753+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain New_Export was added by admin@internal', false, NULL, '', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3317963c', '1fa8db16-b516-4188-ba38-2450b35a7c9a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (304, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:25:51.815+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain New_Export (Data Center iSCSI) was activated by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '00000000-0000-0000-0000-000000000000', '', '4a1234c8', '85053016-f6d4-41f0-860c-e4fa6d5ba792', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (305, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:26:19.055+02', 'USER_UPDATE_STORAGE_POOL', 952, 0, 'Data Center iSCSI was updated by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '00000000-0000-0000-0000-000000000000', '', '4c70c5e7', 'c4eb0f37-b3fa-4bfb-891e-6b5a0628068c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (310, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:26:56.113+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '684f780c', '7b953746-8f9d-425f-a471-f87c740bb4ab', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (311, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:26:57.457+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (312, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:26:57.636+02', 'VDS_STORAGES_CONNECTION_FAILED', 535, 2, 'Failed to connect Host gold-vdsd to the Storage Domains ext4.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (313, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:26:57.664+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection /dev/mapper/1paikov94 returned by VDSM was following General Exception', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (314, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:27:00.101+02', 'VDS_STORAGE_CONNECTION_FAILED_BUT_LAST_VDS', 533, 2, 'Failed to connect Host gold-vdsd to Data Center, due to connectivity errors with the Storage. Host gold-vdsd will remain in Up state (but inactive), as it is the last Host in the Data Center, to enable manual intervention by the Administrator.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (315, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:27:00.338+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool POSIX_EXT4', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '306f9e2a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (317, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:27:10.376+02', 'USER_DEACTIVATE_STORAGE_DOMAIN_FAILED', 969, 2, 'Failed to deactivate Storage Domain ext4 (Data Center POSIX_EXT4). (User: admin@internal)', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'ext4', '00000000-0000-0000-0000-000000000000', '', '719172d0', '27b37a57-7426-406c-850a-4eb8c962ef9d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (321, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:27:41.306+02', 'USER_REMOVE_STORAGE_POOL_FAILED', 955, 2, 'Failed to remove Data Center POSIX_EXT4. (User: admin@internal)', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '7e7a2bb9', 'b3d312d4-45c2-430d-ae15-f0335706830d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (322, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 16:27:53.597+02', 'IMPORTEXPORT_IMPORT_TEMPLATE', 1158, 0, 'Template XP_iSCSI was imported successfully to Data Center iSCSI, Cluster iSCSI', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5b0133e2', 'fb508db7-9594-434a-8a4f-de590013aaa8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (302, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 16:16:47.314+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL_FAILED', 963, 2, 'Failed to attach Storage Domain New_Export to Data Center iSCSI. (User: admin@internal)', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4c18478d', '2a65ef2b-bbbe-4d53-8a53-d58990612ca5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (316, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-12 16:27:07.423+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', '00000000-0000-0000-0000-000000000000', '', '26e9098d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (318, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:27:12.889+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center POSIX_EXT4 (please check your storage infrastructure).', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'ext4', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '3fadc4a0', '8bef3d58-21bd-45d8-a0f2-784f542afae5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (323, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 16:42:13.538+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '5381cd77', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (324, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:42:18.696+02', 'VDS_NETWORKS_OUT_OF_SYNC', 1110, 1, 'Host gold-vdsd''s following network(s) are not synchronized with their Logical Network configuration: rhevm.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (325, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 16:42:18.717+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (326, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 16:42:21.607+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (327, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 16:42:25.941+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (328, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 16:42:32.674+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center iSCSI. Setting status to Non-Responsive.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '8b948f7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (329, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 16:42:32.86+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (330, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 17:12:20.4+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (331, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:12:42.141+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '77d35245', '089bc914-9b04-44c4-a08b-2921600765ac', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (332, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:13:53.435+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '77d35245', '089bc914-9b04-44c4-a08b-2921600765ac', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (333, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 17:22:35.899+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (334, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:23:58.457+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3ca356bc', '3ac91f66-56d4-4e24-8cae-dc46fbf53706', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (335, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 17:24:21.435+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center POSIX_EXT4_hateya was added by admin@internal', false, NULL, 'POSIX_EXT4_hateya', NULL, '', '00000000-0000-0000-0000-000000000000', '', '60784768', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (336, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 17:24:27.84+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster POSOSOS was added by admin@internal', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '420f3865', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (337, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:24:36.319+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1af97447', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (338, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:24:36.472+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '702ebc6b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (339, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:24:42.327+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '2c70869f', 'd18d6728-fc72-4976-b780-3d890dfef9ad', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (340, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:24:42.888+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (341, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:28:15.065+02', 'USER_STARTED_VM', 153, 0, 'VM XP was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '8270571', 'b84d0103-b558-4746-92e5-3a8a9039c047', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (342, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:28:24.989+02', 'USER_STOP_VM', 33, 0, 'VM XP stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '53d017a0', 'd3cb6d4f-c37d-4041-a5f1-1f05d607990e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (343, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:28:30.787+02', 'USER_UPDATE_VM', 35, 0, 'VM XP parameters were updated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '30ad659e', '85ea992b-e131-4699-8d57-dc9790cf8acc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (344, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:28:35.934+02', 'USER_STARTED_VM', 153, 0, 'VM XP was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '452640ba', '6e85727a-c93a-4637-8e98-b4bb2cb7a3a4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (345, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:30:06.845+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (346, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:31:02.5+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of XP_iSCSI_Disk1 creation for VM XP was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4b57c852', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (347, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:31:02.546+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (348, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:31:23.34+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of XP_iSCSI_Disk1 creation for VM XP has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (349, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:31:23.936+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (350, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:31:23.964+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (351, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:31:34+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (352, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:31:34.035+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (353, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 17:32:02.873+02', 'USER_FORCE_REMOVE_STORAGE_DOMAIN', 981, 0, 'Storage Domain ext4 was forcibly removed by admin@internal', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'ext4', '00000000-0000-0000-0000-000000000000', '', '3e412e75', '30cd47ab-3975-4465-8f7a-9a1e914358cb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (355, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:32:45.816+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (356, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:32:45.823+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (357, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-12 17:32:52.374+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7688cf32', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (358, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:32:53.468+02', 'USER_MOVED_VM_DISK_FINISHED_SUCCESS', 2010, 0, 'User admin@internal finished to move the disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (354, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:32:27.079+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain ext333 was added by admin@internal', false, NULL, '', '4016d559-2560-490c-a6a4-53229a4542b1', 'ext333', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '5ee147fa', 'edb22098-3672-4269-8475-5139741f7206', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (359, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:33:16.646+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (360, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 17:33:17.031+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain ext333 (Data Center POSIX_EXT4_hateya) was activated by admin@internal', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', '4016d559-2560-490c-a6a4-53229a4542b1', 'ext333', '00000000-0000-0000-0000-000000000000', '', '42f9d498', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (361, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:33:17.048+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center POSIX_EXT4_hateya by admin@internal', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '509145f7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (362, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 17:33:17.103+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain ext333 was attached to Data Center POSIX_EXT4_hateya by admin@internal', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', '4016d559-2560-490c-a6a4-53229a4542b1', 'ext333', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '2c739099', '995f4987-2505-452e-b43a-10612244d474', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (363, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:33:28.791+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of XP_iSCSI_Disk1 creation for VM XP was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '41a260b4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (364, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:33:28.844+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (365, '00000000-0000-0000-0000-000000000000', NULL, 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:33:31.623+02', 'VM_DOWN', 61, 0, 'VM XP is down. Exit message: User shut down', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (366, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:33:34.389+02', 'USER_CREATE_SNAPSHOT_FINISHED_FAILURE', 69, 2, 'Failed to complete Snapshot Auto-generated for Live Storage Migration of XP_iSCSI_Disk1 creation for VM XP.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (367, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:33:35.165+02', 'USER_MOVED_VM_DISK_FINISHED_FAILURE', 2011, 2, 'User admin@internal have failed to move the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (368, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:33:45.229+02', 'USER_STARTED_VM', 153, 0, 'VM XP was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3359cd1a', '0b0c47ee-774f-4300-945b-15be0c6bae2b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (369, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:34:45.457+02', 'USER_RUN_VM', 32, 0, 'VM XP started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3359cd1a', '0b0c47ee-774f-4300-945b-15be0c6bae2b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (370, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:36:15.055+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of XP_iSCSI_Disk1 creation for VM XP was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '47d75961', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (371, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:36:15.09+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (372, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:36:45.183+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of XP_iSCSI_Disk1 creation for VM XP has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (373, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:36:45.991+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (374, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:36:46.001+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (375, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:36:55.416+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (376, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:36:55.806+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (377, '00000000-0000-0000-0000-000000000000', NULL, 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:37:49.697+02', 'VM_DOWN', 61, 0, 'VM XP is down. Exit message: User shut down', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (378, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:39:51.984+02', 'USER_MOVED_VM_DISK_FINISHED_FAILURE', 2011, 2, 'User admin@internal have failed to move the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (379, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:40:02.008+02', 'USER_MOVED_VM_DISK_FINISHED_FAILURE', 2011, 2, 'User admin@internal have failed to move the disk XP_iSCSI_Disk1 to domain Dafna-si25-01.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (380, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:44:20.387+02', 'USER_STARTED_VM', 153, 0, 'VM XP was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '21d57419', '3733a27e-11c1-4f0f-b5e7-4e28d7c75713', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (381, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:45:21.3+02', 'USER_RUN_VM', 32, 0, 'VM XP started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '21d57419', '3733a27e-11c1-4f0f-b5e7-4e28d7c75713', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (382, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:51:06.302+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 1 creation for VM XP was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6cb88709', '558e49d6-29fb-4dfb-b823-f929269eda97', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (383, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:51:41.961+02', 'USER_CREATE_LIVE_SNAPSHOT_FINISHED_FAILURE', 170, 1, 'Failed to configure VM XP with Live-Snapshot 1. VM restart is recommended.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6cb88709', '558e49d6-29fb-4dfb-b823-f929269eda97', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (384, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:51:42.276+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 1 creation for VM XP has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6cb88709', '558e49d6-29fb-4dfb-b823-f929269eda97', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (385, '00000000-0000-0000-0000-000000000000', NULL, 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:51:43.638+02', 'VM_DOWN_ERROR', 119, 2, 'VM XP is down. Exit message: Domain not found: no domain with matching uuid ''a912e6de-671c-4ecd-8dc2-08a2e17bbca2''.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (396, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:26.719+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-2 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2a5c10ed', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (400, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:31.892+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-6 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5bfd3bcf', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (409, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:40.518+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-10 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '677f27b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (416, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:45.95+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-8 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6d3f6c32', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (417, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:01:13.318+02', 'IMPORTEXPORT_IMPORT_TEMPLATE', 1158, 0, 'Template NFS-RHEL6_iSCSI was imported successfully to Data Center iSCSI, Cluster iSCSI', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35ba64c', '65664a07-0c91-4d8c-b32d-a437e0428dc8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (420, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:02:05.94+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (426, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:04:19.483+02', 'USER_REMOVE_STORAGE_DOMAIN', 960, 0, 'Storage Domain ext333 was removed by admin@internal', false, NULL, '', '4016d559-2560-490c-a6a4-53229a4542b1', 'ext333', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '7d6adf36', 'a74470d3-45d8-4f8f-a23c-5ad01b3758dc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (386, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:53:47.979+02', 'USER_TRY_BACK_TO_SNAPSHOT', 46, 0, 'Snapshot-Preview for VM XP was initiated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '269c565c', '95106c08-b5cd-4ac7-909e-e4fe3ddf0175', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (387, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:53:52.715+02', 'USER_TRY_BACK_TO_SNAPSHOT_FINISH_SUCCESS', 71, 0, 'Snapshot-Preview for VM XP has been completed.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '269c565c', '95106c08-b5cd-4ac7-909e-e4fe3ddf0175', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (390, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:56:03.203+02', 'USER_STARTED_VM', 153, 0, 'VM XP was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '27913cfe', '0aa3c1a8-4584-45ac-bfc9-94c981bfe0f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (395, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:25.872+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-1 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2e6ec99d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (443, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:33.875+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-4 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '24042bda', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (458, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:48.401+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-7 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4d3632d4', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (388, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:55:33.275+02', 'USER_RESTORE_FROM_SNAPSHOT_START', 1190, 0, 'Restoring VM XP from snapshot started by user admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7ac15191', '6dba0977-c1da-4f8e-af73-b5c0b15cb88d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (393, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:58:17.908+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5de155bd', 'ab5a4f61-24d0-46ae-8c0c-19f90faf8cb7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (410, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:40.709+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool XP (containing 10 VMs) was created by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '00000000-0000-0000-0000-000000000000', '', '4fb3f4c6', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (412, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:43.755+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-10 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '677f27b', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (439, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:27.571+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-2 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '391eadca', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (440, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:05:28.833+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '50803d83', '2d8d9aac-7e5b-4cc5-9620-8b2680385335', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (444, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:34.45+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-3 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5768ce04', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (447, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:37.397+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-5 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '542022c6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (449, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:41.088+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-7 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4d3632d4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (450, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:05:42.189+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '651c56aa', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (459, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:48.52+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-6 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '83452cb', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (464, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:05:52.569+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '74a5c2dc', '02e11058-34ff-422a-88d8-4783feb4f18a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (466, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:05:53.251+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (389, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:55:42.331+02', 'USER_RESTORE_FROM_SNAPSHOT_FINISH_SUCCESS', 100, 0, 'VM XP restoring from Snapshot has been completed.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7ac15191', '6dba0977-c1da-4f8e-af73-b5c0b15cb88d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (391, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:57:04.331+02', 'USER_RUN_VM', 32, 0, 'VM XP started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '27913cfe', '0aa3c1a8-4584-45ac-bfc9-94c981bfe0f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (392, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 17:57:57.697+02', 'USER_STOP_VM', 33, 0, 'VM XP stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '366101fd', '8b32fbd3-3f7d-4d87-aa4d-9777dbd2233d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (394, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a912e6de-671c-4ecd-8dc2-08a2e17bbca2', 'XP', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-12 17:58:22.438+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5de155bd', 'ab5a4f61-24d0-46ae-8c0c-19f90faf8cb7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (397, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:27.691+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-3 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3ed8e758', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (398, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:29.184+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-4 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '41e60a41', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (399, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:30.522+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-5 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'd4b3c05', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (401, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:32.854+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-5 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'd4b3c05', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (402, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:35.322+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-4 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '41e60a41', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (403, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:35.656+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-2 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2a5c10ed', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (404, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:35.756+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-3 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3ed8e758', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (405, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:35.792+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-7 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2e4e7601', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (406, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:36.137+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-1 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2e6ec99d', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (407, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:37.141+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-8 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6d3f6c32', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (408, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:38.527+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-9 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '739f01be', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (411, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 17:59:41.541+02', 'IMPORTEXPORT_STARTING_IMPORT_TEMPLATE', 1163, 0, 'Starting to import Template NFS-RHEL6_iSCSI to Data Center iSCSI, Cluster iSCSI', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35ba64c', '65664a07-0c91-4d8c-b32d-a437e0428dc8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (413, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:43.907+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-6 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5bfd3bcf', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (414, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:44.098+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-7 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2e4e7601', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (415, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 17:59:45.818+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-9 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '739f01be', 'bf3b0c74-f902-447f-bfa8-47b7cb062bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (418, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 18:01:26.058+02', 'USER_DEACTIVATED_STORAGE_DOMAIN', 968, 0, 'Storage Domain ext333 (Data Center POSIX_EXT4_hateya) was deactivated by admin@internal', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', '4016d559-2560-490c-a6a4-53229a4542b1', 'ext333', '00000000-0000-0000-0000-000000000000', '', '57a407d9', '5e702f74-3428-4dc0-b4d4-068e860ade3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (419, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-12 18:01:44.005+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', NULL, '', '00000000-0000-0000-0000-000000000000', '', '460a6022', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (421, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:02:11.574+02', 'USER_REMOVE_STORAGE_POOL', 954, 0, 'Data Center POSIX_EXT4_hateya was removed by admin@internal', false, '36377726-7ef6-4c34-ae37-e61f517feb1e', 'POSIX_EXT4_hateya', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '51fc609b', '6ec0efcf-a3ba-4ad6-b649-bbe474c0610c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (422, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:02:19.142+02', 'USER_REMOVE_STORAGE_POOL', 954, 0, 'Data Center POSIX_EXT4 was removed by admin@internal', false, 'e1180de1-7b00-4b77-8cf2-102112a3ca38', 'POSIX_EXT4', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', '6a24911e', '345c081e-e500-49d1-bf43-593cbcc48983', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (425, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:02:26.051+02', 'USER_REMOVE_STORAGE_DOMAIN_FAILED', 961, 2, 'Failed to remove Storage Domain ext333. (User: admin@internal)', false, NULL, '', '4016d559-2560-490c-a6a4-53229a4542b1', 'ext333', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'e7d8e56', '6897c871-02c9-4c52-a4d1-d0082aaa360e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (427, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:11.024+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-1 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '38a02ea5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (920, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:27:05.538+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster EDU was added by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '2ea41f05', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (428, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:11.662+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-2 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2ddfef73', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (429, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:11.845+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-3 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '75500862', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (430, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:11.935+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-4 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '569e2a32', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (431, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:12.03+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-5 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '71017335', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (432, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:12.134+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-6 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '49710daf', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (433, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:12.398+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-7 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4d9a8dc1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (434, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:12.421+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-8 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '110d19d2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (435, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:12.508+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-9 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '46a8224c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (436, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:05:12.586+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-10 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1155507a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (437, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 18:05:12.782+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool XP was removed by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35bf7bad', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (438, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:25.766+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-1 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4546264d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (441, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:31.722+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-3 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5768ce04', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (442, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:05:31.842+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '6ffe13e0', 'd0df527d-4e29-4405-b703-7e9415607235', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (448, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:38.887+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-6 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '83452cb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (451, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:05:42.601+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '36e6d299', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (452, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:43.372+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-8 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '48ea78b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (453, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:47.696+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-5 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '542022c6', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (456, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:05:48.111+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7533dbd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (457, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:48.263+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-4 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '24042bda', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (445, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:37.08+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-1 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4546264d', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (446, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:37.234+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-2 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '391eadca', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (460, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:48.788+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-8 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '48ea78b', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (461, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:49.294+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-10 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3706cd8d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (467, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:57.822+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-9 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '49b14557', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (454, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:05:47.714+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '70dd8be3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (455, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:47.735+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL6-9 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '49b14557', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (462, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:49.447+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool RHEL6 (containing 10 VMs) was created by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7db3c081', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (463, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:05:52.515+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '51287360', '75e14e67-23bb-41cf-96a5-8ce05b50b925', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (465, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:05:52.919+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (468, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:05:58.1+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL6-10 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3706cd8d', '4d0bf222-5db6-4b24-a84f-d5f801981fd9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (469, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:11.877+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-1 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '70ce8766', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (470, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:11.957+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-10 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3b1622da', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (471, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.009+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-3 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5e7f8a79', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (472, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.068+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-4 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '784ed7ed', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (473, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.149+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-5 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2cd6da6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (474, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.232+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-6 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5bf79134', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (475, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.267+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-7 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '566acd2f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (476, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.363+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-8 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'f017dec', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (477, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.422+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-9 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'ee39f50', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (478, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:12:12.474+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL6-2 was removed from VM Pool RHEL6 by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '67341699', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (479, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 18:12:12.547+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool RHEL6 was removed by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5c703196', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (480, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:12:57.658+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-1 was started by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6fd1e687', 'b8301334-f3d9-4625-9ec0-5ee7be07c81e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (481, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:12:58.13+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-2 was started by admin@internal (Host: gold-vdsc).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3bb47e3f', '248d76bf-de5a-4fe8-882b-855535b65713', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (482, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:12:58.422+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-3 was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '286d4395', '3e04a95d-d2b2-4fbe-86ab-49d249252eff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (483, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:12:58.724+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-4 was started by admin@internal (Host: gold-vdsc).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '12290a00', '2d5400be-e935-4d53-94e9-57d2da3ca69e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (484, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:12:59.119+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-5 was started by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '13796e7d', '0dc5c8c0-185e-44ca-a475-c2d04b67f4c2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (485, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:12:59.56+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-6 was started by admin@internal (Host: gold-vdsc).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2a458cec', '7b66fb8a-f2fb-4e17-b4a4-36b1d9dd44e4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (486, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:13:00.504+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-7 was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35e07f4a', 'ed8c01d2-0a75-45db-8b32-ba6c217a9a61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (487, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:13:00.734+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-8 was started by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '617c6b47', '7fe939f6-df05-4afa-8836-308bb3b9aa0f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (488, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:13:00.991+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-9 was started by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '59b3f6c7', '3c00429d-eeab-497f-a8b0-eddad5402a5b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (489, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:13:01.404+02', 'USER_STARTED_VM', 153, 0, 'VM RHEL6-10 was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '56fd1fc9', '40222450-0396-497c-bc53-97e4f6254684', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (490, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:13:01.869+02', 'USER_STARTED_VM', 153, 0, 'VM XP-1 was started by admin@internal (Host: gold-vdsc).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '375096e0', '937222b0-e333-4b14-8d8c-78c4864b97d2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (491, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:13:02.409+02', 'USER_STARTED_VM', 153, 0, 'VM XP-2 was started by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '36aec01a', '21ccceee-1b13-4a91-9f71-41398a2b6abf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (498, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:13:06.278+02', 'USER_STARTED_VM', 153, 0, 'VM XP-9 was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '72cdff39', '39ee78dd-fba5-4820-a702-b0ed334466b8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (506, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:14:02.67+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-8 started on Host gold-vdsd', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '617c6b47', '7fe939f6-df05-4afa-8836-308bb3b9aa0f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (507, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:14:02.968+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-9 started on Host gold-vdsd', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '59b3f6c7', '3c00429d-eeab-497f-a8b0-eddad5402a5b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (510, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:14:03.099+02', 'USER_RUN_VM', 32, 0, 'VM XP-2 started on Host gold-vdsd', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '36aec01a', '21ccceee-1b13-4a91-9f71-41398a2b6abf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (518, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:14:07.802+02', 'USER_RUN_VM', 32, 0, 'VM XP-8 started on Host gold-vdsc', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '76adf1a2', 'be87a546-5c86-4250-912d-4cb15330ad00', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (519, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:14:08.026+02', 'USER_RUN_VM', 32, 0, 'VM XP-10 started on Host gold-vdsc', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3259d650', '6a9b2b37-dbb4-4ea6-b3b2-2cb2f2356b18', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (520, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-12 18:15:10.578+02', 'USER_COPIED_TEMPLATE_DISK', 2004, 0, 'User admin@internal is copying template disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '00000000-0000-0000-0000-000000000000', '', '7ae266f', '9621e503-fc9f-40e3-b9f4-589f03ae8ae7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (539, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:47.244+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-2 has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (492, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:13:02.97+02', 'USER_STARTED_VM', 153, 0, 'VM XP-3 was started by admin@internal (Host: gold-vdsc).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '754b827', '88812e73-9d91-4047-bd2d-8aac45b3a949', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (495, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:13:04.482+02', 'USER_STARTED_VM', 153, 0, 'VM XP-6 was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '59a4e42e', 'da7355d4-0148-454b-83be-96af7a5303fe', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (548, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:50.82+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (549, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:50.843+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (566, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:57.663+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (567, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:57.678+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (493, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:13:03.485+02', 'USER_STARTED_VM', 153, 0, 'VM XP-4 was started by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '283227ba', '1e0a615d-ea26-47b8-ab90-43ac47b06e42', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (494, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:13:03.966+02', 'USER_STARTED_VM', 153, 0, 'VM XP-5 was started by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6e6efd7d', '19724247-1a4d-4250-932d-a688061f5667', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (497, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:13:05.827+02', 'USER_STARTED_VM', 153, 0, 'VM XP-8 was started by admin@internal (Host: gold-vdsc).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '76adf1a2', 'be87a546-5c86-4250-912d-4cb15330ad00', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (499, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:13:06.704+02', 'USER_STARTED_VM', 153, 0, 'VM XP-10 was started by admin@internal (Host: gold-vdsc).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3259d650', '6a9b2b37-dbb4-4ea6-b3b2-2cb2f2356b18', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (503, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:14:00.407+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-3 started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '286d4395', '3e04a95d-d2b2-4fbe-86ab-49d249252eff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (521, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-12 18:15:13.947+02', 'USER_COPIED_TEMPLATE_DISK', 2004, 0, 'User admin@internal is copying template disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '00000000-0000-0000-0000-000000000000', '', '737fdc6b', 'a6391350-96d5-45c0-bcb6-3db2382286d1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (523, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 18:17:31.406+02', 'USER_COPIED_TEMPLATE_DISK_FINISHED_SUCCESS', 2006, 0, 'User admin@internal finished to copy the template disk XP_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '00000000-0000-0000-0000-000000000000', '', '737fdc6b', 'a6391350-96d5-45c0-bcb6-3db2382286d1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (524, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:17:55.652+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-1 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1557bad0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (525, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:17:55.691+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (526, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:01.744+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-10 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'b5b3846', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (530, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:12.412+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-3 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1a21e339', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (531, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:12.491+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (540, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:47.284+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-10 has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (541, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:47.309+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-3 has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (542, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:47.897+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (543, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:47.91+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (544, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:18:48.413+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (545, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:18:48.449+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (546, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:49.186+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (547, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:49.212+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (551, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:19:01.734+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (552, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:19:01.756+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (590, '00000000-0000-0000-0000-000000000000', NULL, '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:12.639+02', 'VM_DOWN', 61, 0, 'VM XP-2 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (496, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:13:05.517+02', 'USER_STARTED_VM', 153, 0, 'VM XP-7 was started by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6d6b8440', 'c906c3dc-c855-4e62-8b23-ff6b4bf5c8a5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (500, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:13:57.725+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-1 started on Host gold-vdsd', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6fd1e687', 'b8301334-f3d9-4625-9ec0-5ee7be07c81e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (501, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:14:00.407+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-6 started on Host gold-vdsc', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2a458cec', '7b66fb8a-f2fb-4e17-b4a4-36b1d9dd44e4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (502, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:14:00.409+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-5 started on Host gold-vdsd', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '13796e7d', '0dc5c8c0-185e-44ca-a475-c2d04b67f4c2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (504, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:14:00.501+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-4 started on Host gold-vdsc', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '12290a00', '2d5400be-e935-4d53-94e9-57d2da3ca69e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (505, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:14:00.569+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-2 started on Host gold-vdsc', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3bb47e3f', '248d76bf-de5a-4fe8-882b-855535b65713', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (508, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:14:03.017+02', 'USER_RUN_VM', 32, 0, 'VM XP-1 started on Host gold-vdsc', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '375096e0', '937222b0-e333-4b14-8d8c-78c4864b97d2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (509, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:14:03.09+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-7 started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35e07f4a', 'ed8c01d2-0a75-45db-8b32-ba6c217a9a61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (511, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:14:03.216+02', 'USER_RUN_VM', 32, 0, 'VM RHEL6-10 started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '56fd1fc9', '40222450-0396-497c-bc53-97e4f6254684', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (512, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:14:05.487+02', 'USER_RUN_VM', 32, 0, 'VM XP-7 started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6d6b8440', 'c906c3dc-c855-4e62-8b23-ff6b4bf5c8a5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (513, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:14:05.559+02', 'USER_RUN_VM', 32, 0, 'VM XP-3 started on Host gold-vdsc', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '754b827', '88812e73-9d91-4047-bd2d-8aac45b3a949', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (514, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:14:05.579+02', 'USER_RUN_VM', 32, 0, 'VM XP-6 started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '59a4e42e', 'da7355d4-0148-454b-83be-96af7a5303fe', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (515, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:14:05.7+02', 'USER_RUN_VM', 32, 0, 'VM XP-4 started on Host gold-vdsd', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '283227ba', '1e0a615d-ea26-47b8-ab90-43ac47b06e42', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (516, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:14:05.76+02', 'USER_RUN_VM', 32, 0, 'VM XP-5 started on Host gold-vdsd', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6e6efd7d', '19724247-1a4d-4250-932d-a688061f5667', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (517, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:14:07.757+02', 'USER_RUN_VM', 32, 0, 'VM XP-9 started on Host camel-vdsb', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '72cdff39', '39ee78dd-fba5-4820-a702-b0ed334466b8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (522, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 18:17:09.582+02', 'USER_COPIED_TEMPLATE_DISK_FINISHED_SUCCESS', 2006, 0, 'User admin@internal finished to copy the template disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '00000000-0000-0000-0000-000000000000', '', '7ae266f', '9621e503-fc9f-40e3-b9f4-589f03ae8ae7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (527, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:18:01.839+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (528, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:05.783+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-2 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5196ff6f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (529, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:05.872+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (532, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:17.342+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-4 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '327bee27', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (533, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:17.359+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (534, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:18:25.951+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-1 has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (535, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:18:26.846+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (536, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:18:26.86+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (537, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:18:27.314+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-5 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'b8aba19', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (538, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:18:27.359+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (550, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:18:57.581+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-4 has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (553, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:02.312+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot Auto-generated for Live Storage Migration of NFS-RHEL6_iSCSI_Disk1 creation for VM RHEL6-5 has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (554, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:05.376+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (555, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:05.513+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (556, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:19:11.035+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (557, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:19:11.125+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (558, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:19:11.646+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (559, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:19:11.685+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (560, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:19:20.223+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (561, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:19:20.358+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (562, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:19:43.872+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (563, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:19:43.904+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (568, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:58.545+02', 'USER_MOVED_VM_DISK_FINISHED_SUCCESS', 2010, 0, 'User admin@internal finished to move the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (564, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:48.436+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (565, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:19:48.502+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (569, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:20:47.802+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (570, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:20:47.826+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (571, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:20:50.781+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (572, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:20:50.827+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (573, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:20:52.131+02', 'USER_MOVED_VM_DISK_FINISHED_SUCCESS', 2010, 0, 'User admin@internal finished to move the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (574, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:20:52.145+02', 'USER_MOVED_VM_DISK_FINISHED_SUCCESS', 2010, 0, 'User admin@internal finished to move the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (575, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:20:55.971+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (576, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:20:56.007+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (577, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-12 18:21:02.527+02', 'USER_MOVED_VM_DISK_FINISHED_SUCCESS', 2010, 0, 'User admin@internal finished to move the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (578, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:21:09.404+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (579, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:21:09.441+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (580, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-12 18:21:12.942+02', 'USER_MOVED_VM_DISK_FINISHED_SUCCESS', 2010, 0, 'User admin@internal finished to move the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (581, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:21:25.587+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (582, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:21:25.675+02', 'USER_MOVED_VM_DISK', 2008, 0, 'User admin@internal moving the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (583, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-12 18:21:33.522+02', 'USER_MOVED_VM_DISK_FINISHED_SUCCESS', 2010, 0, 'User admin@internal finished to move the disk NFS-RHEL6_iSCSI_Disk1 to domain Dafna-si25-02.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'Dafna-si25-02', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (584, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-12 18:42:13.233+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '27ce49bf', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (585, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 09:46:11.497+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (586, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:04:54.95+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '63badb89', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (587, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:04:57.564+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3a528d25', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (588, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:09.418+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-2, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2d05ee88', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (589, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:12.127+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-5, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35edcceb', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (601, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 10:07:21.404+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center upgrade was added by admin@internal', false, NULL, 'upgrade', NULL, '', '00000000-0000-0000-0000-000000000000', '', '18e682d4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (591, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:13.186+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-4, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2ac86182', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (592, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:13.207+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: RHEL6-8, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2535ead0', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (593, '00000000-0000-0000-0000-000000000000', NULL, '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:15.011+02', 'VM_DOWN', 61, 0, 'VM XP-4 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (594, '00000000-0000-0000-0000-000000000000', NULL, 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:15.133+02', 'VM_DOWN', 61, 0, 'VM RHEL6-8 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (595, '00000000-0000-0000-0000-000000000000', NULL, 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:15.237+02', 'VM_DOWN', 61, 0, 'VM XP-5 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (596, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:15.36+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-5, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '515619bf', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (597, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:17.845+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: RHEL6-9, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6f16517a', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (598, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:44.879+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3a528d25', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (599, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:05:44.969+02', 'VM_MIGRATION_FAILED_DURING_MOVE_TO_MAINTANANCE', 140, 2, 'VM migration failed due to Error: Fatal error during migration while Host is in ''preparing for maintenance'' state.
  Consider manual intervention: stopping/migrating Vms as Host''s state will not
  turn to maintenance while VMs are still running on it.(VM: RHEL6-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3a528d25', 'f89590d7-5ab0-47cf-8c18-3477b8e968f7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (600, '00000000-0000-0000-0000-000000000000', NULL, '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 10:05:46.421+02', 'VM_DOWN_ERROR', 119, 2, 'VM RHEL6-5 is down. Exit message: Domain not found: no domain with matching uuid ''516b826e-7136-4a24-b5fc-9363466d4588''.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (602, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 10:07:30.257+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster Upgrade was added by admin@internal', false, 'e1b30f83-a2e4-4fad-8bba-418d4700a8c4', 'upgrade', NULL, '', '24129ce4-44fc-11e2-8dc2-001a4a169741', 'Upgrade', '7193dcd3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (603, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:10:23.634+02', 'VM_MIGRATION_START', 62, 0, 'Starting migration of VM RHEL6-1 from Host gold-vdsd to Host gold-vdsc (User: admin@internal.).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1626e0c7', '87f68409-c1c9-40a1-b241-9a0ebf2841cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (604, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:10:56.626+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1626e0c7', '87f68409-c1c9-40a1-b241-9a0ebf2841cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (605, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:10:57.592+02', 'VM_MIGRATION_START', 62, 0, 'Starting migration of VM RHEL6-1 from Host gold-vdsd to Host camel-vdsb (User: admin@internal.).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1626e0c7', '87f68409-c1c9-40a1-b241-9a0ebf2841cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (606, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:11:29.922+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1626e0c7', '87f68409-c1c9-40a1-b241-9a0ebf2841cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (607, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:11:30.058+02', 'VM_MIGRATION_FAILED_DURING_MOVE_TO_MAINTANANCE', 140, 2, 'VM migration failed due to Error: Fatal error during migration while Host is in ''preparing for maintenance'' state.
  Consider manual intervention: stopping/migrating Vms as Host''s state will not
  turn to maintenance while VMs are still running on it.(VM: RHEL6-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1626e0c7', '87f68409-c1c9-40a1-b241-9a0ebf2841cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (611, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:14:54.992+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '460554bc', '588fa0ab-11ef-4579-959c-351a97d0b374', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (612, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:14:55.179+02', 'VM_MIGRATION_FAILED_DURING_MOVE_TO_MAINTANANCE', 140, 2, 'VM migration failed due to Error: Fatal error during migration while Host is in ''preparing for maintenance'' state.
  Consider manual intervention: stopping/migrating Vms as Host''s state will not
  turn to maintenance while VMs are still running on it.(VM: RHEL6-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '460554bc', '588fa0ab-11ef-4579-959c-351a97d0b374', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (613, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 11:12:17.445+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '20dbd813', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (614, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 11:18:12.823+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (620, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:25:54.468+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (632, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:54.95+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (633, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:56.106+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SET_SYSTEM_TIME; Details: setSystemTime ended successfully.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (634, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.636+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHN_REGISTRATION; Details: Host properly registered with RHN/Satellite..', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (608, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:13:50.101+02', 'VM_MIGRATION_START', 62, 0, 'Starting migration of VM RHEL6-1 from Host gold-vdsd to Host gold-vdsc (User: admin@internal.).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '460554bc', '588fa0ab-11ef-4579-959c-351a97d0b374', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (609, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:14:22.552+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '460554bc', '588fa0ab-11ef-4579-959c-351a97d0b374', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (610, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 10:14:22.977+02', 'VM_MIGRATION_START', 62, 0, 'Starting migration of VM RHEL6-1 from Host gold-vdsd to Host camel-vdsb (User: admin@internal.).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '460554bc', '588fa0ab-11ef-4579-959c-351a97d0b374', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (615, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 11:18:23.755+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-1 stopped by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '34084e7e', '0fda0c00-b3a8-4041-a9a5-76135c51b7fb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (616, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 11:18:28.882+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-5 stopped by admin@internal (Host: gold-vdsd).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3e4d2f28', 'd5927f1d-1193-45ed-9839-d96eb60e322a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (617, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 11:18:43.896+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '63e4c043', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (618, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 11:18:44.207+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '24129ce4-44fc-11e2-8dc2-001a4a169741', 'Upgrade', '52e94dc7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (619, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:12:15.161+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '647d1339', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (621, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:10.303+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '24129ce4-44fc-11e2-8dc2-001a4a169741', 'Upgrade', '6db3d9a4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (622, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:10.418+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '99408929-82cf-4dc7-a532-9d998063fa95', 'Default', '37afe75d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (623, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:26:15.455+02', 'USER_REMOVE_STORAGE_POOL', 954, 0, 'Data Center upgrade was removed by admin@internal', false, 'e1b30f83-a2e4-4fad-8bba-418d4700a8c4', 'upgrade', NULL, '', '00000000-0000-0000-0000-000000000000', '', '588c8607', '9bae5219-cad9-4e9c-bf10-489c29edac75', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (624, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:26:19.146+02', 'USER_REMOVE_VDS_GROUP', 813, 0, 'Host cluster Upgrade was removed by admin@internal', false, NULL, '', NULL, '', '24129ce4-44fc-11e2-8dc2-001a4a169741', 'Upgrade', '2a0bcdeb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (625, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:26:22.914+02', 'USER_REMOVE_VDS_GROUP', 813, 0, 'Host cluster POSIX_EXT4 was removed by admin@internal', false, NULL, '', NULL, '', 'ae7ad4b2-4459-11e2-b4a1-001a4a169741', 'POSIX_EXT4', 'b2c55f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (626, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:26:22.955+02', 'USER_REMOVE_VDS_GROUP', 813, 0, 'Host cluster POSOSOS was removed by admin@internal', false, NULL, '', NULL, '', '049121c4-4470-11e2-837d-001a4a169741', 'POSOSOS', '58bbe054', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (627, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:26:33.382+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center Upgrade was added by admin@internal', false, NULL, 'Upgrade', NULL, '', '00000000-0000-0000-0000-000000000000', '', '44ddd66c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (628, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 12:26:40.138+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster Upgrade was added by admin@internal', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '750570a5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (629, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:43.509+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '99408929-82cf-4dc7-a532-9d998063fa95', 'Default', '71152ea3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (630, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:54.021+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '7e36c6eb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (631, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:54.371+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL; Details: Connected to Host gold-vdsd.qa.lab.tlv.redhat.com with SSH key fingerprint: 08:9f:23:94:2c:0c:5a:80:72:5d:36:b4:e5:46:86:b2.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (657, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:28.76+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (667, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:56:51.595+02', 'VDS_FAILURE', 12, 2, 'Host gold-vdsd is non-responsive.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (669, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:58:38.401+02', 'USER_REMOVE_VDS', 44, 0, 'Host gold-vdsd was removed by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '4bbdbe3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (670, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:58:55.176+02', 'VDS_ALERT_FENCING_IS_NOT_CONFIGURED', 9000, 10, 'Failed to verify Power Management configuration for Host gold-vdsd.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (672, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:58:55.417+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL; Details: Connected to Host gold-vdsd.qa.lab.tlv.redhat.com with SSH key fingerprint: 08:9f:23:94:2c:0c:5a:80:72:5d:36:b4:e5:46:86:b2.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (693, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.567+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-img-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-img).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (694, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.62+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (695, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.666+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (696, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:12.37+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-kvm-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-kvm).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (701, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:26.224+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (635, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.796+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDSM_MAJOR_VER; Details: Available VDSM matches requirements.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (636, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.825+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VT_SVM; Details: Server supports virtualization.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (637, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.863+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: OS; Details: Supported platform version.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (638, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.898+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: KERNEL; Details: Supported kernel version: 220.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (639, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.938+02', 'VDS_INSTALL_IN_PROGRESS_WARNING', 510, 1, 'Host gold-vdsd installation in progress . Step: REQ PACKAGES; Details: package SDL.x86_64 is not installed   (SDL.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (640, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.962+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: bridge-utils-1.2-9.el6.x86_64   (bridge-utils.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (641, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:26:59.992+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: mesa-libGLU-7.11-3.el6.x86_64   (mesa-libGLU.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (642, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.021+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: openssl-1.0.0-20.el6.x86_64   (openssl.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (643, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.053+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: m2crypto-0.20.2-7.el6.x86_64   (m2crypto.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (644, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.087+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: rsync-3.0.6-5.el6_0.1.x86_64   (rsync.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (645, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.12+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-kvm-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-kvm).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (646, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.159+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9-105.el6.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (647, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.188+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (648, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.217+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (649, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.24+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (650, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.263+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (651, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.299+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-img-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-img).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (652, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.357+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (653, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:00.378+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (658, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:30.855+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (659, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:34.019+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (662, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:40.23+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (663, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:42.302+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (664, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:44.15+02', 'VDS_INSTALL_IN_PROGRESS_ERROR', 511, 2, 'Failed to install Host gold-vdsd. Step: VDS PACKAGES; Details: Loaded plugins: product-id, rhnplugin, security, subscription-manager Updating certificate-based repositories. Setting up Install Process No package sanlock-python available. Error: Nothing to do   (sanlock-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (665, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:44.318+02', 'VDS_INSTALL_FAILED', 505, 2, 'Host gold-vdsd installation failed. SSH command failed while executing at host ''gold-vdsd.qa.lab.tlv.redhat.com'', refer to logs for further information.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '1263a041', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (666, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:56:46.701+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '25bd0ba9', '869800aa-1714-4987-96d9-35ca6edee2dc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (668, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:57:20.381+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '16402b0', 'c4393538-122d-489b-909e-e6ce9759a2b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (654, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:21.695+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: SDL-1.2.14-3.el6.x86_64   (SDL.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (655, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:24.532+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-kvm-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-kvm).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (656, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:26.674+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9-105.el6.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (660, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:36.139+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (661, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '6e15dbdc-445a-11e2-9775-001a4a169741', 'gold-vdsd', '2012-12-13 12:27:38.132+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-img-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-img).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (671, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:58:55.263+02', 'USER_ADD_VDS', 42, 0, 'Host gold-vdsd was added by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '30740ddf', 'e320255e-fa47-4801-af0b-d373a2df815b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (673, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:58:56.034+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (674, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:58:58.133+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SET_SYSTEM_TIME; Details: setSystemTime ended successfully.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (675, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:00.856+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHN_REGISTRATION; Details: Host properly registered with RHN/Satellite..', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (676, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:01.584+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDSM_MAJOR_VER; Details: Available VDSM matches requirements.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (677, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:01.627+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VT_SVM; Details: Server supports virtualization.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (678, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:01.77+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: OS; Details: Supported platform version.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (679, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:01.852+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: KERNEL; Details: Supported kernel version: 220.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (680, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:01.889+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: SDL-1.2.14-3.el6.x86_64   (SDL.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (681, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:01.973+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: bridge-utils-1.2-9.el6.x86_64   (bridge-utils.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (682, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.08+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: mesa-libGLU-7.11-3.el6.x86_64   (mesa-libGLU.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (683, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.134+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: openssl-1.0.0-20.el6.x86_64   (openssl.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (684, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.22+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: m2crypto-0.20.2-7.el6.x86_64   (m2crypto.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (685, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.236+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: rsync-3.0.6-5.el6_0.1.x86_64   (rsync.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (686, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.245+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-kvm-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-kvm).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (687, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.295+02', 'VDS_INSTALL_IN_PROGRESS_WARNING', 510, 1, 'Host gold-vdsd installation in progress . Step: VDS PACKAGES; Details: package qemu-kvm-tools is not installed   (qemu-kvm-tools).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (688, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.347+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9-105.el6.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (689, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.423+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (690, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.466+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (691, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.507+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (692, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:02.523+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (697, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:15.072+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9-105.el6.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (698, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:17.6+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (699, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:20.311+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (700, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:23.125+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (704, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:34.775+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (702, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:29.438+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-img-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-img).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (703, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:32.08+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (705, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:37.428+02', 'VDS_INSTALL_IN_PROGRESS_ERROR', 511, 2, 'Failed to install Host gold-vdsd. Step: VDS PACKAGES; Details: Loaded plugins: product-id, rhnplugin, security, subscription-manager Updating certificate-based repositories. Setting up Install Process No package sanlock-python available. Error: Nothing to do   (sanlock-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (706, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 12:59:37.804+02', 'VDS_INSTALL_FAILED', 505, 2, 'Host gold-vdsd installation failed. SSH command failed while executing at host ''gold-vdsd.qa.lab.tlv.redhat.com'', refer to logs for further information.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '350b5a1', 'e320255e-fa47-4801-af0b-d373a2df815b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (707, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:27.25+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '78843b90', '752c1743-4cc9-4e73-9731-72012fe177d8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (708, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:32.705+02', 'VDS_FAILURE', 12, 2, 'Host gold-vdsd is non-responsive.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (709, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:37.694+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '120ec5e', 'ce08e8d2-a9e5-47a6-99a5-73a727c45ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (710, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:50.273+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '3f887602', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (711, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:50.326+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL; Details: Connected to Host gold-vdsd.qa.lab.tlv.redhat.com with SSH key fingerprint: 08:9f:23:94:2c:0c:5a:80:72:5d:36:b4:e5:46:86:b2.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (712, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:50.939+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (713, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:52.038+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SET_SYSTEM_TIME; Details: setSystemTime ended successfully.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (714, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:01:59.847+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHN_REGISTRATION; Details: Host properly registered with RHN/Satellite..', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (715, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:00.029+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDSM_MAJOR_VER; Details: Available VDSM matches requirements.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (716, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:00.166+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VT_SVM; Details: Server supports virtualization.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (717, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:00.289+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: OS; Details: Supported platform version.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (718, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:00.332+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: KERNEL; Details: Supported kernel version: 220.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (719, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:00.374+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: SDL-1.2.14-3.el6.x86_64   (SDL.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (720, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:00.536+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: bridge-utils-1.2-9.el6.x86_64   (bridge-utils.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (721, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:01.04+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: mesa-libGLU-7.11-3.el6.x86_64   (mesa-libGLU.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (722, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:01.935+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: openssl-1.0.0-20.el6.x86_64   (openssl.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (723, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.017+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: m2crypto-0.20.2-7.el6.x86_64   (m2crypto.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (724, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.159+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: REQ PACKAGES; Details: rsync-3.0.6-5.el6_0.1.x86_64   (rsync.x86_64).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (725, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.234+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-kvm-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-kvm).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (726, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.278+02', 'VDS_INSTALL_IN_PROGRESS_WARNING', 510, 1, 'Host gold-vdsd installation in progress . Step: VDS PACKAGES; Details: package qemu-kvm-tools is not installed   (qemu-kvm-tools).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (727, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.36+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9-105.el6.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (728, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.583+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (729, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.603+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (730, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:03.66+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (731, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:04.101+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (733, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:05.385+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (735, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:05.929+02', 'VDS_INSTALL_IN_PROGRESS_WARNING', 510, 1, 'Host gold-vdsd installation in progress . Step: VDS PACKAGES; Details: package sanlock is not installed   (sanlock).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (741, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:17.715+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: seabios-0.6.1.2-19.el6.x86_64   (seabios).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (771, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 14:13:49.573+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain upgrade (Data Center Upgrade) was activated by admin@internal', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', 'b50f7700-e46d-46b9-b2f1-eec1c106bf68', 'upgrade', '00000000-0000-0000-0000-000000000000', '', '4f904414', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (772, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:13:49.677+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center Upgrade by admin@internal', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '7bef7c13', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (773, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:13:49.841+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain upgrade was attached to Data Center Upgrade by admin@internal', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', 'b50f7700-e46d-46b9-b2f1-eec1c106bf68', 'upgrade', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '5836a3f0', '3f9f09b2-7587-4773-9f83-0aceaaa1aec2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (780, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:19:08.754+02', 'USER_RUN_VM', 32, 0, 'VM teset started on Host gold-vdsd', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '3e017db', '23d76353-3d22-44bc-b228-779848af78d0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (783, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:19:28.658+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM teset was successfully removed.', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '4b9565ac', '2f9563ff-144b-4606-a93b-8e7302004f00', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (792, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:21:21.652+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (794, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-13 14:23:15.642+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '6ffca31d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (800, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:54:12.775+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain Upgrade2 was attached to Data Center Upgrade2 by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '1fe997fa-f2d0-473d-969f-faf9aa4df52c', 'Upgrade2', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5a521d5d', '1f30c27a-51b7-4514-b0eb-f62a4c2331a1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (802, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:59:17.336+02', 'USER_ADD_VM', 34, 0, 'VM test was created by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', 'ff9547bb-3452-4922-b326-e354ae0b07b1', 'upgrade1', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '219f8ea', '1a847947-7d34-42a0-86a7-b1104832e818', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (811, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:00:58.493+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-3 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5349bb46', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (814, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:02.888+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-5 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2e6d60d6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (815, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:05.13+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-6 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5eedca50', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (821, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:12.2+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-5 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2e6d60d6', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (828, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:20.09+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-8 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '62e4ceab', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (829, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:29.595+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-10 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5437b986', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (732, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:04.794+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-img-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-img).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (734, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:05.691+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (742, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:20.189+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-img-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-img).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (743, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:22.344+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: fence-agents-3.1.5-17.1.el6_3.x86_64   (fence-agents).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (744, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:24.504+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libselinux-python-2.0.94-5.3.el6.x86_64   (libselinux-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (757, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:42.893+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: instCert.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (758, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:42.909+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: CoreDump.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (759, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:42.946+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: cleanAll.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (760, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:42.98+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS Configuration.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (761, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:42.995+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (762, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:43.008+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: Reboot; Details: Rebooting machine.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (763, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:43.108+02', 'VDS_INSTALL', 504, 0, 'Host gold-vdsd installed', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '75250262', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (764, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:08:47.611+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (767, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:11:50.851+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (770, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:13:49.309+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (801, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 14:57:37.424+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain Upgrade2 (Data Center Upgrade2) was activated by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '1fe997fa-f2d0-473d-969f-faf9aa4df52c', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '616f7203', '75661874-cc02-400a-9991-81413e3c46ce', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (809, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:00:54.711+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-1 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '52fe2140', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (810, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:00:56.843+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-2 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '47b89fd0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (813, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:00.228+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-4 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '3f3ab5e4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (825, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:16.359+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool testt (containing 10 VMs) was created by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '2c9168e', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (826, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:19.905+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-9 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7d99cf1', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (736, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:07.153+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-kvm-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-kvm).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (737, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:09.141+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: vdsm-4.9-105.el6.x86_64   ((~vdsm~, ~vdsm-cli~)).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (738, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:11.248+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: libjpeg-6b-46.el6.x86_64   (libjpeg).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (739, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:13.4+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: spice-server-0.10.1-10.el6.x86_64   (spice-server).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (740, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:15.497+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: pixman-0.18.4-1.el6_0.1.x86_64   (pixman).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (745, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:37.713+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: sanlock-python-2.3-1.el6.x86_64   (sanlock-python).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (746, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:48.713+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: sanlock-2.3-1.el6.x86_64   (sanlock).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (747, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:59.277+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VDS PACKAGES; Details: qemu-kvm-tools-0.12.1.2-2.295.el6_3.8.x86_64   (qemu-kvm-tools).', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (748, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:59.328+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: CreateConf; Details: Basic configuration set.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (749, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:02:59.371+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: CheckLocalHostname; Details: Local hostname is correct..', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (750, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:02.645+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SetNetworking; Details: Created management bridge..', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (751, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:02.773+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: SetSSHAccess; Details: SUCCESS.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (752, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:02.825+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: Firewall; Details: overridden firewall successfully.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (753, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:04.574+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: VerifyServices; Details: Needed services set.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (754, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:10.974+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: Encryption setup; Details: Ended successfully.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (755, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:11.006+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: RHEV_INSTALL.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (756, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 13:03:12.367+02', 'VDS_INSTALL_IN_PROGRESS', 509, 0, 'Installing Host gold-vdsd. Step: INSTALLER; Details: Test platform succeeded.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (765, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 13:42:13.251+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '77573cce', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (766, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 13:56:52.59+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (768, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:13:05.917+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain upgrade was added by admin@internal', false, NULL, '', 'b50f7700-e46d-46b9-b2f1-eec1c106bf68', 'upgrade', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '3aa7e190', '3a4dead4-6781-4aaf-83fb-334888d968b9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (769, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-13 14:13:28.544+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7fb5881c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (774, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:16:20.531+02', 'USER_ADD_VM', 34, 0, 'VM teset was created by admin@internal.', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', 'b50f7700-e46d-46b9-b2f1-eec1c106bf68', 'upgrade', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '387a32f2', '5f1528a8-18fa-4a87-9410-de91174062ec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (775, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:16:23.134+02', 'NETWORK_ACTIVATE_VM_INTERFACE_SUCCESS', 1012, 0, 'Network Interface nic1 (Red Hat VirtIO) activated for VM teset. (User: admin@internal)', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '36ebff57', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (776, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:16:23.22+02', 'NETWORK_ADD_VM_INTERFACE', 932, 0, 'Interface nic1 (Red Hat VirtIO) was added to VM teset. (User: admin@internal)', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '7364bfac', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (777, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:16:28.542+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of teset_Disk1 was initiated on VM teset by admin@internal.', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', 'b50f7700-e46d-46b9-b2f1-eec1c106bf68', 'upgrade', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '1f684198', 'ee1d88a0-4af3-4735-8c39-7930c123743d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (778, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:16:38.556+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk teset_Disk1 was successfully added to VM teset.', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', 'b50f7700-e46d-46b9-b2f1-eec1c106bf68', 'upgrade', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '1f684198', 'ee1d88a0-4af3-4735-8c39-7930c123743d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (779, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:18:08.639+02', 'USER_STARTED_VM', 153, 0, 'VM teset was started by admin@internal (Host: gold-vdsd).', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '3e017db', '23d76353-3d22-44bc-b228-779848af78d0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (781, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:19:16.155+02', 'USER_STOP_VM', 33, 0, 'VM teset stopped by admin@internal (Host: gold-vdsd).', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '7318d625', 'f6313f85-0301-41ef-887b-4fc3f3ae3cdf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (782, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7aab5510-3fea-4c7d-93c1-7076ca1047fb', 'teset', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:19:23.151+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM teset was initiated by admin@internal.', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '4b9565ac', '2f9563ff-144b-4606-a93b-8e7302004f00', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (784, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:20:18.745+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '602ecda6', 'f1e5e9f4-4637-407c-b6ac-4670dcf8c193', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (789, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 14:21:11.569+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster Upgrade2 was added by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2cc6d8cd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (807, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 14:59:36.026+02', 'USER_ADD_VM_TEMPLATE', 48, 0, 'Creation of Template 1 from VM test was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4cf38087', '4d7efc6e-b9c8-43b0-a5d4-52585dd7fb6a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (808, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 14:59:48.108+02', 'USER_ADD_VM_TEMPLATE_FINISHED_SUCCESS', 51, 0, 'Creation of Template 1 from VM test has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4cf38087', '4d7efc6e-b9c8-43b0-a5d4-52585dd7fb6a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (812, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:00:59.487+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-1 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '52fe2140', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (817, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:09.675+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-2 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '47b89fd0', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (785, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-13 14:20:21.747+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center Upgrade. Setting status to Non-Responsive.', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '00000000-0000-0000-0000-000000000000', '', '6e0efe96', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (786, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:20:51.324+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '4e3176eb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (787, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:20:51.43+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '99408929-82cf-4dc7-a532-9d998063fa95', 'Default', '33a290fd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (788, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 14:21:05.291+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center Upgrade2 was added by admin@internal', false, NULL, 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '22810fa4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (793, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:22:49.137+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain upgrade1 was added by admin@internal', false, NULL, '', 'ff9547bb-3452-4922-b326-e354ae0b07b1', 'upgrade1', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '255495aa', 'b145f7e5-3970-475d-802c-78b0d4a6592a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (806, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:59:28.639+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk test_Disk1 was successfully added to VM test.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '1fe997fa-f2d0-473d-969f-faf9aa4df52c', 'Upgrade2', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '64adfa5f', '130a8ffd-196a-4dda-bf88-bf52f00a6bf6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (820, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:11.988+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-4 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '3f3ab5e4', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (822, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:12.279+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-8 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '62e4ceab', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (823, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:13.894+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-9 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7d99cf1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (824, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:16.28+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-10 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5437b986', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (827, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:19.994+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-7 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4c9e55c2', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (790, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:21:15.202+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '99408929-82cf-4dc7-a532-9d998063fa95', 'Default', '78bd2fd4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (791, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:21:21.285+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '1e321d23', 'ba9285b0-a31f-4cb1-b34e-540fbc216578', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (795, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:23:41.173+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (796, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 14:23:41.776+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain upgrade1 (Data Center Upgrade2) was activated by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', 'ff9547bb-3452-4922-b326-e354ae0b07b1', 'upgrade1', '00000000-0000-0000-0000-000000000000', '', '46adcc38', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (797, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:23:41.835+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center Upgrade2 by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '163d44de', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (798, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:23:41.904+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain upgrade1 was attached to Data Center Upgrade2 by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', 'ff9547bb-3452-4922-b326-e354ae0b07b1', 'upgrade1', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '40e06e28', 'e77e977e-5773-4e4f-ab03-e65524f76b58', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (799, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 14:54:06.343+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain Upgrade2 was added by admin@internal', false, NULL, '', '1fe997fa-f2d0-473d-969f-faf9aa4df52c', 'Upgrade2', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '28dcbc6', 'a52d4ff2-473b-46dc-bd9f-a4b44da8d68c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (803, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:59:19.396+02', 'NETWORK_ACTIVATE_VM_INTERFACE_SUCCESS', 1012, 0, 'Network Interface nic1 (Red Hat VirtIO) activated for VM test. (User: admin@internal)', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5de65c97', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (804, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:59:19.453+02', 'NETWORK_ADD_VM_INTERFACE', 932, 0, 'Interface nic1 (Red Hat VirtIO) was added to VM test. (User: admin@internal)', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7d6c34a6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (805, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 14:59:27.147+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of test_Disk1 was initiated on VM test by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '1fe997fa-f2d0-473d-969f-faf9aa4df52c', 'Upgrade2', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '64adfa5f', '130a8ffd-196a-4dda-bf88-bf52f00a6bf6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (816, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:08.197+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM testt-7 creation was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4c9e55c2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (818, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:10.247+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-3 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5349bb46', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (819, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:01:11.835+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM testt-6 creation has been completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5eedca50', '95874ca4-542b-4b51-980d-9f8f24ed978f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (830, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:38.197+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-1 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '44e9030b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (831, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:38.47+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-10 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7ec11139', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (832, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:38.639+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-2 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '29eb4436', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (833, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:38.898+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-3 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '71339e6e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (834, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:39.041+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-4 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2196a796', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (835, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:39.19+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-5 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '3de86907', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (836, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:39.322+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-7 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '1656f44', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (837, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:39.447+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-8 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', 'f936124', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (838, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:39.534+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-9 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '54546fce', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (839, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 15:02:39.597+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM testt-6 was removed from VM Pool testt by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2a6b89df', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (840, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:02:39.713+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool testt was removed by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '79058f86', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (841, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:09:33.468+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '168a6acc', 'effe295e-7857-4806-b475-dd3305ed0ec3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (842, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-13 15:09:43.777+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center Upgrade2. Setting status to Non-Responsive.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '13e2674c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (843, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:42:14.741+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '2296f0f5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (844, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:43:29.087+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (845, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:46:09.265+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5369efa1', 'f9ba2ddf-4e2a-4f89-a855-fd79da21f686', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (847, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:46:12.613+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-lvbug2 (LUN y9413r-izvH-P348-qfe3-CKdl-nQXr-1s3G21) returned by VDSM was following Failed to login to iSCSI node', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (848, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:46:12.626+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-lvbug1 (LUN y9413r-izvH-P348-qfe3-CKdl-nQXr-1s3G21) returned by VDSM was following Failed to login to iSCSI node', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (851, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:46:17.409+02', 'RECONSTRUCT_MASTER_FAILED', 985, 2, 'Failed to Reconstruct Master Domain for Data Center Upgrade2.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', 'ff9547bb-3452-4922-b326-e354ae0b07b1', 'upgrade1', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '726837ab', '67473fc4-9a7e-489c-b3cd-0ba60114fa4f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (852, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:46:22.772+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-lvbug1 (LUN y9kwki-3Lus-WOK6-Zb2a-B37e-5GuQ-6kOE72) returned by VDSM was following Failed to login to iSCSI node', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (853, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:46:23.283+02', 'USER_ACTIVATE_STORAGE_DOMAIN_FAILED', 967, 2, 'Failed to activate Storage Domain upgrade1 (Data Center Upgrade2) by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', 'ff9547bb-3452-4922-b326-e354ae0b07b1', 'upgrade1', '00000000-0000-0000-0000-000000000000', '', '1263586b', 'd8b41b56-21b5-4d1d-ae8c-eb70d48af2af', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (861, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:50:46.939+02', 'VDS_FAILURE', 12, 2, 'Host gold-vdsd is non-responsive.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (865, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:53:06.569+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (868, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:53:57.333+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '38b05671', '5e5887d9-9e32-4881-a667-935610c518d0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (869, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-13 15:53:57.377+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center Upgrade2. Setting status to Non-Responsive.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '714310f9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (870, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:57:50.462+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (872, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:26.863+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-3, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7611af08', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (873, '00000000-0000-0000-0000-000000000000', NULL, '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:28.17+02', 'VM_DOWN', 61, 0, 'VM XP-3 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (877, '00000000-0000-0000-0000-000000000000', NULL, '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:30.469+02', 'VM_DOWN', 61, 0, 'VM XP-4 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (878, '00000000-0000-0000-0000-000000000000', NULL, 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:30.522+02', 'VM_DOWN', 61, 0, 'VM XP-8 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (879, '00000000-0000-0000-0000-000000000000', NULL, '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:30.596+02', 'VM_DOWN', 61, 0, 'VM RHEL6-9 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (880, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:30.803+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-4, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6331cf40', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (881, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:31.5+02', 'VM_MIGRATION_FAILED_DURING_MOVE_TO_MAINTANANCE', 140, 2, 'VM migration failed due to Error: Fatal error during migration while Host is in ''preparing for maintenance'' state.
  Consider manual intervention: stopping/migrating Vms as Host''s state will not
  turn to maintenance while VMs are still running on it.(VM: RHEL6-4, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6331cf40', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (886, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:59:37.557+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (888, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:42.853+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-10, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6c009828', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (889, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:42.869+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-1, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '33583625', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (891, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:47.451+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: RHEL6-8, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '50499d49', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (849, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:46:13.084+02', 'VDS_STORAGE_CONNECTION_FAILED_BUT_LAST_VDS', 533, 2, 'Failed to connect Host gold-vdsd to Data Center, due to connectivity errors with the Storage. Host gold-vdsd will remain in Up state (but inactive), as it is the last Host in the Data Center, to enable manual intervention by the Administrator.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (850, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:46:13.125+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool Upgrade2', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7de21211', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (854, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:47:05.023+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2bb07fd0', '01c8c41f-bfce-4b83-b912-b41ecf0eb1ad', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (855, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:47:15.5+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '102f0a06', 'b9c92c1c-47be-43af-bd5b-9062b0b465d0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (856, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:47:16.928+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (857, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:47:17.792+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-lvbug2 (LUN y9413r-izvH-P348-qfe3-CKdl-nQXr-1s3G21) returned by VDSM was following Failed to login to iSCSI node', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (858, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:47:17.805+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-lvbug1 (LUN y9413r-izvH-P348-qfe3-CKdl-nQXr-1s3G21) returned by VDSM was following Failed to login to iSCSI node', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (859, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:47:18.133+02', 'VDS_STORAGE_CONNECTION_FAILED_BUT_LAST_VDS', 533, 2, 'Failed to connect Host gold-vdsd to Data Center, due to connectivity errors with the Storage. Host gold-vdsd will remain in Up state (but inactive), as it is the last Host in the Data Center, to enable manual intervention by the Administrator.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (860, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:47:18.162+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool Upgrade2', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '6f5a5258', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (862, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:52:01.688+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (863, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:52:06.293+02', 'VDS_STORAGE_CONNECTION_FAILED_BUT_LAST_VDS', 533, 2, 'Failed to connect Host gold-vdsd to Data Center, due to connectivity errors with the Storage. Host gold-vdsd will remain in Up state (but inactive), as it is the last Host in the Data Center, to enable manual intervention by the Administrator.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (864, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:52:06.439+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool Upgrade2', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4c95c1ee', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (866, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:53:06.681+02', 'RECONSTRUCT_MASTER_DONE', 984, 0, 'Reconstruct Master Domain for Data Center Upgrade2 completed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', 'ff9547bb-3452-4922-b326-e354ae0b07b1', 'upgrade1', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '713ee2c9', '22851e03-b563-444c-ae39-92f478a85cb7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (867, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 15:53:07.116+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain Upgrade2 (Data Center Upgrade2) was activated by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', '1fe997fa-f2d0-473d-969f-faf9aa4df52c', 'Upgrade2', '00000000-0000-0000-0000-000000000000', '', '4f8832a1', 'cd051323-2a74-4f45-a1e7-bac0ea8e056b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (874, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:29.65+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-4, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6d237f9f', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (875, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:29.702+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-8, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '10ca63b6', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (876, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:29.761+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: RHEL6-9, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5cca3dc3', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (882, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:33.122+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: RHEL6-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '549734d2', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (883, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:33.229+02', 'VM_MIGRATION_FAILED_DURING_MOVE_TO_MAINTANANCE', 140, 2, 'VM migration failed due to Error: Fatal error during migration while Host is in ''preparing for maintenance'' state.
  Consider manual intervention: stopping/migrating Vms as Host''s state will not
  turn to maintenance while VMs are still running on it.(VM: RHEL6-2, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '549734d2', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (884, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:36.951+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: RHEL6-6, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '610a0941', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (885, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 15:59:37.068+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4f036275', '7cc6257a-093c-444d-b7d1-3173b7515da7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (887, '00000000-0000-0000-0000-000000000000', NULL, 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:37.735+02', 'VM_DOWN', 61, 0, 'VM RHEL6-6 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (892, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:00:10.442+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (871, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:10.528+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '60a52c0c', 'a810dee5-c1c0-4f69-bb9a-7c304a81482a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (890, '00000000-0000-0000-0000-000000000000', NULL, 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 15:59:44.925+02', 'VM_DOWN', 61, 0, 'VM XP-1 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (893, '00000000-0000-0000-0000-000000000000', NULL, '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:01:27.281+02', 'VM_DOWN_ERROR', 119, 2, 'VM RHEL6-4 is down. Exit message: Lost connection with qemu process.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (894, '00000000-0000-0000-0000-000000000000', NULL, '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:01:27.385+02', 'VM_DOWN_ERROR', 119, 2, 'VM RHEL6-2 is down. Exit message: Lost connection with qemu process.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (895, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:28.086+02', 'USER_STARTED_VM', 153, 0, 'VM test was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5dd02999', 'd6bb6e13-019c-4e81-9528-be837f58bc96', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (896, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:28.37+02', 'USER_STARTED_VM', 153, 0, 'VM testt-1 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '14f6a38e', '03f1064d-183e-49a0-899d-12e5c020fa4c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (897, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:28.79+02', 'USER_STARTED_VM', 153, 0, 'VM testt-2 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '54d927a', '4de84489-c3a7-43e9-8650-616b6b467713', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (898, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:29.253+02', 'USER_STARTED_VM', 153, 0, 'VM testt-3 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5fbbe070', '293a6b44-e6c5-42c3-9baa-693df278baba', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (899, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:29.759+02', 'USER_STARTED_VM', 153, 0, 'VM testt-5 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '12bbe0c', '46cf8b82-e050-4a81-be67-8074c79def84', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (900, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:30.156+02', 'USER_STARTED_VM', 153, 0, 'VM testt-6 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5de88460', '9e35656f-7cf5-4868-91d1-2e0774959aa3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (901, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:32.091+02', 'USER_STARTED_VM', 153, 0, 'VM testt-7 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2647d103', 'cad66ee2-32d6-40dd-9ddf-2d410f0a3890', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (902, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:32.597+02', 'USER_STARTED_VM', 153, 0, 'VM testt-8 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '1191bb85', 'a11c6606-6357-4efd-8104-c5e7d0d531b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (903, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:33.146+02', 'USER_STARTED_VM', 153, 0, 'VM testt-9 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '14637aa6', '3694e8f0-4a40-4486-bf5b-c5cf4d43e75f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (904, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:33.494+02', 'USER_STARTED_VM', 153, 0, 'VM testt-4 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '6c3f9847', '73bda230-367a-4801-9168-58ceb3bdebe8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (905, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:01:33.835+02', 'USER_STARTED_VM', 153, 0, 'VM testt-10 was started by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', 'd42ca13', '15c89f5f-4a77-48cc-80e5-f677b8a54a86', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (906, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:29.466+02', 'USER_RUN_VM', 32, 0, 'VM test started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5dd02999', 'd6bb6e13-019c-4e81-9528-be837f58bc96', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (907, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:29.539+02', 'USER_RUN_VM', 32, 0, 'VM testt-3 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5fbbe070', '293a6b44-e6c5-42c3-9baa-693df278baba', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (908, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:29.618+02', 'USER_RUN_VM', 32, 0, 'VM testt-2 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '54d927a', '4de84489-c3a7-43e9-8650-616b6b467713', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (909, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:29.756+02', 'USER_RUN_VM', 32, 0, 'VM testt-1 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '14f6a38e', '03f1064d-183e-49a0-899d-12e5c020fa4c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (910, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:32.503+02', 'USER_RUN_VM', 32, 0, 'VM testt-5 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '12bbe0c', '46cf8b82-e050-4a81-be67-8074c79def84', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (911, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:32.835+02', 'USER_RUN_VM', 32, 0, 'VM testt-7 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2647d103', 'cad66ee2-32d6-40dd-9ddf-2d410f0a3890', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (912, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:33.074+02', 'USER_RUN_VM', 32, 0, 'VM testt-6 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5de88460', '9e35656f-7cf5-4868-91d1-2e0774959aa3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (913, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:35.355+02', 'USER_RUN_VM', 32, 0, 'VM testt-4 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '6c3f9847', '73bda230-367a-4801-9168-58ceb3bdebe8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (914, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:35.461+02', 'USER_RUN_VM', 32, 0, 'VM testt-8 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '1191bb85', 'a11c6606-6357-4efd-8104-c5e7d0d531b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (915, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:35.552+02', 'USER_RUN_VM', 32, 0, 'VM testt-9 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '14637aa6', '3694e8f0-4a40-4486-bf5b-c5cf4d43e75f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (916, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:02:35.63+02', 'USER_RUN_VM', 32, 0, 'VM testt-10 started on Host gold-vdsd', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', 'd42ca13', '15c89f5f-4a77-48cc-80e5-f677b8a54a86', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (917, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:02:44.448+02', 'USER_UPDATE_VDS_GROUP', 811, 0, 'Host cluster Upgrade2 was updated by admin@internal', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '585006c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (918, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:04:58.696+02', 'USER_UPDATE_STORAGE_POOL', 952, 0, 'Data Center Upgrade2 was updated by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '5eb09c7b', '6ed4cbfb-834b-463c-b29c-26efbc2b9ef0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (925, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:29:11.959+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain 1paikov94 was added by admin@internal', false, NULL, '', '04f43930-ac7b-4ae8-bf16-fbddb782f9b0', '1paikov94', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '307934b2', 'ac2c4bf2-09c4-499b-9df4-e3c1fd484d84', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (949, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:45:55.984+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (921, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:27:14.949+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '34b9be85', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (922, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:27:15.119+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '46502de5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (926, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-13 16:29:36.606+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', NULL, '', '00000000-0000-0000-0000-000000000000', '', '38a1b72d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (927, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:30:04.607+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (929, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:30:04.817+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center EDU by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '763b082e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (930, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:30:04.854+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain 1paikov94 was attached to Data Center EDU by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', '04f43930-ac7b-4ae8-bf16-fbddb782f9b0', '1paikov94', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '39d5fa76', '1daa321c-7415-43e9-a372-c6f28dbe5c37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (931, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:30:40.946+02', 'USER_DEACTIVATED_STORAGE_DOMAIN', 968, 0, 'Storage Domain 1paikov94 (Data Center EDU) was deactivated by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', '04f43930-ac7b-4ae8-bf16-fbddb782f9b0', '1paikov94', '00000000-0000-0000-0000-000000000000', '', '5bf87b4e', '442119fb-f266-4434-9c46-e9c7e117f133', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (944, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:37:45.984+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain gold-vdsc-Local (Data Center gold-vdsc-Local) was activated by admin@internal', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', '42c6e7b3-b60d-4490-9c93-6753413b9b0d', 'gold-vdsc-Local', '00000000-0000-0000-0000-000000000000', '', '5d2b7e05', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (945, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:37:46.012+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center gold-vdsc-Local by admin@internal', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '6d88a7ad', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (946, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:37:46.047+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain gold-vdsc-Local was attached to Data Center gold-vdsc-Local by admin@internal', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', '42c6e7b3-b60d-4490-9c93-6753413b9b0d', 'gold-vdsc-Local', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '6a9ecb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (951, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:35.615+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-6 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5f6ed620', '1713b9f9-4a7c-4833-8b61-fbd95ed9dade', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (952, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:36.959+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-7 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '65abffd2', '61231e37-c6fb-400e-975c-a59e67f4afbd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (953, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:38.025+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-8 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7f286823', '28de6fca-f85e-4140-a5e1-3f012ab1427a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (954, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:39.2+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-9 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35cd130d', '4f50f0b7-cf06-4572-aa44-240fce70c5dc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (956, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:42.041+02', 'USER_STOP_VM', 33, 0, 'VM testt-1 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '60518f40', '5085c0c6-fc6f-4a97-850b-9dbd2230d951', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (957, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:42.998+02', 'USER_STOP_VM', 33, 0, 'VM testt-10 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', 'a93e427', 'b8f4318f-52f7-4d80-a3d9-2b618f0ba550', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (958, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:43.782+02', 'USER_STOP_VM', 33, 0, 'VM testt-2 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7367c1dd', '3550378e-5581-47f9-9670-ac93b2a4e49d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (961, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:45.906+02', 'USER_STOP_VM', 33, 0, 'VM testt-5 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '530e5f63', 'aef03b99-4c31-4a24-a81b-72ddae39ef9b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (982, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:20.223+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-5 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1a128360', '9a5f0470-a846-47d9-b82f-07299be1b252', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1001, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:32.14+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-2 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '15040ab1', '63ed4c6e-2deb-4b19-8878-ce47fd54e262', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1003, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:34.739+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-4 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4a1cdb1a', '73c4bded-89d7-48ba-a90f-aa8119c682d8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1004, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:36.127+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-5 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '70dfdc0a', '62a8a208-96f5-4f75-a4b3-9ede95be8647', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1006, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:40.284+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-7 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '26fbcc7c', 'e196f5b3-625c-435e-9fce-2cf515f0c99b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (923, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:27:17.983+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '2e7baec', 'c69712aa-0a6c-424a-a6fa-b7826f0e10af', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (932, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-13 16:30:46.08+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', NULL, '', '00000000-0000-0000-0000-000000000000', '', '3b3bb2fa', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (933, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:31:14.074+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (937, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:36:06.611+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center gold-vdsc-Local was added by admin@internal', false, NULL, 'gold-vdsc-Local', NULL, '', '00000000-0000-0000-0000-000000000000', '', '3104b273', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (938, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:36:07.442+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster gold-vdsc-Local was added by admin@internal', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '_WEBADMIN_17322667_Configure_Local_Storage', 'cbce1b87-767a-48f7-9a0d-c4403cba5d88', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (939, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:36:07.931+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '_WEBADMIN_17322667_Configure_Local_Storage', '3fd19031-bde9-4762-a9d6-70cce63e603a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (940, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:36:08.846+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '_WEBADMIN_17322667_Configure_Local_Storage', 'f7ccd493-85eb-476c-bc9a-511914b47bc3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (941, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:36:09.307+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (947, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:37:46.253+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain gold-vdsc-Local was added by admin@internal', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', '42c6e7b3-b60d-4490-9c93-6753413b9b0d', 'gold-vdsc-Local', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '_WEBADMIN_17322667_Configure_Local_Storage', '29f67126-b77c-464b-9f14-68076062c5ef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (948, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:42:13.118+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '66cbead0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (977, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:14.598+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-1 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '357652ff', '3e8ee9cd-777a-4d8e-a12d-3ecb50c37998', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (978, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:15.552+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-2 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '595e5754', '534ab288-abf3-4775-8ecb-7a132812614e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (979, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:17.289+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-3 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6ce29462', '0613f1ca-2c79-4774-91b6-0af201fc6f0e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (980, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:18.154+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-4 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4484e801', '478bc5ec-43b4-4c41-bab7-485dacdde08a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (924, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:27:19.905+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (934, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:31:14.418+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain 1paikov94 (Data Center EDU) was activated by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', '04f43930-ac7b-4ae8-bf16-fbddb782f9b0', '1paikov94', '00000000-0000-0000-0000-000000000000', '', '51ca3ce7', '34d3df63-aae5-4a58-bbea-6a883b5b9f5d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (964, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:48.959+02', 'USER_STOP_VM', 33, 0, 'VM testt-8 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '1dcc552a', '6bce6b6b-6628-43af-9b3a-8c9b0383be2d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (972, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:56.128+02', 'USER_STOP_VM', 33, 0, 'VM XP-6 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1e8794c8', 'e3cf6c8f-e694-475d-b58c-d0388b34a7ef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (975, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:50:00.152+02', 'USER_STOP_VM', 33, 0, 'VM XP-9 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6aecfc2e', 'b0b6278a-a1bb-4846-a5ea-26373633faaa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (981, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '516b826e-7136-4a24-b5fc-9363466d4588', 'RHEL6-5', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:19.133+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-5 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1a128360', '9a5f0470-a846-47d9-b82f-07299be1b252', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (983, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98cb4511-adb9-4148-a55b-35922cd45305', 'RHEL6-2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:20.263+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-2 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '595e5754', '534ab288-abf3-4775-8ecb-7a132812614e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (985, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6a76cf99-1dab-46aa-984c-2f9183d816aa', 'RHEL6-1', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:20.448+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-1 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '357652ff', '3e8ee9cd-777a-4d8e-a12d-3ecb50c37998', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (928, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:30:04.765+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain 1paikov94 (Data Center EDU) was activated by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', '04f43930-ac7b-4ae8-bf16-fbddb782f9b0', '1paikov94', '00000000-0000-0000-0000-000000000000', '', '58ae0cf7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (987, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '019c3116-e094-45ce-a974-ab7c5059d849', 'RHEL6-4', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:20.615+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-4 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4484e801', '478bc5ec-43b4-4c41-bab7-485dacdde08a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (988, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:22.599+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-7 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4821db43', '3b5b0f9c-9332-4f6b-84f9-4ba9ab4e43fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (989, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:23.718+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-8 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1e3e2a1', 'f02fca6f-6d98-4c36-be12-77599ad249d7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (990, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:24.948+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-9 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3338497a', 'b361b501-9f7f-4301-8d60-f04fcd55c8e7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (991, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 16:50:27.02+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM test was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '3e0a87bd', 'f405d441-5d9c-473b-891c-80d32a598cc8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (992, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:28.573+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-1 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '47c98d7a', 'a713e687-aed6-411e-acb7-a276f6ed9e64', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (996, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 16:50:30.925+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM test was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '3e0a87bd', 'f405d441-5d9c-473b-891c-80d32a598cc8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (935, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 16:34:02.495+02', 'USER_DEACTIVATED_STORAGE_DOMAIN', 968, 0, 'Storage Domain 1paikov94 (Data Center EDU) was deactivated by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', '04f43930-ac7b-4ae8-bf16-fbddb782f9b0', '1paikov94', '00000000-0000-0000-0000-000000000000', '', '415c9832', 'd8e651a2-3a02-47f0-975c-cafc43dcfe10', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (936, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:34:22.099+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '7b27adad', '6408057f-87a0-4002-9ac3-6db6642f08ce', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (942, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-13 16:36:55.664+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', NULL, '', '00000000-0000-0000-0000-000000000000', '', '2428972e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (943, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 16:37:45.625+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (950, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:34.602+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-3 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7f4e714', 'a403b746-da83-4af1-8d8b-7a5c8763fc23', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (955, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1ac1425b-6f94-49ed-ae97-2fc3340728c4', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:40.177+02', 'USER_STOP_VM', 33, 0, 'VM test stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '2a9dd613', 'd574de58-1ff9-4574-9aba-0d1477290784', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (959, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:44.489+02', 'USER_STOP_VM', 33, 0, 'VM testt-3 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '20e8cf5c', 'ec7329ca-7e8b-4ddb-8a7d-db74b1079d75', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (960, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:45.233+02', 'USER_STOP_VM', 33, 0, 'VM testt-4 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '1485b1e5', 'cd508d86-66fc-4ae6-95d3-441499ce183d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (962, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:47.366+02', 'USER_STOP_VM', 33, 0, 'VM testt-6 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '5498872e', '6618f8df-d91e-4f6f-b42c-385c31973b26', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (963, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:48.258+02', 'USER_STOP_VM', 33, 0, 'VM testt-7 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '69d30865', '34c55cbe-dac9-4ffe-a21d-258b4dc09c24', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (965, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 16:49:49.641+02', 'USER_STOP_VM', 33, 0, 'VM testt-9 stopped by admin@internal (Host: gold-vdsd).', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '51eb47ae', '21d4bf5f-7dbc-4f18-9fb0-3323e7154f7c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (966, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:50.599+02', 'USER_STOP_VM', 33, 0, 'VM XP-1 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2daf1a86', '7791dc7e-a527-4d8d-9c9b-c7f08635e375', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (967, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:51.551+02', 'USER_STOP_VM', 33, 0, 'VM XP-10 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '42f66ad8', '78c6f512-8f14-4653-b11d-de43bb86f98c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (968, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:52.949+02', 'USER_STOP_VM', 33, 0, 'VM XP-2 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3fe0ad40', 'b54bd99e-0d6e-4d1f-b12e-e138ecc5892c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (969, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:53.733+02', 'USER_STOP_VM', 33, 0, 'VM XP-3 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '378e6583', '8144dbee-bb0c-4fd6-bf63-b9268353f356', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (970, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:54.493+02', 'USER_STOP_VM', 33, 0, 'VM XP-4 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '65aa97f3', '335eee16-850f-4f5a-8b3c-5c775d3629dd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (971, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:55.242+02', 'USER_STOP_VM', 33, 0, 'VM XP-5 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '22de06aa', '13ba5207-25d8-430f-9a6c-4545bc0c2885', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (973, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:58.098+02', 'USER_STOP_VM', 33, 0, 'VM XP-7 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5738e620', '689b640a-5de5-4c08-8451-feb250dbfcb8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (974, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:49:58.889+02', 'USER_STOP_VM', 33, 0, 'VM XP-8 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '588c6b9c', '06be6b68-dcc2-4fac-8889-e9e7d2fbca05', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (976, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 16:50:00.818+02', 'USER_STOP_VM', 33, 0, 'VM RHEL6-10 stopped by admin@internal (Host: camel-vdsb).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6ca066d9', 'b7c74ff3-5101-4240-a7d7-f9e272a95cbb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (984, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '98a345a6-0352-42a9-9740-825f72287bd7', 'RHEL6-3', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:20.424+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-3 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6ce29462', '0613f1ca-2c79-4774-91b6-0af201fc6f0e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (986, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:20.519+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-6 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '169818fa', '518a7c9f-b99a-4ea9-b97c-9dd5818ea5cc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (993, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:30.042+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-10 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '424b3b20', '7253ceaa-6729-473e-be5d-188dec0e2a7d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (994, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ce7fb093-f666-4696-9af2-a5507bb5b455', 'RHEL6-8', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:30.806+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-8 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1e3e2a1', 'f02fca6f-6d98-4c36-be12-77599ad249d7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (995, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '21b8b28e-aa85-4b2f-8679-6c2baa5c7816', 'testt-10', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:30.921+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-10 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '424b3b20', '7253ceaa-6729-473e-be5d-188dec0e2a7d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (997, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ee680787-3dfb-47cd-9942-558f82ac776e', 'RHEL6-7', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:31.062+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-7 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4821db43', '3b5b0f9c-9332-4f6b-84f9-4ba9ab4e43fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (998, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3918c0d2-e3d7-4491-9e1a-239ccbbc3d87', 'RHEL6-9', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:31.068+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-9 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3338497a', 'b361b501-9f7f-4301-8d60-f04fcd55c8e7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (999, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0fb3bafd-4193-4d04-9517-ca8abfcb1687', 'testt-1', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:31.11+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-1 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '47c98d7a', 'a713e687-aed6-411e-acb7-a276f6ed9e64', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1000, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c805df1e-7bc5-4129-95ea-441e656ca545', 'RHEL6-6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:31.814+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-6 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '169818fa', '518a7c9f-b99a-4ea9-b97c-9dd5818ea5cc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1002, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:33.41+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-3 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '55c94d74', '096fcac1-6581-455d-ac18-5713686312ef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1005, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:38.795+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-6 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '76709975', '74f31897-e2fc-481c-a37f-8835f2376aa2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1007, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dca39d09-80bb-46fa-8bdf-550ffdc063b1', 'testt-2', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:42.364+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-2 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '15040ab1', '63ed4c6e-2deb-4b19-8878-ce47fd54e262', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1008, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '78080411-b2d7-4c29-b933-ba5f4faeed10', 'testt-7', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:42.4+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-7 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '26fbcc7c', 'e196f5b3-625c-435e-9fce-2cf515f0c99b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1009, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4693cccb-fedf-4acd-ba9c-464683ed6d4a', 'testt-4', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:42.451+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-4 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4a1cdb1a', '73c4bded-89d7-48ba-a90f-aa8119c682d8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1010, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '501a3861-238d-4f8b-9b8b-5e6afd060ae3', 'testt-6', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:42.461+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-6 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '76709975', '74f31897-e2fc-481c-a37f-8835f2376aa2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1011, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48de6815-0891-47d3-b9a0-841023eb63fa', 'testt-5', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:42.473+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-5 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '70dfdc0a', '62a8a208-96f5-4f75-a4b3-9ede95be8647', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1012, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:42.48+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-8 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7822cf8c', 'cdb23b3c-9cdf-456c-bfb6-33c78f34d0e5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1013, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3e0c66c7-367f-4db8-bbe3-794c261c1ee1', 'testt-3', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:42.58+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-3 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '55c94d74', '096fcac1-6581-455d-ac18-5713686312ef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1014, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:43.982+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM testt-9 was initiated by admin@internal.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7e19f48', 'f8d51409-4057-40c6-bda6-b2ac7d2413d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1015, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:44.895+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-1 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '197f3fd3', 'fc578ba8-5182-4e87-b1a2-34277c813a21', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1016, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:46.125+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-10 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4b16f672', 'dbfe33e1-649f-495e-884a-d936a913e974', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1017, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:47.848+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-2 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '17d5826f', '7cda69b6-28f7-41eb-8611-b21119008ff2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1018, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:48.762+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-3 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '31c9aab5', '55220bb0-ae23-4131-ac69-b030c9de896b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1019, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:49.636+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-4 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '74b90c28', '96e99fe2-fa2a-45cf-81a6-e3609b1c9429', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1020, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:50.436+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-5 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '53262fce', 'f990d751-a0c5-4444-a198-ef6898a34fbc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1021, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:52.422+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-6 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1dac0056', 'a8942975-2212-40c0-8974-9887170563f1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1022, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84340b7b-c765-4051-a7ea-e5d0ca9b4949', 'testt-8', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:52.66+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-8 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7822cf8c', 'cdb23b3c-9cdf-456c-bfb6-33c78f34d0e5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1023, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cc501428-1f8c-4be6-a99d-0b025bd7dfc2', 'testt-9', '51afb64d-e00d-4342-922b-196af28f5b3e', '1', NULL, NULL, '2012-12-13 16:50:52.752+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM testt-9 was successfully removed.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7e19f48', 'f8d51409-4057-40c6-bda6-b2ac7d2413d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1024, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bb78b159-bf3e-4487-9227-61168a4ed804', 'XP-5', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:52.814+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-5 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '53262fce', 'f990d751-a0c5-4444-a198-ef6898a34fbc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1025, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '91abfde7-7014-4d48-a52d-64c64d4f7ac8', 'XP-3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:52.833+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-3 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '31c9aab5', '55220bb0-ae23-4131-ac69-b030c9de896b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1026, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ad97040b-399b-4403-afb3-9bfb246e5226', 'XP-10', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:52.879+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-10 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4b16f672', 'dbfe33e1-649f-495e-884a-d936a913e974', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1027, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '32fd0cdf-c88e-4d75-9701-639142e30b14', 'XP-2', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:52.915+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-2 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '17d5826f', '7cda69b6-28f7-41eb-8611-b21119008ff2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1028, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '63a91076-ceff-4227-a43c-55860a85afe3', 'XP-4', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:52.975+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-4 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '74b90c28', '96e99fe2-fa2a-45cf-81a6-e3609b1c9429', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1029, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dd933e5a-bdf2-436e-b325-1b4ed10e45aa', 'XP-1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:53.024+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-1 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '197f3fd3', 'fc578ba8-5182-4e87-b1a2-34277c813a21', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1030, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:53.874+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-7 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '78635668', '556439d9-0169-4f33-a50c-afb20971c334', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1031, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:54.745+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-8 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '53707a07', '93179fb0-259a-457a-9b6b-42c849b441c9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1032, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:50:55.713+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-9 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5aa6bd22', '20a8457b-8700-471c-9289-3d54a3187754', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1109, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:20:58.043+02', 'USER_ADD_VDS_GROUP', 809, 0, 'Host cluster NFS was added by admin@internal', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47b91767', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1033, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:50:57.531+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL6-10 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7b86313a', 'af5a4157-47ab-40d5-96d2-5cf573e4399e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1034, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6fef92d8-a684-479c-804c-8a5cba85a75c', 'RHEL6-10', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 16:51:03.051+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL6-10 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7b86313a', 'af5a4157-47ab-40d5-96d2-5cf573e4399e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1041, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 17:41:45.031+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '1df76318', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1042, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 17:41:45.142+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'b7eaa5c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1044, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-13 17:41:59.545+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center gold-vdsc-Local. Setting status to Non-Responsive.', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', NULL, '', '00000000-0000-0000-0000-000000000000', '', '4d0292f5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1047, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:42:04.055+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '230df7e3', '542d8b3d-0bc0-4eeb-8416-afd75910fed9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1051, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:09.896+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-si25-02 (LUN C8qzHi-fyIN-r1sx-NRfF-LUG8-omqa-hVacQU) returned by VDSM was following Failed to setup iSCSI subsystem', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1052, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:09.908+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-si25-01 (LUN C8qzHi-fyIN-r1sx-NRfF-LUG8-omqa-hVacQU) returned by VDSM was following Failed to setup iSCSI subsystem', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1053, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:09.921+02', 'STORAGE_DOMAIN_ERROR', 996, 2, 'The error code for connection 10.35.64.10 Dafna-si25-03 (LUN C8qzHi-fyIN-r1sx-NRfF-LUG8-omqa-hVacQU) returned by VDSM was following Failed to setup iSCSI subsystem', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1054, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:42:10.223+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center iSCSI. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1a736d96', '698c8f1c-19a8-4214-878e-767c5fb87e23', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1055, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:42:10.337+02', 'CONNECT_STORAGE_SERVERS_FAILED', 994, 1, 'Failed to connect Host gold-vdsc to Storage Servers', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4a823642', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1056, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:13.125+02', 'USER_REMOVE_STORAGE_POOL', 954, 0, 'Data Center EDU was removed by admin@internal', false, '3cc17386-ca4a-4b60-89c0-12891e81d486', 'EDU', NULL, '', '00000000-0000-0000-0000-000000000000', '', '268107cc', '88a3e945-3578-4ca5-a317-9ab4b985b4da', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1058, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:22.399+02', 'USER_REMOVE_STORAGE_POOL', 954, 0, 'Data Center Upgrade was removed by admin@internal', false, '3feca2dd-2f80-4616-9f43-c2c81fdfb0a7', 'Upgrade', NULL, '', '00000000-0000-0000-0000-000000000000', '', '3409cf71', '6dd22826-b74b-46e2-9ec1-89337ca9ddc3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1059, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:30.361+02', 'USER_REMOVE_STORAGE_POOL', 954, 0, 'Data Center Upgrade2 was removed by admin@internal', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '498ebd86', 'bf7d26c4-eec1-4170-aa90-087ab6a16061', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1060, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:37.441+02', 'USER_REMOVE_VDS_GROUP', 813, 0, 'Host cluster gold-vdsc-Local was removed by admin@internal', false, NULL, '', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '5f579352', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1061, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:39.231+02', 'USER_REMOVE_VDS_GROUP', 813, 0, 'Host cluster EDU was removed by admin@internal', false, NULL, '', NULL, '', '2b366638-4531-11e2-a36b-001a4a169741', 'EDU', '2804d59d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1063, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:44.301+02', 'USER_REMOVE_VDS_GROUP', 813, 0, 'Host cluster Upgrade2 was removed by admin@internal', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '7314da20', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1073, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:53:04.397+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM Dafna creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4568479', '38804ef3-b24f-4286-9b45-e8c775d71d18', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1074, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:53:13.71+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM Dafna creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '4568479', '38804ef3-b24f-4286-9b45-e8c775d71d18', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1087, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'e85083e7-801d-4b2a-ad38-aee2669c6035', NULL, NULL, NULL, '2012-12-13 17:55:23.733+02', 'IMPORTEXPORT_STARTING_EXPORT_VM', 1162, 0, 'Starting export Vm Dafna1 to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '634eb13a', '4dcae18d-24bb-4522-af7d-d93fe1f31f78', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1090, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6439698c-7ac3-4663-99c9-a07bd56156a7', 'dafna', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 17:56:12.933+02', 'USER_ADD_VM', 34, 0, 'VM dafna was created by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '59bdbcf4', 'a2fd6932-4a5c-4c83-9285-3da550b0c37d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1091, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6439698c-7ac3-4663-99c9-a07bd56156a7', 'dafna', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-13 17:56:21.221+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM dafna was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1f5b28c8', 'b9efbc14-50dd-4893-aa37-f658ffb5f096', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1098, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'e85083e7-801d-4b2a-ad38-aee2669c6035', NULL, NULL, NULL, '2012-12-13 18:02:41.202+02', 'IMPORTEXPORT_EXPORT_VM', 1150, 0, 'Vm Dafna1 was exported successfully to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '634eb13a', '4dcae18d-24bb-4522-af7d-d93fe1f31f78', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1035, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '86db35b7-1b85-46e8-964a-6e56357b2eb2', 'XP-6', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:51:03.127+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-6 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1dac0056', 'a8942975-2212-40c0-8974-9887170563f1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1043, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:41:49.772+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '6800b520', '9917c979-1121-4f02-8e78-8ea4db580a8d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1081, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:54:08.189+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 1 creation for VM Dafna1 has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '138c06d5', 'c5f87e1b-300a-4c58-98e3-adf0ae5decc2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1083, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:54:50.779+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of Dafna1_Disk2 was initiated on VM Dafna1 by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1944fe0a', 'b9241af8-53a2-4b44-94ef-a6af2ac70902', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1084, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:54:58.453+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk Dafna_Disk2 was successfully added to VM Dafna.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '16018573', '6dc52696-6bab-4922-bb77-095997869245', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1095, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', 'Dafna3', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', NULL, NULL, NULL, '2012-12-13 17:58:22.126+02', 'IMPORTEXPORT_EXPORT_VM', 1150, 0, 'Vm Dafna3 was exported successfully to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '52fc0d8c', 'cfd65f91-5184-472d-9678-f46e6e2353e7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1036, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77be6693-182c-4561-9e22-0ed9af27cbfd', 'XP-9', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:51:03.129+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-9 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5aa6bd22', '20a8457b-8700-471c-9289-3d54a3187754', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1037, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '441892b9-a468-4f4b-93d1-c1f12c437d20', 'XP-7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:51:03.178+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-7 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '78635668', '556439d9-0169-4f33-a50c-afb20971c334', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1038, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e79386c4-dc75-4e22-b6d1-718bfbd5a09e', 'XP-8', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 16:51:03.203+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-8 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '53707a07', '93179fb0-259a-457a-9b6b-42c849b441c9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1039, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 17:41:37.516+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '94b17d26-451f-11e2-ba1d-001a4a169741', 'Upgrade2', '4bbe6169', '938c0dfe-a38c-4ab3-a8d2-031806535f39', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1040, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-13 17:41:42.208+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center Upgrade2. Setting status to Non-Responsive.', false, 'fcca3f81-bee3-4cff-a043-3d5e4cc7c1c4', 'Upgrade2', NULL, '', '00000000-0000-0000-0000-000000000000', '', '2d2d369f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1067, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 17:46:49.369+02', 'VDS_FAILURE', 12, 2, 'Host camel-vdsb is non-responsive.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1068, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 17:48:04.974+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1072, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 17:52:26.9+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1075, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:53:28.256+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM Dafna1 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '569ca20d', 'fd91d84b-12d6-48e5-84b3-13910bd6572d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1079, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:53:58.654+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 1 creation for VM Dafna1 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '138c06d5', 'c5f87e1b-300a-4c58-98e3-adf0ae5decc2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1080, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:54:08.144+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 1 creation for VM Dafna has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '67c76fa3', 'd8d658a9-e089-41e6-aa51-131ac6cc6150', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1089, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', 'Dafna2', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', NULL, NULL, NULL, '2012-12-13 17:55:50.941+02', 'IMPORTEXPORT_STARTING_EXPORT_VM', 1162, 0, 'Starting export Vm Dafna2 to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3593ddbd', '0d25f3f3-eb1f-4a5a-a178-40426da12b34', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1093, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', 'Dafna3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:56:39.094+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM Dafna3 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1ab6d3ca', '30712692-266a-414f-851a-375346ab26d6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1094, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', 'Dafna3', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', NULL, NULL, NULL, '2012-12-13 17:56:55.436+02', 'IMPORTEXPORT_STARTING_EXPORT_VM', 1162, 0, 'Starting export Vm Dafna3 to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '52fc0d8c', 'cfd65f91-5184-472d-9678-f46e6e2353e7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1097, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', 'Dafna2', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', NULL, NULL, NULL, '2012-12-13 17:59:25.233+02', 'IMPORTEXPORT_EXPORT_VM', 1150, 0, 'Vm Dafna2 was exported successfully to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '3593ddbd', '0d25f3f3-eb1f-4a5a-a178-40426da12b34', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1045, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:42:00.898+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '6e347faa-4532-11e2-b8e1-001a4a169741', 'gold-vdsc-Local', '28132a62', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1046, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:42:01.018+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5d606fb3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1048, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 17:42:05.342+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', 'a00c5d5', '8a1f2d5b-38bd-44fe-aede-80e7468c2955', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1049, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:42:05.738+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1050, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 17:42:06.112+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1057, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:17.883+02', 'USER_REMOVE_STORAGE_POOL', 954, 0, 'Data Center gold-vdsc-Local was removed by admin@internal', false, 'ebc6c6a9-4eb3-4194-9a50-f4d2cc0bd971', 'gold-vdsc-Local', NULL, '', '00000000-0000-0000-0000-000000000000', '', '3f5f3ee5', '01aa6290-4ec8-46ac-9f65-535657b6fcc7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1062, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-13 17:42:41.9+02', 'USER_REMOVE_VDS_GROUP', 813, 0, 'Host cluster Upgrade was removed by admin@internal', false, NULL, '', NULL, '', '95010e1e-450f-11e2-8fbb-001a4a169741', 'Upgrade', '5d132239', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1064, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 17:43:27.604+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_WITH_ERROR', 987, 1, 'Invalid status on Data Center iSCSI. Setting Data Center status to Non-Responsive (On host camel-vdsb, Error: Network error during communication with the Host.).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7f083bde', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1065, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:43:29.32+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7b7e6eae', '288451aa-d5b3-41c5-a90f-8a0fd50cccb3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1066, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-13 17:46:43.544+02', 'VDS_FAILURE', 12, 2, 'Host gold-vdsd is non-responsive.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1069, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-13 17:49:35.633+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1070, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:49:39.468+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '505438c7', '2138d12a-fa59-4525-983d-697e7babb07e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1071, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-13 17:49:39.818+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1076, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:53:33.811+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM Dafna1 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '569ca20d', 'fd91d84b-12d6-48e5-84b3-13910bd6572d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1077, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', 'Dafna2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:53:44.105+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM Dafna2 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '44d10dda', '884c0def-a470-4abb-8a63-f01aa1583db6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1078, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:53:57.514+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 1 creation for VM Dafna was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '67c76fa3', 'd8d658a9-e089-41e6-aa51-131ac6cc6150', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1082, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:54:47.519+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of Dafna_Disk2 was initiated on VM Dafna by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '16018573', '6dc52696-6bab-4922-bb77-095997869245', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1085, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:54:58.492+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk Dafna1_Disk2 was successfully added to VM Dafna1.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1944fe0a', 'b9241af8-53a2-4b44-94ef-a6af2ac70902', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1086, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', 'Dafna2', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-13 17:55:08.241+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM Dafna2 creation has been completed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'Dafna-si25-01', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '44d10dda', '884c0def-a470-4abb-8a63-f01aa1583db6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1088, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '6528b153-270a-4f54-94d2-e73cc95983cc', NULL, NULL, NULL, '2012-12-13 17:55:39.016+02', 'IMPORTEXPORT_STARTING_EXPORT_VM', 1162, 0, 'Starting export Vm Dafna to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '9db0cb7', 'a9dcc2bd-4a2a-42a5-b496-ca94a420c68f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1092, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', 'Dafna3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-13 17:56:32.666+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM Dafna3 creation was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '00000000-0000-0000-0000-000000000000', '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1ab6d3ca', '30712692-266a-414f-851a-375346ab26d6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1096, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '6528b153-270a-4f54-94d2-e73cc95983cc', NULL, NULL, NULL, '2012-12-13 17:59:15.053+02', 'IMPORTEXPORT_EXPORT_VM', 1150, 0, 'Vm Dafna was exported successfully to New_Export', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '9db0cb7', 'a9dcc2bd-4a2a-42a5-b496-ca94a420c68f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1099, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:19:37.609+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1100, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', 'Dafna3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-16 10:20:18.691+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM Dafna3 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1896a292', '5cabe2f5-eeb8-4fed-9ac2-9392a9f817ec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1101, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-16 10:20:22.456+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM Dafna was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '67484821', '873422fd-a281-4e09-8673-5bd187c4caff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1102, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-16 10:20:25.202+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM Dafna1 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7080094e', 'fa566591-8eb0-4edb-a6cf-5522b8b3c07a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1103, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a1f071a5-c88e-452c-b491-aa49ce239b1d', 'Dafna3', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-16 10:20:25.642+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM Dafna3 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1896a292', '5cabe2f5-eeb8-4fed-9ac2-9392a9f817ec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1104, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e85083e7-801d-4b2a-ad38-aee2669c6035', 'Dafna1', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', NULL, NULL, '2012-12-16 10:20:25.732+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM Dafna1 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '7080094e', 'fa566591-8eb0-4edb-a6cf-5522b8b3c07a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1105, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6528b153-270a-4f54-94d2-e73cc95983cc', 'Dafna', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-16 10:20:25.738+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM Dafna was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '67484821', '873422fd-a281-4e09-8673-5bd187c4caff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1106, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', 'Dafna2', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 10:20:26.619+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM Dafna2 was initiated by admin@internal.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '790200cb', '6429071c-ef33-45be-a2de-2454ee677013', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1107, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fab0a423-c355-4fbe-8aa6-6aa7900b1dc6', 'Dafna2', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 10:20:35.764+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM Dafna2 was successfully removed.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '790200cb', '6429071c-ef33-45be-a2de-2454ee677013', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1108, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:20:51.765+02', 'USER_ADD_STORAGE_POOL', 950, 0, 'Data Center NFS was added by admin@internal', false, NULL, 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '6ab3ab0c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1115, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-16 10:29:21.779+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center iSCSI. Setting status to Non-Responsive.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '00000000-0000-0000-0000-000000000000', '', '5c58046', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1139, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:40:40.517+02', 'IMPORTEXPORT_IMPORT_TEMPLATE', 1158, 0, 'Template XP_iSCSI_Copy was imported successfully to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3390721f', '27de5b62-fac4-4db3-8786-6e249995e611', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1140, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:41:16.402+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '483b23a2', '1334f677-54f7-4120-8cb0-8d315c683b7e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1156, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9683977d-a3e0-4edc-9029-db39143fae2b', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:50.456+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-3 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67c47246', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1110, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:21:32.22+02', 'USER_DEACTIVATED_STORAGE_DOMAIN', 968, 0, 'Storage Domain New_Export (Data Center iSCSI) was deactivated by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '00000000-0000-0000-0000-000000000000', '', '72041ac2', 'ca2f199c-2f6b-418b-a602-429e1bac839c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1111, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:22:25.833+02', 'USER_DETACH_STORAGE_DOMAIN_FROM_POOL', 964, 0, 'Storage Domain New_Export was detached from Data Center iSCSI by admin@internal', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '00000000-0000-0000-0000-000000000000', '', '40eafb6e', 'e4a815c5-19cf-488f-8aa4-d54d952efa5d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1112, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:29:12.442+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '14db5ce0', 'cc0af727-3b24-4ede-a911-b5a9d9eadc01', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1113, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:29:16.337+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '35f8a4ac', '0980b5f3-42d8-4dc5-88e6-12e0dee43eec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1116, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:29:25.876+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '6dba38e1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1117, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:29:25.966+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61d28a33', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1118, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:29:32.345+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2e7bb05a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1119, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:29:32.422+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f7850ec', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1136, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:35:03.303+02', 'IMPORTEXPORT_STARTING_IMPORT_TEMPLATE', 1163, 0, 'Starting to import Template NFS-RHEL6_iSCSI_Copy to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c37cd6f', '208e5b78-47f3-4302-9f00-8ac5c1353d36', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1137, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:35:05.102+02', 'IMPORTEXPORT_STARTING_IMPORT_TEMPLATE', 1163, 0, 'Starting to import Template XP_iSCSI_Copy to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3390721f', '27de5b62-fac4-4db3-8786-6e249995e611', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1141, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:41:20.218+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9ecc96b', '9d4994bd-31ed-4061-ae6f-3db6915310ab', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1142, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:41:20.924+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host camel-vdsb was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1855e84b', 'daf191b5-ad0b-480d-8235-cbb0696e47fc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1143, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-16 10:41:21.142+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '414d8cbc', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1157, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '73824b44-8219-443c-9ea1-514c12444224', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:50.734+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-2 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d660a86', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1114, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:29:19.518+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host camel-vdsb was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '355e67bf', 'fa080041-8f6e-4345-a027-013befc81f11', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1124, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:29:43.247+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1127, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:29:45.494+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1130, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:32:11.254+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1146, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:42:37.916+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6099f0d3', 'c78ed96c-88c0-4818-bbc3-b7da2aba783a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1147, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:42:38.146+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1152, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:43:26.018+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host camel-vdsb was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d5403ce', '2c73ff34-18e4-4dd7-8323-1e0c9202c472', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1153, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:43:29.702+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31cb0e11', '3c4151a5-b1cb-4747-aa0a-4c77906d244f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1120, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:29:38.116+02', 'USER_UPDATE_VDS', 43, 0, 'Host camel-vdsb parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '93d0386', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1121, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:29:38.223+02', 'USER_UPDATE_VDS', 43, 0, 'Host camel-vdsb parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '70b216a3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1122, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:29:41.117+02', 'VDS_ACTIVATE', 16, 0, 'Host camel-vdsb was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50c18c0f', '9786cb96-5018-4f0b-865b-bb8f4b172ace', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1123, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:29:42.114+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22b0d1ee', 'f8221c6c-4418-433c-9402-83ddbef0fa9b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1125, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:29:45.188+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1126, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 10:29:45.249+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45ccea9d', 'db5083b6-4244-45d0-bc86-4e53e75e723e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1128, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:31:16.086+02', 'USER_ADD_STORAGE_DOMAIN', 956, 0, 'Storage Domain NFs was added by admin@internal', false, NULL, '', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d9f196e', '3fdfdd17-230d-41fe-88ff-ee88750c84dd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1129, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '00000000-0000-0000-0000-000000000000', 'Unavailable', '2012-12-16 10:31:46.692+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_SEARCHING_NEW_SPM', 986, 1, 'Data Center is being initialized, please wait for initialization to complete.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '551da7d0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1131, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:32:15.524+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain NFs (Data Center NFS) was activated by admin@internal', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '00000000-0000-0000-0000-000000000000', '', '34f58036', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1132, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:32:15.633+02', 'USER_ATTACH_STORAGE_DOMAINS_TO_POOL', 1002, 0, 'Storage Domains were attached to Data Center NFS by admin@internal', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4161a2d0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1133, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:32:15.677+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain NFs was attached to Data Center NFS by admin@internal', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c9182f2', '637ae156-a184-477d-949f-dcc838ef2a31', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1134, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:34:04.537+02', 'USER_ATTACH_STORAGE_DOMAIN_TO_POOL', 962, 0, 'Storage Domain New_Export was attached to Data Center NFS by admin@internal', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5446c6d', 'ad602d90-4041-40f6-b05d-891cad26a1ce', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1135, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:34:13.493+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain New_Export (Data Center NFS) was activated by admin@internal', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '00000000-0000-0000-0000-000000000000', '', '3b72fc47', 'e3bb2011-7d7c-4bba-b915-580bd6f76938', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1138, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:37:36.511+02', 'IMPORTEXPORT_IMPORT_TEMPLATE', 1158, 0, 'Template NFS-RHEL6_iSCSI_Copy was imported successfully to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c37cd6f', '208e5b78-47f3-4302-9f00-8ac5c1353d36', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1144, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:42:35.659+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '589c34a2', '14806af7-b81f-413f-93ed-50f4b36b00eb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1145, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:42:36.471+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1148, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 10:43:01.905+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1149, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:43:06.631+02', 'VDS_ACTIVATE', 16, 0, 'Host camel-vdsb was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1dc9a273', '86267edb-c3e9-4248-a933-7533f7995a94', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1150, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:43:06.89+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1151, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 10:43:17.466+02', 'USER_UPDATE_VDS', 43, 0, 'Host camel-vdsb parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '92d19fd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1154, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f01846f3-92c8-425d-ba24-b549dd7fac44', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:46.972+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-1 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e7bfa29', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1155, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '73824b44-8219-443c-9ea1-514c12444224', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:48.32+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-2 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d660a86', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1158, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f01846f3-92c8-425d-ba24-b549dd7fac44', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:51.637+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-1 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e7bfa29', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1159, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7bd9a064-afd2-4cda-a646-e8c04ccfb738', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:51.669+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-4 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '388a2f12', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1160, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '29b3d93f-10fb-4168-b352-c9d3db347f45', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:53.401+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-5 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72993b4e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1161, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '263e9153-a17c-4e4a-98bb-435fbcb207c4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:54.846+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-6 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73583743', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1162, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '446b539d-fabb-4f98-963e-7702927688a2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:56.597+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-7 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5860fc4a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1163, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd4dbd787-9238-43b4-993d-27b71dd5cbd0', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:57.271+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-1 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '385b2235', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1164, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '457be3d0-438b-40db-aace-ff29184aef99', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:58.007+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-8 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24c61faa', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1165, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '270ad305-0edd-40fe-a16a-819eeacabddd', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:59.657+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-2 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9a7dd65', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1166, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '185a6d56-3e80-4c7e-8040-91f251da09f7', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:43:59.801+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-9 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '364f1887', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1167, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fe30198f-b83d-4f16-908d-9c08ca0d3b74', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:01.282+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-3 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d19d48', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1168, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7bd9a064-afd2-4cda-a646-e8c04ccfb738', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:02.159+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-4 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '388a2f12', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1171, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2205b2f0-fa77-4524-9ee3-c545967b6861', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:02.887+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-10 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31025062', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1174, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '446b539d-fabb-4f98-963e-7702927688a2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:06.417+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-7 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5860fc4a', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1175, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '263e9153-a17c-4e4a-98bb-435fbcb207c4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:06.623+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-6 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73583743', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1176, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '312199d0-3f55-4920-ac60-4e3af7c4a69c', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:06.78+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-11 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5dddcbd9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1181, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '312199d0-3f55-4920-ac60-4e3af7c4a69c', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:11.701+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-11 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5dddcbd9', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1183, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2205b2f0-fa77-4524-9ee3-c545967b6861', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:13.611+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-10 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31025062', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1192, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60770e60-302e-4193-bdfa-4be0ba97fb0e', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:19.986+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-15 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '781eb7a8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1195, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'edd6dcfc-732a-423f-9f11-6b0d381e5f58', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:22.563+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-8 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '69ca957f', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1197, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b88cc68f-2dcc-4cf4-8dd2-29b0ac385193', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:23.288+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-12 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44e6768b', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1201, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '01b1d936-6d0a-4e0f-9e3f-e33e8dd7daaa', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:25.045+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-7 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26b5fa18', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1211, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c1e4bef6-918d-41db-8f50-3178678214e4', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:32.89+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-15 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b630242', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1212, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e923eb45-4d24-4c68-b474-3129cb586502', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:33.144+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-20 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '77af41a4', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1218, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '10d9d1ef-fa5e-45c4-8a05-ee4881edaa37', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:36.187+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-19 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64e6d99c', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1219, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '697384ff-19d1-4145-b538-1e77c94ca051', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:36.364+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-9 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c2dea8f', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1223, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5374cf9e-7f10-4ddc-b302-cbc55b962c49', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:37.351+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-16 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35c47556', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1226, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8d8ba953-0b7f-4839-9c91-a472b63153d8', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:44.549+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-18 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '101f55ac', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1229, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c1e4bef6-918d-41db-8f50-3178678214e4', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:47.629+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-15 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b630242', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1237, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '04a042c2-c28b-4aa4-b17e-f3cb39749c79', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:58.722+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-16 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2da5bf50', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1239, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '95323edc-0cb0-4001-868d-b14e77b04410', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:00.001+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-17 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3aa8ce87', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1240, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1caab087-52d9-475e-b6a2-584ffa7d7ece', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:00.848+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-18 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fbaac02', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1241, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '10d9d1ef-fa5e-45c4-8a05-ee4881edaa37', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:00.92+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-19 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63550a4a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1242, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '73824b44-8219-443c-9ea1-514c12444224', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.035+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-2 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50307f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1243, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f01846f3-92c8-425d-ba24-b549dd7fac44', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.127+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-1 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '780970d4', 'c90a477d-6d74-49ee-8755-b0fc783b5381', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1169, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd4dbd787-9238-43b4-993d-27b71dd5cbd0', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:02.304+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-1 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '385b2235', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1170, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '29b3d93f-10fb-4168-b352-c9d3db347f45', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:02.806+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-5 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72993b4e', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1172, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9683977d-a3e0-4edc-9029-db39143fae2b', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:05.75+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-3 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67c47246', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1173, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6503f3a5-575e-4514-ab31-9c0b3a0c9cef', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:06.125+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-4 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '121171c0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1177, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '94b1c954-5666-4f03-9cf2-64bdf9cec633', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:07.63+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-5 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '634e0a7f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1178, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b88cc68f-2dcc-4cf4-8dd2-29b0ac385193', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:08.198+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-12 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44e6768b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1179, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f959672e-af7b-4495-a53e-233516a321fa', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:10.213+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-6 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2753d0c7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1180, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f0f5e50f-383a-441d-8e64-c5316193d3a0', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:10.299+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-13 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3dd6bdc1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1184, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '457be3d0-438b-40db-aace-ff29184aef99', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:15.123+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-8 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24c61faa', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1186, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '270ad305-0edd-40fe-a16a-819eeacabddd', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:17.003+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-2 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9a7dd65', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1191, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'edd6dcfc-732a-423f-9f11-6b0d381e5f58', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:18.466+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-8 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '69ca957f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1196, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f0f5e50f-383a-441d-8e64-c5316193d3a0', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:22.693+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-13 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3dd6bdc1', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1198, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f959672e-af7b-4495-a53e-233516a321fa', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:23.472+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-6 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2753d0c7', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1199, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '05b53401-a504-4f9f-9783-1d3594c4bec7', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:24.667+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-14 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'fc03b0', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1200, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '95323edc-0cb0-4001-868d-b14e77b04410', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:24.7+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-17 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '13b59da9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1203, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1caab087-52d9-475e-b6a2-584ffa7d7ece', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:26.021+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-18 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '157caa08', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1207, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e923eb45-4d24-4c68-b474-3129cb586502', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:29.646+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-20 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '77af41a4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1208, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8074111c-47cf-4d51-9077-552bf8aabe1e', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:29.696+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-13 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22914ea3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1209, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:29.783+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool XP (containing 20 VMs) was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '453306d8', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1210, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '12082718-df99-4af2-ac30-36b2fe795578', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:31.289+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-14 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58c91256', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1214, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b054f31d-aec7-4b8a-808f-4d4b698512dd', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:34.747+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-12 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7778f7f1', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1216, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '95323edc-0cb0-4001-868d-b14e77b04410', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:35.623+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-17 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '13b59da9', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1220, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60770e60-302e-4193-bdfa-4be0ba97fb0e', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:36.53+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-15 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '781eb7a8', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1221, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2c0f22cd-3b0c-4582-b716-42af77064bb0', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:36.766+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-10 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5cce5169', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1227, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b026853c-2ea2-4170-91ca-bad87607cd37', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:45.759+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-17 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c59e526', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1234, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f0f5e50f-383a-441d-8e64-c5316193d3a0', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:57.351+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-13 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6fb8043', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1235, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '05b53401-a504-4f9f-9783-1d3594c4bec7', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:57.906+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-14 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4fd90569', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1182, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '185a6d56-3e80-4c7e-8040-91f251da09f7', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:13.007+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-9 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '364f1887', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1185, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6503f3a5-575e-4514-ab31-9c0b3a0c9cef', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:15.263+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-4 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '121171c0', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1187, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '01b1d936-6d0a-4e0f-9e3f-e33e8dd7daaa', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:17.081+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-7 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26b5fa18', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1188, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '05b53401-a504-4f9f-9783-1d3594c4bec7', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:17.448+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-14 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'fc03b0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1189, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '94b1c954-5666-4f03-9cf2-64bdf9cec633', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:17.552+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-5 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '634e0a7f', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1190, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fe30198f-b83d-4f16-908d-9c08ca0d3b74', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:17.802+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-3 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d19d48', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1193, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '697384ff-19d1-4145-b538-1e77c94ca051', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:20.966+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-9 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c2dea8f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1194, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '04a042c2-c28b-4aa4-b17e-f3cb39749c79', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:21.372+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-16 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64017335', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1202, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2c0f22cd-3b0c-4582-b716-42af77064bb0', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:25.087+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-10 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5cce5169', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1204, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'af697533-5a9d-4516-9898-96dfa5581696', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:26.505+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-11 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '747daae2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1205, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '10d9d1ef-fa5e-45c4-8a05-ee4881edaa37', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:28.115+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-19 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64e6d99c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1206, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b054f31d-aec7-4b8a-808f-4d4b698512dd', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:28.51+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-12 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7778f7f1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1213, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1caab087-52d9-475e-b6a2-584ffa7d7ece', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:33.635+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-18 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '157caa08', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1215, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '04a042c2-c28b-4aa4-b17e-f3cb39749c79', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:35.064+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-16 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64017335', '58738c73-70aa-407a-9fcc-f8d952708829', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1217, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8074111c-47cf-4d51-9077-552bf8aabe1e', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:35.912+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-13 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22914ea3', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1222, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'af697533-5a9d-4516-9898-96dfa5581696', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:37.319+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-11 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '747daae2', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1224, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b026853c-2ea2-4170-91ca-bad87607cd37', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:40.739+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-17 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c59e526', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1225, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5374cf9e-7f10-4ddc-b302-cbc55b962c49', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:44.521+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-16 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35c47556', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1228, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f01846f3-92c8-425d-ba24-b549dd7fac44', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:47.455+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-1 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '396951a2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1230, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2205b2f0-fa77-4524-9ee3-c545967b6861', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:47.961+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-10 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '60f9e9f3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1231, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '12082718-df99-4af2-ac30-36b2fe795578', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:48.036+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-14 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58c91256', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1232, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '312199d0-3f55-4920-ac60-4e3af7c4a69c', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:48.138+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-11 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '43412e7c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1233, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b88cc68f-2dcc-4cf4-8dd2-29b0ac385193', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:53.635+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-12 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2b6419f8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1238, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ac33a799-c6d9-4c74-81d4-ed2696641b2c', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:58.787+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-19 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '662c973', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1244, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e923eb45-4d24-4c68-b474-3129cb586502', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.181+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-20 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f5db03b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1247, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '29b3d93f-10fb-4168-b352-c9d3db347f45', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.436+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-5 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '21ab8501', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1248, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '263e9153-a17c-4e4a-98bb-435fbcb207c4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.487+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-6 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6386362b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1573, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 12:42:13.617+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '141d33d0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1236, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60770e60-302e-4193-bdfa-4be0ba97fb0e', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:44:58.386+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-15 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b81626', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1313, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7bd9a064-afd2-4cda-a646-e8c04ccfb738', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:17.984+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-4 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '43649cac', '4db0636a-6887-46f3-90f0-775720f1d1a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1315, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7bd9a064-afd2-4cda-a646-e8c04ccfb738', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:29.688+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-4 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '43649cac', '4db0636a-6887-46f3-90f0-775720f1d1a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1316, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1caab087-52d9-475e-b6a2-584ffa7d7ece', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:29.907+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-18 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c804895', '3114749e-e213-44df-8ac3-2b7a0a0255b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1328, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8074111c-47cf-4d51-9077-552bf8aabe1e', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:54.517+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-13 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1bdd9f16', 'f0ab7669-2f6e-4091-b7c0-8ee02b0a1f07', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1245, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9683977d-a3e0-4edc-9029-db39143fae2b', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.271+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-3 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d160514', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1246, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8d8ba953-0b7f-4839-9c91-a472b63153d8', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.333+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-18 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '101f55ac', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1265, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ac33a799-c6d9-4c74-81d4-ed2696641b2c', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:31.159+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-19 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '662c973', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1268, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b88cc68f-2dcc-4cf4-8dd2-29b0ac385193', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:31.672+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-12 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2edeeb36', '579defa6-de69-4487-8912-3641500dc46d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1284, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6503f3a5-575e-4514-ab31-9c0b3a0c9cef', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:01.938+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-4 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '10798ef6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1286, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '94b1c954-5666-4f03-9cf2-64bdf9cec633', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:13.541+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-5 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3e215e98', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1293, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60770e60-302e-4193-bdfa-4be0ba97fb0e', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:52.269+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-15 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7231e623', 'af84e795-6010-4ad9-96b0-6108cda922ae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1330, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '12082718-df99-4af2-ac30-36b2fe795578', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:54.98+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-14 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11fa07c6', '9cc5b0a3-c4e2-43b2-8513-f7d1592cdfdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1336, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '446b539d-fabb-4f98-963e-7702927688a2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:08.516+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-7 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c9f6eb5', 'ff40db73-6c2f-4426-8059-c24075890e81', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1339, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b026853c-2ea2-4170-91ca-bad87607cd37', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:13.842+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-17 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '266e49d5', '2d6a360a-7800-426e-b7cc-1b74fcd53b2d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1341, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5374cf9e-7f10-4ddc-b302-cbc55b962c49', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:19.903+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-16 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '238858e2', '06bd2ef2-8a7f-4d05-b305-2599aad26a9a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1344, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8d8ba953-0b7f-4839-9c91-a472b63153d8', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:29.832+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-18 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'afa4860', '47df7e00-aa31-4fef-83ae-10901cca86f8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1347, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '270ad305-0edd-40fe-a16a-819eeacabddd', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:42.392+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-2 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '55bf2d0b', '614a47a7-fd9f-4257-8588-c1d5b233ee23', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1249, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '446b539d-fabb-4f98-963e-7702927688a2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.548+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-7 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19c79fd8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1250, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '457be3d0-438b-40db-aace-ff29184aef99', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.576+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-8 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15c94499', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1251, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '185a6d56-3e80-4c7e-8040-91f251da09f7', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.62+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-9 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '366770dc', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1252, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7bd9a064-afd2-4cda-a646-e8c04ccfb738', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.649+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-4 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c2a6ad', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1253, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:45:01.692+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool XP was removed by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '38d466ef', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1254, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2205b2f0-fa77-4524-9ee3-c545967b6861', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:01.953+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-10 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3656727d', 'dd627e69-eb4e-4951-ae96-2b1e91b2c1b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1255, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48cfc9b4-9f4a-48be-ba55-4748d8aeee44', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:02.109+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-20 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44fafeca', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1258, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f01846f3-92c8-425d-ba24-b549dd7fac44', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:38.392+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-1 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '780970d4', 'c90a477d-6d74-49ee-8755-b0fc783b5381', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1256, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:02.201+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool RHEL (containing 20 VMs) was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '68123d86', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1257, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2205b2f0-fa77-4524-9ee3-c545967b6861', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:38.329+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-10 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3656727d', 'dd627e69-eb4e-4951-ae96-2b1e91b2c1b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1260, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48cfc9b4-9f4a-48be-ba55-4748d8aeee44', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:40.543+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-20 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44fafeca', 'b40c669d-9689-4c26-9963-2ad34b30cd3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1326, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '29b3d93f-10fb-4168-b352-c9d3db347f45', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:53.631+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-5 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '46444a77', '61c03bdb-9ee1-400c-b7ae-583805038070', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1332, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c1e4bef6-918d-41db-8f50-3178678214e4', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:03.081+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-15 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26fce341', 'f568e525-5057-41ff-a6d7-05feb4cae260', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1334, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '457be3d0-438b-40db-aace-ff29184aef99', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:07.417+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-8 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50e9ca', 'b38ab1b9-dd49-4c76-b194-457860d3c001', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1345, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ac33a799-c6d9-4c74-81d4-ed2696641b2c', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:32.883+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-19 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41b6866b', '81f68bdf-d32d-471f-8780-07e2d3a8762e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1259, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '312199d0-3f55-4920-ac60-4e3af7c4a69c', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:45:39.076+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-11 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '797158d9', 'efe6b2be-901c-4a1b-8d97-1ded32036762', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1297, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '697384ff-19d1-4145-b538-1e77c94ca051', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:49:06.714+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-9 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4cd15a3e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1300, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60770e60-302e-4193-bdfa-4be0ba97fb0e', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:49:07.777+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-15 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7231e623', 'af84e795-6010-4ad9-96b0-6108cda922ae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1314, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1caab087-52d9-475e-b6a2-584ffa7d7ece', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:22.976+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-18 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c804895', '3114749e-e213-44df-8ac3-2b7a0a0255b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1261, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f0f5e50f-383a-441d-8e64-c5316193d3a0', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:03.609+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-13 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25ee8e8f', 'bdc673f3-ff79-4d16-b3fe-f444d1985d43', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1262, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd4dbd787-9238-43b4-993d-27b71dd5cbd0', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:26.277+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-1 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f3d9169', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1263, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'af697533-5a9d-4516-9898-96dfa5581696', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:29.66+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-11 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7929202f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1264, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b054f31d-aec7-4b8a-808f-4d4b698512dd', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:31.117+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-12 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d0e7df6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1266, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8074111c-47cf-4d51-9077-552bf8aabe1e', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:31.546+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-13 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'f3b044b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1269, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '12082718-df99-4af2-ac30-36b2fe795578', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:34.423+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-14 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '51e58126', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1270, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c1e4bef6-918d-41db-8f50-3178678214e4', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:44.694+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-15 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '21c57b2d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1271, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5374cf9e-7f10-4ddc-b302-cbc55b962c49', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:46.42+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-16 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '247a91a8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1272, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b026853c-2ea2-4170-91ca-bad87607cd37', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:50.775+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-17 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5772e859', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1273, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8d8ba953-0b7f-4839-9c91-a472b63153d8', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:52.651+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-18 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54c70cae', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1275, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ac33a799-c6d9-4c74-81d4-ed2696641b2c', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:54.71+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-19 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '472857d1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1278, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '270ad305-0edd-40fe-a16a-819eeacabddd', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:56.156+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-2 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '222421e4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1290, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f959672e-af7b-4495-a53e-233516a321fa', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:44.092+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-6 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c28d4a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1292, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '01b1d936-6d0a-4e0f-9e3f-e33e8dd7daaa', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:49.396+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-7 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '123f98d1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1294, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'edd6dcfc-732a-423f-9f11-6b0d381e5f58', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:57.419+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-8 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53bf3ab5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1296, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '697384ff-19d1-4145-b538-1e77c94ca051', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:49:06.706+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-9 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e8238aa', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1267, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '312199d0-3f55-4920-ac60-4e3af7c4a69c', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:31.655+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-11 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '797158d9', 'efe6b2be-901c-4a1b-8d97-1ded32036762', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1274, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b88cc68f-2dcc-4cf4-8dd2-29b0ac385193', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:54.364+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-12 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2edeeb36', '579defa6-de69-4487-8912-3641500dc46d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1276, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f0f5e50f-383a-441d-8e64-c5316193d3a0', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:54.858+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-13 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25ee8e8f', 'bdc673f3-ff79-4d16-b3fe-f444d1985d43', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1277, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '05b53401-a504-4f9f-9783-1d3594c4bec7', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:46:55.425+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-14 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78ef6efc', '6878c936-3039-438a-8c56-e9b190b651a2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1279, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48cfc9b4-9f4a-48be-ba55-4748d8aeee44', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:47:05.773+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-20 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7960e919', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1280, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2c0f22cd-3b0c-4582-b716-42af77064bb0', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:47:05.79+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-10 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75165dd6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1281, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48cfc9b4-9f4a-48be-ba55-4748d8aeee44', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:47:26.91+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-20 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7ae47d4b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1282, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fe30198f-b83d-4f16-908d-9c08ca0d3b74', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:47:31.217+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-3 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '252c024c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1283, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fe30198f-b83d-4f16-908d-9c08ca0d3b74', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:47:56.429+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-3 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '666c5b4d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1285, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6503f3a5-575e-4514-ab31-9c0b3a0c9cef', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:01.969+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-4 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '121c7546', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1302, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e923eb45-4d24-4c68-b474-3129cb586502', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:49:16.269+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-20 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6843bc8', '32a2805a-0b70-494a-85d4-21c43d85c483', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1303, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2c0f22cd-3b0c-4582-b716-42af77064bb0', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:50:48.24+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-10 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1460b72d', 'a0a434f3-8baf-4332-a397-3fbddb33902a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1305, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '04a042c2-c28b-4aa4-b17e-f3cb39749c79', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:50:52.08+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-16 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5dcfe3b4', '5fa481ad-ae52-418b-9bfc-8213b89f6b13', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1308, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9683977d-a3e0-4edc-9029-db39143fae2b', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:50:57.262+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-3 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '621dcdc5', '1e95010c-d461-4d9a-97a5-db49c264a1b2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1309, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '95323edc-0cb0-4001-868d-b14e77b04410', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:00.143+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-17 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26a3c95c', '87c14fa3-2b99-482e-a9d2-157fac08db0b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1310, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'af697533-5a9d-4516-9898-96dfa5581696', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:04.692+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-11 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a0bef12', '06339672-09c8-4863-810c-0d14c82e298a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1318, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '29b3d93f-10fb-4168-b352-c9d3db347f45', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:29.951+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-5 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '46444a77', '61c03bdb-9ee1-400c-b7ae-583805038070', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1319, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '10d9d1ef-fa5e-45c4-8a05-ee4881edaa37', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:29.977+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-19 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1dff7215', 'dc63c591-6ee6-4602-b05b-a0d5ff14eef2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1320, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b054f31d-aec7-4b8a-808f-4d4b698512dd', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:30.244+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-12 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35c58f0f', 'bf6ceefe-a135-43b1-b1df-6702d0dd2caa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1321, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '263e9153-a17c-4e4a-98bb-435fbcb207c4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:37.55+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-6 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c8e16fa', '333a7a3d-1bb2-4451-a191-ef0392ddfcdb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1323, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '73824b44-8219-443c-9ea1-514c12444224', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:38.729+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-2 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3aa22e85', '53cbd606-7ce6-42ae-be55-95758c0f7f30', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1325, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b054f31d-aec7-4b8a-808f-4d4b698512dd', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:51.322+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-12 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35c58f0f', 'bf6ceefe-a135-43b1-b1df-6702d0dd2caa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1329, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '446b539d-fabb-4f98-963e-7702927688a2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:54.981+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-7 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c9f6eb5', 'ff40db73-6c2f-4426-8059-c24075890e81', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1331, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '457be3d0-438b-40db-aace-ff29184aef99', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:02.927+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-8 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50e9ca', 'b38ab1b9-dd49-4c76-b194-457860d3c001', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1337, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '73824b44-8219-443c-9ea1-514c12444224', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:08.799+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-2 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3aa22e85', '53cbd606-7ce6-42ae-be55-95758c0f7f30', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1340, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b026853c-2ea2-4170-91ca-bad87607cd37', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:19.75+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-17 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '266e49d5', '2d6a360a-7800-426e-b7cc-1b74fcd53b2d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1342, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8d8ba953-0b7f-4839-9c91-a472b63153d8', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:20.143+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-18 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'afa4860', '47df7e00-aa31-4fef-83ae-10901cca86f8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1287, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '94b1c954-5666-4f03-9cf2-64bdf9cec633', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:13.541+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-5 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1cf70896', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1289, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f959672e-af7b-4495-a53e-233516a321fa', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:44.089+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-6 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '70455892', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1291, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '01b1d936-6d0a-4e0f-9e3f-e33e8dd7daaa', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:49.395+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-7 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67961fa0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1295, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'edd6dcfc-732a-423f-9f11-6b0d381e5f58', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:57.419+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-8 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67bc7f32', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1288, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '05b53401-a504-4f9f-9783-1d3594c4bec7', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:48:44.062+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-14 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78ef6efc', '6878c936-3039-438a-8c56-e9b190b651a2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1298, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2c0f22cd-3b0c-4582-b716-42af77064bb0', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:49:07.343+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-10 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67a53a66', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1299, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:49:07.77+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool RHEL was removed by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3370b881', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1301, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:49:07.781+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool <UNKNOWN> was removed by admin@internal.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '6ea766c3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1304, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e923eb45-4d24-4c68-b474-3129cb586502', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:50:48.76+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-20 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6843bc8', '32a2805a-0b70-494a-85d4-21c43d85c483', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1306, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '04a042c2-c28b-4aa4-b17e-f3cb39749c79', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:50:57.156+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-16 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5dcfe3b4', '5fa481ad-ae52-418b-9bfc-8213b89f6b13', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1307, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2c0f22cd-3b0c-4582-b716-42af77064bb0', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:50:57.214+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-10 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1460b72d', 'a0a434f3-8baf-4332-a397-3fbddb33902a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1311, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9683977d-a3e0-4edc-9029-db39143fae2b', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:15.144+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-3 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '621dcdc5', '1e95010c-d461-4d9a-97a5-db49c264a1b2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1312, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '95323edc-0cb0-4001-868d-b14e77b04410', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:17.516+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-17 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26a3c95c', '87c14fa3-2b99-482e-a9d2-157fac08db0b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1317, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'af697533-5a9d-4516-9898-96dfa5581696', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:29.911+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-11 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a0bef12', '06339672-09c8-4863-810c-0d14c82e298a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1322, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8074111c-47cf-4d51-9077-552bf8aabe1e', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:38.726+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-13 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1bdd9f16', 'f0ab7669-2f6e-4091-b7c0-8ee02b0a1f07', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1324, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '263e9153-a17c-4e4a-98bb-435fbcb207c4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:49.947+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-6 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c8e16fa', '333a7a3d-1bb2-4451-a191-ef0392ddfcdb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1327, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '10d9d1ef-fa5e-45c4-8a05-ee4881edaa37', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 10:51:54.044+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-19 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1dff7215', 'dc63c591-6ee6-4602-b05b-a0d5ff14eef2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1333, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '12082718-df99-4af2-ac30-36b2fe795578', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:07.269+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-14 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11fa07c6', '9cc5b0a3-c4e2-43b2-8513-f7d1592cdfdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1335, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c1e4bef6-918d-41db-8f50-3178678214e4', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:08.515+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-15 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26fce341', 'f568e525-5057-41ff-a6d7-05feb4cae260', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1338, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5374cf9e-7f10-4ddc-b302-cbc55b962c49', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:08.87+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-16 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '238858e2', '06bd2ef2-8a7f-4d05-b305-2599aad26a9a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1343, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ac33a799-c6d9-4c74-81d4-ed2696641b2c', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:28.467+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-19 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41b6866b', '81f68bdf-d32d-471f-8780-07e2d3a8762e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1346, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '270ad305-0edd-40fe-a16a-819eeacabddd', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:38.705+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-2 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '55bf2d0b', '614a47a7-fd9f-4257-8588-c1d5b233ee23', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1348, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48cfc9b4-9f4a-48be-ba55-4748d8aeee44', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:52:49.162+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-20 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b89ca8d', '0d882675-7bdd-4c24-8b9f-77dc79c4727d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1349, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '48cfc9b4-9f4a-48be-ba55-4748d8aeee44', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:14.987+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-20 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b89ca8d', '0d882675-7bdd-4c24-8b9f-77dc79c4727d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1350, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fe30198f-b83d-4f16-908d-9c08ca0d3b74', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:18.325+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-3 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6de912b8', 'e55b1e77-9ba1-43dd-b4b4-a0f01b992960', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1351, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fe30198f-b83d-4f16-908d-9c08ca0d3b74', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:27.68+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-3 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6de912b8', 'e55b1e77-9ba1-43dd-b4b4-a0f01b992960', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1352, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6503f3a5-575e-4514-ab31-9c0b3a0c9cef', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:29.392+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-4 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37cd8de3', '219511aa-bd41-4af6-8ad9-83ff2b72c8f9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1353, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '94b1c954-5666-4f03-9cf2-64bdf9cec633', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:34.906+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-5 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3432b07c', '282ed457-e869-4449-8bbb-cbf5e5be4fb8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1354, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '94b1c954-5666-4f03-9cf2-64bdf9cec633', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:38.262+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-5 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3432b07c', '282ed457-e869-4449-8bbb-cbf5e5be4fb8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1355, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6503f3a5-575e-4514-ab31-9c0b3a0c9cef', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:38.579+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-4 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37cd8de3', '219511aa-bd41-4af6-8ad9-83ff2b72c8f9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1356, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f959672e-af7b-4495-a53e-233516a321fa', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:40.191+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-6 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58a5521', 'c0fa4b53-0721-47d7-ac40-31196b370fd0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1357, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd4dbd787-9238-43b4-993d-27b71dd5cbd0', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:47.337+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-1 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57d7db6b', '1d0f37ef-3b7d-44d6-9f99-fa0e8efbf049', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1574, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 13:02:01.174+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1358, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd4dbd787-9238-43b4-993d-27b71dd5cbd0', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:48.978+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-1 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57d7db6b', '1d0f37ef-3b7d-44d6-9f99-fa0e8efbf049', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1360, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 10:58:29.118+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1372, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '67ad0bc7-759d-4b70-b8d7-831654373e96', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:15.633+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-1 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f4f4e38', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1375, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a98333e1-3e08-42a0-8fbf-d1070a1db195', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:18.191+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-4 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c03267e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1396, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8239525c-8498-4eb1-a78b-7b0288901dbb', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:53.287+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-9 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1142cde0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1359, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f959672e-af7b-4495-a53e-233516a321fa', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 10:53:49.153+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-6 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58a5521', 'c0fa4b53-0721-47d7-ac40-31196b370fd0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1361, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '697384ff-19d1-4145-b538-1e77c94ca051', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:31.401+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-9 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25814cc1', 'ac353842-22e6-4620-8fa1-4509def363cb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1362, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '697384ff-19d1-4145-b538-1e77c94ca051', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:32.159+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-9 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25814cc1', 'ac353842-22e6-4620-8fa1-4509def363cb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1363, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '01b1d936-6d0a-4e0f-9e3f-e33e8dd7daaa', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:32.2+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-7 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '65348158', 'f2d9e446-5dea-4e56-855f-3a2a4049b221', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1364, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'edd6dcfc-732a-423f-9f11-6b0d381e5f58', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:32.829+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-8 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f86cd4e', 'fa1d07e8-754a-486d-983a-5079ab2a4042', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1368, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '01b1d936-6d0a-4e0f-9e3f-e33e8dd7daaa', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:42.296+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-7 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '65348158', 'f2d9e446-5dea-4e56-855f-3a2a4049b221', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1374, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '09c7e7a8-f938-48c1-9a3e-23461aca02ca', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:16.261+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-1 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '354cc151', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1376, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ef69bea-bebc-4426-987b-9429a80375e3', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:18.676+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-2 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c25160c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1381, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ef69bea-bebc-4426-987b-9429a80375e3', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:25.605+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-2 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c25160c', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1383, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a98333e1-3e08-42a0-8fbf-d1070a1db195', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:27.736+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-4 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c03267e', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1384, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '22a8a881-f8fe-44de-8f3a-9915a646d4d5', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:28.305+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-3 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '17241340', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1385, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0c996b54-d0dd-4649-8f38-8a909b1fac2a', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:30.05+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-6 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '695db960', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1386, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8ceb639e-aeed-4c70-92bc-0b9f0f03f65b', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:33.606+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-5 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'fc142b5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1389, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0c996b54-d0dd-4649-8f38-8a909b1fac2a', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:43.206+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-6 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '695db960', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1390, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4fc07870-3236-4593-be56-cbec73f37617', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:46.303+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-3 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47ec8722', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1391, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8ceb639e-aeed-4c70-92bc-0b9f0f03f65b', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:50.659+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-5 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'fc142b5', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1392, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2fcf2b80-69be-45f3-9cfd-46e7a182bcf0', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:51.127+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-8 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30fd3cb1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1398, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2fcf2b80-69be-45f3-9cfd-46e7a182bcf0', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:03.574+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-8 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30fd3cb1', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1399, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9390c5f2-66bf-4da1-9419-976fa86ad83d', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:03.787+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-10 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f4b83de', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1406, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '919a9de3-801c-468a-88c1-26db7c6cf8cc', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:09.537+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-11 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f229187', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1407, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '66e5cb76-a6c2-44f0-bd67-ec377b2f1634', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:11.836+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-12 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5ccaf679', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1408, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9390c5f2-66bf-4da1-9419-976fa86ad83d', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:13.668+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-10 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f4b83de', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1409, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c495f96c-ac39-4ad0-8763-1b27b1f8d399', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:14.225+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-13 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '60b0d59f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1410, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8206b4fd-696f-41a7-ab0c-de3e89f779ed', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:14.387+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-9 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2794fa36', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1428, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d736eb4-580a-4fa2-ad3d-ec1ddce24f07', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:30.087+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-12 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '592e64d0', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1431, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd5ea0580-dba9-401c-8aba-efe007b594c8', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:32.953+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-17 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19a6607', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1432, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd59a9f25-e748-45c5-a428-7166c2fd82f2', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:36.421+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-19 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7be07dfd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1365, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '185a6d56-3e80-4c7e-8040-91f251da09f7', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:33.475+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-9 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37a02de2', '1b8c85a1-bb76-4f15-bc10-0e88d1ad704a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1367, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '185a6d56-3e80-4c7e-8040-91f251da09f7', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:42.257+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-9 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37a02de2', '1b8c85a1-bb76-4f15-bc10-0e88d1ad704a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1369, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '67ad0bc7-759d-4b70-b8d7-831654373e96', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:05.977+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-1 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f4f4e38', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1373, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '22a8a881-f8fe-44de-8f3a-9915a646d4d5', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:15.845+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-3 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '17241340', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1378, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4fc07870-3236-4593-be56-cbec73f37617', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:23.016+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-3 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47ec8722', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1379, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '09c7e7a8-f938-48c1-9a3e-23461aca02ca', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:24.286+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-1 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '354cc151', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1366, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'edd6dcfc-732a-423f-9f11-6b0d381e5f58', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:39:42.236+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-8 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f86cd4e', 'fa1d07e8-754a-486d-983a-5079ab2a4042', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1370, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1020a25-d5ab-493c-b378-28ebd72f57d3', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:11.282+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-2 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fa68265', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1371, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1020a25-d5ab-493c-b378-28ebd72f57d3', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:14.058+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-2 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fa68265', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1377, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '16fb9535-f0d0-4325-b5b2-fdcb7ff4f7c5', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:21.916+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-5 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c965217', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1380, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '16fb9535-f0d0-4325-b5b2-fdcb7ff4f7c5', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:25.29+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-5 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c965217', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1382, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '54a99a16-80ca-491e-a752-232b661536ce', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:25.875+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-4 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20261298', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1387, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'efee80cf-2ba6-4b63-966e-588fcd4bf170', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:37.345+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-7 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6194fae9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1388, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '54a99a16-80ca-491e-a752-232b661536ce', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:37.742+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-4 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20261298', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1393, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f8741086-ff6d-4934-be49-c4aa64b4a5a3', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:51.005+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-6 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1cc08f4d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1394, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'efee80cf-2ba6-4b63-966e-588fcd4bf170', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:51.626+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-7 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6194fae9', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1395, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d36788f-3791-4e49-b9bd-9f0bad87e438', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:52.914+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-7 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4985f867', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1397, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8442facb-713d-40bb-a220-a2723d413b4e', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:50:58.758+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-8 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40c0758e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1400, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f8741086-ff6d-4934-be49-c4aa64b4a5a3', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:05.528+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-6 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1cc08f4d', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1401, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d36788f-3791-4e49-b9bd-9f0bad87e438', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:06.605+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-7 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4985f867', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1402, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8239525c-8498-4eb1-a78b-7b0288901dbb', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:06.604+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-9 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1142cde0', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1403, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8442facb-713d-40bb-a220-a2723d413b4e', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:06.846+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-8 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40c0758e', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1404, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8206b4fd-696f-41a7-ab0c-de3e89f779ed', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:07.675+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-9 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2794fa36', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1405, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '68df3327-bf82-499b-9784-7e9ad69b0215', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:09.13+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-10 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54cd59c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1411, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c6f41a-3a77-4f7e-a64a-a866cf25faa5', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:14.782+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-11 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c7421a4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1412, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '919a9de3-801c-468a-88c1-26db7c6cf8cc', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:15.71+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-11 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f229187', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1413, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '66e5cb76-a6c2-44f0-bd67-ec377b2f1634', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:16.422+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-12 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5ccaf679', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1414, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '68df3327-bf82-499b-9784-7e9ad69b0215', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:16.583+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-10 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54cd59c', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1415, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c3db67-f631-433f-a967-311399fc17bd', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:18.18+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-14 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f3de56d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1416, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d736eb4-580a-4fa2-ad3d-ec1ddce24f07', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:18.545+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-12 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '592e64d0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1417, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6823aa89-e8fe-4eac-a161-5743092bdca8', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:20.61+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-15 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7781d203', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1418, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f91ffb5f-249f-4691-9b2b-b4f8c156579b', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:20.754+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-13 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e75f84b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1419, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c60f58ca-25f7-4393-89e0-64aad342ff41', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:22.614+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-16 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9c75e23', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1420, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4943ba4e-17b8-4740-9c19-3617d6c5c085', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:23.109+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-14 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e6d625a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1421, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f91ffb5f-249f-4691-9b2b-b4f8c156579b', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:26.863+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-13 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e75f84b', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1438, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c60f58ca-25f7-4393-89e0-64aad342ff41', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:39.302+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-16 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9c75e23', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1442, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:40.744+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool RHEL (containing 20 VMs) was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '4770c2f7', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1506, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '919a9de3-801c-468a-88c1-26db7c6cf8cc', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:38.64+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-11 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5725cc53', 'ebb8fa61-247c-4366-9e9c-a33067b4a2e3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1508, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '35f41882-502c-4a12-a240-8412c4ff7129', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:41.048+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-17 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '59eacb7b', '1119d3f9-4fee-49bb-80f8-f7c36f9387bd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1509, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7535733c-4fef-4955-be3d-ccedce883760', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:42.234+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-18 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a9bd2d5', '3575a89f-9811-414a-b919-bf5a2e07e78d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1510, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd59a9f25-e748-45c5-a428-7166c2fd82f2', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:42.846+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-19 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '459aa84', 'ef8682d5-71c6-476d-9b6e-b760a2681981', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1511, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1020a25-d5ab-493c-b378-28ebd72f57d3', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:43.575+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-2 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '55057bb9', '666522d2-90ad-4bc9-b725-0a59418dd340', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1512, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c2b5f0f-e46f-4749-a42c-ba9ba16ca603', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:44.219+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-20 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'bddf4fd', 'c7b6bbe7-0f80-4917-9ace-de9a0da40e5f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1513, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '22a8a881-f8fe-44de-8f3a-9915a646d4d5', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:45.773+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-3 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58aaf6dd', 'c1b99c3f-c4d6-40dd-bfd0-b9b72db2bcee', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1514, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a98333e1-3e08-42a0-8fbf-d1070a1db195', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:46.979+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-4 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '29abbdab', '6cfa4daf-67bc-4f31-9238-4d9a78612f86', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1515, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '16fb9535-f0d0-4325-b5b2-fdcb7ff4f7c5', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:48.038+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-5 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2469be62', 'f0f79a37-c316-415e-86e0-ecee7647633c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1521, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c60f58ca-25f7-4393-89e0-64aad342ff41', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:50.503+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-16 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '500fe5a', 'df5ac686-0354-4b22-a993-20918e180f71', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1537, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'efee80cf-2ba6-4b63-966e-588fcd4bf170', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.636+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-7 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75d22e3c', '37f0a839-b456-4057-b1bb-be001c202a59', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1422, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f996f3d-5b2e-4ba8-a755-26c43c6daadb', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:26.898+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-15 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '23611a68', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1424, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '35f41882-502c-4a12-a240-8412c4ff7129', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:27.024+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-17 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58667c1b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1433, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f996f3d-5b2e-4ba8-a755-26c43c6daadb', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:37.499+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-15 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '23611a68', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1449, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1a9918d6-eb4d-42f8-8c0c-e2cd2624dd5d', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:48.373+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-20 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '43d5f836', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1541, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2fcf2b80-69be-45f3-9cfd-46e7a182bcf0', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.725+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-8 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53b3427c', '9936ca50-907a-4d4c-b424-d98c5f3730dd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1542, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4943ba4e-17b8-4740-9c19-3617d6c5c085', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:02.281+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-14 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c3fce5a', 'dbf85fe5-ae87-447c-8cfe-a4012ea64914', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1543, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f996f3d-5b2e-4ba8-a755-26c43c6daadb', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:03.067+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-15 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6022f17b', '4f4ad94b-47a8-4101-938c-1e46a1402ff4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1423, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6823aa89-e8fe-4eac-a161-5743092bdca8', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:26.997+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-15 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7781d203', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1434, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7535733c-4fef-4955-be3d-ccedce883760', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:37.719+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-18 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7da6cf32', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1439, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c2b5f0f-e46f-4749-a42c-ba9ba16ca603', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:39.342+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-20 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35f6c838', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1441, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f89f414c-e931-4633-b535-ba1e8cd9f1c9', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:40.338+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-18 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57f4044d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1443, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a60064ee-8e99-4641-9aa1-20f832750eea', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:41.838+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-19 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2575f242', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1444, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1a9918d6-eb4d-42f8-8c0c-e2cd2624dd5d', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:42.988+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-20 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '43d5f836', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1448, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c2b5f0f-e46f-4749-a42c-ba9ba16ca603', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:48.367+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-20 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35f6c838', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1472, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '68df3327-bf82-499b-9784-7e9ad69b0215', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:11.944+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-10 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d6bcb23', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1473, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c6f41a-3a77-4f7e-a64a-a866cf25faa5', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.006+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-11 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c726d02', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1474, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d736eb4-580a-4fa2-ad3d-ec1ddce24f07', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.077+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-12 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25b6e925', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1475, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f91ffb5f-249f-4691-9b2b-b4f8c156579b', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.126+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-13 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd6535f2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1476, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4943ba4e-17b8-4740-9c19-3617d6c5c085', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.16+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-14 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f610089', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1477, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f996f3d-5b2e-4ba8-a755-26c43c6daadb', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.351+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-15 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6fe30078', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1478, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'db8bb060-316d-4f20-bb9e-7ce3d79cbd87', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.406+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-16 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '376cd187', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1479, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd5ea0580-dba9-401c-8aba-efe007b594c8', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.551+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-17 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58b683c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1480, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f89f414c-e931-4633-b535-ba1e8cd9f1c9', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.581+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-18 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3eb8ecbb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1481, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a60064ee-8e99-4641-9aa1-20f832750eea', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.627+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-19 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '506b1d67', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1482, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ef69bea-bebc-4426-987b-9429a80375e3', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.657+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-2 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7ba8ef54', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1483, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1a9918d6-eb4d-42f8-8c0c-e2cd2624dd5d', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.708+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-20 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c0aa8dd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1484, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4fc07870-3236-4593-be56-cbec73f37617', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.745+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-3 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '441e3008', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1485, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '54a99a16-80ca-491e-a752-232b661536ce', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.809+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-4 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c1a483c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1486, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8ceb639e-aeed-4c70-92bc-0b9f0f03f65b', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.853+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-5 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b0a1b88', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1487, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f8741086-ff6d-4934-be49-c4aa64b4a5a3', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.92+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-6 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '288980c6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1488, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d36788f-3791-4e49-b9bd-9f0bad87e438', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:12.963+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-7 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '132e0d20', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1489, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8442facb-713d-40bb-a220-a2723d413b4e', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:13.01+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-8 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e97a623', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1490, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8206b4fd-696f-41a7-ab0c-de3e89f779ed', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:13.044+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-9 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30cc6874', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1491, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '09c7e7a8-f938-48c1-9a3e-23461aca02ca', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:13.073+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-1 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4ed4380b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1492, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 11:52:13.123+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool XP was removed by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '234d26e4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1493, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '919a9de3-801c-468a-88c1-26db7c6cf8cc', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:28.053+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-11 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5725cc53', 'ebb8fa61-247c-4366-9e9c-a33067b4a2e3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1425, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c6f41a-3a77-4f7e-a64a-a866cf25faa5', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:29.229+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-11 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c7421a4', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1500, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c60f58ca-25f7-4393-89e0-64aad342ff41', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:37.793+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-16 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '500fe5a', 'df5ac686-0354-4b22-a993-20918e180f71', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1502, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c495f96c-ac39-4ad0-8763-1b27b1f8d399', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:38.319+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-13 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7ed8132', '138ad9e1-1ae3-4834-b5ed-bee3353767c9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1517, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd59a9f25-e748-45c5-a428-7166c2fd82f2', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:49.159+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-19 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '459aa84', 'ef8682d5-71c6-476d-9b6e-b760a2681981', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1539, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c6f41a-3a77-4f7e-a64a-a866cf25faa5', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.639+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-11 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f0f50a9', 'bf290d44-6395-4ecf-9fbd-ea8ef8480915', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1426, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c3db67-f631-433f-a967-311399fc17bd', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:29.376+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-14 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f3de56d', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1427, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c495f96c-ac39-4ad0-8763-1b27b1f8d399', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:30.085+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-13 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '60b0d59f', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1429, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'db8bb060-316d-4f20-bb9e-7ce3d79cbd87', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:30.931+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-16 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d09ffe9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1430, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7535733c-4fef-4955-be3d-ccedce883760', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:31.638+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM RHEL-18 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7da6cf32', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1440, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4943ba4e-17b8-4740-9c19-3617d6c5c085', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:40.312+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-14 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e6d625a', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1447, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd59a9f25-e748-45c5-a428-7166c2fd82f2', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:48.15+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-19 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7be07dfd', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1450, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f89f414c-e931-4633-b535-ba1e8cd9f1c9', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:48.524+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-18 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57f4044d', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1451, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '67ad0bc7-759d-4b70-b8d7-831654373e96', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:00.683+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-1 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7340efa8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1452, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9390c5f2-66bf-4da1-9419-976fa86ad83d', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:00.829+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-10 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2eda0eb9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1453, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '919a9de3-801c-468a-88c1-26db7c6cf8cc', 'RHEL-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:00.912+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-11 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50c129d2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1454, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c495f96c-ac39-4ad0-8763-1b27b1f8d399', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.122+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-13 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '182a7439', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1455, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c3db67-f631-433f-a967-311399fc17bd', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.173+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-14 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15cc2858', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1456, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6823aa89-e8fe-4eac-a161-5743092bdca8', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.215+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-15 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '259a157b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1457, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c60f58ca-25f7-4393-89e0-64aad342ff41', 'RHEL-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.241+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-16 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37f4b5f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1458, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '35f41882-502c-4a12-a240-8412c4ff7129', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.278+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-17 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c307212', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1459, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7535733c-4fef-4955-be3d-ccedce883760', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.309+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-18 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a4de7e8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1460, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd59a9f25-e748-45c5-a428-7166c2fd82f2', 'RHEL-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.35+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-19 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c3525f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1461, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1020a25-d5ab-493c-b378-28ebd72f57d3', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.4+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-2 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b6c8d2e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1462, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c2b5f0f-e46f-4749-a42c-ba9ba16ca603', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.428+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-20 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3930aa1a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1463, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '22a8a881-f8fe-44de-8f3a-9915a646d4d5', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.523+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-3 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c921197', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1464, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a98333e1-3e08-42a0-8fbf-d1070a1db195', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.581+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-4 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58b79d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1465, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '16fb9535-f0d0-4325-b5b2-fdcb7ff4f7c5', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.616+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-5 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b532c71', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1466, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0c996b54-d0dd-4649-8f38-8a909b1fac2a', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.683+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-6 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7427ece2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1467, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'efee80cf-2ba6-4b63-966e-588fcd4bf170', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.754+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-7 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '52b7d7e9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1468, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2fcf2b80-69be-45f3-9cfd-46e7a182bcf0', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.794+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-8 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47f5a5e3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1469, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8239525c-8498-4eb1-a78b-7b0288901dbb', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.854+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-9 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a93f29c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1470, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '66e5cb76-a6c2-44f0-bd67-ec377b2f1634', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:01.884+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM RHEL-12 was removed from VM Pool RHEL by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f7860c7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1471, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 11:52:01.924+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool RHEL was removed by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3532ac94', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1518, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '22a8a881-f8fe-44de-8f3a-9915a646d4d5', 'RHEL-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:49.256+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-3 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58aaf6dd', 'c1b99c3f-c4d6-40dd-bfd0-b9b72db2bcee', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1523, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '7535733c-4fef-4955-be3d-ccedce883760', 'RHEL-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:50.885+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-18 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a9bd2d5', '3575a89f-9811-414a-b919-bf5a2e07e78d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1435, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd5ea0580-dba9-401c-8aba-efe007b594c8', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:38.084+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-17 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19a6607', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1501, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '67ad0bc7-759d-4b70-b8d7-831654373e96', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:38.213+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-1 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72f2fe56', '148ced94-2c54-462d-9021-efdc92a6c1d0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1519, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1020a25-d5ab-493c-b378-28ebd72f57d3', 'RHEL-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:49.33+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-2 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '55057bb9', '666522d2-90ad-4bc9-b725-0a59418dd340', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1524, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '16fb9535-f0d0-4325-b5b2-fdcb7ff4f7c5', 'RHEL-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:50.886+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-5 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2469be62', 'f0f79a37-c316-415e-86e0-ecee7647633c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1526, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'efee80cf-2ba6-4b63-966e-588fcd4bf170', 'RHEL-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:52.216+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-7 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75d22e3c', '37f0a839-b456-4057-b1bb-be001c202a59', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1527, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2fcf2b80-69be-45f3-9cfd-46e7a182bcf0', 'RHEL-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:53.657+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-8 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53b3427c', '9936ca50-907a-4d4c-b424-d98c5f3730dd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1528, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8239525c-8498-4eb1-a78b-7b0288901dbb', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:54.573+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-9 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '467cea26', '358b090e-ccb2-40e4-a24d-205fe12a1223', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1529, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '09c7e7a8-f938-48c1-9a3e-23461aca02ca', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:56.387+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-1 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d558e94', 'ee2bf8c6-6ac6-497e-8948-ed143cabce05', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1530, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '68df3327-bf82-499b-9784-7e9ad69b0215', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:57.253+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-10 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '790d1158', 'ff91ce05-410c-47ab-bbd4-06260f274b3b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1531, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c6f41a-3a77-4f7e-a64a-a866cf25faa5', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:58.072+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-11 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f0f50a9', 'bf290d44-6395-4ecf-9fbd-ea8ef8480915', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1532, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d736eb4-580a-4fa2-ad3d-ec1ddce24f07', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:58.852+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-12 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40aef333', '1dda8d34-7de9-44f3-922e-83a9a5157bf0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1533, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '09c7e7a8-f938-48c1-9a3e-23461aca02ca', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.287+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-1 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d558e94', 'ee2bf8c6-6ac6-497e-8948-ed143cabce05', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1436, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '35f41882-502c-4a12-a240-8412c4ff7129', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:38.231+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM RHEL-17 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58667c1b', '877bea21-32b6-4866-ae66-e46ac83bedf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1507, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c3db67-f631-433f-a967-311399fc17bd', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:38.799+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-14 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2068385e', 'b3a16e7a-64a6-4bca-abbc-1cf65666e867', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1516, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '35f41882-502c-4a12-a240-8412c4ff7129', 'RHEL-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:48.971+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-17 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '59eacb7b', '1119d3f9-4fee-49bb-80f8-f7c36f9387bd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1520, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a98333e1-3e08-42a0-8fbf-d1070a1db195', 'RHEL-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:49.58+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-4 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '29abbdab', '6cfa4daf-67bc-4f31-9238-4d9a78612f86', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1535, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '68df3327-bf82-499b-9784-7e9ad69b0215', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.36+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-10 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '790d1158', 'ff91ce05-410c-47ab-bbd4-06260f274b3b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1536, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0c996b54-d0dd-4649-8f38-8a909b1fac2a', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.413+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-6 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66738860', '945bd871-7b50-457b-89fb-e96e5d1ac7fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1437, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'db8bb060-316d-4f20-bb9e-7ce3d79cbd87', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:39.019+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-16 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d09ffe9', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1503, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6823aa89-e8fe-4eac-a161-5743092bdca8', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:38.388+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-15 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '768ffe30', '589f13e4-3b63-40b1-b357-a7b79516f1bd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1505, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9390c5f2-66bf-4da1-9419-976fa86ad83d', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:38.583+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-10 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4730ae41', 'e4bdc93c-792a-4958-93b0-b6eb45fdec33', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1538, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8239525c-8498-4eb1-a78b-7b0288901dbb', 'RHEL-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.635+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-9 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '467cea26', '358b090e-ccb2-40e4-a24d-205fe12a1223', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1445, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:43.131+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool XP (containing 20 VMs) was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '35376e72', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1446, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a60064ee-8e99-4641-9aa1-20f832750eea', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:51:47.932+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-19 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2575f242', 'c549eca0-099d-4742-b168-7df2a27cc143', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1494, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '67ad0bc7-759d-4b70-b8d7-831654373e96', 'RHEL-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:28.921+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-1 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72f2fe56', '148ced94-2c54-462d-9021-efdc92a6c1d0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1495, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9390c5f2-66bf-4da1-9419-976fa86ad83d', 'RHEL-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:30.382+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-10 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4730ae41', 'e4bdc93c-792a-4958-93b0-b6eb45fdec33', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1496, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '66e5cb76-a6c2-44f0-bd67-ec377b2f1634', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:31.465+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-12 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '259745c', 'b0d888ac-e5a0-4315-a57a-d776a311e58d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1497, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c495f96c-ac39-4ad0-8763-1b27b1f8d399', 'RHEL-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:32.364+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-13 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7ed8132', '138ad9e1-1ae3-4834-b5ed-bee3353767c9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1498, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '42c3db67-f631-433f-a967-311399fc17bd', 'RHEL-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:33.631+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-14 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2068385e', 'b3a16e7a-64a6-4bca-abbc-1cf65666e867', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1499, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6823aa89-e8fe-4eac-a161-5743092bdca8', 'RHEL-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:34.357+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-15 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '768ffe30', '589f13e4-3b63-40b1-b357-a7b79516f1bd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1504, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '66e5cb76-a6c2-44f0-bd67-ec377b2f1634', 'RHEL-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:38.541+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-12 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '259745c', 'b0d888ac-e5a0-4315-a57a-d776a311e58d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1522, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c2b5f0f-e46f-4749-a42c-ba9ba16ca603', 'RHEL-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:50.808+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM RHEL-20 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'bddf4fd', 'c7b6bbe7-0f80-4917-9ace-de9a0da40e5f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1525, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '0c996b54-d0dd-4649-8f38-8a909b1fac2a', 'RHEL-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 11:52:50.9+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM RHEL-6 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66738860', '945bd871-7b50-457b-89fb-e96e5d1ac7fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1534, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d736eb4-580a-4fa2-ad3d-ec1ddce24f07', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.354+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-12 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40aef333', '1dda8d34-7de9-44f3-922e-83a9a5157bf0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1540, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f91ffb5f-249f-4691-9b2b-b4f8c156579b', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:01.722+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-13 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '138d7f73', '5f272d4b-48fb-483a-86d2-f2a7b82184fe', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1544, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'db8bb060-316d-4f20-bb9e-7ce3d79cbd87', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:03.873+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-16 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d5ac9c0', 'c88ddb3a-3324-43c3-9495-ba3c2906193c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1545, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd5ea0580-dba9-401c-8aba-efe007b594c8', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:05.963+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-17 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12a441c3', '62ec03f7-c0d9-4f43-85c3-562ef21d3c31', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1546, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f89f414c-e931-4633-b535-ba1e8cd9f1c9', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:06.992+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-18 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '32c128d5', '89b9de2d-c738-4aa0-aa85-19796ddc27d6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1547, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a60064ee-8e99-4641-9aa1-20f832750eea', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:07.635+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-19 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '442cdbd1', '917af00d-97af-4f03-b5e0-42e2684ef02f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1548, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ef69bea-bebc-4426-987b-9429a80375e3', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:08.587+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-2 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c11767b', 'ab57042a-54e8-4b03-861a-c99b619899a5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1549, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1a9918d6-eb4d-42f8-8c0c-e2cd2624dd5d', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:10.777+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-20 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '122d3b57', '02034361-0f02-452f-a39d-bb43aad2bf0c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1550, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f89f414c-e931-4633-b535-ba1e8cd9f1c9', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.392+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-18 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '32c128d5', '89b9de2d-c738-4aa0-aa85-19796ddc27d6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1551, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f91ffb5f-249f-4691-9b2b-b4f8c156579b', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.402+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-13 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '138d7f73', '5f272d4b-48fb-483a-86d2-f2a7b82184fe', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1552, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a60064ee-8e99-4641-9aa1-20f832750eea', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.453+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-19 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '442cdbd1', '917af00d-97af-4f03-b5e0-42e2684ef02f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1553, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'db8bb060-316d-4f20-bb9e-7ce3d79cbd87', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.457+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-16 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d5ac9c0', 'c88ddb3a-3324-43c3-9495-ba3c2906193c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1554, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1a9918d6-eb4d-42f8-8c0c-e2cd2624dd5d', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.541+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-20 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '122d3b57', '02034361-0f02-452f-a39d-bb43aad2bf0c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1555, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4943ba4e-17b8-4740-9c19-3617d6c5c085', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.565+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-14 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c3fce5a', 'dbf85fe5-ae87-447c-8cfe-a4012ea64914', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1556, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd5ea0580-dba9-401c-8aba-efe007b594c8', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.612+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-17 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12a441c3', '62ec03f7-c0d9-4f43-85c3-562ef21d3c31', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1557, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ef69bea-bebc-4426-987b-9429a80375e3', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.658+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-2 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c11767b', 'ab57042a-54e8-4b03-861a-c99b619899a5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1558, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f996f3d-5b2e-4ba8-a755-26c43c6daadb', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.665+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-15 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6022f17b', '4f4ad94b-47a8-4101-938c-1e46a1402ff4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1559, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4fc07870-3236-4593-be56-cbec73f37617', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:12.676+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-3 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20a23c3d', 'ec342290-f8fa-4090-841c-1efd02b930fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1560, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '54a99a16-80ca-491e-a752-232b661536ce', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:13.549+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-4 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2306af0c', 'cae482dc-fa2a-409f-8097-3eff63e29da0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1561, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8ceb639e-aeed-4c70-92bc-0b9f0f03f65b', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:14.3+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-5 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '779e2fad', 'e5f06c1e-2ce7-4b64-9ee2-f396a23b744d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1562, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f8741086-ff6d-4934-be49-c4aa64b4a5a3', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:15.725+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-6 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2debcbdf', '7bd08459-1a17-41fe-8df6-1c7257ed1eaa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1563, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d36788f-3791-4e49-b9bd-9f0bad87e438', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:16.515+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-7 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '418dc22b', '2590bf73-956b-4053-8e78-795a45b58c7e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1564, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8442facb-713d-40bb-a220-a2723d413b4e', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:17.091+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-8 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '413c2c13', '21fdc9ac-2a22-42b1-9a08-80eb0e41fcb7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1565, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8206b4fd-696f-41a7-ab0c-de3e89f779ed', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:18.295+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-9 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3ca8613f', '06639985-9a1f-4a1c-a47b-dbc332b1851b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1566, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5d36788f-3791-4e49-b9bd-9f0bad87e438', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:22.779+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-7 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '418dc22b', '2590bf73-956b-4053-8e78-795a45b58c7e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1567, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8442facb-713d-40bb-a220-a2723d413b4e', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:22.779+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-8 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '413c2c13', '21fdc9ac-2a22-42b1-9a08-80eb0e41fcb7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1568, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8206b4fd-696f-41a7-ab0c-de3e89f779ed', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:22.792+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-9 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3ca8613f', '06639985-9a1f-4a1c-a47b-dbc332b1851b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1569, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '8ceb639e-aeed-4c70-92bc-0b9f0f03f65b', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:22.893+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-5 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '779e2fad', 'e5f06c1e-2ce7-4b64-9ee2-f396a23b744d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1570, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4fc07870-3236-4593-be56-cbec73f37617', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:22.945+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-3 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20a23c3d', 'ec342290-f8fa-4090-841c-1efd02b930fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1571, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '54a99a16-80ca-491e-a752-232b661536ce', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:22.973+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-4 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2306af0c', 'cae482dc-fa2a-409f-8097-3eff63e29da0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1572, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f8741086-ff6d-4934-be49-c4aa64b4a5a3', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 11:53:23.072+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-6 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2debcbdf', '7bd08459-1a17-41fe-8df6-1c7257ed1eaa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1578, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:17.998+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-1 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5bd84e0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1580, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:20.038+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-3 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '704ec9e2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1581, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:22.118+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-4 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45ac7fbe', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1583, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:23.541+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-1 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5bd84e0', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1589, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:27.334+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-8 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2833d2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1590, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:27.991+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-2 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c21a8d7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1591, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:28.577+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-9 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '463b3884', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1592, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:29.304+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-3 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '529c9cdc', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1606, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:37.163+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-2 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c21a8d7', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1609, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:37.809+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-7 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a952dfd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1611, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:38.242+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-13 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '59d6ba56', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1575, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', NULL, NULL, '2012-12-16 13:02:30.239+02', 'USER_FAILED_UPDATE_VM_TEMPLATE', 109, 2, 'Failed to update Template NFS-RHEL6_iSCSI (User: admin@internal).', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '558ddcd9', '68ed09ee-3e27-4f5c-b084-98456f5291f9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1576, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:02:53.037+02', 'USER_UPDATE_VM_TEMPLATE', 49, 0, 'Template NFS-RHEL6_iSCSI_Copy parameters were updated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '70ceca41', '43a49b98-9fd5-4188-a0a2-caef9d3a65d7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1585, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:24.506+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-2 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25777907', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1597, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:33.566+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-10 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2359ff05', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1601, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:35.859+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-5 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1eeb6a46', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1624, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:46.704+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-8 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2874669f', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1625, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:46.744+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-14 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37c44ae4', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1631, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:48.069+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-18 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f030dd1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1633, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:48.914+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-19 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7842b2ca', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1643, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:56.726+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-20 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d87dc68', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1577, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:03.275+02', 'USER_UPDATE_VM_TEMPLATE', 49, 0, 'Template XP_iSCSI_Copy parameters were updated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31307315', '2d608c83-9230-43d5-b9ed-4b60a47ccaf9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1620, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:45.134+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-15 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '77c1e4a5', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1621, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:45.219+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-17 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4cc99438', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1651, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:58.375+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-11 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1fcf31fc', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1665, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.807+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-18 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'f69aa3f', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1686, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:14.921+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-14 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '357e9ee9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1687, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:14.973+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-15 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '737f085d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1688, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.02+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-16 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '17f5a7a8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1689, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.075+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-17 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '16ee952e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1690, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.107+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-18 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '622d2cb1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1691, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.148+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-19 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19adf680', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1692, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.174+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-2 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '325f9721', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1693, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.22+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-20 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a33e7da', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1694, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.292+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-3 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fdf783b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1695, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:15.396+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-4 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '714f183a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1696, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:16.47+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-5 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4516cd1b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1697, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:16.776+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-6 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2921f82d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1698, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:16.841+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-7 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '13e365c8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1699, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:16.893+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-8 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b9b3e60', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1700, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:16.937+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-9 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '39b6334', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1701, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 13:04:17.047+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool XP was removed by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25801f87', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1579, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:19.361+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-2 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25777907', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1586, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:24.535+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-6 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '704b4429', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1600, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:35.092+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-3 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '529c9cdc', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1602, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:35.885+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-12 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '48916840', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1646, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:57.607+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-18 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f030dd1', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1648, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:57.901+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-16 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '656fd85f', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1650, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:58.121+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-18 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'f69aa3f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1654, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:01.287+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool XP (containing 20 VMs) was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '57ff06ff', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1662, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.539+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-17 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2680f7e3', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1666, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.867+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-16 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4d7eb829', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1667, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.94+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-17 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49f42aba', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1669, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.025+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-18 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'f7cf82c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1670, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.166+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-19 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c594fdb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1703, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:23.663+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-4 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c14d22', '78443845-3345-43f9-9055-517bedd80ec7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1708, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:27.219+02', 'USER_STARTED_VM', 153, 0, 'VM XP-4 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f75a48', '3dbe9eaf-8502-4ca2-a3f9-e0292979ec35', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1582, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:23.057+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-5 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1eeb6a46', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1584, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:24.289+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-3 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '704ec9e2', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1587, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:26.165+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-7 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f154d7e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1588, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:26.261+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-1 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ea6ff99', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1604, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:36.148+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-6 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c9aff47', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1619, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:44.929+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-5 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '428fe544', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1622, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:45.908+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-9 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f9c3666', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1649, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:58.094+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-14 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b0541b5', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1652, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:58.984+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-19 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5324090f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1653, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:00.277+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-20 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b956b83', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1655, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.13+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-6 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d48d6ef', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1656, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.28+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-1 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d7739f1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1658, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.33+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-10 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '328622b5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1659, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.381+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-11 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36c76be6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1660, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.408+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-12 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b9b6cfe', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1661, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.526+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-13 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47888681', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1663, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.664+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-14 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '16b827f7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1664, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.714+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-15 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e24b733', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1681, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:14.552+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-1 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e6bf29', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1682, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:14.653+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-10 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '126e0463', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1683, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:14.731+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-11 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3eb4478d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1684, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:14.779+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-12 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6261ba70', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1685, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:14.856+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM XP-13 was removed from VM Pool XP by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '17154666', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1593, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:30.284+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-10 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2359ff05', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1594, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:31.773+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-4 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7765b148', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1595, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:32.466+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-11 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a372a1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1596, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:32.969+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-5 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '428fe544', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1598, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:33.899+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-1 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ea6ff99', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1599, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:34.983+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-9 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '463b3884', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1603, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:36.127+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-4 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7765b148', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1605, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:37.077+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-7 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f154d7e', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1607, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:37.284+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-8 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2833d2', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1608, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:37.779+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-4 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45ac7fbe', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1610, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:38.223+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-6 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '704b4429', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1612, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:39.005+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-8 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2874669f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1613, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:39.799+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-14 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37c44ae4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1614, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:40.304+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-9 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f9c3666', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1615, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:41.504+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-15 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '77c1e4a5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1616, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:42.519+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-10 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '371c2bd1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1617, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:43.538+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-16 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '656fd85f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1618, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:43.88+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-11 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1fcf31fc', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1623, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:46.504+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-11 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a372a1', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1626, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:46.937+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-6 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c9aff47', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1627, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:47.038+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-13 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '59d6ba56', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1628, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:47.276+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-7 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a952dfd', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1629, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:47.383+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-12 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5812db06', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1630, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:47.848+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-12 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '48916840', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1632, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:48.762+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-13 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61117551', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1634, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:49.822+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-14 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b0541b5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1635, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:50.442+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM NFS-20 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d87dc68', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1636, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:51.089+02', 'USER_ADD_VM_POOL_WITH_VMS', 302, 0, 'VM Pool NFS (containing 20 VMs) was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '13eecc9f', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1638, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:52.483+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-16 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f0b869', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1637, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:51.498+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-15 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a4817e6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1641, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:55.293+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-12 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5812db06', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1639, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:53.489+02', 'USER_ADD_VM_STARTED', 37, 0, 'VM XP-17 creation was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2680f7e3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1647, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:57.874+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-10 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '371c2bd1', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1668, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.002+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-20 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b956b83', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1672, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.312+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-2 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1497752f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1673, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.384+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-20 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4042ef0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1674, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.577+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-3 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c6a86f0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1675, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.641+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-4 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41370175', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1676, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.692+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-5 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6eb9e3d5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1677, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.784+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-7 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b8f3590', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1678, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.869+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-8 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c2690a0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1679, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.913+02', 'USER_REMOVE_VM_FROM_POOL', 308, 0, 'VM NFS-9 was removed from VM Pool NFS by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53cde378', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1680, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 13:04:08.993+02', 'USER_REMOVE_VM_POOL', 304, 0, 'VM Pool NFS was removed by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '152199e5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1723, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:34.217+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-12 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30feb146', 'b3786f66-610d-44b1-a92c-eb6f01bdca2c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1724, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:34.44+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-7 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '510b3adc', '939a9a70-5ade-4508-bc9d-5001a5bc6652', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1725, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:34.613+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-1 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '743b4b35', '685dca69-6826-4ed0-ac92-8b0aecddaf18', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1726, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:34.807+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-8 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '51fc6e01', 'd04b5b22-2377-4490-a7b5-60288bb68bfb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1727, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:35.024+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-3 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1748d04b', '823eea89-64a8-4601-b692-ab0c203aac8d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1728, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:35.334+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-13 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '254314ff', '98f02718-ddaa-4f82-9686-087a7258c844', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1729, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:36.69+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-18 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e2dfba0', 'dc2190f2-f0e3-44f4-a41c-09fb63f4b09a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1730, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:36.947+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-13 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fad6', '318b0466-077d-46b7-8ace-89fc6eaa63aa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1736, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:38.522+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-5 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a722abe', 'bde2a7f7-75ef-4626-8c60-671c65840a6d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1738, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:39.008+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-14 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c3982aa', '5f64a407-e29e-400c-ad7d-bc760b77784a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1739, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:39.213+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-8 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e09197e', 'fa5a7ac6-1597-4572-a494-442b9b9559a9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1740, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:39.377+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-9 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2bbf976b', 'b87d5d40-b208-4e6d-9028-5d34f42974e6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1741, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:39.542+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-15 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76899851', '3afb7f53-43b4-4a8d-a4cc-5ab592f98ce6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1756, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:34.721+02', 'USER_RUN_VM', 32, 0, 'VM XP-11 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7311b374', '9ef42c20-b2ba-4684-aa68-72aa4d268873', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1757, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:34.771+02', 'USER_RUN_VM', 32, 0, 'VM NFS-6 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3754ecda', 'bcae5a83-d341-4649-a589-a7091d98d983', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1758, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:34.82+02', 'USER_RUN_VM', 32, 0, 'VM XP-17 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2e6f71a6', 'e31ed104-7fe3-46e3-b9d8-5d3cf41b288e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1640, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:55.139+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-19 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7842b2ca', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1645, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:57.058+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM NFS-17 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4cc99438', 'af799da9-3686-43c0-b148-e116c5c4d424', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1657, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:07.305+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-16 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f0b869', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1642, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:56.527+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-13 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61117551', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1702, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:23.252+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-1 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd6e64e7', '267546b8-44a2-4c3b-af49-fa290b3c517f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1704, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:24.242+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-5 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '77d568a0', '4838a712-2828-4377-a60a-a9518dce6da5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1714, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:29.66+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-3 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f38efce', 'bc230fe9-fb80-4bfa-b410-053a4b45a90c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1715, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:29.895+02', 'USER_STARTED_VM', 153, 0, 'VM XP-10 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '209a82bd', '5c12354b-2108-412f-91eb-fd9d20007b7b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1716, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:31.593+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-16 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2916ace8', '364a9d2f-af22-4569-99f3-9bfd7bd0b543', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1720, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:33.125+02', 'USER_STARTED_VM', 153, 0, 'VM XP-18 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '590ae2ef', '173b7617-1bec-424b-915a-065a947103b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1721, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:33.368+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-6 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3754ecda', 'bcae5a83-d341-4649-a589-a7091d98d983', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1722, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:33.925+02', 'USER_STARTED_VM', 153, 0, 'VM XP-7 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26041851', '8be9392b-eb81-40cb-9cc5-33caf4c521f3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1733, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:38.038+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-19 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '412835ce', '9d5fd952-e8d1-4030-8dbd-a74b7f389ec4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1734, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:38.189+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-20 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '252856e4', 'a7d1f1e2-4230-4175-8725-80e298f0fbd6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1735, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:38.372+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-11 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d2806e8', 'd97099bc-37a9-4384-9fcd-fc9a6af98c99', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1737, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:38.838+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-12 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45064677', '2a853d48-4ce3-4ce3-af31-c6440ee3f78a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1644, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:03:56.862+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-15 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a4817e6', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1705, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:24.608+02', 'USER_STARTED_VM', 153, 0, 'VM XP-2 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30ce46b1', '8ea4016e-8611-4cfb-8a56-b61ff2993123', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1706, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:24.95+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-9 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '56ead6c0', '0d879177-3c14-4283-abaf-c84eb0502899', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1707, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:26.399+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-10 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1a298964', 'e8945145-be5f-4349-99dc-64193fc1eae4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1709, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:27.619+02', 'USER_STARTED_VM', 153, 0, 'VM XP-6 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '264f5baa', 'd65d0474-6524-4156-a1c1-c715864e8038', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1710, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:27.916+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-14 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '60b1696b', '5d037392-0669-410b-8989-7d3eede4bfa6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1711, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:28.178+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-15 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7aef37bf', '89f2b750-83b2-4356-a145-e0418b2f7352', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1717, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:32.204+02', 'USER_STARTED_VM', 153, 0, 'VM XP-11 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7311b374', '9ef42c20-b2ba-4684-aa68-72aa4d268873', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1742, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:24.646+02', 'USER_RUN_VM', 32, 0, 'VM NFS-1 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd6e64e7', '267546b8-44a2-4c3b-af49-fa290b3c517f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1743, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:24.684+02', 'USER_RUN_VM', 32, 0, 'VM NFS-4 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c14d22', '78443845-3345-43f9-9055-517bedd80ec7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1744, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:27.301+02', 'USER_RUN_VM', 32, 0, 'VM NFS-5 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '77d568a0', '4838a712-2828-4377-a60a-a9518dce6da5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1745, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:27.403+02', 'USER_RUN_VM', 32, 0, 'VM XP-2 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30ce46b1', '8ea4016e-8611-4cfb-8a56-b61ff2993123', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1746, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:27.51+02', 'USER_RUN_VM', 32, 0, 'VM NFS-9 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '56ead6c0', '0d879177-3c14-4283-abaf-c84eb0502899', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1747, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:27.594+02', 'USER_RUN_VM', 32, 0, 'VM NFS-10 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1a298964', 'e8945145-be5f-4349-99dc-64193fc1eae4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1748, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:27.672+02', 'USER_RUN_VM', 32, 0, 'VM XP-4 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f75a48', '3dbe9eaf-8502-4ca2-a3f9-e0292979ec35', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1749, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:30.301+02', 'USER_RUN_VM', 32, 0, 'VM XP-10 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '209a82bd', '5c12354b-2108-412f-91eb-fd9d20007b7b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1750, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:30.338+02', 'USER_RUN_VM', 32, 0, 'VM NFS-14 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '60b1696b', '5d037392-0669-410b-8989-7d3eede4bfa6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1751, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:31.859+02', 'USER_RUN_VM', 32, 0, 'VM XP-6 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '264f5baa', 'd65d0474-6524-4156-a1c1-c715864e8038', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1752, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:31.997+02', 'USER_RUN_VM', 32, 0, 'VM XP-16 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7773e43f', '70c2ae1b-f1f3-449b-8760-9c6e4733cd21', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1753, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:32.125+02', 'USER_RUN_VM', 32, 0, 'VM NFS-2 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '189b9c87', '6e927f98-080c-4d38-984a-5e4534163222', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1754, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:32.197+02', 'USER_RUN_VM', 32, 0, 'VM NFS-15 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7aef37bf', '89f2b750-83b2-4356-a145-e0418b2f7352', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1755, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:32.373+02', 'USER_RUN_VM', 32, 0, 'VM NFS-3 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f38efce', 'bc230fe9-fb80-4bfa-b410-053a4b45a90c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1671, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-16 13:04:08.166+02', 'USER_ADD_VM_FINISHED_SUCCESS', 53, 0, 'VM XP-19 creation has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5324090f', '68ea83fe-0c69-4ebd-a44b-bc647a72b540', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1712, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:28.522+02', 'USER_STARTED_VM', 153, 0, 'VM XP-16 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7773e43f', '70c2ae1b-f1f3-449b-8760-9c6e4733cd21', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1713, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:29.199+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-2 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '189b9c87', '6e927f98-080c-4d38-984a-5e4534163222', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1718, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:32.47+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-17 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '798d5cf6', '7f1157b9-91d9-43f1-9121-017319823b3e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1719, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:04:32.767+02', 'USER_STARTED_VM', 153, 0, 'VM XP-17 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2e6f71a6', 'e31ed104-7fe3-46e3-b9d8-5d3cf41b288e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1731, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:37.15+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-19 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a789afc', '388d3423-7b5a-43f0-b028-bf0ae0586ef6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1732, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 13:04:37.771+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM NFS-20 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73bc6454', '8e2b610d-eca7-4036-b0a9-fcf2c5aa1ee7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1759, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:34.849+02', 'USER_RUN_VM', 32, 0, 'VM NFS-16 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2916ace8', '364a9d2f-af22-4569-99f3-9bfd7bd0b543', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1760, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:34.925+02', 'USER_RUN_VM', 32, 0, 'VM NFS-17 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '798d5cf6', '7f1157b9-91d9-43f1-9121-017319823b3e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1761, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:34.986+02', 'USER_RUN_VM', 32, 0, 'VM XP-18 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '590ae2ef', '173b7617-1bec-424b-915a-065a947103b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1762, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 13:05:35.124+02', 'USER_RUN_VM', 32, 0, 'VM XP-7 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26041851', '8be9392b-eb81-40cb-9cc5-33caf4c521f3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1763, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 13:42:14.851+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '56051735', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1764, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 13:59:32.058+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1765, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:22.903+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-13 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4547bd18', '33526b95-827a-4272-8dd3-230dce94d37f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1766, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:23.217+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-11 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'daef303', '9d05419e-bc0b-440f-9ecc-9e33065f429f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1767, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:23.57+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-12 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79215270', '7918e7a7-01b3-4e66-bc1c-1fce5dd4c18f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1768, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:26.792+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-18 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e8fd064', 'e8729f04-3e9f-4fd2-9423-5d527fcbca76', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1769, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:27.358+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-19 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a2f9a91', 'efff47be-5b4f-49e2-83f2-1f45d606f1ff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1770, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:29.616+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-20 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a7a2a58', 'a5477c1f-66a6-4257-bf2b-cdc4c5138256', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1771, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:32.033+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-7 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c16cbbb', '0ae46ad7-1683-4062-907c-ab3f10290922', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1772, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:32.317+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-8 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '91d56b1', '716612ba-6ea5-4518-8c9b-ec067ef87de4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1773, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:35.759+02', 'USER_STARTED_VM', 153, 0, 'VM XP-1 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7db62c27', '83a97bab-e10a-40b8-aeca-b66946753563', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1774, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:39.569+02', 'USER_STARTED_VM', 153, 0, 'VM XP-12 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a86a9d4', 'edf0bd9a-0404-4439-9c77-6fce32f7ede3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1775, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:00:40.662+02', 'USER_STARTED_VM', 153, 0, 'VM XP-13 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5155a00c', '92aadb21-efe4-473e-83cb-f8a0d5349fb9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1776, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 14:00:40.947+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-14 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34f726d8', '11be85e5-372a-4a91-a85e-c2b13797e1f9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1777, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 14:00:41.121+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-15 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '46d3b386', '556f2c21-ebd0-4d9c-bc6f-fd2d0bd1e0ed', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1778, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:23.382+02', 'USER_RUN_VM', 32, 0, 'VM NFS-13 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4547bd18', '33526b95-827a-4272-8dd3-230dce94d37f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1779, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:26.022+02', 'USER_RUN_VM', 32, 0, 'VM NFS-12 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79215270', '7918e7a7-01b3-4e66-bc1c-1fce5dd4c18f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1780, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:26.077+02', 'USER_RUN_VM', 32, 0, 'VM NFS-11 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'daef303', '9d05419e-bc0b-440f-9ecc-9e33065f429f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1781, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:28.489+02', 'USER_RUN_VM', 32, 0, 'VM NFS-19 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a2f9a91', 'efff47be-5b4f-49e2-83f2-1f45d606f1ff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1782, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:28.654+02', 'USER_RUN_VM', 32, 0, 'VM NFS-18 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e8fd064', 'e8729f04-3e9f-4fd2-9423-5d527fcbca76', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1783, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:31.176+02', 'USER_RUN_VM', 32, 0, 'VM NFS-20 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a7a2a58', 'a5477c1f-66a6-4257-bf2b-cdc4c5138256', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1784, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:33.555+02', 'USER_RUN_VM', 32, 0, 'VM NFS-7 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c16cbbb', '0ae46ad7-1683-4062-907c-ab3f10290922', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1785, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:33.612+02', 'USER_RUN_VM', 32, 0, 'VM NFS-8 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '91d56b1', '716612ba-6ea5-4518-8c9b-ec067ef87de4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1786, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:35.942+02', 'USER_RUN_VM', 32, 0, 'VM XP-1 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7db62c27', '83a97bab-e10a-40b8-aeca-b66946753563', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1790, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:41.037+02', 'USER_RUN_VM', 32, 0, 'VM XP-13 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5155a00c', '92aadb21-efe4-473e-83cb-f8a0d5349fb9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1791, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:41.127+02', 'USER_RUN_VM', 32, 0, 'VM XP-12 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a86a9d4', 'edf0bd9a-0404-4439-9c77-6fce32f7ede3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1793, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 14:01:43.19+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-8 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '52bfc896', '5ba5855a-7784-45b0-9440-65f8c6baf451', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1795, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:02:40.598+02', 'USER_RUN_VM', 32, 0, 'VM XP-3 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2170b49a', '71366c03-b142-4f1a-93eb-f63d72c28468', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1796, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:02:40.683+02', 'USER_RUN_VM', 32, 0, 'VM XP-19 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '39a25bc0', 'c2f67e0b-39c0-4a86-a2ea-ecfd4cd0e31b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1798, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 14:12:56.86+02', 'VDS_ACTIVATE', 16, 0, 'Host camel-vdsb was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6453def8', 'affba11d-8b3c-41b2-9c8e-8fcea6b386fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1800, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 14:12:59.863+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1806, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:15:08.881+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_WITH_ERROR', 987, 1, 'Invalid status on Data Center NFS. Setting Data Center status to Non-Responsive (On host gold-vdsc, Error: Network error during communication with the Host.).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c050064', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1807, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:15:11.943+02', 'VDS_INITIALIZING', 514, 1, 'Host gold-vdsc is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1808, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:15:19.34+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1819, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:18:07.512+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-10, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '754d8c39', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1823, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:18:38.755+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-9, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1afcdbe6', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1826, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:19:09.122+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-8, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '555f7821', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1829, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:19:36.628+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-14, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '32324b04', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1835, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:07.95+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-4, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50bd90be', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1843, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:23:11.644+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-6, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '38084d21', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1844, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:23:34.634+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-18, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '14178fc3', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1848, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:26:04.8+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2aae9e65', 'd8c67c2a-3511-4175-acb8-557e9ded346b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1849, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:26:04.905+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7de1cdfd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1851, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:26:07.736+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28a95d46', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1852, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:26:13.821+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-17, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b545bbb', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1854, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:27:30.719+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-17, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c51674d', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1855, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:27:31.13+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-17, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c51674d', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1914, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:03:44.261+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '431aa2f1', 'd81ee235-8c9d-4298-ad08-e244b7522d3c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1787, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:37.916+02', 'USER_STARTED_VM', 153, 0, 'VM XP-3 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2170b49a', '71366c03-b142-4f1a-93eb-f63d72c28468', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1799, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 14:12:59.836+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e11e4d9', 'a478d409-8cc9-462c-8c3d-a8551aa91a42', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1802, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:14:56.944+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1803, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:14:56.962+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1804, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:14:57.014+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1805, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:14:57.046+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1809, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:16:27.712+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3acc406b', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1810, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:16:27.847+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '68a0d89e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1822, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:18:38.725+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-13, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d614082', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1825, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:19:06.955+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-3, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3529b7fb', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1827, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:19:09.124+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-10, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '718adc1d', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1828, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 14:19:20.251+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6abfa2b3', 'dfe149a3-e818-4015-a2e3-3a7221c4cbdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1830, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:19:57.96+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-16, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f08e119', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1836, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:07.955+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-19, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '648ad2a9', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1841, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:22:10.447+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-1, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1ed9e7cf', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1846, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:24:50.52+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7ebf7fa7', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1870, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:31:35.229+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-19, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '377aa0bf', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1871, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:31:35.362+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-19, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '377aa0bf', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1875, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:32:55.427+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6696da4c', '2a2aac6e-5123-4a0f-bec8-e776c01c2f4a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1876, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:32:57.073+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1877, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 14:33:42.186+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host camel-vdsb was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd34a33e', '74622630-57b1-453b-87fe-79ab9a8a6845', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1899, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:39:17.96+02', 'USER_RESUME_VM', 40, 0, 'VM XP-10 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '688d0e05', 'f1be6b76-279e-4786-9c4c-947f6b0cd077', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1901, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 14:40:50.943+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_WITH_ERROR', 987, 1, 'Invalid status on Data Center NFS. Setting Data Center status to Non-Responsive (On host gold-vdsd, Error: Network error during communication with the Host.).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '196c2607', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1788, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:38.871+02', 'USER_STARTED_VM', 153, 0, 'VM XP-19 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '39a25bc0', 'c2f67e0b-39c0-4a86-a2ea-ecfd4cd0e31b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1789, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 14:01:39.039+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-20 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '14f2d755', 'aa98cf13-de4e-471f-9270-6453b44cbfbf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1797, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:02:42.958+02', 'USER_RUN_VM', 32, 0, 'VM XP-5 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4fdc8feb', '93838ee4-bec5-4d4f-913e-4fd5a30453fb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1801, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 14:13:01.697+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1817, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:17:34.98+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-12, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63b31421', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1821, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:18:07.533+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-19, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '377aa0bf', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1882, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:13.349+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-20, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b852b3f', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1883, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:13.377+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-20, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b852b3f', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1884, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:13.388+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1afcdbe6', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1887, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:16.259+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-3, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3529b7fb', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1889, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:32.263+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-8, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '555f7821', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1890, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:32.305+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-8, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '555f7821', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1894, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:35:16.957+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-11, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b118c3e', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1898, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 14:35:27.735+02', 'USER_ACTIVATED_STORAGE_DOMAIN', 966, 0, 'Storage Domain NFs (Data Center NFS) was activated by admin@internal', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '00000000-0000-0000-0000-000000000000', '', '7e39eb3b', 'dbb26e78-a123-491b-8275-861aecffccea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1792, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:01:42.697+02', 'USER_STARTED_VM', 153, 0, 'VM XP-5 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4fdc8feb', '93838ee4-bec5-4d4f-913e-4fd5a30453fb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1794, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '00000000-0000-0000-0000-000000000000', NULL, '2012-12-16 14:01:43.427+02', 'USER_FAILED_RUN_VM', 54, 2, 'Failed to run VM XP-9 (User: admin@internal).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6a42021a', '7412e739-a5c7-406b-89ad-8e874ecab1d1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1812, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:17:02.094+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5650f939', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1824, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:19:06.953+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-20, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b852b3f', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1831, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:20:01.679+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsc was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7afafcef', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1832, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:20:02.429+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1845, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:23:52.238+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-7, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '400edb85', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1858, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:28:32.374+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e90c3c1', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1859, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:28:32.547+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e90c3c1', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1864, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:30:12.616+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63b31421', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1865, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:30:12.789+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63b31421', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1873, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:32:08.602+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-13, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d614082', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1874, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:32:08.684+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-13, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d614082', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1811, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:17:02.09+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-17, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c51674d', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1813, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:17:04.306+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b924491', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1815, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:17:06.859+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-6, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64540bec', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1820, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:18:07.514+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5efb4716', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1833, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:05.501+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7477491', '9c11a04f-18c7-43d0-ad62-431d54d7cba8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1834, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:05.558+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5ecb8fd1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1838, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:07.977+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-11, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b118c3e', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1839, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:10.252+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-15, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '62808cb2', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1840, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:13.031+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-11, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4cacce88', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1842, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:22:54.763+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-1, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '489f2bc3', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1853, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:26:31.051+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-16, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7dc3b90', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1866, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:30:56.353+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-4, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67f2fd13', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1867, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:30:56.452+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-4, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67f2fd13', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1872, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:31:51.429+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1814, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:17:04.306+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e90c3c1', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1816, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 14:17:20.542+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '10a9e62b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1818, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:17:37.109+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-4, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67f2fd13', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1837, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:21:07.976+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-13, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c82b839', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1847, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:25:01.605+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1850, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:26:07.692+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-18, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41e5a106', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1856, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:28:16.646+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5650f939', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1857, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:28:17.517+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-2, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5650f939', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1868, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:31:11.49+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5efb4716', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1869, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:31:11.566+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5efb4716', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1878, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 14:33:45.218+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '798e78dc', '867f85aa-aed1-4868-9aec-9513b2407cd3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1900, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:40:39.513+02', 'USER_RESUME_VM', 40, 0, 'VM XP-10 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7362a8ed', '192d0cee-23ac-4479-8cdb-d703c02d6ee8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1860, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:28:57.139+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b924491', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1861, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:28:57.227+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-5, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b924491', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1862, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:29:11.953+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64540bec', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1863, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:29:12.091+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64540bec', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1879, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:06.839+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67f6de29', '0e8af4fa-3842-46f7-8dd9-27225c0e8e71', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1880, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:07.192+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '29c89182', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1881, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:13.341+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1afcdbe6', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1885, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:13.401+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-10, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '718adc1d', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1886, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:13.477+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-10, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '718adc1d', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1888, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:17.64+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-3, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3529b7fb', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1891, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:33.975+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63409a7c', '1842b137-c901-4bd2-94de-4eaaf76f8040', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1892, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:34:34.654+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1893, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:35:14.045+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-14, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '32324b04', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1895, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:35:16.969+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-16, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f08e119', '0e7133b9-739d-4725-9681-342af52f10f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1896, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:35:20.169+02', 'VM_DOWN', 61, 0, 'VM NFS-14 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1897, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 14:35:26.104+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1902, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:41:05.271+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1903, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:51:52.435+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '429d1755', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1904, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 14:52:11.777+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1905, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:01:01.27+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1906, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:01:07.579+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Preparing For Maintenance.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1907, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:01:08.393+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Preparing For Maintenance.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1908, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:01:12.747+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '56f1e4a4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1909, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:01:13.588+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1910, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 15:01:28.216+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1911, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:01:47.759+02', 'USER_RESUME_VM', 40, 0, 'VM XP-10 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b370c25', '4ad6a000-58a3-4f39-92ba-d679a121ad74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1912, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:03:41.945+02', 'VDS_ACTIVATE', 16, 0, 'Host camel-vdsb was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50e40833', '1db03d46-0bc6-4f26-98a8-b69aa3182ba2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1913, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:03:43.955+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1915, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:03:45.152+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1925, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:09.277+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-8, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '48c16b35', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1927, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:40.787+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2efd291', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1931, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:08:15.699+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-19, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6164ab07', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1932, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:08:42.836+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-12, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4089afaa', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1937, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:09:40.664+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-20, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '327a42f3', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1938, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:09:40.859+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-20, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '327a42f3', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1940, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:10:00.651+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsc was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2537cac0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1941, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:10:02.507+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1942, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-16 15:10:32.632+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '4f6442d0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1948, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:09.553+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-17, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2cb86e7', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1949, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:09.602+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d07b513', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1956, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:12:32.952+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2efd291', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1957, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:12:33.101+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-2, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2efd291', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1981, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:16:05.855+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c3becd0', '07e487e9-9874-48b5-b3a1-c046cb95b46c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1982, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:16:06.014+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3131e842', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1916, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:05:22.282+02', 'VDS_INITIALIZING', 514, 1, 'Host gold-vdsc is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1917, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:05:24.313+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '86e2eeb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1918, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:05:27.459+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1919, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:06:32.468+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78ae5ed4', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1920, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:06:32.679+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '129c6330', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1921, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:04.417+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-6, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d07b513', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1922, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:06.761+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '188ba440', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1923, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:09.245+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-4, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c0e0118', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1924, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:09.256+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-20, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '327a42f3', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1926, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:40.788+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-17, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2cb86e7', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1929, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:08:09.179+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24a5a82f', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1930, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:08:09.217+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-10, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '779ba625', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1933, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:09:09.091+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-13, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a8e5587', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1935, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:09:15.226+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '188ba440', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1936, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:09:15.278+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-2, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '188ba440', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1947, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:09.547+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7cbba534', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1952, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:31.744+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-8, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '48c16b35', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1953, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:32.268+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-8, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '48c16b35', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1958, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:13:24.07+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24a5a82f', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1959, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:13:24.125+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24a5a82f', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1960, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:13:36.854+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-10, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '779ba625', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1961, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:13:37.07+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-10, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '779ba625', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1970, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:35.737+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4089afaa', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1928, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:07:43.1+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-9, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '685fb44f', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1934, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:09:09.093+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-3, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6e2a9037', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1939, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:09:42.101+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2b3dd674', 'de284d1a-91fd-41b5-865f-d2fd0a476925', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1946, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:09.545+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d07b513', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1951, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:09.623+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-17, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2cb86e7', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1954, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:55.043+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-4, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c0e0118', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1955, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:55.085+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-4, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c0e0118', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1943, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:07.111+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34ddc0f', '55a7fd85-88ea-417b-9c71-8464ed6f4468', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1944, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:07.181+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f623bd4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1945, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:09.543+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-9, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '685fb44f', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1950, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:11:09.619+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-9, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '685fb44f', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1962, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:13:55.761+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-3, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6e2a9037', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1963, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:13:55.794+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-3, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6e2a9037', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1964, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:12.204+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1965, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:12.292+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1966, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:12.317+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1967, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:14.577+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-19, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6164ab07', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1968, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:14.648+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-19, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6164ab07', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1969, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:25.052+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1980, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:15:02.475+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1985, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:16:40.947+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-17, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4dba84c4', '07e487e9-9874-48b5-b3a1-c046cb95b46c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1986, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:16:52.774+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d400213', '55a7fd85-88ea-417b-9c71-8464ed6f4468', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1987, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:16:52.831+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-2, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d400213', '55a7fd85-88ea-417b-9c71-8464ed6f4468', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1971, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:35.853+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4089afaa', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1972, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:42.31+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1973, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:42.331+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1974, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:42.348+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1975, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:42.366+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1976, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:44.508+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1977, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:44.583+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-2 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1978, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:47.17+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-5, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7cbba534', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1979, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:14:47.457+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-5, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7cbba534', '2930bdbd-64e3-44f9-bc23-02abfb597833', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1983, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:16:09.943+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1984, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:16:17.049+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsc). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d400213', '55a7fd85-88ea-417b-9c71-8464ed6f4468', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1990, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:19:22.999+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1988, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:18:50.564+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1989, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:18:50.584+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1991, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:20:12.063+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1992, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:21:18.717+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '265865e2', '904507f5-bf52-4816-a71d-7b990124a6a3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1993, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:21:18.803+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30fd81e5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1994, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:22:09.651+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-2 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1995, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:25:20.036+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1996, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:26:29.028+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31a64b12', 'c47dac22-ee9c-4ab4-9b8b-bba2f4e40c0b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1997, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:26:30.216+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '471b60ab', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1998, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:30:11.595+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (1999, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:31:19.14+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15a0fb1', 'ac341d6a-97f6-4c5b-b0fd-ff69007ce6f1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2000, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:31:19.402+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a5a5eb0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2001, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:35:05.438+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2002, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:36:04.686+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2003, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:12.476+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-4 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4db01217', 'e63f8fb1-3446-472b-b48c-29ad3b7e8e01', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2004, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:17.236+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-4 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4db01217', 'e63f8fb1-3446-472b-b48c-29ad3b7e8e01', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2005, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:18.778+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-5 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2e9709f0', 'b8f027c4-64c0-45cf-8634-995dc1dcc2c9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2006, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:25.231+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-5 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2e9709f0', 'b8f027c4-64c0-45cf-8634-995dc1dcc2c9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2007, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:26.794+02', 'USER_RESUME_VM', 40, 0, 'VM XP-2 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '694239f3', 'c925e2e6-9652-4322-b6b5-de507904a588', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2008, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:27.826+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-9 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6be4962f', '9ac40b04-6834-41f9-ba16-05e8027e7340', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2009, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:42:28.061+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-1 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d0e629f', 'ac5b0235-423c-4006-9477-163f1c4bd138', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2010, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:31.997+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-9 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6be4962f', '9ac40b04-6834-41f9-ba16-05e8027e7340', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2011, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:42:32.177+02', 'USER_STARTED_VM', 153, 0, 'VM XP-4 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5bfbf34d', 'fdc145af-837e-4852-82b7-7fb7ecbe95da', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2012, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:32.445+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-10 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b36262', '7103cfce-de15-4c32-82fb-c1e734e47fa6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2013, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:42:33.144+02', 'USER_STARTED_VM', 153, 0, 'VM XP-6 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18e37c42', '043e2f82-b1b9-42f8-9334-56fadfa5f0f9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2014, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:33.174+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-2 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50ec8107', '9b4c0f6a-bc62-4d32-a659-77902c9761bf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2015, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:35.072+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-10 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b36262', '7103cfce-de15-4c32-82fb-c1e734e47fa6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2127, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:11.628+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2016, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:35.486+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-2 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50ec8107', '9b4c0f6a-bc62-4d32-a659-77902c9761bf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2026, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:42:51.102+02', 'USER_STARTED_VM', 153, 0, 'VM XP-16 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47bf098f', '5b1be575-4daa-4d02-9986-1cee3e4d1758', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2029, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:02.147+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-20 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3e467ccd', '60265bef-3ede-4991-8297-2255d554858e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2032, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:05.796+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61a1ed9e', '3ab683cf-b0c8-4e0b-be54-16b35870c269', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2033, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:06.421+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-20 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3e467ccd', '60265bef-3ede-4991-8297-2255d554858e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2034, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:06.813+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-16 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e75f7ac', '03146e30-dacd-4e8e-a759-5a0d913f6909', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2036, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:10.269+02', 'USER_RESUME_VM', 40, 0, 'VM XP-3 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28e1ac5b', '610ab490-d2f7-4b72-9382-cc8c5718a6e3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2038, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:11.304+02', 'USER_STARTED_VM', 153, 0, 'VM XP-11 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a95c88c', '52be8919-3ab3-4bc6-a17d-2876c9144199', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2042, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:16.445+02', 'USER_STARTED_VM', 153, 0, 'VM XP-18 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c47a613', 'd3279b3b-91ad-4abe-a0a2-41ed3447a0d2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2043, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:17.023+02', 'USER_RESUME_VM', 40, 0, 'VM XP-5 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30147420', 'c0f49e8b-175f-4b82-91c8-ef6cc2d23c3c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2082, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:46:45.1+02', 'USER_RESUME_VM', 40, 0, 'VM XP-10 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4689e78d', '64b2f956-af22-4ebc-a58e-89769f69a132', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2083, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:46:50.185+02', 'USER_STOP_VM', 33, 0, 'VM XP-2 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63078e4c', '8097df8c-b688-4837-b079-57a1523ec1f8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2091, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:54:21.452+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2093, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:59:58.375+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-2 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2094, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:00:00.359+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2095, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:00:00.631+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2106, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:49.006+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2107, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:50.353+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2108, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:50.934+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2140, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:10:40.24+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2162, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:32.183+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2177, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:15:20.398+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2178, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:15:20.546+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2184, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:17:20.342+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2185, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:17:25.334+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2187, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:17:38.341+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2189, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:18:27.303+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2190, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:18:33.294+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2191, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:19:28.964+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2215, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:25:34.823+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2017, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:35.923+02', 'USER_RESUME_VM', 40, 0, 'VM XP-10 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a0eac43', '5e8db7fa-0a2e-49f0-90f3-061ff621e887', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2085, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:47:29.05+02', 'USER_STARTED_VM', 153, 0, 'VM XP-2 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '239d02df', 'deaba32b-d2c4-4d3e-beab-1f9c5ca7a30f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2087, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:48:30.67+02', 'USER_RUN_VM', 32, 0, 'VM XP-2 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '239d02df', 'deaba32b-d2c4-4d3e-beab-1f9c5ca7a30f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2119, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:06:15.775+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2120, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:08:50.441+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2122, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:02.138+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2124, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:04.976+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2126, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:09.493+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2128, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:11.629+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2130, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:13.785+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2131, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:14+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-14 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2136, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:17.465+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2138, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:17.768+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2139, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:18.01+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2149, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:02.217+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2150, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:02.725+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2155, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:11:15.389+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2156, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:11:17.021+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2157, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:11:17.58+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2158, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:19.625+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2159, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:19.763+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2198, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:21:26.377+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2199, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:21:34.151+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2200, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:21:42.603+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2203, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:22:32.866+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2018, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:42:36.84+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-14 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4185d1f9', 'ca7832e3-2ea0-486e-89e2-d03c535b565a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2028, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:01.205+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-19 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '858d6e', 'd2ba6d54-7c64-4655-983a-67fa3eb0a37b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2035, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:06.824+02', 'USER_RESUME_VM', 40, 0, 'VM XP-3 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28e1ac5b', '610ab490-d2f7-4b72-9382-cc8c5718a6e3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2053, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:42.525+02', 'USER_STARTED_VM', 153, 0, 'VM XP-1 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fc13bdc', '6bfc9e7d-958f-4b3b-8b22-6a8c4742f7b8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2064, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:44:10.476+02', 'USER_RUN_VM', 32, 0, 'VM NFS-16 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e75f7ac', '03146e30-dacd-4e8e-a759-5a0d913f6909', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2065, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:44:12.574+02', 'USER_RUN_VM', 32, 0, 'VM XP-11 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a95c88c', '52be8919-3ab3-4bc6-a17d-2876c9144199', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2066, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:44:17.455+02', 'USER_RUN_VM', 32, 0, 'VM NFS-17 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18972064', 'c0e9248c-35e9-41aa-ab9e-5b893610062a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2067, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:44:17.643+02', 'USER_RUN_VM', 32, 0, 'VM XP-18 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c47a613', 'd3279b3b-91ad-4abe-a0a2-41ed3447a0d2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2069, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:44:30.581+02', 'USER_RUN_VM', 32, 0, 'VM XP-20 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33a4c121', 'de9a2275-7a89-4f27-ae25-56a67f7ab72d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2070, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:44:31.454+02', 'USER_RUN_VM', 32, 0, 'VM XP-12 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1dc452d2', 'f1177b3a-fbfa-48a8-b5c8-3c615c396ce2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2080, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:45:10.279+02', 'USER_RUN_VM', 32, 0, 'VM XP-8 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7597a0c', '51e1b698-f4de-4b48-91b2-f7104ae46372', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2097, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:00:12.441+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2f3c78fb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2109, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:54.687+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2110, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:57.057+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2019, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:37.111+02', 'USER_RESUME_VM', 40, 0, 'VM XP-17 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '631ce734', 'e2fd340c-4f52-45ea-aeff-9d1124f66619', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2023, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:47.465+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-6 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78e1db82', '790ce121-b0cc-491c-bfb2-0fbf4bd09d58', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2025, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:50.842+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-13 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2bba2e7', '1692df24-ec9f-48c2-a835-7b3c4bbfb43f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2031, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:02.908+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61a1ed9e', '3ab683cf-b0c8-4e0b-be54-16b35870c269', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2045, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:24.799+02', 'USER_STARTED_VM', 153, 0, 'VM XP-12 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1dc452d2', 'f1177b3a-fbfa-48a8-b5c8-3c615c396ce2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2049, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:37.247+02', 'USER_RUN_VM', 32, 0, 'VM NFS-1 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d0e629f', 'ac5b0235-423c-4006-9477-163f1c4bd138', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2054, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:42.937+02', 'USER_RUN_VM', 32, 0, 'VM XP-6 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18e37c42', '043e2f82-b1b9-42f8-9334-56fadfa5f0f9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2061, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:56.286+02', 'USER_STARTED_VM', 153, 0, 'VM XP-9 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66607ff6', 'ca405629-583f-4051-a847-973907eaf286', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2062, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:57.149+02', 'USER_STARTED_VM', 153, 0, 'VM XP-15 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b885a54', '1ff2ed91-d455-4200-a1ec-54f146303f91', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2151, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:03.086+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2152, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:03.266+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2153, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:03.565+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2154, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:03.74+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2161, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:11:22.594+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2167, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:13:17.564+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2168, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:13:22.018+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2193, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:19:36.127+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2194, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:20:18.623+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2196, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:20:35.774+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2197, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:20:37.344+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2208, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:23:32.908+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2210, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:24:22.229+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2212, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:24:34.059+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2020, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:38.07+02', 'USER_RESUME_VM', 40, 0, 'VM XP-17 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '631ce734', 'e2fd340c-4f52-45ea-aeff-9d1124f66619', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2021, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:41.993+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-6 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78e1db82', '790ce121-b0cc-491c-bfb2-0fbf4bd09d58', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2037, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:10.698+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-12 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5a7b44fa', '0713dfcb-f329-413a-8692-a74bcb82fcf6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2057, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:51.057+02', 'USER_STARTED_VM', 153, 0, 'VM XP-14 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42826aee', 'f8bfcf74-b63a-4063-aead-2d62aad27cc4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2059, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:54.51+02', 'USER_RUN_VM', 32, 0, 'VM XP-16 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47bf098f', '5b1be575-4daa-4d02-9986-1cee3e4d1758', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2063, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:44:06.738+02', 'USER_RUN_VM', 32, 0, 'VM NFS-3 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42efec94', 'a1d1e7ff-234c-4f79-80e3-a8ed102769cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2071, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:44:35.289+02', 'USER_RUN_VM', 32, 0, 'VM NFS-18 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '150250a6', '33ef4783-1337-422a-9803-012702323e9c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2075, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:44:55.603+02', 'USER_RUN_VM', 32, 0, 'VM NFS-11 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24b4c312', '0a22f093-c615-41da-b693-36a832fa6708', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2077, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:44:56.243+02', 'USER_RUN_VM', 32, 0, 'VM XP-14 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42826aee', 'f8bfcf74-b63a-4063-aead-2d62aad27cc4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2078, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:45:00.503+02', 'USER_RUN_VM', 32, 0, 'VM XP-15 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b885a54', '1ff2ed91-d455-4200-a1ec-54f146303f91', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2084, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:46:59.168+02', 'USER_STOP_VM', 33, 0, 'VM XP-10 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a30fef5', 'b44cb5c5-6d9e-4072-aac8-ecb56bdb3634', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2089, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:54:11.463+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_WITH_ERROR', 987, 1, 'Invalid status on Data Center NFS. Setting Data Center status to Non-Responsive (On host gold-vdsd, Error: Network error during communication with the Host.).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '530c2f92', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2090, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:54:15.956+02', 'VDS_INITIALIZING', 514, 1, 'Host gold-vdsd is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2092, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:54:41.342+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2111, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:01:10.621+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2112, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:01:11.223+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2113, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:01:11.513+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2114, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:01:11.985+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2115, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:01:12.134+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2116, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:01:12.255+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2117, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:01:13.395+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2209, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:23:38.973+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2211, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:24:29.797+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2214, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:25:21.137+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2217, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:26:21.416+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2218, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:26:21.442+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2223, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.418+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2224, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.486+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2225, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.586+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2226, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.601+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2022, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:42:43.234+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-15 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c4a6ac3', '8f95d709-5987-4daf-b16a-d7566724e15e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2024, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:50.552+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-13 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2bba2e7', '1692df24-ec9f-48c2-a835-7b3c4bbfb43f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2027, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:42:51.754+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-19 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '858d6e', 'd2ba6d54-7c64-4655-983a-67fa3eb0a37b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2040, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:14.887+02', 'USER_RESUME_VM', 40, 0, 'VM XP-5 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30147420', 'c0f49e8b-175f-4b82-91c8-ef6cc2d23c3c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2041, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:15.313+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-17 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18972064', 'c0e9248c-35e9-41aa-ab9e-5b893610062a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2046, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:26.382+02', 'USER_STARTED_VM', 153, 0, 'VM XP-20 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33a4c121', 'de9a2275-7a89-4f27-ae25-56a67f7ab72d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2048, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:35.582+02', 'USER_RUN_VM', 32, 0, 'VM XP-4 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5bfbf34d', 'fdc145af-837e-4852-82b7-7fb7ecbe95da', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2051, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:41.802+02', 'USER_RUN_VM', 32, 0, 'VM NFS-14 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4185d1f9', 'ca7832e3-2ea0-486e-89e2-d03c535b565a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2060, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:54.758+02', 'USER_STARTED_VM', 153, 0, 'VM XP-8 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7597a0c', '51e1b698-f4de-4b48-91b2-f7104ae46372', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2068, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:44:22.72+02', 'USER_RUN_VM', 32, 0, 'VM XP-7 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '69e8c9ac', '9872878e-a1be-4ae3-8fdf-60350e66c7f5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2072, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:44:42.599+02', 'USER_RUN_VM', 32, 0, 'VM NFS-7 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b3d4c1c', '13e47412-7145-4711-a5a3-ca06f9460af4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2030, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:02.502+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-3 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42efec94', 'a1d1e7ff-234c-4f79-80e3-a8ed102769cd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2039, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:13.605+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-12 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5a7b44fa', '0713dfcb-f329-413a-8692-a74bcb82fcf6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2044, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:20.28+02', 'USER_STARTED_VM', 153, 0, 'VM XP-7 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '69e8c9ac', '9872878e-a1be-4ae3-8fdf-60350e66c7f5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2047, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:30.037+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-18 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '150250a6', '33ef4783-1337-422a-9803-012702323e9c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2050, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:37.595+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-7 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b3d4c1c', '13e47412-7145-4711-a5a3-ca06f9460af4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2052, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 15:43:42.175+02', 'USER_RUN_VM', 32, 0, 'VM NFS-15 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c4a6ac3', '8f95d709-5987-4daf-b16a-d7566724e15e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2055, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:46.301+02', 'USER_STARTED_VM', 153, 0, 'VM XP-13 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4db2dab3', 'ef7265c9-b452-4e19-acdc-2332a2a3bdb0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2056, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:43:49.545+02', 'USER_STARTED_VM', 153, 0, 'VM XP-19 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4e869b8d', '9f914903-ce46-4184-bf09-e79eace7a131', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2058, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:43:52.298+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-11 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24b4c312', '0a22f093-c615-41da-b693-36a832fa6708', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2073, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:44:51.419+02', 'USER_RUN_VM', 32, 0, 'VM XP-1 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fc13bdc', '6bfc9e7d-958f-4b3b-8b22-6a8c4742f7b8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2074, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:44:52.544+02', 'USER_RUN_VM', 32, 0, 'VM XP-13 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4db2dab3', 'ef7265c9-b452-4e19-acdc-2332a2a3bdb0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2076, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:44:55.684+02', 'USER_RUN_VM', 32, 0, 'VM XP-19 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4e869b8d', '9f914903-ce46-4184-bf09-e79eace7a131', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2079, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:45:00.652+02', 'USER_RUN_VM', 32, 0, 'VM XP-9 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66607ff6', 'ca405629-583f-4051-a847-973907eaf286', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2081, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 15:46:44.974+02', 'USER_RESUME_VM', 40, 0, 'VM XP-2 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '52d4ca08', '9100b8b6-4a85-4e77-a66b-c2e09fea4697', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2086, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:47:33.319+02', 'USER_STARTED_VM', 153, 0, 'VM XP-10 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '574166a2', '447bdd05-1ceb-4e72-a397-caf9858cd7e1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2088, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 15:48:37.927+02', 'USER_RUN_VM', 32, 0, 'VM XP-10 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '574166a2', '447bdd05-1ceb-4e72-a397-caf9858cd7e1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2096, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:01.717+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2098, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:22.795+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2099, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:24.986+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2100, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:25.179+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-10 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2101, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:25.392+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2102, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:00:25.509+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2103, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:00:32.302+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2104, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:00:35.02+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2105, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:00:36.029+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2118, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:05:09.816+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '620bb00e', '163cb4f0-b341-4458-8590-7062805058a3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2121, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:00.962+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2123, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:04.97+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2125, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:09.49+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2129, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:13.786+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2132, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:14.001+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2133, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:14.757+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2134, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:09:15.107+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2135, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:17.22+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2137, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:09:17.624+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2163, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:11:49.656+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2165, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:12:37.56+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2166, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:12:47.594+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2173, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:14:20.877+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2174, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:14:32.541+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2175, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:14:33.359+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2141, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:58.524+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2142, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:58.715+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2143, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:58.879+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2144, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:59.017+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-10 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2145, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:59.253+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2146, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:59.397+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2147, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:59.589+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2148, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:10:59.669+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2160, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:11:20.994+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2172, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:14:17.486+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-10 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2176, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:14:36.038+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-14 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2179, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:15:33.477+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2183, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:16:38.421+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2188, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:18:24.966+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2192, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:19:33.597+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2195, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:20:29.195+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2221, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:21.829+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2222, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:24.018+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2164, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:12:20.556+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2169, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:13:32.297+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2170, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:13:32.443+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2171, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:13:46.966+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2180, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:15:47.123+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2181, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:16:20.217+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-14 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2182, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:16:23.236+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2186, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:17:34.378+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2201, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:22:22.098+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2202, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:22:22.34+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2204, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:22:33.927+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2205, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:22:47.433+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2206, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:23:25.327+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-10 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2207, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:23:32.23+02', 'VM_DOWN_ERROR', 119, 2, 'VM NFS-5 is down. Exit message: Lost connection with qemu process.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2213, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:24:40.046+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2216, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:25:37.05+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2219, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:26:34.464+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2220, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:26:38.947+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2232, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:27:37.45+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2227, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.659+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2228, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.699+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2229, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.722+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-14 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2230, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.78+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2231, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:27:31.829+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2233, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:27:41.75+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2234, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.016+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2235, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.048+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2236, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.076+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2237, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.118+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2238, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.151+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2239, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.171+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2240, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.218+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2241, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.255+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2242, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:28:04.28+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2243, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:29.866+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-1 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4bed7c3b', 'aca173c1-4d22-4508-b3b1-f3283f29f022', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2244, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:30.213+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-14 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '186198a9', 'dfae1fb5-4c92-4e0b-b9b6-9bbb1b78723c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2245, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:30.622+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-11 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12d525bd', 'f536659a-f96c-49d4-852d-3ebbedd60059', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2246, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:31.302+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-14 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '186198a9', 'dfae1fb5-4c92-4e0b-b9b6-9bbb1b78723c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2247, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:32.212+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-1 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4bed7c3b', 'aca173c1-4d22-4508-b3b1-f3283f29f022', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2248, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:32.582+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-11 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12d525bd', 'f536659a-f96c-49d4-852d-3ebbedd60059', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2249, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:36.514+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-15 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1751d183', '8a7737e2-370a-4764-8cc2-a301ce3f0049', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2250, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:36.875+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-16 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49a60173', '8a1c405c-f704-4d2a-b76b-2052a20319b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2251, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:37.32+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-17 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6676f01b', 'c7ca235b-e21f-43f0-8eb4-2c3ff56e22ec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2252, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:37.628+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-18 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b98832d', '7e3f5b98-d865-4d36-83f9-e2a81385ef65', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2253, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:37.983+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-16 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49a60173', '8a1c405c-f704-4d2a-b76b-2052a20319b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2254, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:40.027+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-17 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6676f01b', 'c7ca235b-e21f-43f0-8eb4-2c3ff56e22ec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2255, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:40.245+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-15 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1751d183', '8a7737e2-370a-4764-8cc2-a301ce3f0049', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2315, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:47.554+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2256, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:40.411+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-18 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b98832d', '7e3f5b98-d865-4d36-83f9-e2a81385ef65', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2257, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:40.618+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-4 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '219c4871', '3b6eeac3-1302-4524-901c-4422b66ef5cb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2258, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:40.996+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-3 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f269d37', 'e70807db-401c-46e5-8f27-247c0df242c5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2259, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:41.32+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-4 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '219c4871', '3b6eeac3-1302-4524-901c-4422b66ef5cb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2260, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:42.178+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-3 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f269d37', 'e70807db-401c-46e5-8f27-247c0df242c5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2263, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:45.597+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-6 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7109e12d', '70e7d932-b1e1-45e7-9c5a-a67402afc56a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2264, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:45.753+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c92907', '6a9c863e-3d6f-4147-900b-5d7459b39685', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2265, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:46.071+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-7 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '27975531', 'f06ec6c4-56e2-4d31-bf46-8b4b4e55552c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2266, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:46.859+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-7 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '27975531', 'f06ec6c4-56e2-4d31-bf46-8b4b4e55552c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2267, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:47.975+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c92907', '6a9c863e-3d6f-4147-900b-5d7459b39685', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2328, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:41:04.387+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2329, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:41:04.662+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2330, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:41:04.935+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2331, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:41:05.318+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2332, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:41:05.407+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2333, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:41:06.696+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2341, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:44:02.047+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1609ccfb', '99b1a22f-5eea-4def-baa9-85f6c511b785', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2366, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:52:52.97+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2367, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:52:53.962+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2380, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:59:05.171+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c2ecd10', 'a2e30a75-5254-4fca-a9a6-810c4ede7927', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2381, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:59:05.44+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c2ecd10', 'a2e30a75-5254-4fca-a9a6-810c4ede7927', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2398, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:06:07.183+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2403, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:08:10.794+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '603e2b7e', 'fcc8711d-f1db-4ffa-bf0a-216f86838841', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2407, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:11:04.906+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '32a60605', '63d4c5c6-39b2-445c-9672-0c7db4b6d7a1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2408, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:11:05.063+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '443b2571', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2409, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:12:17.006+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '145e1fae', '63d4c5c6-39b2-445c-9672-0c7db4b6d7a1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2410, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:12:17.075+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '145e1fae', '63d4c5c6-39b2-445c-9672-0c7db4b6d7a1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2261, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:42.503+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-5 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '32256457', 'bb21244b-66bf-4210-940a-ff7d680a1231', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2262, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:45.319+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-6 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7109e12d', '70e7d932-b1e1-45e7-9c5a-a67402afc56a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2308, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:39:35.061+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2309, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:39:35.996+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2310, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:39:36.1+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2268, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:54.588+02', 'USER_RESUME_VM', 40, 0, 'VM XP-16 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '8d6042c', 'a3572151-98b4-4b79-af5d-cf22a615bcdc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2269, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:54.871+02', 'USER_RESUME_VM', 40, 0, 'VM XP-11 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73ee74e7', '41f88a5b-d602-45e6-ba38-5760fdd4bafb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2270, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:55.126+02', 'USER_RESUME_VM', 40, 0, 'VM XP-10 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3dbb3516', '3f7475ca-bc5e-40d0-aa2c-3792393a8ac6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2271, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:55.213+02', 'USER_RESUME_VM', 40, 0, 'VM XP-10 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3dbb3516', '3f7475ca-bc5e-40d0-aa2c-3792393a8ac6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2272, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:55.276+02', 'USER_RESUME_VM', 40, 0, 'VM XP-16 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '8d6042c', 'a3572151-98b4-4b79-af5d-cf22a615bcdc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2273, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:55.501+02', 'USER_RESUME_VM', 40, 0, 'VM XP-12 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49e50395', '4d4fae15-d2d6-4224-a27b-18d004934a9a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2274, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:55.723+02', 'USER_RESUME_VM', 40, 0, 'VM XP-1 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28e23b9e', 'a625d23f-f6ee-4d21-8e55-66df2d222a7d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2275, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:56.036+02', 'USER_RESUME_VM', 40, 0, 'VM XP-13 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2176010e', '4f8db17a-c16c-44a0-880e-4ecd35ca9c65', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2276, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:56.429+02', 'USER_RESUME_VM', 40, 0, 'VM XP-14 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36c11e82', 'fbd5e1f4-2f0f-493a-bd3a-35f820384333', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2277, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:56.561+02', 'USER_RESUME_VM', 40, 0, 'VM XP-11 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73ee74e7', '41f88a5b-d602-45e6-ba38-5760fdd4bafb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2278, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:56.644+02', 'USER_RESUME_VM', 40, 0, 'VM XP-12 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49e50395', '4d4fae15-d2d6-4224-a27b-18d004934a9a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2279, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:56.998+02', 'USER_RESUME_VM', 40, 0, 'VM XP-15 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2905e8bd', 'cad79714-0d58-4e63-af1d-e7222245d3c0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2280, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:57.746+02', 'USER_RESUME_VM', 40, 0, 'VM XP-13 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2176010e', '4f8db17a-c16c-44a0-880e-4ecd35ca9c65', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2281, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:57.784+02', 'USER_RESUME_VM', 40, 0, 'VM XP-1 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28e23b9e', 'a625d23f-f6ee-4d21-8e55-66df2d222a7d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2282, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:34:57.813+02', 'USER_RESUME_VM', 40, 0, 'VM XP-15 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2905e8bd', 'cad79714-0d58-4e63-af1d-e7222245d3c0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2283, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:34:59.696+02', 'USER_RESUME_VM', 40, 0, 'VM XP-14 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36c11e82', 'fbd5e1f4-2f0f-493a-bd3a-35f820384333', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2284, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:34:59.938+02', 'USER_RESUME_VM', 40, 0, 'VM XP-18 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7dbe8bc2', 'd3e31244-12a9-4889-8245-0a72e87601ae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2285, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:35:00.27+02', 'USER_RESUME_VM', 40, 0, 'VM XP-19 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '55b42e90', 'fabc6d23-f2d1-4f01-a2a3-6b23c4255af2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2286, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:01.628+02', 'USER_RESUME_VM', 40, 0, 'VM XP-18 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7dbe8bc2', 'd3e31244-12a9-4889-8245-0a72e87601ae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2287, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:35:01.996+02', 'USER_RESUME_VM', 40, 0, 'VM XP-19 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '55b42e90', 'fabc6d23-f2d1-4f01-a2a3-6b23c4255af2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2288, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:35:02.545+02', 'USER_RESUME_VM', 40, 0, 'VM XP-4 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44159a72', '7627d7b4-ad89-43b2-83f4-04a1697068e4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2289, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:02.826+02', 'USER_RESUME_VM', 40, 0, 'VM XP-20 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d5c35c7', '1ed77f24-62d9-4ab4-8da1-b400c738935e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2290, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:03.86+02', 'USER_RESUME_VM', 40, 0, 'VM XP-20 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d5c35c7', '1ed77f24-62d9-4ab4-8da1-b400c738935e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2291, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:35:04.135+02', 'USER_RESUME_VM', 40, 0, 'VM XP-4 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44159a72', '7627d7b4-ad89-43b2-83f4-04a1697068e4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2292, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:06.985+02', 'USER_RESUME_VM', 40, 0, 'VM XP-6 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '197d6b86', '8398115d-cefd-41c9-a81d-f7af1814be8c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2314, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:47.388+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-2 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2293, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:07.217+02', 'USER_RESUME_VM', 40, 0, 'VM XP-7 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '166324d2', 'bccd6a4e-52b1-4881-811b-9b96eee48a15', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2294, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:35:07.481+02', 'USER_RESUME_VM', 40, 0, 'VM XP-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11da372d', '8066b5fb-d127-4652-be11-7b9e6a9a6130', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2295, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:35:07.874+02', 'USER_RESUME_VM', 40, 0, 'VM XP-9 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c030c05', '3ad3b600-b9b2-4c26-a845-92a89681ddbe', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2313, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:39:42.358+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_WITH_ERROR', 987, 1, 'Invalid status on Data Center NFS. Setting Data Center status to Non-Responsive (On host gold-vdsd, Error: Network error during communication with the Host.).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79b7c149', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2339, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:43:31.219+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1de757f9', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2342, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:44:32.565+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d84a43c', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2345, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:45:03.088+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2346, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:45:03.409+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2347, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:45:06.411+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2348, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:46:08.497+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4484c6', 'a94be8ad-7e2c-479d-9f5a-27412761ebb3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2349, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:46:09.91+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f4f3749', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2368, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:54:58.332+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a55adea', 'e2ecd762-14ef-4ded-82e4-375de9943898', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2369, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:54:58.438+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30362824', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2382, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:00:01.464+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2383, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:00:02.905+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2391, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:02:35.23+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4e6db775', 'ff46d487-ad26-4b96-b7af-a021e168b6ff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2393, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:02:35.451+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4e6db775', 'ff46d487-ad26-4b96-b7af-a021e168b6ff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2399, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:07:06.831+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '512f92b5', '175e7c37-b974-4a44-911f-a2826d2c59f4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2400, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:07:06.938+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '512f92b5', '175e7c37-b974-4a44-911f-a2826d2c59f4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2406, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:10:03.741+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2417, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:17:05.681+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12797edf', '6d7397f9-0f26-4e5d-bf77-8fce0fd95018', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2418, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:17:05.712+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12797edf', '6d7397f9-0f26-4e5d-bf77-8fce0fd95018', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2419, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:17:10.039+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ddecf84', '2b2631ee-149e-43d5-9608-3e5372a99341', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2420, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:17:10.11+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a9baa08', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2421, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:20:01.691+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2422, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:20:02.102+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2646, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:24:12.278+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4946f6eb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2296, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:35:08.042+02', 'USER_RESUME_VM', 40, 0, 'VM XP-9 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c030c05', '3ad3b600-b9b2-4c26-a845-92a89681ddbe', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2297, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:35:08.094+02', 'USER_RESUME_VM', 40, 0, 'VM XP-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11da372d', '8066b5fb-d127-4652-be11-7b9e6a9a6130', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2298, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:10.084+02', 'USER_RESUME_VM', 40, 0, 'VM XP-7 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '166324d2', 'bccd6a4e-52b1-4881-811b-9b96eee48a15', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2299, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:10.152+02', 'USER_RESUME_VM', 40, 0, 'VM XP-6 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '197d6b86', '8398115d-cefd-41c9-a81d-f7af1814be8c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2300, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:30.193+02', 'VDS_INITIALIZING', 514, 1, 'Host camel-vdsb is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2302, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:34.572+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2303, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:35:35.63+02', 'VDS_INITIALIZING', 514, 1, 'Host gold-vdsc is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2307, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:50.521+02', 'USER_RUN_VM', 32, 0, 'VM NFS-5 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '32256457', 'bb21244b-66bf-4210-940a-ff7d680a1231', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2311, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:39:36.224+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2312, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:39:36.679+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2324, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:52.083+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2334, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:41:40.973+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b5e14aa', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2336, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:43:04.575+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2337, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:43:05.068+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-10 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2338, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:43:31.181+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '699cad51', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2343, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:44:34.85+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-4, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '774957c', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2344, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:45:01.561+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsd was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2460f1f2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2350, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:46:13.069+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '474ec955', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2351, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:46:13.099+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42023a8b', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2352, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:46:13.141+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42023a8b', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2353, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:46:27.716+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-3, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4146353d', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2364, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:49:21.034+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30cdb77c', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2373, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:56:58.739+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '193033ad', '49d6a8cd-4e80-43e6-abd5-767e0e9031d1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2374, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:56:59.312+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ee6202f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2384, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:01:04.918+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '178fc13d', 'ff46d487-ad26-4b96-b7af-a021e168b6ff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2385, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:01:05.149+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f4e296c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2386, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:01:07.767+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5155f94c', 'a2e30a75-5254-4fca-a9a6-810c4ede7927', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2301, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:35:34.494+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_WITH_ERROR', 987, 1, 'Invalid status on Data Center NFS. Setting Data Center status to Non-Responsive (On host gold-vdsc, Error: Network error during communication with the Host.).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '77581379', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2304, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:35:42.781+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2305, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:35:44.994+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2306, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:35:47.102+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2354, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:47:34.923+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '699cad51', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2355, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:47:35.079+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-16, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '699cad51', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2357, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:47:55.928+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-13, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ffee569', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2358, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:48:03.292+02', 'VM_DOWN', 61, 0, 'VM XP-13 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2359, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:48:54.845+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1de757f9', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2360, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:48:54.938+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1de757f9', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2363, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:49:12.076+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c82dbfa', 'de215ea7-9218-49e4-8e03-6ff01f96bf49', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2370, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:55:01.08+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2389, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:01:33.617+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-16, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '70323b6a', 'a2e30a75-5254-4fca-a9a6-810c4ede7927', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2396, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:06:04.871+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50bf22fe', '175e7c37-b974-4a44-911f-a2826d2c59f4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2404, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:08:10.897+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c6c0b18', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2415, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:16:04.709+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ccd54ca', '6d7397f9-0f26-4e5d-bf77-8fce0fd95018', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2416, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:16:04.906+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45fdcc5f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2435, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:27:08.925+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4be23e8e', 'b2ac2a54-5bea-4472-872a-eedcba194337', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2436, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:27:09.038+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a754bf2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2444, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:32:45.566+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11710dba', 'fe86cdc9-cd3c-48d2-8ba8-005b544ab310', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2445, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:32:45.87+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2fff4d00', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2483, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:45:01.255+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2486, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:04.093+02', 'USER_STOP_VM', 33, 0, 'VM NFS-11 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3e20e2c2', 'e8c7d28f-f381-459d-8717-3d4c7d683805', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2487, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:05.356+02', 'USER_STOP_VM', 33, 0, 'VM NFS-12 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61074e6b', 'e806966b-ddaa-428a-8f33-4e6326537874', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2501, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:48:19.031+02', 'USER_STOP_VM', 33, 0, 'VM NFS-7 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7af41f53', 'b4bf1242-01e7-4268-b437-862938f47c72', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2503, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:21.476+02', 'USER_STOP_VM', 33, 0, 'VM NFS-9 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e7897cf', '8d6336e2-e9bd-4828-89be-7621f0e36ee2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2647, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:32:12.749+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2316, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:47.827+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-10 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2317, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:47.976+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2318, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:48.095+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2319, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:48.143+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2320, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:48.224+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2321, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:49.617+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2322, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:51.583+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-2 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2323, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:39:51.922+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2325, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:40:07.016+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2326, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:40:25.737+02', 'VDS_INITIALIZING', 514, 1, 'Host gold-vdsd is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2327, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:40:30.57+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2335, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:41:41.157+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34aafee', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2340, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:44:00.561+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2356, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 16:47:48.227+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2361, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:49:11.267+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6a5d179', 'cd967bc0-f1ea-4929-8a3d-d342af9d5d29', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2362, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 16:49:11.413+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c78f9bb', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2365, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:52:51.38+02', 'VM_DOWN', 61, 0, 'VM XP-1 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2371, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:55:12.203+02', 'VM_DOWN', 61, 0, 'VM XP-1 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2372, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:55:12.248+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2375, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:58:02.78+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24b794dc', 'a2e30a75-5254-4fca-a9a6-810c4ede7927', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2376, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:58:02.831+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '56c8cbe', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2377, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:58:03.147+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '449bbdaf', 'e42d076c-b5ff-4187-b597-9f3a571f53c5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2378, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:58:11.834+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-10, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6769c571', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2379, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 16:58:33.311+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2390, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:02:35.081+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '604c0bda', '25a87ea6-453a-48bb-b82f-cd7f61844f79', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2392, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:02:35.255+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2e08f3ee', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2394, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:05:01.27+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2395, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:05:02.513+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2397, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:06:04.956+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ea7303b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2401, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:08:05.927+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '535f09f9', '175e7c37-b974-4a44-911f-a2826d2c59f4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2405, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:10:01.754+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2387, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:01:07.814+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5155f94c', 'a2e30a75-5254-4fca-a9a6-810c4ede7927', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2388, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:01:16.582+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2402, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:08:06.019+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '535f09f9', '175e7c37-b974-4a44-911f-a2826d2c59f4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2411, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:12:37.009+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49cef041', '8fd101f4-259e-41bc-a942-fc153068f21d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2412, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:12:37.272+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c6afb49', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2427, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:22:45.568+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd6a84e0', '666185d9-03be-427c-88ca-829bd3df6ab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2428, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:22:45.714+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '614ad36f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2433, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:27:06.047+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4bb163a4', 'fd03dc59-80cf-47df-b016-8eede2dab21a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2434, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:27:06.119+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4bb163a4', 'fd03dc59-80cf-47df-b016-8eede2dab21a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2437, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:30:01.559+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2438, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:30:03.589+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2442, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:32:06.21+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2443, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:32:08.49+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42a46056', 'd847c484-04db-4053-9c9f-1f4a1f24beef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2451, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:36:08.268+02', 'VM_DOWN', 61, 0, 'VM NFS-16 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2452, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:36:37.677+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64c6d3ef', '32599b63-4f64-4dd9-9116-430d329b71c4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2453, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:36:37.776+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64c6d3ef', '32599b63-4f64-4dd9-9116-430d329b71c4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2454, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:37:10.959+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '141ac7c2', '3e2c4069-41ad-4340-997d-9299d3e21e2f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2455, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:37:11.075+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '616f78b7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2462, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:41:08.377+02', 'VM_DOWN', 61, 0, 'VM NFS-3 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2479, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:44:02.757+02', 'VM_DOWN', 61, 0, 'VM XP-19 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2480, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:44:26.59+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-4, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '774957c', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2481, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:44:26.745+02', 'VDS_FAILED_TO_RUN_VMS', 500, 2, 'Host gold-vdsc will be switched to Error status for 30 minutes because it failed to run a VM.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2482, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:44:27.992+02', 'VM_DOWN', 61, 0, 'VM XP-4 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2413, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:15:01.346+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2425, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:22:07.024+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '554c46db', '9dfe4f64-1844-451a-8641-ad625d66d55c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2426, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:22:07.113+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '554c46db', '9dfe4f64-1844-451a-8641-ad625d66d55c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2431, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:26:05.111+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '630a4ee9', 'fd03dc59-80cf-47df-b016-8eede2dab21a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2432, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:26:05.209+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2b039211', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2489, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:07.159+02', 'USER_STOP_VM', 33, 0, 'VM NFS-14 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49da5f6d', 'f8bbe10c-fd22-49b0-afee-9e6ebae8adee', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2414, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:15:03.443+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2463, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:41:38.358+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7834c439', '5e9aa513-6bb5-43c3-a265-17109f86b597', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2464, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:41:38.45+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7834c439', '5e9aa513-6bb5-43c3-a265-17109f86b597', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2468, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:30.974+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2469, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:31.023+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-2 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2470, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:31.039+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-14 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2471, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:31.067+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2423, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:21:05.216+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49ff67d', '9dfe4f64-1844-451a-8641-ad625d66d55c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2424, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:21:05.361+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49f0e9ee', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2429, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:25:01.756+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2430, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:25:03.597+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2439, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 17:30:50.289+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '1392f676', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2440, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:31:05.243+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3ddb9eed', 'd847c484-04db-4053-9c9f-1f4a1f24beef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2441, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:31:05.395+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2b474996', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2446, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:35:03.076+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2447, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:35:03.844+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2448, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:35:12.556+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-16, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d84a43c', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2449, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:36:05.916+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '625456ee', '32599b63-4f64-4dd9-9116-430d329b71c4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2450, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:36:05.986+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '23c8b57', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2456, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:40:02.968+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2457, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:40:03.983+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2458, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:40:11.868+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-3, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4146353d', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2459, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 17:40:25.31+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2460, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:41:05.935+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b22ac11', '5e9aa513-6bb5-43c3-a265-17109f86b597', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2461, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:41:06.081+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7eb4d31d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2465, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:41:52.825+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2466, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:42:45.601+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4094bd97', 'ee3d32b5-bc03-4562-a6f8-6f5a3406ea03', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2467, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:42:45.74+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c5882ad', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2472, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:33.499+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2473, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:33.594+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2474, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:33.642+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2475, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:33.711+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2476, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:33.755+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2477, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:43:33.773+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2478, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:44:02.734+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-19, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5fa61b8a', '6a08cf66-503a-4eda-8257-2393e30b41fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2484, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:02.42+02', 'USER_STOP_VM', 33, 0, 'VM NFS-1 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2f2b6536', '7b91fc76-c4b0-4c0a-9dce-4b6782070b90', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2485, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:03.339+02', 'USER_STOP_VM', 33, 0, 'VM NFS-10 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a01d46b', 'c93c1730-a71f-452e-a857-ff32cda9c44a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2488, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:06.314+02', 'USER_STOP_VM', 33, 0, 'VM NFS-13 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '26ad8491', 'a04f9178-bf08-49b5-b389-68b4652f5e4c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2490, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:08.605+02', 'USER_STOP_VM', 33, 0, 'VM NFS-15 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1faf12fc', 'd294809c-b473-4098-9704-5f2516f9f6b1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2491, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:10.026+02', 'USER_STOP_VM', 33, 0, 'VM NFS-16 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f076ea4', 'f9eb0eb5-c65d-47ae-8c58-6ef379e57139', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2492, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:11.087+02', 'USER_STOP_VM', 33, 0, 'VM NFS-17 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20f0e0e6', '224b6aeb-b466-43aa-98e2-9d0d0ed2377b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2493, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:11.849+02', 'USER_STOP_VM', 33, 0, 'VM NFS-18 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '263d2cef', '3060cf55-6275-48e1-a342-51f6fa37354c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2494, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:12.609+02', 'USER_STOP_VM', 33, 0, 'VM NFS-19 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a511285', 'fd4c0d37-30d2-4305-97e9-19b3761ec704', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2495, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:13.382+02', 'USER_STOP_VM', 33, 0, 'VM NFS-2 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6097187f', 'd2744628-bd96-4021-880a-d797d8ec59a1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2496, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:14.152+02', 'USER_STOP_VM', 33, 0, 'VM NFS-20 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5fc96b63', '05b02148-9df5-4433-9212-00ce67c20b4f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2497, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:14.992+02', 'USER_STOP_VM', 33, 0, 'VM NFS-3 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20a961b6', '3133f124-742a-461d-8608-7977d941b9ed', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2498, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:16.059+02', 'USER_STOP_VM', 33, 0, 'VM NFS-4 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2f0202d3', '0600f4ab-0de3-4041-9787-f01198cb5378', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2499, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:16.729+02', 'USER_STOP_VM', 33, 0, 'VM NFS-5 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d0782c1', '16f7ee3d-335b-4641-8f47-e8706e634f37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2500, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:18.152+02', 'USER_STOP_VM', 33, 0, 'VM NFS-6 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '481963ff', 'c2503a65-4fd0-4126-90ff-38a9233f8a64', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2502, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:20.404+02', 'USER_STOP_VM', 33, 0, 'VM NFS-8 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3134c135', 'b2165816-9d94-4367-bc90-aecf70137ca9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2504, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:22.715+02', 'USER_STOP_VM', 33, 0, 'VM XP-1 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f36d7e7', '695adb54-1d98-4de9-8e5b-afd3b5d71468', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2505, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:23.486+02', 'USER_STOP_VM', 33, 0, 'VM XP-10 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49988eb3', 'ed465e78-83fe-4e2e-bb0a-d218aa86b6f6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2506, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:24.205+02', 'USER_STOP_VM', 33, 0, 'VM XP-11 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3ec0af84', '0b09d816-d589-42ce-86d3-f6756c0d1b16', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2507, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:25.442+02', 'USER_STOP_VM', 33, 0, 'VM XP-12 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c43234b', 'fefda443-da6d-4e2e-9e7d-e05cfeff24ea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2508, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:26.194+02', 'USER_STOP_VM', 33, 0, 'VM XP-13 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3bc2403f', 'e892eadb-b076-4e68-a73c-e5be4a6b3735', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2509, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:27.081+02', 'USER_STOP_VM', 33, 0, 'VM XP-14 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4e0806bf', '830092ab-2dde-49bc-9182-3ed0c1d95705', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2510, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 17:48:28.242+02', 'USER_STOP_VM', 33, 0, 'VM XP-15 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '70f30d9e', '92b44eba-af96-4935-b4cb-97e9058699d4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2515, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:35.519+02', 'USER_STOP_VM', 33, 0, 'VM XP-2 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6993da71', '671764a2-3cfb-46fb-a593-93e4c87f76b2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2516, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:36.606+02', 'USER_STOP_VM', 33, 0, 'VM XP-20 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '69ea66dd', 'e22f9f0b-d775-4c80-98b5-3b4d72cc2d7f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2517, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:37.535+02', 'USER_STOP_VM', 33, 0, 'VM XP-3 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c076d7e', '3ad80af4-84a5-4e2c-83bd-4901830e3ede', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2518, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:49:12.912+02', 'USER_STOP_VM', 33, 0, 'VM XP-4 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ba57992', '7756ba0c-7b03-4f5d-87c2-9499450ec25c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2519, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:49:13.648+02', 'USER_STOP_VM', 33, 0, 'VM XP-5 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7cd076a0', 'ab672040-7aad-4ed3-8daa-a13b4040550b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2511, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:29.244+02', 'USER_STOP_VM', 33, 0, 'VM XP-16 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '65033a00', '594a4403-038a-41ba-b5e5-159b78082fa5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2512, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:48:31.265+02', 'USER_STOP_VM', 33, 0, 'VM XP-17 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36d509cf', 'c8d97df9-1fa6-4897-bc4e-e9bf63945b6d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2513, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:32.273+02', 'USER_STOP_VM', 33, 0, 'VM XP-18 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c771128', '62344a6f-6b08-4b68-acaa-292b04928b80', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2514, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:48:33.393+02', 'USER_STOP_VM', 33, 0, 'VM XP-19 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd078885', '8cf58112-8363-4bf7-9077-5b494a97a6ef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2520, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:49:15.246+02', 'USER_STOP_VM', 33, 0, 'VM XP-6 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5a1c4264', 'd9896fb6-2ccc-474b-95fd-372cfd08f941', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2521, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 17:49:16.654+02', 'USER_STOP_VM', 33, 0, 'VM XP-7 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '754ae173', 'fc673bc5-5669-4fc9-b840-e6d878397887', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2522, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:49:17.338+02', 'USER_STOP_VM', 33, 0, 'VM XP-8 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '717812e', '8a16e310-0996-4040-bbbb-ea8e06242571', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2523, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 17:49:18.006+02', 'USER_STOP_VM', 33, 0, 'VM XP-9 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1821f6a5', '6d46e16a-0468-4cba-9fcf-9eb38d48c218', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2524, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-16 18:08:34.005+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2525, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 18:08:37.089+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2526, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-16 18:08:40.83+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2527, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 18:08:47.873+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1fe36267', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2528, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-16 18:08:48.017+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2529, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 18:23:03.878+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2530, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:31:22.123+02', 'USER_ADD_VM', 34, 0, 'VM GAGA was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28c73062', '74d34a16-0252-4fe4-a992-0f2f1cb1d2ae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2531, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:31:25.518+02', 'NETWORK_ACTIVATE_VM_INTERFACE_SUCCESS', 1012, 0, 'Network Interface nic1 (Red Hat VirtIO) activated for VM GAGA. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25fcf08f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2532, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:31:25.655+02', 'NETWORK_ADD_VM_INTERFACE', 932, 0, 'Interface nic1 (Red Hat VirtIO) was added to VM GAGA. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4daa84b8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2533, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:31:30.958+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of GAGA_Disk1 was initiated on VM GAGA by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40b80efd', '6814544d-1d50-4ae4-bf38-dcbc0d91cb7b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2534, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:31:38.321+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk GAGA_Disk1 was successfully added to VM GAGA.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40b80efd', '6814544d-1d50-4ae4-bf38-dcbc0d91cb7b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2535, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:31:46.407+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of GAGA_Disk2 was initiated on VM GAGA by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58235c1a', '1faa889a-ee7a-4483-9fc6-a0ce628a8946', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2536, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:32:48.614+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk GAGA_Disk2 was successfully added to VM GAGA.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58235c1a', '1faa889a-ee7a-4483-9fc6-a0ce628a8946', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2537, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:36:03.42+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 1 creation for VM GAGA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1562c733', 'd033a18c-2e62-4b97-9a63-8bff6eef211c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2538, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:36:09.012+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 1 creation for VM GAGA has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1562c733', 'd033a18c-2e62-4b97-9a63-8bff6eef211c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2539, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', 'd09ef335-9339-420e-b29e-76ac8dd667cb', NULL, NULL, NULL, '2012-12-16 18:37:38.637+02', 'IMPORTEXPORT_STARTING_EXPORT_VM', 1162, 0, 'Starting export Vm GAGA to New_Export', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76b4a101', 'ebf16868-84d0-4187-a081-1066d8afeed9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2540, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', 'd09ef335-9339-420e-b29e-76ac8dd667cb', NULL, NULL, NULL, '2012-12-16 18:38:49.241+02', 'IMPORTEXPORT_EXPORT_VM', 1150, 0, 'Vm GAGA was exported successfully to New_Export', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '72ec1321-a114-451f-bee1-6790cbca1bc6', 'New_Export', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76b4a101', 'ebf16868-84d0-4187-a081-1066d8afeed9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2541, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bd38ec77-ecdc-4273-aaf1-71ec2ac6d064', 'GAGA_Copy', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-16 18:45:08.555+02', 'IMPORTEXPORT_STARTING_IMPORT_VM', 1165, 0, 'Starting to import Vm GAGA_Copy to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19af9231', '7a633e95-ba60-4324-b308-8d4412164453', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2542, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA_Copy', 'd09ef335-9339-420e-b29e-76ac8dd667cb', NULL, NULL, NULL, '2012-12-16 18:46:41.554+02', 'IMPORTEXPORT_IMPORT_VM', 1152, 0, 'Vm GAGA_Copy was imported successfully to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19af9231', '7a633e95-ba60-4324-b308-8d4412164453', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2543, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA_Copy', 'd09ef335-9339-420e-b29e-76ac8dd667cb', NULL, NULL, NULL, '2012-12-16 18:46:41.715+02', 'IMPORTEXPORT_IMPORT_VM_FAILED', 1153, 2, 'Failed to import Vm GAGA_Copy to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19af9231', '7a633e95-ba60-4324-b308-8d4412164453', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2544, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA_Copy', 'd09ef335-9339-420e-b29e-76ac8dd667cb', NULL, NULL, NULL, '2012-12-16 18:46:51.754+02', 'IMPORTEXPORT_IMPORT_VM', 1152, 0, 'Vm GAGA_Copy was imported successfully to Data Center NFS, Cluster NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19af9231', '7a633e95-ba60-4324-b308-8d4412164453', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2545, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-16 19:38:29.743+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '38ff740c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2546, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-17 11:09:02.167+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2547, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:09:23.99+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM GAGA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2472ac7a', '190c37e4-9693-4c92-86c5-b0783cdcfa98', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2548, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bd38ec77-ecdc-4273-aaf1-71ec2ac6d064', 'GAGA_Copy', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:09:25.269+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM GAGA_Copy was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a40e17c', '6a37086a-b69d-43b0-9594-c29e821f27e4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2549, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bd38ec77-ecdc-4273-aaf1-71ec2ac6d064', 'GAGA_Copy', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:09:34.344+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM GAGA_Copy was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a40e17c', '6a37086a-b69d-43b0-9594-c29e821f27e4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2550, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd09ef335-9339-420e-b29e-76ac8dd667cb', 'GAGA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:09:34.381+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM GAGA was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2472ac7a', '190c37e4-9693-4c92-86c5-b0783cdcfa98', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2551, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:51:26.168+02', 'USER_ADD_VM', 34, 0, 'VM test was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d2a584b', 'f5ac2801-4f8e-464d-bf72-b3f44b03722e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2552, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:51:29.86+02', 'NETWORK_ACTIVATE_VM_INTERFACE_SUCCESS', 1012, 0, 'Network Interface nic1 (Red Hat VirtIO) activated for VM test. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a99e127', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2553, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:51:29.904+02', 'NETWORK_ADD_VM_INTERFACE', 932, 0, 'Interface nic1 (Red Hat VirtIO) was added to VM test. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36c38e91', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2554, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 11:51:42.211+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of test_Disk1 was initiated on VM test by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64e4b1ca', 'cf78825e-53f3-43df-8f9e-2e6cc2dd0769', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2565, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:48:50.032+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-10 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7dd4d456', 'eabdec46-cfa0-427a-9dd2-a2dda9cf0af5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2568, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:48:51.64+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-1 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '253ef8ec', 'eec6475b-9886-447f-be11-e8b961545280', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2569, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:48:52.156+02', 'USER_STARTED_VM', 153, 0, 'VM XP-4 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66fa0379', 'bb4f1740-25f2-4c4e-8a83-7da052daab19', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2570, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:52.484+02', 'USER_STARTED_VM', 153, 0, 'VM XP-6 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5106bd45', '33728a5b-bb5e-4dad-b13f-6d6041b76a0f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2571, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:48:53.203+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-14 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75c5e19a', '11cf6077-0fea-420c-b4e9-d2a8a6c472bd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2572, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:48:53.573+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-2 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2de99ad3', '57b690b4-2e22-43a5-8fd3-13564998ae6f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2573, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:48:53.913+02', 'USER_STARTED_VM', 153, 0, 'VM XP-17 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '248d02ae', 'bd3c2cd1-9198-4cf8-878c-3c6b5e7f91ff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2574, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:54.784+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-3 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '29e89b5e', 'baa7413c-d1aa-440b-a793-0dfa237698a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2575, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:48:56.328+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-16 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd8e39a0', '8a721b38-3d1a-47c4-8081-f412de445e11', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2576, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:56.926+02', 'USER_STARTED_VM', 153, 0, 'VM XP-11 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '27f6f972', 'd6f06d76-2d26-46b2-bd2c-ebee02211432', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2577, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:57.343+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-17 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '23d96d61', 'c9a14b6a-599a-4173-9d8c-6a5d9b0e71d7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2581, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:02.428+02', 'USER_STARTED_VM', 153, 0, 'VM XP-7 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18ec1913', '8706e194-7b58-4d0d-98b8-4a5cc3defdab', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2582, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:03.373+02', 'USER_STARTED_VM', 153, 0, 'VM XP-12 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5191a0f9', 'f40def8b-8b89-4746-af83-af9533e2da21', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2591, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:08.388+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-7 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ecfcf2', 'f7f46ed4-a83d-4ba2-bd78-88cebdb51c7c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2592, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:08.778+02', 'USER_STARTED_VM', 153, 0, 'VM XP-1 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '130d86ab', 'e545fd08-e2a9-4436-b442-939307807eb9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2689, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:36:51.176+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e15420', '3e0fd70d-2d63-4202-adb3-31363b45607e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2690, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:37:06.741+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d72cd29', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2691, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:37:56.771+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-18, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '721dc94f', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2692, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:37:58.861+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '8ef5b3e', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2695, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-17 15:38:28.086+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '21662db1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2697, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:39:45.201+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-10, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '678cd2e2', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2698, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:40:02.087+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2555, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 12:00:00.595+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk test_Disk1 was successfully added to VM test.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64e4b1ca', 'cf78825e-53f3-43df-8f9e-2e6cc2dd0769', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2556, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 12:29:46.212+02', 'USER_ADD_VM', 34, 0, 'VM VM was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2b12d4ef', '5cf8e181-1fad-46d3-bd87-81cd80532eec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2557, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 12:29:50.085+02', 'NETWORK_ACTIVATE_VM_INTERFACE_SUCCESS', 1012, 0, 'Network Interface nic1 (Red Hat VirtIO) activated for VM VM. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5558175a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2558, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 12:29:50.218+02', 'NETWORK_ADD_VM_INTERFACE', 932, 0, 'Interface nic1 (Red Hat VirtIO) was added to VM VM. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66b4a74d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2559, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 12:29:58.249+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of VM_Disk1 was initiated on VM VM by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a75f8', '0317051f-9cc0-473a-b769-0b72c4dc9477', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2560, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 12:34:41.585+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk VM_Disk1 was successfully added to VM VM.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a75f8', '0317051f-9cc0-473a-b769-0b72c4dc9477', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2578, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:58.589+02', 'USER_STARTED_VM', 153, 0, 'VM XP-18 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6e1674b9', '719eb004-b1cc-41c0-bdc1-26ea3172b6ac', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2579, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:59.129+02', 'USER_STARTED_VM', 153, 0, 'VM XP-10 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45872a9a', '68712f1a-49e2-4a1e-a5af-e978fedd7618', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2594, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:11.251+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-12 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a7f5fae', 'a1c6f064-077c-497c-8f11-1acee41aca5e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2602, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:16.016+02', 'USER_STARTED_VM', 153, 0, 'VM XP-16 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d63f690', '9c044fa3-4061-4e3f-966d-a9ec71a69e65', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2604, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:48.195+02', 'USER_RUN_VM', 32, 0, 'VM test started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63f68878', '899fe902-4d28-4600-9036-2c655b0e154e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2614, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:55.521+02', 'USER_RUN_VM', 32, 0, 'VM NFS-2 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2de99ad3', '57b690b4-2e22-43a5-8fd3-13564998ae6f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2616, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:56.172+02', 'USER_RUN_VM', 32, 0, 'VM NFS-3 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '29e89b5e', 'baa7413c-d1aa-440b-a793-0dfa237698a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2617, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:57.906+02', 'USER_RUN_VM', 32, 0, 'VM NFS-16 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd8e39a0', '8a721b38-3d1a-47c4-8081-f412de445e11', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2641, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:15.747+02', 'USER_RUN_VM', 32, 0, 'VM XP-9 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d31b00', 'd4a2b46b-81f7-47ef-821a-2bf65521c2cf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2642, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:15.845+02', 'USER_RUN_VM', 32, 0, 'VM NFS-15 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ec8248e', 'b3880632-035d-46fc-a45a-5c07a075d849', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2643, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:50:16.88+02', 'USER_RUN_VM', 32, 0, 'VM XP-15 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'fa61c3f', 'bc609c93-3e92-49f7-bbf6-60dc13b62449', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2644, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:50:16.93+02', 'USER_RUN_VM', 32, 0, 'VM XP-16 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d63f690', '9c044fa3-4061-4e3f-966d-a9ec71a69e65', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2680, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:35:02.251+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host camel-vdsb was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5af072bd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2681, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:35:02.548+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2682, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:35:17.931+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2346fb18', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2683, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:36:07.338+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d312ff2', 'b69b5f00-8ed6-4dbd-86d6-63bf1d4392a4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2684, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:36:07.431+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7213903b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2686, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:36:09.799+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'bf8a297', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2725, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:06.558+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a981fd2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2726, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:46:07.573+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '473c00c4', '06b026e7-b685-48a2-b854-fe90e2edd235', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2727, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:09.648+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2754, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:06.846+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33d60d84', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2561, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:48:47.242+02', 'USER_STARTED_VM', 153, 0, 'VM VM was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d983632', '1f0621ba-acad-44cd-b38b-2e6fc05ea510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2562, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:48:47.72+02', 'USER_STARTED_VM', 153, 0, 'VM test was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63f68878', '899fe902-4d28-4600-9036-2c655b0e154e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2563, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:48:48.461+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-4 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1ec82727', '9cf4de08-17cb-4186-8f20-7cb7e5cb6d37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2564, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:48.894+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-9 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '38968417', 'e90d02fb-4aae-436b-9ce3-a324df3f478c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2566, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:48:51.101+02', 'USER_STARTED_VM', 153, 0, 'VM XP-2 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '14a0d4fa', '7c10b672-fc1c-461e-9eb4-838fc486a95f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2567, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:48:51.366+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-5 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3591e89c', '19927236-ef0d-438f-ac71-5b2506406f0f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2580, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:01.638+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-6 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b5a0655', 'bb72b6d0-3c00-4dd8-b7ca-1f10892d3eaa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2583, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:03.738+02', 'USER_STARTED_VM', 153, 0, 'VM XP-19 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22fdf0a2', 'b03ada63-c455-4971-ab9d-34b5b7e98fad', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2584, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:04.117+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-13 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1928ea0c', '96df885f-74a1-4265-b29e-8b6e89ff5bf5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2585, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:05.565+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-19 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79bbfd68', '4e1d1c2f-eb70-47fb-8964-7bff352e3069', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2586, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:05.937+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-20 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64c4e040', 'c0a9c3d5-6429-4eb5-b58d-aa9c8e897a58', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2587, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:06.533+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-8 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58bd0fd2', '0d6603b1-0d9f-4b46-aa88-cf1ae1c07843', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2588, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:07.028+02', 'USER_STARTED_VM', 153, 0, 'VM XP-3 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '158e2795', '5b397606-a684-4308-94f0-ce6c4e3028be', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2589, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:07.331+02', 'USER_STARTED_VM', 153, 0, 'VM XP-20 was started by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7123ebf4', '39dbb231-2b42-45c6-979f-e489f4db628d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2590, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:07.777+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-18 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78c17da5', '18081764-2271-497b-b5f5-65d19b906e98', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2593, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:10.4+02', 'USER_STARTED_VM', 153, 0, 'VM XP-13 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a1337e0', '6cb2ee14-6235-4927-915a-a6335940c4b7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2595, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:11.69+02', 'USER_STARTED_VM', 153, 0, 'VM XP-5 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a05526a', 'ae38b719-56af-443e-b57c-cf82188665d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2596, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:12.228+02', 'USER_STARTED_VM', 153, 0, 'VM XP-14 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6241990c', '1b9070b5-01c9-482a-963b-59c795039dc2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2597, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:12.492+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-11 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '230a5031', 'e257a0b7-88bf-4e1f-be2a-2b15c8b64281', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2598, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:12.874+02', 'USER_STARTED_VM', 153, 0, 'VM XP-8 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2bdf455d', '84d93d2e-1acc-4163-aaa7-196254fc018e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2599, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:13.141+02', 'USER_STARTED_VM', 153, 0, 'VM XP-9 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d31b00', 'd4a2b46b-81f7-47ef-821a-2bf65521c2cf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2600, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:13.941+02', 'USER_STARTED_VM', 153, 0, 'VM NFS-15 was started by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ec8248e', 'b3880632-035d-46fc-a45a-5c07a075d849', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2601, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:14.952+02', 'USER_STARTED_VM', 153, 0, 'VM XP-15 was started by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'fa61c3f', 'bc609c93-3e92-49f7-bbf6-60dc13b62449', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2603, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:47.489+02', 'USER_RUN_VM', 32, 0, 'VM VM started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d983632', '1f0621ba-acad-44cd-b38b-2e6fc05ea510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2605, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:50.089+02', 'USER_RUN_VM', 32, 0, 'VM NFS-10 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7dd4d456', 'eabdec46-cfa0-427a-9dd2-a2dda9cf0af5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2645, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-17 15:06:50.188+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2606, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:50.726+02', 'USER_RUN_VM', 32, 0, 'VM NFS-4 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1ec82727', '9cf4de08-17cb-4186-8f20-7cb7e5cb6d37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2607, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:50.863+02', 'USER_RUN_VM', 32, 0, 'VM NFS-9 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '38968417', 'e90d02fb-4aae-436b-9ce3-a324df3f478c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2608, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:52.742+02', 'USER_RUN_VM', 32, 0, 'VM XP-4 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66fa0379', 'bb4f1740-25f2-4c4e-8a83-7da052daab19', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2609, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:49:52.78+02', 'USER_RUN_VM', 32, 0, 'VM NFS-1 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '253ef8ec', 'eec6475b-9886-447f-be11-e8b961545280', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2610, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:53.252+02', 'USER_RUN_VM', 32, 0, 'VM NFS-5 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3591e89c', '19927236-ef0d-438f-ac71-5b2506406f0f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2611, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:53.302+02', 'USER_RUN_VM', 32, 0, 'VM NFS-14 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75c5e19a', '11cf6077-0fea-420c-b4e9-d2a8a6c472bd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2612, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:53.389+02', 'USER_RUN_VM', 32, 0, 'VM XP-2 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '14a0d4fa', '7c10b672-fc1c-461e-9eb4-838fc486a95f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2613, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:53.461+02', 'USER_RUN_VM', 32, 0, 'VM XP-6 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5106bd45', '33728a5b-bb5e-4dad-b13f-6d6041b76a0f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2615, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:49:55.683+02', 'USER_RUN_VM', 32, 0, 'VM XP-17 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '248d02ae', 'bd3c2cd1-9198-4cf8-878c-3c6b5e7f91ff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2618, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:58.648+02', 'USER_RUN_VM', 32, 0, 'VM XP-11 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '27f6f972', 'd6f06d76-2d26-46b2-bd2c-ebee02211432', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2619, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:58.718+02', 'USER_RUN_VM', 32, 0, 'VM NFS-17 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '23d96d61', 'c9a14b6a-599a-4173-9d8c-6a5d9b0e71d7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2620, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:49:58.794+02', 'USER_RUN_VM', 32, 0, 'VM XP-18 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6e1674b9', '719eb004-b1cc-41c0-bdc1-26ea3172b6ac', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2621, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:01.23+02', 'USER_RUN_VM', 32, 0, 'VM XP-10 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45872a9a', '68712f1a-49e2-4a1e-a5af-e978fedd7618', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2622, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:02.766+02', 'USER_RUN_VM', 32, 0, 'VM XP-7 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18ec1913', '8706e194-7b58-4d0d-98b8-4a5cc3defdab', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2623, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:03.584+02', 'USER_RUN_VM', 32, 0, 'VM NFS-6 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b5a0655', 'bb72b6d0-3c00-4dd8-b7ca-1f10892d3eaa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2624, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:05.051+02', 'USER_RUN_VM', 32, 0, 'VM NFS-13 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1928ea0c', '96df885f-74a1-4265-b29e-8b6e89ff5bf5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2625, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:05.119+02', 'USER_RUN_VM', 32, 0, 'VM XP-12 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5191a0f9', 'f40def8b-8b89-4746-af83-af9533e2da21', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2626, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:05.174+02', 'USER_RUN_VM', 32, 0, 'VM XP-19 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22fdf0a2', 'b03ada63-c455-4971-ab9d-34b5b7e98fad', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2627, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:07.453+02', 'USER_RUN_VM', 32, 0, 'VM NFS-8 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58bd0fd2', '0d6603b1-0d9f-4b46-aa88-cf1ae1c07843', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2628, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:07.514+02', 'USER_RUN_VM', 32, 0, 'VM XP-3 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '158e2795', '5b397606-a684-4308-94f0-ce6c4e3028be', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2629, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:07.611+02', 'USER_RUN_VM', 32, 0, 'VM XP-20 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7123ebf4', '39dbb231-2b42-45c6-979f-e489f4db628d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2630, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:07.683+02', 'USER_RUN_VM', 32, 0, 'VM NFS-20 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64c4e040', 'c0a9c3d5-6429-4eb5-b58d-aa9c8e897a58', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2631, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 14:50:07.75+02', 'USER_RUN_VM', 32, 0, 'VM NFS-19 started on Host gold-vdsc', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79bbfd68', '4e1d1c2f-eb70-47fb-8964-7bff352e3069', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2660, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:32:55.853+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2661, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:09.905+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2662, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:09.932+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2663, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:10.808+02', 'VM_NOT_RESPONDING', 126, 1, 'VM test is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2665, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:10.982+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2670, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:33:17.588+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2632, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:50:10.411+02', 'USER_RUN_VM', 32, 0, 'VM NFS-7 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ecfcf2', 'f7f46ed4-a83d-4ba2-bd78-88cebdb51c7c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2633, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 14:50:10.476+02', 'USER_RUN_VM', 32, 0, 'VM NFS-18 started on Host gold-vdsd', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78c17da5', '18081764-2271-497b-b5f5-65d19b906e98', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2634, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:10.683+02', 'USER_RUN_VM', 32, 0, 'VM XP-1 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '130d86ab', 'e545fd08-e2a9-4436-b442-939307807eb9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2635, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:10.758+02', 'USER_RUN_VM', 32, 0, 'VM XP-13 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a1337e0', '6cb2ee14-6235-4927-915a-a6335940c4b7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2636, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:13.275+02', 'USER_RUN_VM', 32, 0, 'VM NFS-12 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a7f5fae', 'a1c6f064-077c-497c-8f11-1acee41aca5e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2637, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:13.345+02', 'USER_RUN_VM', 32, 0, 'VM NFS-11 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '230a5031', 'e257a0b7-88bf-4e1f-be2a-2b15c8b64281', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2638, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:13.412+02', 'USER_RUN_VM', 32, 0, 'VM XP-5 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a05526a', 'ae38b719-56af-443e-b57c-cf82188665d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2639, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:13.508+02', 'USER_RUN_VM', 32, 0, 'VM XP-14 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6241990c', '1b9070b5-01c9-482a-963b-59c795039dc2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2640, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 14:50:13.56+02', 'USER_RUN_VM', 32, 0, 'VM XP-8 started on Host camel-vdsb', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2bdf455d', '84d93d2e-1acc-4163-aaa7-196254fc018e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2685, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:36:09.798+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-11, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '10daf305', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2648, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:32:23.744+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2649, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:32:23.777+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2650, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:32:23.802+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2651, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:32:29.731+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2652, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:32:30.418+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2653, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:32:31.401+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2654, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:32:31.807+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2655, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:32:32.404+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2656, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:32:32.437+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2657, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:32:32.593+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2658, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:32:32.634+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2659, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:32:36.614+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC_WITH_ERROR', 987, 1, 'Invalid status on Data Center NFS. Setting Data Center status to Non-Responsive (On host camel-vdsb, Error: Network error during communication with the Host.).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19c70bc7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2664, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:33:10.896+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2666, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:33:10.994+02', 'VM_NOT_RESPONDING', 126, 1, 'VM VM is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2667, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:33:11.179+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-2 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2668, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:33:11.261+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-10 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2669, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:33:12.666+02', 'VDS_INITIALIZING', 514, 1, 'Host camel-vdsb is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2677, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:36.625+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-14 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2687, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:36:09.819+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-3, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28a8beb9', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2693, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:38:00.957+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b63b910', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2694, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:38:03.326+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-5, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7d2ab67b', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2696, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:38:46.628+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-15, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b933f7e', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2699, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:40:41.23+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2702, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:08.242+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33c12413', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2710, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:42:14.363+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'bf8a297', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2711, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:42:15.341+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'bf8a297', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2712, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:42:17.077+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-3, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28a8beb9', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2713, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:42:17.127+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-3, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28a8beb9', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2671, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:23.545+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2672, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:23.575+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2673, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:23.595+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2674, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:33:23.677+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2675, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:33:23.762+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-16 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2676, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:33:36.194+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2678, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:34:22.499+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '13edf61e', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2679, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:34:22.736+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7edcda24', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2688, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:36:09.82+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-6, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19d79f2d', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2703, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:08.246+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ef370e1', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2714, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:42:25.618+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b1bd485', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2717, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:43:11.663+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-14, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d72cd29', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2718, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:43:11.719+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-14, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d72cd29', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2719, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:43:18.219+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73743042', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2720, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:43:20.342+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '68da3f9a', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2721, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:44:15.751+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2739, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:31.957+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ef370e1', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2740, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:31.997+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ef370e1', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2741, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:38.073+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '177e6d62', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2743, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:41.221+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-17, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '90c74cf', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2744, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:41.255+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-17, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '90c74cf', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2748, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:49:36.545+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b1bd485', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2749, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:49:36.612+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b1bd485', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2751, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:50:02.757+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2753, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:06.571+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5348719f', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2849, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:16:16.359+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2700, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:05.677+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3eed56d4', '8f03f73e-9b8c-4d1a-892d-fd97cb4bb35e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2701, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:05.766+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c781a26', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2704, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:08.27+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '177e6d62', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2705, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:27.236+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-17, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '90c74cf', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2706, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:29.313+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-11, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '10daf305', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2707, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:41:29.456+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-11, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '10daf305', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2708, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:41:52.531+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2709, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:41:52.579+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2715, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:43:03.483+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-6, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19d79f2d', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2716, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:43:03.592+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-6, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '19d79f2d', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2722, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:45:01.817+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2724, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:06.357+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '470bedce', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2734, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:11.402+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b63b910', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2735, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:55.75+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-10, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '678cd2e2', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2736, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:55.822+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-10, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '678cd2e2', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2761, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:20.136+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4cb9c71d', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2762, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:20.733+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4cb9c71d', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2814, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:06.422+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41fe725e', '62270ec6-3ab4-47c8-bd3f-7e6215fb03c1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2815, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:06.873+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3267501b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2816, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:11.401+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2817, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:11.546+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2818, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:11.66+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2819, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:11.732+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2820, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:11.785+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2821, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:11.88+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2822, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:04:11.931+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2823, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:04:13.247+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-12, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37a5aa2a', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2723, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:45:45.013+02', 'USER_VDS_MAINTENANCE_MIGRATION_FAILED', 602, 1, 'Host gold-vdsc cannot change into maintenance mode - not all Vms have been migrated successfully. Consider manual intervention: stopping/migrating Vms: test,NFS-5,XP-3,NFS-14,NFS-13,NFS-19,XP-19,NFS-4,XP-17,XP-12,XP-7,NFS-8,NFS-20,XP-20 (User: admin@internal).      ', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33ef65b4', 'e91414fd-5143-4c73-9eed-6780d0d790ac', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2728, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:46:10.027+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2732, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:11.288+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b63b910', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2759, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:17.598+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '112e66cc', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2760, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:17.642+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '112e66cc', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2763, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:52:15.595+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-11, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '874e79b', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2764, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:52:15.841+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-11, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '874e79b', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2765, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:53:43.414+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61b4e408', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2766, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:53:43.495+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61b4e408', '2905c9bb-5896-44fc-8200-36d4f7a2a853', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2767, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:53:52.891+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2768, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:53:57.059+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '56cadd22', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2769, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:53:57.128+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '56cadd22', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2770, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:54:01.412+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-10, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '426d3537', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2771, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:54:01.438+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-10, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '426d3537', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2773, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:54:07.331+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3943bcb9', '83ee2f18-70c0-4f47-9643-2594cb22fb2c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2778, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:55:02.774+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2779, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:07.287+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '52f78934', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2780, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:07.347+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44b18e4e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2781, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:23.312+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ec6695b', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2782, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:23.346+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ec6695b', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2783, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:31.729+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '527be99f', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2784, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:31.824+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '527be99f', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2785, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:37.909+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3228aed2', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2786, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:37.967+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3228aed2', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2729, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:10.918+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b933f7e', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2730, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:10.978+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b933f7e', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2731, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:11.275+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '8ef5b3e', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2733, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:46:11.379+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '8ef5b3e', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2737, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:23.011+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33c12413', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2738, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:23.05+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33c12413', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2742, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:48:38.105+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '177e6d62', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2745, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:49:04.442+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2746, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:49:11.656+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6072b4cb', 'c62b5650-d1ab-4b38-abca-9356a7b218c1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2747, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:49:11.75+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7fa9cbbf', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2750, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:50:01.282+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsc was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d90161f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2752, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:50:03.143+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2787, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:40.229+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '461c8c9', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2788, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:56:40.272+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '461c8c9', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2789, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:57:02.123+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '38df89f9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2802, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:10.26+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2803, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:10.557+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2804, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:10.626+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2805, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:10.712+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2806, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:10.879+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2807, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:10.954+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2808, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:10.995+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2810, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:00:01.978+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2812, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:01:05.581+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d35cf3f', '0e34ccd1-0e45-4f96-bf03-ccef794c7ec4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2813, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:01:05.73+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '62de72de', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2824, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:04:49.104+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2755, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:09.156+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73743042', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2756, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:09.178+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73743042', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2757, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:11.172+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '68da3f9a', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2758, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:51:11.199+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '68da3f9a', '1b0fffd5-efc6-4476-92b6-317ef9eccab0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2772, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:54:05.488+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2774, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:54:07.441+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b048e6c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2775, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:54:56.23+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f8164c7', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2776, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:54:56.27+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f8164c7', 'ba0a1212-167c-4112-bbe4-a48e9b95383c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2777, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:55:02.76+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2809, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:59:53.99+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2811, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:00:02.827+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2790, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 15:57:05.214+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2791, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.563+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2792, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.595+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2793, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.623+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2794, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.669+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-1 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2795, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.697+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2796, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.723+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2797, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.762+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-15 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2798, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.782+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2799, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 15:58:07.806+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2800, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:07.782+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9fc2bbf', 'c0ec2269-841d-4e93-95e5-9717fe8d3e26', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2801, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 15:59:07.995+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72f5bdcd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2825, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:05:01.664+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2826, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:05:04.392+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2827, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:06:29.943+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5a092b2', '929f98a4-f23f-43f1-9fb8-272a5e4edfd0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2828, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:06:31.274+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12fe8f13', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2829, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:07:36.992+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53bc67ff', 'f57ce2e7-5d2c-4137-b8cb-c1fdd6a66fe8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2830, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:07:37.145+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1fc429c1', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2831, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:10:01.691+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2832, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:39.726+02', 'VM_DOWN', 61, 0, 'VM NFS-12 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2833, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:39.806+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2834, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:39.823+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2835, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:39.898+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2836, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:40.707+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2837, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:40.828+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2838, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:41.073+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c1ed44e', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2839, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:41.129+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c1ed44e', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2840, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:10:44.158+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2841, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:12:06.452+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a0bc8cd', '6421e1d0-aae6-46f1-9317-bb1112e96727', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2842, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:12:06.55+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67a3cbfe', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2843, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:13:44.24+02', 'VM_DOWN', 61, 0, 'VM NFS-12 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2844, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:14:12.205+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a3e37f6', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2847, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:15:03.023+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2848, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:16:13.847+02', 'VM_DOWN', 61, 0, 'VM NFS-9 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2865, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:17.555+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2866, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:17.594+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2867, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:17.615+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2868, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:17.643+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2869, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:17.663+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2890, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:27:36.646+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34c61777', 'de802121-12cc-48a8-9df9-b1ee244fdde2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2891, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:27:37.278+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7016167e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2893, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:29:10.69+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2894, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:29:10.708+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2907, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:12.622+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ad0f96f', '96d1e984-853b-4cc1-81b1-3257b6f45e2c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2908, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:12.83+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3939cb0d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2917, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:50.349+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2918, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:35:02.31+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2919, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:35:03.257+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2920, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:36:07.024+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '229a2b1', '91bfbee1-9373-4bd6-bd91-e43dbfc5b65e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2921, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:36:07.265+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '46fa406e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2924, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:10.399+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2925, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:10.659+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2926, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:15.148+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2931, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:40:03.236+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2945, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:45:02.098+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2957, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:25.538+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2968, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:53:06.937+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2969, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:53:11.34+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2970, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:53:11.374+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2971, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:09.08+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34f7edb6', 'f00ca05d-f670-4a9b-b4a5-619def5460c5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2972, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:09.161+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7167122a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2974, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:11.49+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15098b0f', '7a3ed826-9d50-49ff-aefc-016fb05a684b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2845, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:14:47.84+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61260608', '7a3ed826-9d50-49ff-aefc-016fb05a684b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2846, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:14:47.895+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '14980e3d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2852, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:17:36.436+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c4c3ac0', '213ae41e-1557-4425-a690-776e0bf6f955', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2853, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:17:36.475+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6aa2db3f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2857, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:19:43.711+02', 'VM_DOWN', 61, 0, 'VM NFS-15 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2858, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:20:02.941+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2859, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:20:03.595+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2860, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:22:05.58+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a4def5c', '3dfd2db7-a49d-4fcc-b347-93bd4eb4d62a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2861, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:22:05.65+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7538f04b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2864, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:08.777+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35f7a12f', '59f4259c-7ccd-4804-b985-8dd50c92e7bc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3007, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:17.48+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3580ffa0', 'ec5b531e-0f92-4237-b7e4-d5a7ca1ab436', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3009, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:17.67+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3580ffa0', 'ec5b531e-0f92-4237-b7e4-d5a7ca1ab436', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3010, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:17.726+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33959560', 'ec5b531e-0f92-4237-b7e4-d5a7ca1ab436', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3013, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:05:02.717+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3021, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:09:08.255+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '345db690', '716dd1e7-64b6-4285-8390-1f582a94036f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3022, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:09:08.314+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d5fb1f9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3028, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:11:07.822+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33a413b8', '983aa50c-2ad3-45a0-ab67-0cc5e0516a69', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3029, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:11:08.068+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15423fc4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3045, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:18:08.921+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a513cc4', 'a59a6430-2949-4c12-bcde-9f2776a77029', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3046, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:18:08.984+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a513cc4', 'a59a6430-2949-4c12-bcde-9f2776a77029', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3063, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:23:00.883+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3067, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:24:58.09+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3068, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:24:58.132+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3073, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:28:04.5+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3074, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:28:04.564+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3075, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:28:11.261+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3076, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:29:04.512+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3077, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:29:04.661+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '214f6d6c', '253ae58a-8883-4f0b-b494-97be6e5a93f0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2850, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:16:30.701+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41aa48ab', '13647f96-8ebc-422d-aea8-4b6559e1e2bc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2851, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:16:30.774+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6112d0b7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2854, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:19:13.665+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-15, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42145a28', '7a3ed826-9d50-49ff-aefc-016fb05a684b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2855, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:19:14.082+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53d97a71', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2856, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:19:14.112+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53d97a71', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2862, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:08.482+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ef84cca', '347fe853-e56d-4df8-831a-0979d5a869a6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2863, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:23:08.615+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '994fe4f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2870, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:06.304+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2871, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:06.32+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2872, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:06.337+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2873, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:06.349+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2874, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:06.385+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2875, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:06.402+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2876, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:06.419+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2877, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:24:35.303+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2878, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:25:02.94+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2879, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:25:04.268+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2880, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:30.757+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '769d0298', '80a57dd1-cd3a-460b-be68-d16546f23e2c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2881, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:30.802+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d7c17a7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2882, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.031+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2883, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.052+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2884, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.125+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2885, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.146+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2886, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.167+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2887, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.229+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2888, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.268+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2889, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:26:33.308+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2892, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:29:08.357+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: test, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7bf0ca75', '62270ec6-3ab4-47c8-bd3f-7e6215fb03c1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2896, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:30:09.388+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2897, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.031+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2898, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.284+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2895, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:07.916+02', 'VM_DOWN', 61, 0, 'VM test is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2909, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:15.121+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2910, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:15.657+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2911, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:15.806+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2912, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:15.88+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2913, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:15.946+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2914, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:15.988+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2915, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:16.024+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2916, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:34:16.047+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2922, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:07.767+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6364ce0c', '9b6c4122-b3b6-4222-9e88-8af5374ae1b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2923, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:07.873+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b06308b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2927, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:20.155+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2928, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:20.552+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2929, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:39:20.614+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2930, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:40:03.116+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2932, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:43:03.735+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d2c7bb3', '94f3df56-237c-4570-b56b-28db33c7de37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2933, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:43:03.805+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '105b0f9f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2934, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:43:06.201+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2939, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:44:06.417+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76ec62ef', '96806876-3fa8-4593-8403-c0e9fddd19d7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2940, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:44:06.47+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6039926c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2943, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:44:20.393+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2944, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:44:20.743+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2946, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:45:03.18+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2947, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:46:06.011+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '13d27e57', 'df8e9778-f2a1-4f84-b4dd-73468503d62b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2948, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:46:06.095+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '772c4de6', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2949, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:06.519+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '17f7a120', '8c0cb2da-a174-4c97-aad5-f22c3cb710ec', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2950, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:06.581+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'f3bb29d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2951, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:09.034+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2952, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:11.238+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2953, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:11.271+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2954, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:13.301+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-14, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5393e089', '83ee2f18-70c0-4f47-9643-2594cb22fb2c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2899, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.322+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2900, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.34+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2901, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.357+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2902, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.369+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2903, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.395+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2904, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:30:11.41+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2905, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:31:12.06+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '65d4227', '1e4e60e8-209a-422f-8efe-2bab49810beb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2906, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:31:12.116+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f2ee304', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2935, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:43:08.371+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2936, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:43:08.402+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2937, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:43:08.435+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2938, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:43:20.11+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2941, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:44:12.303+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-5, Source Host: gold-vdsc).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '388df1a4', '62270ec6-3ab4-47c8-bd3f-7e6215fb03c1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2942, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:44:15.408+02', 'VM_DOWN', 61, 0, 'VM NFS-5 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2955, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:49:13.992+02', 'VM_DOWN', 61, 0, 'VM NFS-14 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2958, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:50:03.867+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2959, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:50:05.238+02', 'VM_DOWN', 61, 0, 'VM NFS-3 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2966, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:53:04.436+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42f89c03', 'a2604232-d047-4880-8222-6a46550b6338', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2967, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:53:04.524+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '379a8643', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2975, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:11.514+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6efa0afc', '347fe853-e56d-4df8-831a-0979d5a869a6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2978, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:11.642+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6efa0afc', '347fe853-e56d-4df8-831a-0979d5a869a6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2985, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:58:04.716+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2986, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:58:04.765+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2987, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:58:13.773+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2990, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:59:05.883+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22f34075', 'ec5b531e-0f92-4237-b7e4-d5a7ca1ab436', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2998, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:03:15.642+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2956, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:49:17.762+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: NFS-3, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'c98e552', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2960, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:50:08.407+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2961, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:50:34.687+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2962, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:50:34.715+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2963, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:50:34.739+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2964, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:50:34.759+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2965, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:50:34.778+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2973, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:11.487+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '562880e6', '7a3ed826-9d50-49ff-aefc-016fb05a684b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2976, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:11.55+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '562880e6', '7a3ed826-9d50-49ff-aefc-016fb05a684b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2983, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:58:01.946+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6b6364be', '376152ba-f219-4b53-9e75-1a597fd08866', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2984, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:58:02.036+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22b27a09', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2991, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:59:05.989+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7ef89264', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2992, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:59:38.847+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2997, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:03:06.634+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2999, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:03:40.073+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3000, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:03:42.988+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3001, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:13.767+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '236a130a', '10cfcdc5-114a-4283-9768-ae484336d00e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3023, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:09:10.472+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3024, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:09:47.975+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3025, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:09:52.77+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3026, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:10:02.315+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3027, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:10:03.247+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3030, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:11:10.511+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79d869ec', '716dd1e7-64b6-4285-8390-1f582a94036f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3032, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:11:10.744+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79d869ec', '716dd1e7-64b6-4285-8390-1f582a94036f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3034, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:14:08.405+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5fc6725f', 'c19a8e2c-66a0-43ab-a075-642963e61ac0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3035, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:14:08.467+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a47288a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3036, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:14:10.795+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3037, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:14:10.823+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3039, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:15:03.531+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3040, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:15:04.028+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2977, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:54:11.569+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15098b0f', '7a3ed826-9d50-49ff-aefc-016fb05a684b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2979, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:54:31.534+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2980, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:54:35.961+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2981, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:55:01.45+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2982, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 16:55:02.436+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2988, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:58:35.334+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2989, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 16:58:37.764+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2993, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:00:03.434+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2994, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:00:04.027+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2995, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:03:03.882+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '539a0ce0', '8807d8d3-3990-426e-89f2-1740edef87ed', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (2996, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:03:03.993+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35d833ea', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3003, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:14.342+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-10, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a5df60a', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3006, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:17.476+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33959560', 'ec5b531e-0f92-4237-b7e4-d5a7ca1ab436', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3011, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:04:42.901+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3012, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:05:01.833+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3050, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:19:23.296+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3051, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:19:23.361+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3055, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:21:02.941+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3056, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:21:08.92+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '609b4174', 'b6c1426f-069c-4d32-802b-67be45843271', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3057, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:21:08.97+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '595ceaec', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3059, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:22:02.706+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3060, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:22:09.934+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '68d4e0b0', 'b6c1426f-069c-4d32-802b-67be45843271', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3061, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:22:09.984+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '68d4e0b0', 'b6c1426f-069c-4d32-802b-67be45843271', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3066, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:23:59.254+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3069, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:25:01.326+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3070, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:25:01.887+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3079, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:29:08.901+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3082, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:33:03.203+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1eb1f4fd', 'd9e96e7a-e733-455c-930c-facc5e326f24', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3084, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:33:08.169+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3085, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:33:10.362+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3086, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:33:10.658+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3002, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:14.178+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '246eee0d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3004, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:17.078+02', 'VM_DOWN', 61, 0, 'VM XP-10 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3005, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:17.457+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b185893', 'ec5b531e-0f92-4237-b7e4-d5a7ca1ab436', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3008, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:04:17.609+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b185893', 'ec5b531e-0f92-4237-b7e4-d5a7ca1ab436', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3014, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:08:02.459+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '51d2b3c6', '1cd1bde8-5575-4493-ab20-a53a0250ddfc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3015, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:08:02.545+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7061eaf4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3016, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:08:04.851+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3017, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:08:04.878+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3018, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:08:04.903+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3019, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:08:04.917+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3020, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:08:52.527+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3031, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:11:10.511+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c2a8251', '716dd1e7-64b6-4285-8390-1f582a94036f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3033, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:11:10.757+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c2a8251', '716dd1e7-64b6-4285-8390-1f582a94036f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3038, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:14:52.971+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3047, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:19:13.41+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44dc7af4', '1d3302d2-6812-45f4-8388-952d511b2e96', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3048, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:19:13.696+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4e701344', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3098, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:39:04.503+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3101, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:39:09.193+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3104, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:39:16.305+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3106, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:40:03.07+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3110, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:43:15.197+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3111, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:43:15.324+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3112, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:43:20.931+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3113, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:43:27.711+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3114, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:44:07.958+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5671a160', '83c791ea-c792-4f19-91b5-df5ca9749212', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3115, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:44:08.139+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64280562', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3117, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:45:02.672+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3118, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:48:02.81+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7038f6e3', 'aef380a6-f4d6-49c4-a6e7-6a563d8a1fb4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3119, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:48:02.929+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a41b324', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3120, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:48:05.504+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3041, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:16:07.258+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f534648', 'a59a6430-2949-4c12-bcde-9f2776a77029', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3042, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:16:07.397+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '59bc0cd2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3043, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:17:09.043+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3044, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:17:11.142+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '634bea23', 'a59a6430-2949-4c12-bcde-9f2776a77029', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3049, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:19:16.274+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3052, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:19:55.766+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3053, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:20:03.241+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3054, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:20:58.213+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3058, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:21:57.867+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3062, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:22:58.717+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3064, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:23:09.287+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e12fa6f', 'b6c1426f-069c-4d32-802b-67be45843271', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3065, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:23:09.331+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e12fa6f', 'b6c1426f-069c-4d32-802b-67be45843271', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3071, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:28:02.02+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76fe205d', 'bef5e9d2-6d0e-43c3-9ffc-ede853abad22', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3072, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:28:02.114+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36e7312f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3080, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:30:02.476+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3081, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:30:03.319+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3083, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:33:03.34+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3aeadc3c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3116, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:45:01.906+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3122, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:48:28.006+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3123, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:48:32.553+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3124, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:49:06.898+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c796d18', 'ced60fe9-9422-4505-8955-fdc91330c293', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3125, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:49:07.043+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '52b810b5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3137, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:54:06.128+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ca299cb', 'e69b1cc0-31f6-4e79-b717-3ddb70b98f68', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3138, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:54:06.192+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'bb5fa99', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3148, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:58:46.014+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3149, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:59:08.057+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66d15338', '6e417fbf-55ba-4c55-aa45-45a12f38c052', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3153, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:59:38.128+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3154, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:59:45.153+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3155, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:00:02.409+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3078, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:29:04.705+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '313b665c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3087, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:34:08.12+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d7b5a1f', '22bb93af-f0ed-4f34-9c17-84fb0d55560f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3089, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:34:08.232+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1ff9c9df', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3091, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:34:10.922+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37e95047', '253ae58a-8883-4f0b-b494-97be6e5a93f0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3092, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:35:01.792+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3093, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:35:02.291+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3094, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:36:05.847+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18e4665', 'd3253c73-730c-4f86-ab02-2ed81b23c204', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3095, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:36:06.018+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c01b3ff', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3099, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:39:06.71+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '664ea853', 'aff898fd-c90c-4227-8ec5-f3b87d2520f6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3102, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:39:13.784+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3103, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:39:13.828+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3105, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:40:02.701+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3107, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:43:03.156+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d36f934', '5e84b396-f900-4a0f-a122-af7ff5d6b8ab', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3108, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:43:03.229+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4fafd6ea', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3109, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:43:05.744+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3127, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:49:16.16+02', 'VM_DOWN', 61, 0, 'VM XP-13 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3129, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:50:03.12+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3130, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:53:02.363+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6ec5ce5c', '75078f2f-ef62-4a49-ab2f-c644172f0b22', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3132, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:53:05.033+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3133, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:53:05.054+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3134, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:53:09.542+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3135, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:53:32.827+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3136, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:53:35.339+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3139, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:54:33.004+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3141, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:55:03.551+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3142, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:58:02.342+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50b14a7f', '1912e771-7417-43e4-9df0-95c01c8b2b9a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3143, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:58:02.426+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66d71c06', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3151, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:59:12.169+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-8, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71b0a6b0', '7a3ed826-9d50-49ff-aefc-016fb05a684b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3152, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:59:14.65+02', 'VM_DOWN', 61, 0, 'VM XP-8 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3156, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 18:00:03.703+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3088, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:34:08.191+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3090, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:34:10.88+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37e95047', '253ae58a-8883-4f0b-b494-97be6e5a93f0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3096, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:37:08.803+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61903a9b', 'd3253c73-730c-4f86-ab02-2ed81b23c204', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3097, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:37:08.833+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-9, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61903a9b', 'd3253c73-730c-4f86-ab02-2ed81b23c204', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3100, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:39:06.795+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '782ef5d2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3121, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:48:08.267+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3126, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:49:13.745+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-13, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c2a15f2', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3128, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:50:01.608+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3131, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:53:02.458+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57cf23a9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3140, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:55:01.646+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3144, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:58:04.819+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3145, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:58:04.855+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3146, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:58:11.515+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3147, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 17:58:39.326+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3150, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 17:59:08.135+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ec9e48f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3157, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-17 18:01:22.448+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3158, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:03:02.983+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42178b6f', '584810ae-4a69-40f7-8789-644748ab2ca3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3159, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:03:03.058+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '237288ef', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3160, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 18:03:04.107+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: XP-14, Source Host: camel-vdsb).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6c4d34b7', 'c6750e20-c479-42b1-ae10-966a8ca9adae', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3161, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:03:05.402+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3162, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:03:10.313+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3163, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:03:10.356+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3164, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 18:03:11.134+02', 'VM_DOWN', 61, 0, 'VM XP-14 is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3165, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:03:43.558+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3166, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:04:42.779+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3167, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:04:49.441+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3168, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:05:01.357+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3169, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:08:01.769+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '178893a6', '7272742c-4d35-4481-b4a0-a88ff93a5189', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3170, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:08:01.848+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d80a78f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3171, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:08:04.405+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3172, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:08:13.514+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3173, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:08:13.537+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3174, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:09:48.874+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3175, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:09:53.539+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3176, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:10:01.463+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3177, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:13:02.01+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '96027ea', 'ed882292-cc7d-4010-8e07-0cbf21ca6827', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3178, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:13:02.091+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b23a429', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3179, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:13:04.741+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3180, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:13:06.906+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3187, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:18:04.821+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3190, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:20:01.459+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3191, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:03.511+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3181, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:13:53.075+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3182, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:13:55.531+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3183, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:14:55.504+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3184, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:15:01.811+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3185, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:18:02.377+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12dc3de0', '371eae5c-b911-4e7c-b0b5-f21cecdf1571', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3186, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:18:02.46+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72656fec', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3192, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.797+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3193, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.817+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3194, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.842+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3195, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.872+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3196, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.892+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3197, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.907+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3198, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.939+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3199, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.959+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3200, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:23:05.994+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3201, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-17 18:28:28.886+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '3c111571', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3188, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:18:06.995+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3189, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:18:07.015+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3202, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 18:55:49.199+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3203, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 18:55:52.278+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3204, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 18:55:55.549+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3205, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 18:56:03.16+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d4e9823', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3206, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 18:56:03.285+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3207, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-17 19:24:10.31+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3208, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5351aae0-9645-42a8-a805-65e72260c652', 'ttt', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-17 19:25:25.276+02', 'USER_ADD_VM', 34, 0, 'VM ttt was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '612662cd', 'd7cf3168-cd09-471c-aa09-6dda52e72138', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3209, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-17 19:41:57.689+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '6408844f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3210, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 19:42:03.13+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3211, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:42:06.556+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3212, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 19:42:09.153+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3213, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:42:17+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '352e4515', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3214, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:42:17.161+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3215, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 19:43:00.017+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3216, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:43:03.086+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3217, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 19:43:06.354+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3218, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:43:13.982+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f7ea12a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3219, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:43:14.118+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3220, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:44:02.129+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3221, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 19:44:04.814+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3222, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 19:44:07.986+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3223, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:44:15.636+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '63eef116', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3224, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:44:16.331+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3225, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-17 19:45:15.697+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3226, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-17 19:45:18.691+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3227, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:45:22.047+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3228, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:45:29.62+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '22060c1d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3229, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-17 19:45:29.735+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3230, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 10:06:31.597+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3231, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:06:48.9+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-11 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '765251ee', '632c858e-cbbb-4650-9432-72cbba83b0ea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3232, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:06:49.347+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-11 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '765251ee', '632c858e-cbbb-4650-9432-72cbba83b0ea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3233, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:49.781+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-13 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f2187a5', 'b88c4aaf-c4f4-4164-a647-eddfd6d57b41', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3234, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:51.521+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-13 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f2187a5', 'b88c4aaf-c4f4-4164-a647-eddfd6d57b41', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3237, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:54.677+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-19 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1dde1d64', '7a20d2aa-a250-4c00-a1c9-22f4202f3f90', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3238, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:55.643+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-19 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1dde1d64', '7a20d2aa-a250-4c00-a1c9-22f4202f3f90', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3239, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:57.183+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-20 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '179edf7e', '763dc098-7905-4dc8-97e7-80647a866127', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3240, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:57.747+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-20 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '179edf7e', '763dc098-7905-4dc8-97e7-80647a866127', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3241, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:59.845+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-4 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d65a66e', '9172990b-2841-460c-ad13-46047c56408e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3242, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:06:59.918+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-4 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d65a66e', '9172990b-2841-460c-ad13-46047c56408e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3247, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:08.931+02', 'USER_RESUME_VM', 40, 0, 'VM XP-1 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49a783bf', 'c0a3d11f-091d-4494-a4dc-22acebe2761c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3248, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:09.324+02', 'USER_RESUME_VM', 40, 0, 'VM XP-1 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49a783bf', 'c0a3d11f-091d-4494-a4dc-22acebe2761c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3249, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:11.21+02', 'USER_RESUME_VM', 40, 0, 'VM XP-11 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b6f0edd', '37194390-ba19-4b23-b0cf-e4fbf860bbc6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3235, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:06:52.285+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-17 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '282f7756', '0465b01f-986c-4d7b-a3a8-13cb973c878e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3236, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:06:52.569+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-17 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '282f7756', '0465b01f-986c-4d7b-a3a8-13cb973c878e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3243, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:02.245+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-6 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4d736f86', '8a8a20fa-bd8e-4c89-9a74-b583416d16a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3245, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:05.417+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b03bf8c', '1c7a82d6-3323-4b11-b589-ee9d425a83bb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3246, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:06.44+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-8 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b03bf8c', '1c7a82d6-3323-4b11-b589-ee9d425a83bb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3250, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:11.682+02', 'USER_RESUME_VM', 40, 0, 'VM XP-11 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b6f0edd', '37194390-ba19-4b23-b0cf-e4fbf860bbc6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3251, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:14.395+02', 'USER_RESUME_VM', 40, 0, 'VM XP-12 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66dcaf6c', '0dcee30f-1832-4fa8-86d4-5463212715c6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3252, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:15.711+02', 'USER_RESUME_VM', 40, 0, 'VM XP-12 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66dcaf6c', '0dcee30f-1832-4fa8-86d4-5463212715c6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3244, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:02.778+02', 'USER_RESUME_VM', 40, 0, 'VM NFS-6 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4d736f86', '8a8a20fa-bd8e-4c89-9a74-b583416d16a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3253, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:21.551+02', 'USER_RESUME_VM', 40, 0, 'VM XP-2 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f4955f9', 'f6521a14-2597-47c9-bcc4-0cfaaf2fa42c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3254, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:21.848+02', 'USER_RESUME_VM', 40, 0, 'VM XP-4 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ffda983', 'f6c97452-3b0d-4504-bba9-ccdb64e0c695', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3255, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:21.992+02', 'USER_RESUME_VM', 40, 0, 'VM XP-2 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5f4955f9', 'f6521a14-2597-47c9-bcc4-0cfaaf2fa42c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3256, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:07:22.014+02', 'USER_RESUME_VM', 40, 0, 'VM XP-4 was resumed by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ffda983', 'f6c97452-3b0d-4504-bba9-ccdb64e0c695', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3257, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:22.055+02', 'USER_RESUME_VM', 40, 0, 'VM XP-6 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '344d9b25', '1d434b2a-90db-450d-89fd-ed8281f452e0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3258, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:22.115+02', 'USER_RESUME_VM', 40, 0, 'VM XP-6 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '344d9b25', '1d434b2a-90db-450d-89fd-ed8281f452e0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3259, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:22.327+02', 'USER_RESUME_VM', 40, 0, 'VM XP-17 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4b972e5', '4b2d348a-6c07-40ae-b4dc-bde2ecefd010', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3260, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:22.601+02', 'USER_RESUME_VM', 40, 0, 'VM XP-18 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15e75dd5', 'e7d6cd9d-d7f8-43eb-9eb8-52a663f24e6d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3261, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:22.819+02', 'USER_RESUME_VM', 40, 0, 'VM XP-7 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '395b698e', '075de2cf-ee1c-4f2c-824d-f9dc9236c483', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3262, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:23.449+02', 'USER_RESUME_VM', 40, 0, 'VM XP-19 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67fbb779', '796bc157-9a69-485c-aa4e-52a402aeb9af', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3263, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:23.661+02', 'USER_RESUME_VM', 40, 0, 'VM XP-3 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c10b805', '0d063168-1402-49b8-9256-ac16ca432eb9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3264, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:23.886+02', 'USER_RESUME_VM', 40, 0, 'VM XP-20 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79fb06fc', '8bf2fc7b-b3a5-43ec-826e-e3bf1e21a8a9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3265, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:24.156+02', 'USER_RESUME_VM', 40, 0, 'VM XP-5 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '51d05989', 'ac78838e-f86f-424e-9b5f-f570e60efbc7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3266, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:24.166+02', 'USER_RESUME_VM', 40, 0, 'VM XP-3 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c10b805', '0d063168-1402-49b8-9256-ac16ca432eb9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3267, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:24.255+02', 'USER_RESUME_VM', 40, 0, 'VM XP-20 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79fb06fc', '8bf2fc7b-b3a5-43ec-826e-e3bf1e21a8a9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3268, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:24.324+02', 'USER_RESUME_VM', 40, 0, 'VM XP-7 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '395b698e', '075de2cf-ee1c-4f2c-824d-f9dc9236c483', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3269, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:24.343+02', 'USER_RESUME_VM', 40, 0, 'VM XP-18 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15e75dd5', 'e7d6cd9d-d7f8-43eb-9eb8-52a663f24e6d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3270, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:24.396+02', 'USER_RESUME_VM', 40, 0, 'VM XP-17 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4b972e5', '4b2d348a-6c07-40ae-b4dc-bde2ecefd010', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3271, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:24.41+02', 'USER_RESUME_VM', 40, 0, 'VM XP-5 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '51d05989', 'ac78838e-f86f-424e-9b5f-f570e60efbc7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3272, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:07:24.463+02', 'USER_RESUME_VM', 40, 0, 'VM XP-19 was resumed by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67fbb779', '796bc157-9a69-485c-aa4e-52a402aeb9af', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3273, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:24.589+02', 'USER_RESUME_VM', 40, 0, 'VM XP-9 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '707b7e47', '43ee62f5-46a6-48f5-b186-d543d99db4e0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3274, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:07:26.734+02', 'USER_RESUME_VM', 40, 0, 'VM XP-9 was resumed by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '707b7e47', '43ee62f5-46a6-48f5-b186-d543d99db4e0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3275, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:09:38.762+02', 'VDS_INITIALIZING', 514, 1, 'Host gold-vdsd is initializing. Message: Recovering from crash or Initializing', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3276, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:09:39.241+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d43d61c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3277, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:09:46.24+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3278, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:09:52.469+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3279, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:09:52.494+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3280, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:09:52.537+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3281, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:09:52.553+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3282, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:09:52.579+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3283, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:10:03.586+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3290, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.639+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3291, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.656+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3292, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.697+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3301, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:11:44.772+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '35c87760', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3303, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:12:16.845+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '318609fc', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3304, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:12:32.14+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6a46a4c6', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3314, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:16:07.18+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64bbc3b7', 'cb7761a8-1e01-4154-84ae-20489c3826df', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3315, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:16:07.238+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '10388cc7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3317, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:16:09.478+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20b81c5d', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3318, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:16:24.562+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '222685c6', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3319, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:16:44.406+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e0ae1a5', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3324, '00000000-0000-0000-0000-000000000000', NULL, 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:18:38.757+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3348, '00000000-0000-0000-0000-000000000000', NULL, '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:23:58.01+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3350, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:24:24.072+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '546cc409', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3351, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:24:24.13+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '546cc409', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3352, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:24:43.537+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '318609fc', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3353, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:24:43.781+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-2, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '318609fc', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3356, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:25:08.077+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3359, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:09.064+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6a46a4c6', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3360, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:09.1+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6a46a4c6', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3365, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:26:58.831+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3284, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.412+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3285, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.445+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3286, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.483+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3287, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.552+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3288, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.6+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3289, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.619+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3293, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:10:22.718+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3310, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-18 10:14:51.789+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7d787b09', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3311, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:14:56.974+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1905b878', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3312, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:15:00.567+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsd was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7ab37ca', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3316, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:16:09.473+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4b8bd309', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3321, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:17:48.673+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3322, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:17:50.227+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3323, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:17:55.914+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-18, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd59977a', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3354, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:24:56.008+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3363, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:39.725+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75c15616', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3364, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:39.753+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-16, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75c15616', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3368, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:27:10.629+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3371, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:27:56.589+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1905b878', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3372, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:27:56.622+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1905b878', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3401, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:33:57.903+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31e8756b', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3405, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:36:05.32+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f1058ac', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3406, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:36:05.38+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '551bdd98', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3409, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:36:08.983+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53eb67b8', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3411, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:36:55.684+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3416, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:38:38.441+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '369153e7', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3418, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:38:55.928+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3552, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:07:07.351+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3294, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:10:51.168+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1e995189', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3295, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:10:51.246+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7a274f9b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3296, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:11:27.794+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3297, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:11:33.945+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e2553fa', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3298, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:11:36.072+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47727f34', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3299, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:11:40.635+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61975c12', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3300, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:11:42.704+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '88114e2', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3302, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:12:14.783+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-3, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '546cc409', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3305, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:12:36.266+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-5, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '469f99d8', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3306, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:13:43.615+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75c15616', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3307, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:13:56.775+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53d1bb1c', '5f17fbc5-307b-45f9-8ce1-566f94c85c95', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3309, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:14:40.728+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: NFS-6, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9f61035', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3313, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:15:01.415+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3320, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:17:16.187+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7492a5ac', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3325, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:18:55.513+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3326, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 10:18:58.081+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3327, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:19:04.744+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '212b8610', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3328, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:19:14.506+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3329, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:19:16.757+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3330, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:19:24.302+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44d91ba2', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3332, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:20:00.881+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3333, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:21:04.745+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a567ebc', 'da35b34b-1dde-4d09-8f80-287783c9789e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3334, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:21:04.882+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78401676', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3335, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:21:07.127+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-10, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64201cec', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3336, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:21:12.843+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3308, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:14:36.055+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Error creating the requested Desktop (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '74da3555', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3331, '00000000-0000-0000-0000-000000000000', NULL, '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:19:55.897+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3341, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:21:54.78+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3361, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:09.374+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '469f99d8', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3362, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:09.406+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '469f99d8', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3381, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:06.492+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5af87fd8', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3382, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:06.708+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6492fd28', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3385, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:09.259+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7492a5ac', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3389, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:31:55.963+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3403, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:34:55.838+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3404, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:35:02.307+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3407, '00000000-0000-0000-0000-000000000000', NULL, 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:36:07.762+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-2 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3419, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:39:17.072+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5aa3801d', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3442, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:46:03.977+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '38704fa', '5b13138f-26b1-4c55-8eca-f9eb50b996fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3446, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:46:06.721+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '963821a', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3447, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:46:39.028+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53eb67b8', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3448, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:46:39.05+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '53eb67b8', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3449, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:46:56.422+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3450, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:47:17.226+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a3d79eb', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3451, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:47:17.278+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a3d79eb', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3480, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:52:11.991+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3481, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:52:14.621+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3489, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:54:06.134+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-10 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3490, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:54:38.684+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7abf5f65', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3491, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:54:38.733+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7abf5f65', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3494, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:55:00.875+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3499, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:56:26.252+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3337, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:21:19.905+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78cced32', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3384, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:09.227+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e0ae1a5', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3386, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:09.293+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e0ae1a5', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3392, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:32:15.104+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3393, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:32:24.126+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44d91ba2', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3394, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:32:24.166+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44d91ba2', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3395, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:32:45.732+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-10, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64201cec', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3396, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:32:45.756+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-10, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64201cec', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3397, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:32:56.734+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3400, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:33:57.874+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3470, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:06.57+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71919bf2', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3472, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:06.598+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71919bf2', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3473, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:06.611+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5aa3801d', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3476, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:57.564+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f179bb8', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3477, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:57.604+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f179bb8', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3479, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:52:00.554+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3484, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:52:58.147+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3485, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:53:20.972+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28050bc4', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3486, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:53:20.995+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28050bc4', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3488, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:53:59.83+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3492, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:54:58.555+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3493, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:54:58.577+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3517, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:01:07.497+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57bf1eca', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3519, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:01:46.473+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1200cae5', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3521, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:01:57.824+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3338, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:21:25.478+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3339, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:21:44.523+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e2553fa', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3340, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:21:44.576+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e2553fa', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3342, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:22:03.515+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47727f34', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3343, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:22:03.567+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '47727f34', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3344, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:22:35.571+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61975c12', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3345, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:22:35.612+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '61975c12', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3346, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:23:16.882+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '88114e2', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3347, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:23:16.9+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '88114e2', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3349, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:23:58.077+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3355, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:25:01.482+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3357, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:06.575+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '473c4fb6', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3358, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:26:06.776+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2f811a90', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3383, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:09.225+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7492a5ac', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3402, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:34:38.789+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7db00a08', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3410, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:36:37.496+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41c7794c', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3423, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:41:03.272+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3424, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:41:06.021+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '196af89', 'f377e66a-cf1b-430b-841c-ce7d78e8b7b1', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3425, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:41:06.115+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30a4ef51', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3429, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:41:56.401+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3436, '00000000-0000-0000-0000-000000000000', NULL, 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:43:57.087+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-10, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '126881a0', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3437, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:43:58.498+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3440, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:45:00.909+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3468, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:04.144+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ba0ffce', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3469, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:04.274+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '224ab6b3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3471, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:06.574+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5aa3801d', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3366, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:27:03.54+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '74da3555', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3367, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:27:03.587+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '74da3555', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3369, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:27:24.692+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9f61035', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3370, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:27:24.851+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9f61035', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3373, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:28:36.415+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4b8bd309', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3374, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:28:36.437+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4b8bd309', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3375, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:29:19.13+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20b81c5d', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3376, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:29:19.155+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20b81c5d', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3377, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:29:44.343+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '222685c6', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3378, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:29:44.366+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '222685c6', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3379, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:30:01.464+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3380, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:30:07.838+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3387, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:17.727+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-18, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd59977a', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3388, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:31:17.75+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-18, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd59977a', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3390, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:32:00.716+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '212b8610', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3391, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:32:00.754+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '212b8610', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3398, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:33:17.514+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78cced32', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3399, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:33:17.572+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78cced32', '699b46e5-8c91-454b-a6de-aba726e02ba6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3408, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:36:08.861+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a3d79eb', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3412, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:37:21.167+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25492021', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3413, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:37:44.358+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4029c0db', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3414, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:37:55.723+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3415, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:38:04.194+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33d96cbc', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3417, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:38:55.901+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3420, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:39:59.558+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71919bf2', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3421, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:40:01.902+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3422, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:40:02.874+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3427, '00000000-0000-0000-0000-000000000000', NULL, 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:41:08.884+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f179bb8', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3430, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:41:56.413+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31e8756b', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3431, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:41:56.481+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '31e8756b', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3432, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:42:40.946+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7db00a08', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3433, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:42:40.967+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7db00a08', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3435, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:43:24.385+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-18, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3e02da88', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3460, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:49:16.804+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-16, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33d96cbc', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3461, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:49:16.829+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-16, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33d96cbc', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3426, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:41:08.88+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '415ad3b', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3428, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:41:17.397+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5cf38bb9', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3434, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:43:05.414+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-9, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28050bc4', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3438, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:44:37.327+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7abf5f65', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3439, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:44:57.734+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3441, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:45:57.958+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3443, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:46:04.02+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '16be2512', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3444, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:46:06.702+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '399a8212', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3454, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:48:00.583+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41c7794c', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3455, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:48:00.618+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41c7794c', '245d166e-ba24-4ee6-bc6b-a62ec4b63e74', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3456, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:48:25.012+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25492021', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3457, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:48:25.04+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25492021', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3464, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:49:58.784+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '369153e7', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3465, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:49:59.462+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '369153e7', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3467, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:50:06.476+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3482, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:52:38.688+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5cf38bb9', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3483, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:52:38.714+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5cf38bb9', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3508, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:59:06.183+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64ef0dbe', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3510, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:59:57.277+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3511, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:59:57.941+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '620af61f', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3514, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:00:58.718+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3515, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:01:05.162+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '772fe0ac', '1a43ea8b-04b3-43ae-8fed-6dd93dae9a3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3516, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:01:05.266+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '146c6f02', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3520, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:01:55.502+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3553, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:07:07.554+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3445, '00000000-0000-0000-0000-000000000000', NULL, 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:46:06.706+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-7, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f5c2374', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3452, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:47:56.262+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3453, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:47:56.292+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3458, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:48:44.851+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4029c0db', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3459, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:48:44.902+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4029c0db', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3462, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:49:55.964+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3463, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:49:58.728+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3466, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:50:01.183+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3487, '00000000-0000-0000-0000-000000000000', NULL, 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:53:44.878+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3498, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:56:07.055+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15a87e54', '5b13138f-26b1-4c55-8eca-f9eb50b996fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3500, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:56:45.692+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '399a8212', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3501, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:56:45.734+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '399a8212', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3503, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:57:17.242+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '963821a', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3504, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:57:17.348+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-12, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '963821a', '9caf6ac8-f845-4915-8b91-78f2af1b9ba9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3506, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:57:58.491+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3507, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:58:41.698+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2203cd09', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3474, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:25.789+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '415ad3b', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3475, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:51:25.824+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '415ad3b', '40cfa90c-a8f2-4cbf-ba2a-72977265db37', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3478, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:51:58.147+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3495, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:56:04.711+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3edc603', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3496, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:56:04.777+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '88a1d75', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3497, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:56:07.044+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5554b5d2', '5b13138f-26b1-4c55-8eca-f9eb50b996fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3502, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 10:57:03.684+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3505, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:57:57.567+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d8e557', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3509, '00000000-0000-0000-0000-000000000000', NULL, 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 10:59:25.428+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-16 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3512, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:00:01.533+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3513, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:00:02.346+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3518, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:01:20.143+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3218965d', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3522, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:02:05.553+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-5, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5906338', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3523, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:02:39.32+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b4e9218', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3524, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:03:03.153+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3525, '00000000-0000-0000-0000-000000000000', NULL, '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:03:18.206+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3526, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:04:00.213+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4a39b98d', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3527, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:04:03.823+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3528, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:04:25.845+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7fbd26cb', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3529, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:04:46.992+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15a87e54', '5b13138f-26b1-4c55-8eca-f9eb50b996fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3530, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:04:47.016+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15a87e54', '5b13138f-26b1-4c55-8eca-f9eb50b996fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3531, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:05:02.009+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3532, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:05:05.895+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3533, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:05:08.166+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3534, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:05:08.612+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3535, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:05:08.644+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3536, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:05:08.664+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3537, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:05:08.683+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3538, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:05:08.708+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3539, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:05:58.337+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3540, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:07.278+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '752f59a9', '54825a75-40ef-4329-bb4a-61c12642acef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3541, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:07.724+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d80f703', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3542, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:09.997+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d8e557', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3543, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:09.997+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5554b5d2', '5b13138f-26b1-4c55-8eca-f9eb50b996fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3544, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:10.037+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6d8e557', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3545, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:10.078+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5554b5d2', '5b13138f-26b1-4c55-8eca-f9eb50b996fa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3546, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:42.131+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2203cd09', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3547, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:06:42.152+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-3, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2203cd09', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3551, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:07:07.102+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3548, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:07:05.677+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64ef0dbe', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3549, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:07:05.734+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '64ef0dbe', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3550, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:07:06.709+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3557, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:07:25.56+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '620af61f', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3558, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:07:25.602+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '620af61f', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3559, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:07:58.234+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3561, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:08:09.452+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3598, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:16:09.476+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-2, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '41b0f038', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3601, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:16:26.545+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3602, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:16:26.567+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3605, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:17:21.872+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b974c8c', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3608, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:17:47.789+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66666f42', '54825a75-40ef-4329-bb4a-61c12642acef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3609, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:17:47.819+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66666f42', '54825a75-40ef-4329-bb4a-61c12642acef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3610, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:17:58.693+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3611, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:17:59.005+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3623, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:21:01.079+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3624, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:05.045+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5ed57591', 'aa0836c5-6488-4547-a871-60dcc538c51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3625, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:05.141+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54b34266', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3628, '00000000-0000-0000-0000-000000000000', NULL, '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:07.474+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-2 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3629, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:07.527+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33671ed', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3630, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:07.576+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33671ed', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3640, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:23:48.33+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37a78e3c', 'aa0836c5-6488-4547-a871-60dcc538c51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3643, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:24:28.326+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3647, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:25:29.078+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3652, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:26:31.597+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37a78e3c', 'aa0836c5-6488-4547-a871-60dcc538c51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3654, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:26:31.656+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '37a78e3c', 'aa0836c5-6488-4547-a871-60dcc538c51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3657, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:27:11.914+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3554, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:07:07.619+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3555, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:07:07.667+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3556, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:07:07.9+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3562, '00000000-0000-0000-0000-000000000000', NULL, 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:08:40.026+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3563, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:08:58.382+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3585, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:13:25.172+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3591, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:15:01.117+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3593, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:15:24.467+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3594, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:15:26.968+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3596, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:16:07.074+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49226b88', '42516224-1128-4493-a50a-057396fe3c84', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3597, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:16:07.206+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79d0475d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3599, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:16:09.485+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34f29d26', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3626, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:05.446+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34f29d26', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3627, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:05.512+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '34f29d26', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3636, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:22:42.072+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5765ab1', '42516224-1128-4493-a50a-057396fe3c84', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3637, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:22:42.097+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5765ab1', '42516224-1128-4493-a50a-057396fe3c84', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3639, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:23:28.342+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3641, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:23:48.344+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '163a93a', 'aa0836c5-6488-4547-a871-60dcc538c51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3644, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:24:58.562+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3645, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:25:01.544+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3646, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:25:05.389+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3658, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:27:28.745+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3661, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:28:49.294+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '199253cf', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3666, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:29:31.445+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3674, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:31.61+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '199253cf', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3676, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:31.689+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '199253cf', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3682, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:32:31.805+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3683, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:32:58.903+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3684, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:32:58.973+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3560, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:08:00.464+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54a00547', '1a43ea8b-04b3-43ae-8fed-6dd93dae9a3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3569, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:10:01.994+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3572, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:11:04.843+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c651088', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3573, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:11:04.961+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1ea79507', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3574, '00000000-0000-0000-0000-000000000000', NULL, '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:11:07.213+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3575, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:11:07.348+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1200cae5', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3576, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:11:07.417+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: NFS-6, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1200cae5', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3600, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:16:09.523+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33671ed', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3603, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:16:39.174+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33a84fba', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3604, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:16:58.297+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3606, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:17:26.318+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3607, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:17:28.538+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3612, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:18:06.416+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d6d0a4a', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3613, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:18:06.517+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d6d0a4a', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3616, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:18:59.119+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3617, '00000000-0000-0000-0000-000000000000', NULL, 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:19:19.131+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3618, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:19:33.324+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3620, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:20:00.93+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3622, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 11:20:41.506+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3642, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:24:13.627+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-1 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3648, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:26:05.652+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '549eab3b', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3649, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:26:05.761+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2fc1dd7a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3650, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:26:28.576+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3651, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:26:29.172+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3653, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:26:31.598+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '163a93a', 'aa0836c5-6488-4547-a871-60dcc538c51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3655, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:26:31.668+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '163a93a', 'aa0836c5-6488-4547-a871-60dcc538c51f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3656, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:27:06.224+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3659, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:28:28.963+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3995, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-19 15:49:58.274+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3564, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:09:22.235+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57bf1eca', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3565, '00000000-0000-0000-0000-000000000000', NULL, 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:09:22.262+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-1, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '57bf1eca', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3566, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:09:47.01+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3218965d', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3567, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:09:47.032+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3218965d', 'd930b36c-5fd7-4330-857c-85ca31da2490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3568, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:09:58.199+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3570, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:10:06.118+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3571, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:11:01.26+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3577, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:11:18.081+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b4e9218', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3578, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:11:18.682+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-14, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b4e9218', '6f5f392f-e0bd-46d4-8022-d008653b01b5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3579, '00000000-0000-0000-0000-000000000000', NULL, '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:12:01.348+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-14 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3580, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:12:14.862+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3581, '00000000-0000-0000-0000-000000000000', NULL, '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:12:25.921+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-15 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3582, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:12:46.804+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66666f42', '54825a75-40ef-4329-bb4a-61c12642acef', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3583, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:13:19.886+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54a00547', '1a43ea8b-04b3-43ae-8fed-6dd93dae9a3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3584, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:13:19.995+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54a00547', '1a43ea8b-04b3-43ae-8fed-6dd93dae9a3d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3586, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:13:58.158+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d6d0a4a', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3587, '00000000-0000-0000-0000-000000000000', NULL, 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:14:13.21+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-14 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3588, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:14:26.513+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3589, '00000000-0000-0000-0000-000000000000', NULL, '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:14:40.635+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3590, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:14:58.715+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3592, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 11:15:12.407+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7b432c7b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3595, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:15:58.406+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3614, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:18:31.384+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3615, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:18:49.148+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5765ab1', '42516224-1128-4493-a50a-057396fe3c84', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3619, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:20:00.929+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3621, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:20:06.544+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3631, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:29.107+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33a84fba', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3632, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:29.168+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33a84fba', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3633, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:59.618+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b974c8c', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3634, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:21:59.649+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b974c8c', 'd4150586-ba4b-4ba2-b05c-3f6910de4c47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3635, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:22:14.795+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3638, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:22:59.917+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3663, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:28:49.575+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c09c581', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3660, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:28:29.089+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3714, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:41:33.139+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3716, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:41:33.195+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78c556aa', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3718, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:41:33.283+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78c556aa', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3719, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:41:33.616+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3720, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:41:38.503+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3662, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:28:49.302+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: NFS-11, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3ec50920', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3664, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:29:08.481+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3665, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:29:09.926+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4ead2803', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3667, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:30:02.685+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3668, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:30:06.661+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3670, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:31:00.177+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3671, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:07.72+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'b95c5ba', 'b1a86420-954c-45be-9c01-6f8287638b1f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3672, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:07.844+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6112c486', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3673, '00000000-0000-0000-0000-000000000000', NULL, 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:31.506+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3675, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:31.62+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c09c581', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3677, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:31.709+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c09c581', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3678, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:31:32.017+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3681, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:32:13.455+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3687, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:34:00.011+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3688, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:34:11.341+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30999171', 'b1a86420-954c-45be-9c01-6f8287638b1f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3690, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:35:01.46+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3691, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:35:05.506+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3692, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:36:08.169+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3700, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:38:31.596+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3703, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:38:52.399+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e1ee077', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3708, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:40:07.357+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3715, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:41:33.195+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e1ee077', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3717, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:41:33.275+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e1ee077', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3732, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:45:00.451+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3735, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:45:33.589+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3740, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:46:31.492+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1a9ea3b3', '0e950494-82ae-487b-b051-bce39c686d61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3742, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:46:31.634+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1a9ea3b3', '0e950494-82ae-487b-b051-bce39c686d61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3757, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:51:31.324+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3669, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:30:33.48+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3679, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:51.843+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4ead2803', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3680, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:31:51.916+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4ead2803', '63046d16-fd32-433f-821d-cc7347573510', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3685, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:33:31.506+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3689, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:34:33.56+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3704, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:38:52.411+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '78c556aa', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3710, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:40:59.043+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3739, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:46:31.472+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11a8eab', '0e950494-82ae-487b-b051-bce39c686d61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3743, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:47:01.446+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3746, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:48:00.494+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3747, '00000000-0000-0000-0000-000000000000', NULL, '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:48:49.477+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-8, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '54c61bd', '9a5ea7c4-250a-4dd6-ab27-ee4cbd10152f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3749, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:48:58.642+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3750, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:49:01.244+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3753, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:50:08.199+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-9 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3754, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:51:04.661+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e671200', '9d025b14-7045-44ab-9e8b-03f4df89f046', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3755, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:51:04.718+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42b4a70a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3756, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:51:05.646+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3758, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:51:33.892+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2282a13f', '9a5ea7c4-250a-4dd6-ab27-ee4cbd10152f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3759, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:51:34.416+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2282a13f', '9a5ea7c4-250a-4dd6-ab27-ee4cbd10152f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3763, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:53:46.856+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '451408ee', '9d025b14-7045-44ab-9e8b-03f4df89f046', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3782, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:58:02.378+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3783, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:58:08.93+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3784, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:58:36.918+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3787, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:59:36.287+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3788, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:59:36.318+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3789, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:59:36.346+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-5 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3790, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:59:36.371+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3792, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:59:46.735+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3793, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:00:11.256+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3686, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:33:50.107+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6694e789', 'b1a86420-954c-45be-9c01-6f8287638b1f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3695, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:36:30.944+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6694e789', 'b1a86420-954c-45be-9c01-6f8287638b1f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3696, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:36:30.98+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6694e789', 'b1a86420-954c-45be-9c01-6f8287638b1f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3697, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:36:31.736+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3698, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:36:52.285+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30999171', 'b1a86420-954c-45be-9c01-6f8287638b1f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3699, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:36:52.384+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30999171', 'b1a86420-954c-45be-9c01-6f8287638b1f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3701, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:38:36.452+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3721, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:42:01.371+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3723, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:42:33.848+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3724, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:43:08.269+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-18 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3726, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:43:40.879+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3727, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:43:49.531+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11a8eab', '0e950494-82ae-487b-b051-bce39c686d61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3737, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:46:07.264+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '778d29b5', '9a5ea7c4-250a-4dd6-ab27-ee4cbd10152f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3738, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:46:07.332+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3ddfcd2e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3741, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:46:31.529+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '11a8eab', '0e950494-82ae-487b-b051-bce39c686d61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3744, '00000000-0000-0000-0000-000000000000', NULL, '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:47:06.212+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-5 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3745, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:47:32.509+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3748, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:48:51.556+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2282a13f', '9a5ea7c4-250a-4dd6-ab27-ee4cbd10152f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3751, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:49:36.633+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3752, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:50:00.877+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3765, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:54:06.094+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3768, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:55:01.389+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3772, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:56:04.293+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44429d9a', '83aac1e4-c059-485c-94e0-d1f47c08d07f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3773, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:56:04.357+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '905c8c', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3775, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:56:28.031+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '451408ee', '9d025b14-7045-44ab-9e8b-03f4df89f046', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3777, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:56:28.203+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '451408ee', '9d025b14-7045-44ab-9e8b-03f4df89f046', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3778, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:56:38.59+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3780, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:57:36.983+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3693, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:36:09.293+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66960319', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3694, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:36:09.542+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f1d5c06', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3702, '00000000-0000-0000-0000-000000000000', NULL, '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:38:52.392+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-13, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75686671', 'ed67ee02-6bff-4928-98b4-225f4714bad5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3705, '00000000-0000-0000-0000-000000000000', NULL, '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:39:00.004+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-9 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3706, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:39:33.691+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3707, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:40:01.039+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3709, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:40:37.411+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3711, '00000000-0000-0000-0000-000000000000', NULL, '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:41:01.435+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-18 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3712, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:41:07.035+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '16d9cb9d', '0e950494-82ae-487b-b051-bce39c686d61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3713, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:41:07.1+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25b85679', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3722, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:42:16.197+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-19 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3725, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:43:34.081+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3728, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:43:49.537+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1a9ea3b3', '0e950494-82ae-487b-b051-bce39c686d61', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3729, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:44:01.121+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3730, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:44:05.444+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3731, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:44:41.223+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3733, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:45:02.18+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3734, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:45:31.138+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3736, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:45:58.566+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-6 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3769, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:55:36.346+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3770, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:55:36.371+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3771, '00000000-0000-0000-0000-000000000000', NULL, 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:56:02.16+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3774, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:56:28.013+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36f444de', '9d025b14-7045-44ab-9e8b-03f4df89f046', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3776, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:56:28.176+02', 'VM_MIGRATION_FAILED', 65, 2, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36f444de', '9d025b14-7045-44ab-9e8b-03f4df89f046', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3779, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:57:00.433+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-11 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3786, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:59:36.265+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3791, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:59:38.795+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3801, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:01:37.914+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3802, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:01:44.672+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-4 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3805, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:04:36.912+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '18bc3038', 'ecc19e94-7312-4963-811e-40e962b868fe', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3760, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:51:38.839+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3761, '00000000-0000-0000-0000-000000000000', NULL, '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:52:01.589+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-6 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3762, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:53:36.985+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3764, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:53:46.856+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: VM, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36f444de', '9d025b14-7045-44ab-9e8b-03f4df89f046', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3766, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:54:36.931+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3767, '00000000-0000-0000-0000-000000000000', NULL, '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 11:55:01.157+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-11 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3797, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:01:21.989+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: VM, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30644af', 'df926918-c19a-4b5d-89ef-c3a588c4f4d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3798, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:01:22.025+02', 'VM_MIGRATION_DONE', 63, 0, 'Migration complete (VM: test, Source Host: gold-vdsd).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '302f0000', 'df926918-c19a-4b5d-89ef-c3a588c4f4d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3799, '00000000-0000-0000-0000-000000000000', NULL, 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:01:25.233+02', 'VM_DOWN', 61, 0, 'VM VM is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3800, '00000000-0000-0000-0000-000000000000', NULL, 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:01:25.351+02', 'VM_DOWN', 61, 0, 'VM test is down. Exit message: Migration succeeded', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3808, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:05:00.544+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsc was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2e31f808', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3809, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:05:01.397+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3810, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:05:02.426+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3811, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 12:05:53.5+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3814, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:08:04.637+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3816, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:08:46.127+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-3 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3819, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:09:45.548+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3821, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:10:02.707+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3781, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 11:57:41.569+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-13 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3785, '00000000-0000-0000-0000-000000000000', NULL, '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 11:58:47.31+02', 'VM_MIGRATION_TRYING_RERUN', 128, 1, 'Migration failed due to Error: Fatal error during migration (VM: XP-15, Source Host: gold-vdsd). Trying to migrate to another Host.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5bffff34', '83aac1e4-c059-485c-94e0-d1f47c08d07f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3794, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:00:43.364+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3796, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:01:16.56+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36e0f865', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3803, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:02:38.625+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3804, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:03:42.523+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-20 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3806, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:04:39.98+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3807, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:04:44.418+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-17 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3812, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:08:02.012+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '752d9cd7', '42df5dc2-fdef-4bfa-8bce-33ffc2b2638c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3813, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:08:02.124+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4764f759', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3815, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:08:09.308+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-7 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3817, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:09:07.273+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ba0c2f7', 'f0bfb89b-9ee4-410d-bcb4-bc7ac50fa7da', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3818, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:09:07.336+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6975c43f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3820, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:10:01.886+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3823, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:13:02.427+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4e992cee', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3829, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:04.716+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-8 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3830, '00000000-0000-0000-0000-000000000000', NULL, '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:04.765+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-3 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3831, '00000000-0000-0000-0000-000000000000', NULL, 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:04.812+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3832, '00000000-0000-0000-0000-000000000000', NULL, 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:04.847+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-4 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3833, '00000000-0000-0000-0000-000000000000', NULL, '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:04.889+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-20 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3834, '00000000-0000-0000-0000-000000000000', NULL, '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:05.097+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-7 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3835, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:05.145+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3836, '00000000-0000-0000-0000-000000000000', NULL, 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:05.183+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-17 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3837, '00000000-0000-0000-0000-000000000000', NULL, '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:14:05.215+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3838, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:15:02.359+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3795, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:01:16.492+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7592ca32', 'df926918-c19a-4b5d-89ef-c3a588c4f4d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3827, '00000000-0000-0000-0000-000000000000', NULL, 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:13:50.763+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-13 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3828, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:13:50.8+02', 'VM_NOT_RESPONDING', 126, 1, 'VM XP-12 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3822, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:13:02.347+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7e83b24a', '830c81c6-d1d9-4070-8f16-461b89b11b19', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3824, '00000000-0000-0000-0000-000000000000', NULL, 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:13:05.008+02', 'VM_PAUSED_EIO', 145, 2, 'VM XP-12 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3825, '00000000-0000-0000-0000-000000000000', NULL, '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:13:05.029+02', 'VM_PAUSED_EIO', 145, 2, 'VM NFS-19 has paused due to storage I/O problem.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3826, '00000000-0000-0000-0000-000000000000', NULL, '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:13:14.435+02', 'VM_NOT_RESPONDING', 126, 1, 'VM NFS-8 is not responding.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3839, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:32:31.801+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3840, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:32:34.749+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3841, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 12:32:38.012+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3842, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 12:32:40.687+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '60fbce05', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3843, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 12:32:40.822+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3844, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 12:33:46.192+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '6bb074db', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3845, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 12:39:12.731+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3846, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 12:39:15.582+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3847, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 12:39:19.567+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3848, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 12:39:26.449+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5020f4be', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3849, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 12:39:26.547+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3850, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 14:09:25.442+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3851, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:09:53.777+02', 'USER_STOP_VM', 33, 0, 'VM NFS-1 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4fbe5425', '1dded88b-0215-4426-b6c7-0683ed14d5f5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3852, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:09:55.251+02', 'USER_STOP_VM', 33, 0, 'VM NFS-10 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '484aed85', '2cc5324a-b9ce-4c23-a000-01605286d5f2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3853, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:09:56.212+02', 'USER_STOP_VM', 33, 0, 'VM NFS-11 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2f2fdbd7', 'd010b5ae-8da6-4eae-b54d-65a608353b87', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3854, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:09:56.981+02', 'USER_STOP_VM', 33, 0, 'VM NFS-12 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6f0a1874', '665f7cdd-96b7-4f30-bbff-bd1bf31455cb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3855, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:09:58.113+02', 'USER_STOP_VM', 33, 0, 'VM NFS-13 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7fcba09f', 'a02249c9-8bc4-415d-912e-930ff06a93ea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3856, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:09:58.964+02', 'USER_STOP_VM', 33, 0, 'VM NFS-14 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '119e6845', '147be32d-bed8-4af7-bc0e-6345aeded186', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3857, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:00.156+02', 'USER_STOP_VM', 33, 0, 'VM NFS-15 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36cf930c', '87b30486-4bdf-46c4-8873-21ad4a518ffc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3858, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:00.726+02', 'USER_STOP_VM', 33, 0, 'VM NFS-18 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '588390eb', 'f45a37ed-106d-4c8d-87da-4884e110f252', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3859, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:01.314+02', 'USER_STOP_VM', 33, 0, 'VM NFS-16 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '75bf14f0', 'fe38b776-6836-4110-a210-06b1b3254e13', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3860, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:01.721+02', 'USER_STOP_VM', 33, 0, 'VM NFS-19 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '259f61b3', 'b767346a-b8f8-4e57-ac09-250f1e8af7db', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3861, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:02.449+02', 'USER_STOP_VM', 33, 0, 'VM NFS-2 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c74211', '7bc9cbe3-9faf-47bb-8804-ac50dc75ed6b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3862, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:03.3+02', 'USER_STOP_VM', 33, 0, 'VM NFS-20 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '67c26b83', '927c06f8-59d3-400c-914f-4de370f8cb89', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3863, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:04.028+02', 'USER_STOP_VM', 33, 0, 'VM NFS-3 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'd209aad', '383208ba-91f9-402e-a1d8-8c34241808c8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3864, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:05.44+02', 'USER_STOP_VM', 33, 0, 'VM test stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '74f65841', 'a46e1c39-f72f-485d-8422-46bd4183a5c0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3865, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:05.699+02', 'USER_STOP_VM', 33, 0, 'VM NFS-4 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '578ada96', 'd07cd4af-5e82-4621-8685-f1d1db6fe7da', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3866, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:06.271+02', 'USER_STOP_VM', 33, 0, 'VM NFS-5 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5d14dac0', '5f0d9177-7db8-4df7-b832-d8253c6cf42b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3867, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:06.309+02', 'USER_STOP_VM', 33, 0, 'VM VM stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '591c4f64', '7cdc5db6-ccf2-4ee2-a94e-b29ec0f56428', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3868, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:06.928+02', 'USER_STOP_VM', 33, 0, 'VM NFS-6 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '425a2fe', '23eb1ae2-53eb-40a8-9e4c-34cc5d6c56db', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3869, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:07.546+02', 'USER_STOP_VM', 33, 0, 'VM NFS-7 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '141dfef5', '39d1711c-1978-4140-87ff-9cef184219a9', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3870, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:08.544+02', 'USER_STOP_VM', 33, 0, 'VM NFS-8 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3d4d9124', 'eca5d610-39a8-4472-905c-dbff248af83e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3871, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:09.406+02', 'USER_STOP_VM', 33, 0, 'VM NFS-9 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2f73f1ed', '73bd5f8f-9687-4012-9b0e-10d90c95b092', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3872, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:10.207+02', 'USER_STOP_VM', 33, 0, 'VM NFS-17 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '651016f1', '3e084343-9cc3-46b8-96ce-e28f8b695959', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3881, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:20.424+02', 'USER_STOP_VM', 33, 0, 'VM XP-18 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6746e026', '68670578-a624-4ab9-8bef-5ed8fb9f5bdd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3882, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:21.331+02', 'USER_STOP_VM', 33, 0, 'VM XP-19 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5e2613c2', 'e4f7871d-3981-4a4f-8329-083c5525392e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3887, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:25.408+02', 'USER_STOP_VM', 33, 0, 'VM XP-5 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9c08291', '4397e144-a67f-46d2-9e99-ef1d97916a9d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3891, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:29.37+02', 'USER_STOP_VM', 33, 0, 'VM XP-9 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4eb23e19', 'b78e9bf0-d31d-4ab6-9113-981f2f20fb4f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3894, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:13:58.111+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '14a57481', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3898, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:17:53.47+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2e6d54c9', '305bf9ad-5d55-4946-9dc6-4a4b203a3fb6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3907, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:30:01.255+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3913, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:40:01.786+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3917, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:45:01.271+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3873, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:12.077+02', 'USER_STOP_VM', 33, 0, 'VM XP-10 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71124f63', '80c785e5-0a4e-41e7-8999-6c82b4bf8e93', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3874, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:13.068+02', 'USER_STOP_VM', 33, 0, 'VM XP-11 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '691a2693', 'e48f1c15-f920-440e-94b7-a1473fb35273', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3878, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:17.091+02', 'USER_STOP_VM', 33, 0, 'VM XP-15 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c3cba90', '5de6acea-d824-4f81-a52e-c649efd9a57a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3883, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:21.998+02', 'USER_STOP_VM', 33, 0, 'VM XP-2 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15db55d8', 'c972dc46-a9fe-499b-a4bc-966c4bd48246', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3884, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:22.727+02', 'USER_STOP_VM', 33, 0, 'VM XP-20 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72e0e31d', 'e503de6d-da45-4865-a728-319e20607c7c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3885, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:23.364+02', 'USER_STOP_VM', 33, 0, 'VM XP-3 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a5ebfd7', 'ab6bb970-e003-491e-baa2-a1767eb55aeb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3888, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:10:26.361+02', 'USER_STOP_VM', 33, 0, 'VM XP-6 stopped by admin@internal (Host: camel-vdsb).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3dbc0297', '32c19e5c-70b6-4e51-96b1-eeb59ee9ea7b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3889, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:27.227+02', 'USER_STOP_VM', 33, 0, 'VM XP-7 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '24e272b', '854a29e2-0458-436c-bfe5-0b27fba2782c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3890, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:28.047+02', 'USER_STOP_VM', 33, 0, 'VM XP-8 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '58ed793b', '1a3f7c06-09cb-4b2a-8fe3-edc5bfa18d23', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3892, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:29.982+02', 'USER_STOP_VM', 33, 0, 'VM XP-1 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '180b03ac', '6a6df254-f0c6-4ca9-8223-af7fee119112', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3899, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:20:00.57+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host camel-vdsb was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '505e230f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3900, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:20:01.501+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3901, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:21:04.944+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '592d534d', '8c702176-2bdb-4e88-bf76-d49c8f9c791f', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3902, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:21:04.981+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76bd413a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3921, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:50:00.441+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsc was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '50e5b68f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3922, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:50:01.489+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3923, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:50:01.686+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3924, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:51:04.569+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40cdd1c3', '1b34504d-7f45-409c-92be-c90cc791c3a4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3925, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:51:04.611+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '298861d4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3875, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:13.818+02', 'USER_STOP_VM', 33, 0, 'VM XP-12 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33dab2cd', '33c0b41b-2804-48a6-87b1-87c2439c0b8b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3876, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:15.336+02', 'USER_STOP_VM', 33, 0, 'VM XP-13 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b10cb53', 'ee861487-29a6-47c2-873a-9cff3fb18a7d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3877, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:16.28+02', 'USER_STOP_VM', 33, 0, 'VM XP-14 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2b94e4da', '506fa211-f787-4a55-924e-ca7dc4b2c8e5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3879, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:17.787+02', 'USER_STOP_VM', 33, 0, 'VM XP-16 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '36fc62d5', '9a7f4d41-5851-4eee-aaa1-fde42a60b992', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3880, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:10:18.822+02', 'USER_STOP_VM', 33, 0, 'VM XP-17 stopped by admin@internal (Host: gold-vdsc).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73bcaa26', 'fa4735de-cd2f-4aed-9382-616d69c0870a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3886, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:10:24.346+02', 'USER_STOP_VM', 33, 0, 'VM XP-4 stopped by admin@internal (Host: gold-vdsd).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5284c192', '7dcda0f1-8b18-47a1-98a7-aed9d0862399', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3893, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:13:55.117+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3895, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:15:00.715+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2a0bef05', 'cc8dbb8b-16e4-4bcf-b684-6d2a8000b8c0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3896, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:15:00.77+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '62ee3322', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3897, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:17:09.455+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ef9f3c9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3903, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:22:46.536+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6da162e6', '25bec7b6-2d4f-4b14-9a45-b0f6ecb688c2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3904, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:25:01.633+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3905, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:26:04.415+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2646b45d', '15dec2b5-4f96-4882-bd7e-da1ed6942455', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3906, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:26:04.485+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '27ebd4cd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3908, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:31:03.689+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '72ba997b', 'ed74c4de-0c8c-4fcd-8013-9d022c809f16', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3909, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:31:03.775+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '42f633ee', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3910, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:35:00.681+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3911, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:36:03.117+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1bb377df', '7629b75d-2409-459c-b126-47e3a6d59255', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3912, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:36:03.159+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3539dcf2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3914, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:41:04.383+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '66e80949', '531cd648-32cd-4262-99b5-67b9569ddbea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3915, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:41:04.446+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '740ec7a7', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3916, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 14:42:53.664+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3918, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:45:12.631+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33991540', '141c9734-e3b6-4a8f-9201-21492d499c60', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3919, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:46:04.995+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '237979a9', 'aa3c53d4-3b6b-4394-a7aa-7135535ce953', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3920, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:46:05.048+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '15b74ed0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3926, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:52:07.074+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49e87ead', '1605bc05-14fd-4efe-b3cf-609cd3f0a7fc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3927, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:52:07.131+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79580161', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3928, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:55:01.268+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3929, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:55:01.697+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3930, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:56:37.695+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2acfbd55', '1cf64f08-2872-4456-af86-cecaea43a983', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3931, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 14:56:37.802+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2d5aa5ef', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3932, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:57:40.267+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'e2423', '926152eb-297e-4682-86b9-6195dcb56d49', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3933, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 14:57:40.302+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2f15781f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3934, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:00:00.953+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3935, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:00:02.791+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3936, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:01:04.903+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '45861191', 'd9d3bc2f-40f6-4982-924e-bdbdfcc20454', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3937, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:01:04.941+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3b678d92', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3938, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:02:07.437+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71b1a0bd', '92421cfa-928a-4aca-8fe4-c87444f214d3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3939, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:02:07.493+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2dd12a7a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3940, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:05:01.704+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3941, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:05:02.082+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3942, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:06:38.301+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '27d0252', 'fb0f4047-ef21-4a03-b5fa-9ed5e5f1457e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3943, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:06:38.47+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f02ddea', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3944, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:07:42.018+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '10723874', 'afbc18a3-0c4e-46c6-a2f4-f681f0268fa6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3945, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:07:42.074+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1b05679b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3946, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:08:21.96+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5c024190', '97d6c7c4-71ff-4fba-a26a-62ad38b32a2d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3947, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:08:23.137+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3948, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:08:23.177+02', 'VDS_ACTIVATE', 16, 0, 'Host camel-vdsb was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3e4d83d7', '53e03845-5a94-4243-adbd-2272be37e4db', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3949, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:08:24.553+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3950, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:09:52.221+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7f3a721b', 'e578f36b-9064-4a25-a219-7a2aad6cf551', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3951, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:09:52.283+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsc to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7b7fe999', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3952, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:10:00.788+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3953, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:10:22.616+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3954, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 15:12:56.819+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '47f49e03', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3955, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:13:02.809+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3956, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:13:05.77+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3957, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:13:09.64+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3958, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:13:16.759+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6a1b0942', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3959, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:13:16.903+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3960, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 15:14:28.604+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3966, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:37:53.653+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host camel-vdsb (Address: camel-vdsb.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3961, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:16:06.668+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3962, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:16:11.719+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6200502f', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3963, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:17:11.774+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsd cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c38e6e8', '3578453a-7fab-4a18-9fa0-1553277abcf4', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3964, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:17:11.832+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host gold-vdsd to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '569dc501', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3965, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 15:20:12.134+02', 'RECONSTRUCT_MASTER_FAILED_NO_MASTER', 983, 1, 'No valid Data Storage Domains are available in Data Center NFS (please check your storage infrastructure).', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7c0ead80', '53161368-f4c1-4de1-acb1-71019e0486ed', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3967, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:40:04.687+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '39cfe129', 'e16f70b6-7390-448f-95a7-c534d3caf9f0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3968, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:44:12.678+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '30b19a60', 'a432ea17-fff6-471a-ae92-780bf9564aff', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3969, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 15:44:13.169+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3970, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:44:13.671+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3c4b8782', '74d566c8-4802-4db4-b3b6-d4a0448f2203', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3971, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 15:44:14.998+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3972, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 16:15:51.236+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7433a5ed', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3973, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 16:15:53.134+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3974, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 16:17:01.764+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host camel-vdsb cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, NULL, '', '00000000-0000-0000-0000-000000000000', '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71515fcb', '14b87a68-4bdd-4ef0-b243-a5ea23b7bde0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3975, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 16:17:02.033+02', 'CONNECT_STORAGE_POOL_FAILED', 995, 1, 'Failed to connect Host camel-vdsb to Storage Pool NFS', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '720a01e3', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3976, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 16:19:12.868+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'a50eb35', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3977, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 16:20:06.438+02', 'VDS_SET_NONOPERATIONAL_DOMAIN', 522, 1, 'Host gold-vdsc cannot access one of the Storage Domains attached to the Data Center NFS. Setting Host state to Non-Operational.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1ce6efb8', '96fba0e0-c0e7-49a8-a59e-3ca2c877907d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3978, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 16:20:15.928+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3979, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 16:27:05.001+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '6a6141b2', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3980, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 16:27:13.177+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3981, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 16:27:23.955+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '28c3df01', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3982, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-18 16:27:24.059+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3983, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 16:30:01.491+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host gold-vdsc was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '43b8542a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3984, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 16:30:02.193+02', 'VDS_ACTIVATE_ASYNC', 9502, 0, 'Host camel-vdsb was autorecovered.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3678b4be', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3985, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-18 16:30:02.407+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3986, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-18 16:30:03.917+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3987, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 16:32:43.876+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3988, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 16:44:12.669+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '72f17dc8', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3989, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 16:44:36.491+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3990, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-18 17:27:07.35+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '3d736582', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3991, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-19 11:00:05.561+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3992, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-19 11:57:06.488+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '633b9204', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3993, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-19 12:10:10.098+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3994, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-19 12:57:03.985+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '29347b1a', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3996, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:08.627+02', 'USER_ADD_VM', 34, 0, 'VM AA was created by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1018e00b', '60afc8e9-b72b-4a61-b593-31b266b6c9fd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3997, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:12.033+02', 'NETWORK_ACTIVATE_VM_INTERFACE_SUCCESS', 1012, 0, 'Network Interface nic1 (Red Hat VirtIO) activated for VM AA. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3863d8cd', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3998, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:12.084+02', 'NETWORK_ADD_VM_INTERFACE', 932, 0, 'Interface nic1 (Red Hat VirtIO) was added to VM AA. (User: admin@internal)', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5bf6c6f9', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4000, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:19.586+02', 'USER_ADD_DISK_TO_VM_FINISHED_SUCCESS', 97, 0, 'The disk AA_Disk1 was successfully added to VM AA.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49eb0cb9', 'efb8e92f-8ac2-4a39-9bfe-98ff2f2164d8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4005, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:48.084+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 3 creation for VM AA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '206d6ba3', 'c5665b5a-d5d6-48d4-b889-0cbf8608250b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4006, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:49.78+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 3 creation for VM AA has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '206d6ba3', 'c5665b5a-d5d6-48d4-b889-0cbf8608250b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4009, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:51:07.221+02', 'USER_RESTORE_FROM_SNAPSHOT_START', 1190, 0, 'Restoring VM AA from snapshot started by user admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5537aeef', 'e37dc13c-63c5-4b1c-9c61-f7fb2c213793', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4010, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:51:09.775+02', 'USER_RESTORE_FROM_SNAPSHOT_FINISH_SUCCESS', 100, 0, 'VM AA restoring from Snapshot has been completed.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5537aeef', 'e37dc13c-63c5-4b1c-9c61-f7fb2c213793', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4016, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:10.151+02', 'USER_TRY_BACK_TO_SNAPSHOT_FINISH_SUCCESS', 71, 0, 'Snapshot-Preview for VM AA has been completed.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fc7ca3', 'cfe0c51f-05b7-4171-b448-727ac52b2f71', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4017, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:18.151+02', 'USER_RESTORE_FROM_SNAPSHOT_START', 1190, 0, 'Restoring VM AA from snapshot started by user admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '607fafab', '5deaed61-8ff3-4b2f-92cd-acce1cff0eea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (3999, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:15.964+02', 'USER_ADD_DISK_TO_VM', 78, 0, 'Add-Disk operation of AA_Disk1 was initiated on VM AA by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '9d625863-2423-46d3-8439-d19e805a93fe', 'NFs', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '49eb0cb9', 'efb8e92f-8ac2-4a39-9bfe-98ff2f2164d8', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4001, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:27.201+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 1 creation for VM AA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ab19191', '1bdc94a0-39c0-4e1e-8833-014a6a5a41b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4002, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:29.562+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 1 creation for VM AA has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2ab19191', '1bdc94a0-39c0-4e1e-8833-014a6a5a41b0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4003, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:35.94+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 2 creation for VM AA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25573380', 'b3e7b847-3f82-48d1-b73c-95a786aef8ad', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4004, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:39.664+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 2 creation for VM AA has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '25573380', 'b3e7b847-3f82-48d1-b73c-95a786aef8ad', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4007, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:50:56.714+02', 'USER_TRY_BACK_TO_SNAPSHOT', 46, 0, 'Snapshot-Preview for VM AA was initiated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5662f771', '585e2111-c59f-44ff-9808-8eadf690c809', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4008, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:51:00.071+02', 'USER_TRY_BACK_TO_SNAPSHOT_FINISH_SUCCESS', 71, 0, 'Snapshot-Preview for VM AA has been completed.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5662f771', '585e2111-c59f-44ff-9808-8eadf690c809', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4011, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:51:43.056+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 2 creation for VM AA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '243376f0', 'b6d7b640-6bfe-43ba-b89f-57dc1e521c32', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4012, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:51:49.878+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 2 creation for VM AA has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '243376f0', 'b6d7b640-6bfe-43ba-b89f-57dc1e521c32', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4013, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:51:57.103+02', 'USER_CREATE_SNAPSHOT', 45, 0, 'Snapshot 3 creation for VM AA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7029cc3d', 'd19a2131-a3a5-4ebb-b203-886d7e517904', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4014, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:51:59.92+02', 'USER_CREATE_SNAPSHOT_FINISHED_SUCCESS', 68, 0, 'Snapshot 3 creation for VM AA has been completed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7029cc3d', 'd19a2131-a3a5-4ebb-b203-886d7e517904', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4015, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:05.718+02', 'USER_TRY_BACK_TO_SNAPSHOT', 46, 0, 'Snapshot-Preview for VM AA was initiated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fc7ca3', 'cfe0c51f-05b7-4171-b448-727ac52b2f71', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4018, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:20.105+02', 'USER_RESTORE_FROM_SNAPSHOT_FINISH_SUCCESS', 100, 0, 'VM AA restoring from Snapshot has been completed.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '607fafab', '5deaed61-8ff3-4b2f-92cd-acce1cff0eea', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4019, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:27.156+02', 'USER_TRY_BACK_TO_SNAPSHOT', 46, 0, 'Snapshot-Preview for VM AA was initiated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b915112', 'c3f42951-cae6-4320-aec5-b0790f2d9963', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4020, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:30.303+02', 'USER_TRY_BACK_TO_SNAPSHOT_FINISH_SUCCESS', 71, 0, 'Snapshot-Preview for VM AA has been completed.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5b915112', 'c3f42951-cae6-4320-aec5-b0790f2d9963', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4021, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:36.046+02', 'USER_RESTORE_FROM_SNAPSHOT_START', 1190, 0, 'Restoring VM AA from snapshot started by user admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'badb140', '80bfd2a4-706e-45ae-be79-f4ccb95c5d69', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4022, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-19 15:52:40.131+02', 'USER_RESTORE_FROM_SNAPSHOT_FINISH_SUCCESS', 100, 0, 'VM AA restoring from Snapshot has been completed.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'badb140', '80bfd2a4-706e-45ae-be79-f4ccb95c5d69', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4023, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 09:54:35.084+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4024, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 09:54:37.89+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4025, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 09:54:41.319+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4026, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 09:54:49.021+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '44d72471', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4027, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 09:54:49.196+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsd (Address: gold-vdsd.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4028, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 10:34:59.081+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4029, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 11:24:30.054+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '40a96933', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4030, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 11:36:16.316+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4031, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-20 11:37:04.63+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM AA was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20aca81', '59d3107b-4aae-49d1-ab4c-07c5b2f5aef3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4032, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:05.647+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-1 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ffee43c', 'c4205b78-31f2-4865-a314-b45641edbacd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4033, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:06.647+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-10 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f967f21', '71cf4fdd-51ef-4056-bc30-7eb8a7a99e3a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4034, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:07.444+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-11 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '662262a4', '59cbae38-e94d-4a69-9e15-93b165cc9229', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4035, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:08.578+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-12 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9bc3e52', '552ca306-6da5-4051-afdf-7cdc0c16c27d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4036, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:09.315+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-13 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5628564b', '75ba1508-da60-45c2-bff9-c7471cd70a04', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4037, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd2f4be14-d34c-44fe-b176-c765251c4e46', 'NFS-13', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:09.692+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-13 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5628564b', '75ba1508-da60-45c2-bff9-c7471cd70a04', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4042, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd7b507cc-bf71-4649-8334-76eac3a0c0cc', 'NFS-10', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:09.712+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-10 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3f967f21', '71cf4fdd-51ef-4056-bc30-7eb8a7a99e3a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4054, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.16+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-5 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f0bc046', 'a6853121-71c1-40cb-a415-c817a311773c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4075, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-20 11:37:30.922+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM test was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6924e0dd', 'e52d0ea6-97ea-44f3-b063-f731a6bc98a2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4083, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.596+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-8 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '794af3f2', '1cbdf21e-a577-4d2e-8408-4203800ecbf7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4038, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd1289c6f-641f-4eba-9e29-48a217f544d2', 'NFS-12', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:09.697+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-12 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '9bc3e52', '552ca306-6da5-4051-afdf-7cdc0c16c27d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4055, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.174+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-16 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7cb187e1', '8ff9c529-f170-4996-8c20-1394fbc96330', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4063, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.472+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-3 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '233918b', 'e7b22e9c-ac84-42eb-b9ba-bbb9d539f8a0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4065, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.505+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-6 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d64f52e', '518d5451-d31f-4353-93fe-cee2dfb5f02b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4102, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.653+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-13 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7941a6fb', 'b7d5ee32-e103-47a7-b43b-d8b739c1529d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4106, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.81+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-4 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5de4f1a2', '79c5d04d-72d8-42ed-a092-451b4d615885', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4107, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:43.734+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-5 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fc88bbd', 'b76da831-051f-483a-b942-605922eeb19c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4108, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:44.479+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-6 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a69e908', 'd256cef7-73ce-4e84-9864-e25a46aeff47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4109, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:45.417+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-7 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '48868eff', 'ea342d38-f9f9-4b9b-94fe-6ca25ce46f99', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4110, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:46.064+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-8 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d3e8e0d', 'b4df1194-4476-4987-9678-868b3492b2d5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4111, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:46.931+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-9 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '753444b4', '905b29b5-ddc0-40dd-a13e-8f340e2e1546', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4120, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 11:40:18.85+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsd was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2972b702', 'b06b4fd3-49f7-4aed-a057-89fe8727894c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4124, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:40:32.385+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '157489b0', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4125, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:40:32.526+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsc parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '51e8f5aa', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4039, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'bdf416f0-ac1a-4476-8da6-c9b6cdfb2f73', 'NFS-1', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:09.7+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-1 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', 'ffee43c', 'c4205b78-31f2-4865-a314-b45641edbacd', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4040, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f1de2f99-4715-45a2-8810-ce89ebbede60', 'NFS-11', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:09.702+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-11 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '662262a4', '59cbae38-e94d-4a69-9e15-93b165cc9229', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4041, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '64c5e0e9-847e-4324-806e-c13a9d6c57f8', 'AA', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-20 11:37:09.71+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM AA was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '20aca81', '59d3107b-4aae-49d1-ab4c-07c5b2f5aef3', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4043, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:10.267+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-14 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76b0b0d', '751f0212-63c6-45a7-8234-5cad32ca6104', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4044, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:11.063+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-15 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '280cdff2', '42f937ee-f1ed-4c04-92e6-26ec969de8a2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4045, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c7f0271f-429f-4d2b-ae4b-fde4fd03f31b', 'NFS-16', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:12.355+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-16 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7cb187e1', '8ff9c529-f170-4996-8c20-1394fbc96330', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4046, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:13.074+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-17 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '226c304d', 'eb723862-fa8f-4e24-9096-42ded2f148c6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4047, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:13.933+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-18 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f3307df', 'b5963b4e-0052-458c-a0f7-00cd02145085', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4048, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:14.631+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-19 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6812ae7', '2f080628-eb6a-4a5e-bb6f-f8b41517253e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4049, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:15.422+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-2 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6399ab38', 'd792882c-620e-438c-bb41-100b879c6daa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4050, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:16.15+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-20 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73690e6d', 'b070dc41-54d7-432c-a8ca-5cac852dc30e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4051, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '6baa4493-80cd-492e-8b26-fb48ec7a29da', 'NFS-3', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:16.827+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-3 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '233918b', 'e7b22e9c-ac84-42eb-b9ba-bbb9d539f8a0', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4052, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:18.438+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-4 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '100f6a93', '7dd7b4b9-4013-415c-b88b-425ec5531095', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4053, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '766ddd42-940f-4c23-8f96-e974b2cbc6f0', 'NFS-5', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:19.231+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-5 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1f0bc046', 'a6853121-71c1-40cb-a415-c817a311773c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4056, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2f706310-befa-49ff-9e39-b03b52e524d2', 'NFS-14', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.188+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-14 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '76b0b0d', '751f0212-63c6-45a7-8234-5cad32ca6104', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4057, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '911121f5-620c-442f-806b-bea452dfabeb', 'NFS-19', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.196+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-19 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6812ae7', '2f080628-eb6a-4a5e-bb6f-f8b41517253e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4058, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '153244b6-43a4-4ea8-b6f0-11572a1af588', 'NFS-15', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.255+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-15 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '280cdff2', '42f937ee-f1ed-4c04-92e6-26ec969de8a2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4059, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e2846417-90ae-4417-ad9f-362f4d954a2d', 'NFS-2', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.328+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-2 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6399ab38', 'd792882c-620e-438c-bb41-100b879c6daa', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4060, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'd024f628-bdfa-430a-bc69-a454517352bc', 'NFS-4', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.389+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-4 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '100f6a93', '7dd7b4b9-4013-415c-b88b-425ec5531095', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4061, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'b4ab4452-e80f-4c7a-9c9c-a38a481a9376', 'NFS-17', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.399+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-17 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '226c304d', 'eb723862-fa8f-4e24-9096-42ded2f148c6', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4062, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '4c223459-5e98-43fd-a8e8-058641103e99', 'NFS-20', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.401+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-20 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '73690e6d', 'b070dc41-54d7-432c-a8ca-5cac852dc30e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4066, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:21.301+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-7 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c76650d', 'c6f7982f-ad3b-41a4-8411-d465ab2c7d07', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4070, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5351aae0-9645-42a8-a805-65e72260c652', 'ttt', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-20 11:37:25.56+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM ttt was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '431b9bc9', '07ac0c63-a802-46bc-9d77-578096d68cbf', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4071, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-20 11:37:27.458+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM VM was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33ca24dd', 'e84b3bd4-b181-419d-851e-9f93f2ee2d64', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4072, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:28.307+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-1 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3bc269e3', '47e1166c-cb63-4f94-a8cb-733240f3ea88', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4073, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:29.325+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-10 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2903f6c7', '3bd94752-0092-4c1e-925b-049db46b62a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4074, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:30.073+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-11 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c0b9166', '884f0d26-8fc8-46a7-9442-36dfa50a3b64', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4076, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '3ffd6c2e-d0c8-4e13-a5fb-2dcf670f0dae', 'XP-11', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.132+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-11 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4c0b9166', '884f0d26-8fc8-46a7-9442-36dfa50a3b64', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4064, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'dbe8d577-b1f7-47d7-929c-73f96bcf6603', 'NFS-18', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:20.502+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-18 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '4f3307df', 'b5963b4e-0052-458c-a0f7-00cd02145085', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4067, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '58402952-bd61-4329-ac2c-3cc86f042883', 'NFS-8', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:22.56+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-8 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '794af3f2', '1cbdf21e-a577-4d2e-8408-4203800ecbf7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4068, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:23.265+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM NFS-9 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5ffcd7e8', 'adc4798e-7285-41ed-92c9-21f2333bcdfc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4069, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c92ad239-ce3f-4700-8381-d11ba98d9ad3', 'test', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-20 11:37:25.313+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM test was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '6924e0dd', 'e52d0ea6-97ea-44f3-b063-f731a6bc98a2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4077, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1b2eef7e-a066-4a8d-adfb-977a2585e8e9', 'NFS-9', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.207+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-9 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5ffcd7e8', 'adc4798e-7285-41ed-92c9-21f2333bcdfc', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4079, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'ff88ac52-d4e1-47e5-b92b-f5f557045543', 'NFS-6', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.454+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-6 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d64f52e', '518d5451-d31f-4353-93fe-cee2dfb5f02b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4096, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:41.737+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-19 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3231420c', 'e8d89843-88e1-4eda-887c-c882648157de', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4103, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.689+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-20 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c8cc71', 'f805865d-b068-4fb2-9d4d-d01c6cd6db40', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4078, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fc8afd5f-6993-4ca2-bf40-50d35f688906', 'VM', '00000000-0000-0000-0000-000000000000', 'Blank', NULL, NULL, '2012-12-20 11:37:31.455+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM VM was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '33ca24dd', 'e84b3bd4-b181-419d-851e-9f93f2ee2d64', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4080, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'c8f99248-655e-4584-853d-b8b8f217b216', 'NFS-7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.463+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM NFS-7 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2c76650d', 'c6f7982f-ad3b-41a4-8411-d465ab2c7d07', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4081, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'e9363a2e-cdbd-499a-b360-d9e72e8c6705', 'XP-1', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.494+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-1 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3bc269e3', '47e1166c-cb63-4f94-a8cb-733240f3ea88', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4082, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6e412b-1194-4a21-8fa7-3d70f3f0e663', 'XP-10', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.577+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-10 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '2903f6c7', '3bd94752-0092-4c1e-925b-049db46b62a7', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4084, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:31.673+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-12 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '52fb1a31', '60aeda3a-c650-4a8d-b825-3da5d3ca7283', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4085, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '24c119f5-bd72-4cbb-b4f6-f688050343d8', 'XP-13', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:32.908+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-13 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7941a6fb', 'b7d5ee32-e103-47a7-b43b-d8b739c1529d', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4086, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:33.763+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-14 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '649f757d', '7e590ac2-c666-40c3-aaa5-b20d5a807ac2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4087, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:34.511+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-15 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '17e34f7f', '8af2c568-c06d-4354-97c9-7ad2c8c5a11b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4088, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:35.367+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-16 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '467e366b', 'e846a8c4-daac-427e-9f2a-967dc1bb274a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4089, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:36.048+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-17 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12153e6e', 'd331f5b8-dc7a-4c1e-bb79-08f63c51b84b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4090, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:37.312+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-18 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '578d78bf', '9210e262-ca13-40bf-8bd3-3076f684747e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4091, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c1b95ee-0c09-4a80-899d-259a5b81bda1', 'XP-19', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:38.404+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-19 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3231420c', 'e8d89843-88e1-4eda-887c-c882648157de', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4092, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:39.247+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-2 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40cadf28', '37f892cf-0444-4f20-b1cc-b4081b87a70b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4093, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f3788f40-986a-41c5-8557-67cbc77e99e1', 'XP-20', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:40.016+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-20 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1c8cc71', 'f805865d-b068-4fb2-9d4d-d01c6cd6db40', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4094, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:40.785+02', 'USER_REMOVE_VM', 36, 0, 'Removal of VM XP-3 was initiated by admin@internal.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71daac3', 'c10f82bf-ffd0-4e48-8934-caeaddd481d5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4095, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '84307420-4b50-4d3f-8eb3-9e17941b6750', 'XP-3', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:41.708+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-3 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '71daac3', 'c10f82bf-ffd0-4e48-8934-caeaddd481d5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4099, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '5759212e-27ca-435a-8906-c6fd6d3b21c7', 'XP-16', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.038+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-16 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '467e366b', 'e846a8c4-daac-427e-9f2a-967dc1bb274a', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4100, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '25890ed5-a32e-413a-9a14-cd07c46598e4', 'XP-15', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.038+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-15 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '17e34f7f', '8af2c568-c06d-4354-97c9-7ad2c8c5a11b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4101, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'a7f83a61-dc95-45c3-b143-c383b3f5da4c', 'XP-14', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.634+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-14 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '649f757d', '7e590ac2-c666-40c3-aaa5-b20d5a807ac2', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4104, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'cd9742c3-3c8a-44b7-9d7d-918814ca0e17', 'XP-17', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.722+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-17 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '12153e6e', 'd331f5b8-dc7a-4c1e-bb79-08f63c51b84b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4113, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '77c991b8-f000-4474-af3c-f2a0644b21b2', 'XP-7', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:53.322+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-7 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '48868eff', 'ea342d38-f9f9-4b9b-94fe-6ca25ce46f99', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4114, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '60c8dc46-8332-40a5-a20d-d80b12b147e3', 'XP-8', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:53.381+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-8 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '1d3e8e0d', 'b4df1194-4476-4987-9678-868b3492b2d5', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4117, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '1c97fe0a-7724-46b7-9a47-a8d95c638fb4', 'XP-6', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:53.508+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-6 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3a69e908', 'd256cef7-73ce-4e84-9864-e25a46aeff47', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4118, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 11:40:13.176+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host camel-vdsb was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3743271', '7bcd96aa-4793-42b9-b2aa-00c0fdefac8b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4126, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 11:40:37.786+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '79a485aa', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4127, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 11:40:37.905+02', 'USER_UPDATE_VDS', 43, 0, 'Host gold-vdsd parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '46725745', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4131, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 11:40:41.528+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4132, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 11:40:42.812+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsd was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '1c0bc9e2', '288bc47f-1759-42e3-83f4-467a09574dbb', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4133, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 11:40:44.547+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4134, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:41:11.247+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4135, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 11:41:30.31+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '7a6f9671', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4097, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'fd36a6ce-34bb-4c0d-b07a-b1bd24bce86b', 'XP-12', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:41.742+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-12 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '52fb1a31', '60aeda3a-c650-4a8d-b825-3da5d3ca7283', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4098, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '2855fcb1-13d8-4da3-a5e3-21efcf78876c', 'XP-18', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:41.793+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-18 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '578d78bf', '9210e262-ca13-40bf-8bd3-3076f684747e', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4105, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '9e6d8236-18eb-434b-8acf-d62d8cf6d3d8', 'XP-2', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:42.752+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-2 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '40cadf28', '37f892cf-0444-4f20-b1cc-b4081b87a70b', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4112, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '36b4b410-fbd2-4dbb-8227-08ef53fbedee', 'XP-9', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:53.263+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-9 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '753444b4', '905b29b5-ddc0-40dd-a13e-8f340e2e1546', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4115, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', 'f466562a-5545-4d2d-ab07-5cbbf70f40bc', 'XP-4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:53.471+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-4 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5de4f1a2', '79c5d04d-72d8-42ed-a092-451b4d615885', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4116, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '92da2698-2df6-410d-8f32-143c87fe3cff', 'XP-5', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', NULL, NULL, '2012-12-20 11:37:53.508+02', 'USER_REMOVE_VM_FINISHED', 113, 0, 'VM XP-5 was successfully removed.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '3fc88bbd', 'b76da831-051f-483a-b942-605922eeb19c', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4119, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:40:16.063+02', 'USER_VDS_MAINTENANCE', 600, 0, 'Host gold-vdsc was switched to Maintenance mode by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '7817b737', '06285cf4-fa1c-448d-82a3-43851ed95f50', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4121, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, 'Unavailable', '2012-12-20 11:40:25.187+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center NFS. Setting status to Non-Responsive.', false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', NULL, '', '00000000-0000-0000-0000-000000000000', '', '49574e0b', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4122, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 11:40:25.649+02', 'USER_UPDATE_VDS', 43, 0, 'Host camel-vdsb parameters were updated by admin@internal.', false, NULL, '', NULL, '', '84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', '5fa5579e', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4123, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 11:40:25.761+02', 'USER_UPDATE_VDS', 43, 0, 'Host camel-vdsb parameters were updated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '5dd4e7e4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4128, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 11:40:39.879+02', 'VDS_ACTIVATE', 16, 0, 'Host camel-vdsb was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '748ef108', '00d42eb9-a160-4f29-b752-b69b22b27490', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4129, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:40:40.718+02', 'VDS_ACTIVATE', 16, 0, 'Host gold-vdsc was activated by admin@internal.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '2fed2198', '37a0a3e3-055a-47dd-b3f4-d524cf334794', NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4130, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:40:41.263+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4137, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 11:51:44.388+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4136, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 11:51:44.4+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4138, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:51:46.452+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4139, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:51:54.392+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center iSCSI. Setting status to Non-Responsive.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '32512f2d', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4140, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 11:51:54.508+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4141, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 13:41:04.115+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4142, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 13:44:13.857+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '156258b4', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4143, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 13:44:18.922+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4144, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 13:44:21.721+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4145, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 13:44:24.971+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4146, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 13:44:26.131+02', 'USER_VDC_LOGIN', 30, 0, 'User admin@internal logged in.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4147, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 13:44:32.687+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center iSCSI. Setting status to Non-Responsive.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '75750677', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4148, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 13:44:32.78+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4149, 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin@internal', '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, NULL, NULL, '2012-12-20 14:44:14.487+02', 'USER_VDC_LOGOUT', 31, 0, 'User admin@internal logged out.', false, NULL, '', NULL, '', '00000000-0000-0000-0000-000000000000', '', '45228776', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4150, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', '2012-12-20 15:10:41.025+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsd. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4151, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 15:10:44.101+02', 'VDS_DETECTED', 13, 0, 'Detected new Host gold-vdsc. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4152, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', '2012-12-20 15:10:47.245+02', 'VDS_DETECTED', 13, 0, 'Detected new Host camel-vdsb. Host state was set to Up.', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4153, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 15:10:54.914+02', 'SYSTEM_CHANGE_STORAGE_POOL_STATUS_PROBLEMATIC', 980, 1, 'Invalid status on Data Center iSCSI. Setting status to Non-Responsive.', false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', '60fbee71', NULL, NULL, NULL, NULL, NULL);
INSERT INTO audit_log (audit_log_id, user_id, user_name, vm_id, vm_name, vm_template_id, vm_template_name, vds_id, vds_name, log_time, log_type_name, log_type, severity, message, processed, storage_pool_id, storage_pool_name, storage_domain_id, storage_domain_name, vds_group_id, vds_group_name, correlation_id, job_id, quota_id, quota_name, gluster_volume_id, gluster_volume_name) VALUES (4154, '00000000-0000-0000-0000-000000000000', NULL, '00000000-0000-0000-0000-000000000000', NULL, NULL, NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', '2012-12-20 15:10:55.053+02', 'IRS_HOSTED_ON_VDS', 204, 0, 'Storage Pool Manager runs on Host gold-vdsc (Address: gold-vdsc.qa.lab.tlv.redhat.com).', false, NULL, '', NULL, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, NULL, NULL, NULL, NULL, NULL);


--
-- Data for Name: base_disks; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO base_disks (disk_id, disk_interface, wipe_after_delete, propagate_errors, disk_alias, disk_description, shareable, boot) VALUES ('a8eb3963-520a-435d-aba4-80a0dd2d9983', 'IDE', false, 'Off', 'XP_iSCSI_Disk1', NULL, false, true);
INSERT INTO base_disks (disk_id, disk_interface, wipe_after_delete, propagate_errors, disk_alias, disk_description, shareable, boot) VALUES ('aab71a1c-42cb-4137-b2ae-1e576458f2eb', 'IDE', false, 'Off', 'NFS-RHEL6_iSCSI_Disk1', NULL, false, true);
INSERT INTO base_disks (disk_id, disk_interface, wipe_after_delete, propagate_errors, disk_alias, disk_description, shareable, boot) VALUES ('4373aceb-55a5-4575-8d42-25457dead6fd', 'VirtIO', false, 'Off', 'test_Disk1', NULL, false, true);
INSERT INTO base_disks (disk_id, disk_interface, wipe_after_delete, propagate_errors, disk_alias, disk_description, shareable, boot) VALUES ('a8402909-c2c8-4716-a24c-e2555ccc46b7', 'IDE', false, 'Off', 'NFS-RHEL6_iSCSI_Disk1', NULL, false, true);
INSERT INTO base_disks (disk_id, disk_interface, wipe_after_delete, propagate_errors, disk_alias, disk_description, shareable, boot) VALUES ('4d42b3cf-7f99-4a09-8d45-7648f54287f4', 'IDE', false, 'Off', 'XP_iSCSI_Disk1', NULL, false, true);


--
-- Data for Name: bookmarks; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: business_entity_snapshot; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO business_entity_snapshot (id, command_id, command_type, entity_id, entity_type, entity_snapshot, snapshot_class, snapshot_type, insertion_order, started_at) VALUES ('11204846-4468-11e2-a9a7-001a4a169741', '781741e4-ed9a-4827-b5da-237166cee0d0', 'org.ovirt.engine.core.bll.storage.RemoveStoragePoolCommand', '2b3dabcf-ed47-4bb6-b9c9-ef580e763728', 'org.ovirt.engine.core.common.businessentities.Network', '{
  "@class" : "org.ovirt.engine.core.common.businessentities.Network",
  "id" : [ "org.ovirt.engine.core.compat.Guid", {
    "uuid" : "2b3dabcf-ed47-4bb6-b9c9-ef580e763728"
  } ],
  "description" : "Management Network",
  "type" : null,
  "addr" : null,
  "subnet" : null,
  "gateway" : null,
  "vlan_id" : null,
  "stp" : false,
  "storage_pool_id" : [ "org.ovirt.engine.core.compat.NGuid", {
    "uuid" : "e1180de1-7b00-4b77-8cf2-102112a3ca38"
  } ],
  "cluster" : null,
  "vmNetwork" : true,
  "mtu" : 0
}', 'org.ovirt.engine.core.common.businessentities.Network', 0, 1, '2012-12-12 16:27:32.903347+02');
INSERT INTO business_entity_snapshot (id, command_id, command_type, entity_id, entity_type, entity_snapshot, snapshot_class, snapshot_type, insertion_order, started_at) VALUES ('1129745c-4468-11e2-a90b-001a4a169741', '781741e4-ed9a-4827-b5da-237166cee0d0', 'org.ovirt.engine.core.bll.storage.RemoveStoragePoolCommand', 'storagePoolId = e1180de1-7b00-4b77-8cf2-102112a3ca38, storageId = 484eb3e8-abfb-467b-9d3d-4aa621873262', 'org.ovirt.engine.core.common.businessentities.storage_pool_iso_map', '{
  "id" : {
    "storageId" : [ "org.ovirt.engine.core.compat.Guid", {
      "uuid" : "484eb3e8-abfb-467b-9d3d-4aa621873262"
    } ],
    "storagePoolId" : [ "org.ovirt.engine.core.compat.NGuid", {
      "uuid" : "e1180de1-7b00-4b77-8cf2-102112a3ca38"
    } ]
  },
  "status" : "InActive",
  "storage_pool_id" : [ "org.ovirt.engine.core.compat.NGuid", {
    "uuid" : "e1180de1-7b00-4b77-8cf2-102112a3ca38"
  } ],
  "storage_id" : [ "org.ovirt.engine.core.compat.Guid", {
    "uuid" : "484eb3e8-abfb-467b-9d3d-4aa621873262"
  } ],
  "owner" : "Unknown"
}', 'org.ovirt.engine.core.common.businessentities.storage_pool_iso_map', 0, 2, '2012-12-12 16:27:32.974385+02');
INSERT INTO business_entity_snapshot (id, command_id, command_type, entity_id, entity_type, entity_snapshot, snapshot_class, snapshot_type, insertion_order, started_at) VALUES ('113d1458-4468-11e2-bf45-001a4a169741', '781741e4-ed9a-4827-b5da-237166cee0d0', 'org.ovirt.engine.core.bll.storage.RemoveStoragePoolCommand', '484eb3e8-abfb-467b-9d3d-4aa621873262', 'org.ovirt.engine.core.common.businessentities.storage_domain_static', '{
  "id" : [ "org.ovirt.engine.core.compat.Guid", {
    "uuid" : "484eb3e8-abfb-467b-9d3d-4aa621873262"
  } ],
  "storage" : "95416488-9e8f-4b3c-8f52-0a69144bcfd9",
  "connection" : null,
  "storageFormat" : "V3",
  "autoRecoverable" : true,
  "storage_pool_name" : null,
  "storage_domain_type" : "Master",
  "storage_type" : "POSIXFS",
  "storage_name" : "ext4",
  "lastTimeUsedAsMaster" : 0
}', 'org.ovirt.engine.core.common.businessentities.storage_domain_static', 0, 3, '2012-12-12 16:27:33.10247+02');


--
-- Data for Name: custom_actions; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: disk_image_dynamic; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO disk_image_dynamic (image_id, read_rate, write_rate, actual_size, read_latency_seconds, write_latency_seconds, flush_latency_seconds) VALUES ('39f89a6a-7fbb-43c0-a5ea-19b271f51829', NULL, NULL, 1476395008, NULL, NULL, NULL);
INSERT INTO disk_image_dynamic (image_id, read_rate, write_rate, actual_size, read_latency_seconds, write_latency_seconds, flush_latency_seconds) VALUES ('81471416-05e6-4003-8acb-77f32b6c026c', NULL, NULL, 2137468928, NULL, NULL, NULL);
INSERT INTO disk_image_dynamic (image_id, read_rate, write_rate, actual_size, read_latency_seconds, write_latency_seconds, flush_latency_seconds) VALUES ('0ac952cd-040a-407f-9fdd-7012358583de', NULL, NULL, 1440526336, NULL, NULL, NULL);
INSERT INTO disk_image_dynamic (image_id, read_rate, write_rate, actual_size, read_latency_seconds, write_latency_seconds, flush_latency_seconds) VALUES ('e886fb6e-f91f-46ae-a488-0f24e47f5731', NULL, NULL, 2147483648, NULL, NULL, NULL);


--
-- Data for Name: disk_lun_map; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: dwh_history_timekeeping; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO dwh_history_timekeeping (var_name, var_value, var_datetime) VALUES ('lastSync', NULL, '2000-01-01 00:00:00+02');
INSERT INTO dwh_history_timekeeping (var_name, var_value, var_datetime) VALUES ('lastFullHostCheck', NULL, '2000-01-01 00:00:00+02');


--
-- Data for Name: event_map; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDC_STOP', 'VDC_START');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('IRS_FAILURE', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('IRS_DISK_SPACE_LOW', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('IRS_DISK_SPACE_LOW_ERROR', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDS_FAILURE', 'VDS_ACTIVATE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('USER_VDS_MAINTENANCE', 'VDS_ACTIVATE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('USER_VDS_MAINTENANCE_MIGRATION_FAILED', 'USER_VDS_MAINTENANCE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDS_ACTIVATE_FAILED', 'VDS_ACTIVATE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDS_RECOVER_FAILED', 'VDS_RECOVER');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDS_SLOW_STORAGE_RESPONSE_TIME', 'VDS_ACTIVATE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDS_APPROVE_FAILED', 'VDS_APPROVE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDS_INSTALL_FAILED', 'VDS_INSTALL');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VM_FAILURE', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VM_MIGRATION_START', 'VM_MIGRATION_DONE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VM_MIGRATION_FAILED', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VM_MIGRATION_FAILED_FROM_TO', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VM_NOT_RESPONDING', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('DWH_STOPPED', 'DWH_STARTED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('DWH_ERROR', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_CREATE', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_CREATE_FAILED', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_START', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_START_FAILED', 'GLUSTER_VOLUME_START');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_STOP', 'GLUSTER_VOLUME_START');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_STOP_FAILED', 'GLUSTER_VOLUME_STOP');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_OPTION_SET', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_OPTION_SET_FAILED', 'GLUSTER_VOLUME_OPTION_SET');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_OPTIONS_RESET', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_OPTIONS_RESET_FAILED', 'GLUSTER_VOLUME_OPTIONS_RESET');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_DELETE', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_DELETE_FAILED', 'GLUSTER_VOLUME_DELETE');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_REBALANCE_START', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_REBALANCE_START_FAILED', 'GLUSTER_VOLUME_REBALANCE_START');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_REMOVE_BRICKS', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_REMOVE_BRICKS_FAILED', 'GLUSTER_VOLUME_REMOVE_BRICKS');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_REPLACE_BRICK_FAILED', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_REPLACE_BRICK_START', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_REPLACE_BRICK_START_FAILED', 'GLUSTER_VOLUME_REPLACE_BRICK_START');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_ADD_BRICK', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_VOLUME_ADD_BRICK_FAILED', 'GLUSTER_VOLUME_ADD_BRICK');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('GLUSTER_HOST_REMOVE_FAILED', 'UNASSIGNED');
INSERT INTO event_map (event_up_name, event_down_name) VALUES ('VDS_TIME_DRIFT_ALERT', '');


--
-- Data for Name: event_notification_hist; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: event_notification_methods; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO event_notification_methods (method_id, method_type) VALUES (0, 'Email     ');


--
-- Data for Name: event_subscriber; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: gluster_volume_access_protocols; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: gluster_volume_bricks; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: gluster_volume_options; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: gluster_volume_transport_types; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: gluster_volumes; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: image_storage_domain_map; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO image_storage_domain_map (image_id, storage_domain_id) VALUES ('39f89a6a-7fbb-43c0-a5ea-19b271f51829', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e');
INSERT INTO image_storage_domain_map (image_id, storage_domain_id) VALUES ('81471416-05e6-4003-8acb-77f32b6c026c', '9d625863-2423-46d3-8439-d19e805a93fe');
INSERT INTO image_storage_domain_map (image_id, storage_domain_id) VALUES ('0ac952cd-040a-407f-9fdd-7012358583de', '9d625863-2423-46d3-8439-d19e805a93fe');
INSERT INTO image_storage_domain_map (image_id, storage_domain_id) VALUES ('e886fb6e-f91f-46ae-a488-0f24e47f5731', 'a738573e-35dd-41ee-bd5a-c83e6f5a0f7e');
INSERT INTO image_storage_domain_map (image_id, storage_domain_id) VALUES ('e886fb6e-f91f-46ae-a488-0f24e47f5731', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25');
INSERT INTO image_storage_domain_map (image_id, storage_domain_id) VALUES ('39f89a6a-7fbb-43c0-a5ea-19b271f51829', 'f1ec1456-736f-4fa6-8b8e-639ed994bd25');


--
-- Data for Name: images; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO images (image_guid, creation_date, size, it_guid, parentid, imagestatus, lastmodified, vm_snapshot_id, volume_type, volume_format, image_group_id, _create_date, _update_date, quota_id, active) VALUES ('00000000-0000-0000-0000-000000000000', '2008-04-01 00:00:00+03', 85899345920, '00000000-0000-0000-0000-000000000000', NULL, 0, NULL, NULL, 2, 4, NULL, '2012-12-12 12:40:38.131091+02', NULL, NULL, true);
INSERT INTO images (image_guid, creation_date, size, it_guid, parentid, imagestatus, lastmodified, vm_snapshot_id, volume_type, volume_format, image_group_id, _create_date, _update_date, quota_id, active) VALUES ('e886fb6e-f91f-46ae-a488-0f24e47f5731', '2012-12-12 18:03:22+02', 16106127360, '00000000-0000-0000-0000-000000000000', '00000000-0000-0000-0000-000000000000', 1, '2012-12-12 18:03:22+02', 'df1e0727-64ac-4cae-a35f-7f31058bbd69', 2, 4, 'aab71a1c-42cb-4137-b2ae-1e576458f2eb', '2012-12-12 17:59:40.350748+02', '2012-12-12 18:17:09.477006+02', '00000000-0000-0000-0000-000000000000', true);
INSERT INTO images (image_guid, creation_date, size, it_guid, parentid, imagestatus, lastmodified, vm_snapshot_id, volume_type, volume_format, image_group_id, _create_date, _update_date, quota_id, active) VALUES ('39f89a6a-7fbb-43c0-a5ea-19b271f51829', '2012-12-12 16:30:13+02', 16106127360, '00000000-0000-0000-0000-000000000000', '00000000-0000-0000-0000-000000000000', 1, '2012-12-12 16:30:14+02', '12e33af5-1101-4b85-820d-0de3b905147a', 2, 4, 'a8eb3963-520a-435d-aba4-80a0dd2d9983', '2012-12-12 16:26:31.579997+02', '2012-12-12 18:17:31.262326+02', '00000000-0000-0000-0000-000000000000', true);
INSERT INTO images (image_guid, creation_date, size, it_guid, parentid, imagestatus, lastmodified, vm_snapshot_id, volume_type, volume_format, image_group_id, _create_date, _update_date, quota_id, active) VALUES ('81471416-05e6-4003-8acb-77f32b6c026c', '2012-12-16 10:35:03+02', 16106127360, '00000000-0000-0000-0000-000000000000', '00000000-0000-0000-0000-000000000000', 1, '2012-12-16 10:35:03+02', 'df1e0727-64ac-4cae-a35f-7f31058bbd69', 2, 4, 'a8402909-c2c8-4716-a24c-e2555ccc46b7', '2012-12-16 10:35:01.81998+02', '2012-12-16 10:37:36.236223+02', '00000000-0000-0000-0000-000000000000', true);
INSERT INTO images (image_guid, creation_date, size, it_guid, parentid, imagestatus, lastmodified, vm_snapshot_id, volume_type, volume_format, image_group_id, _create_date, _update_date, quota_id, active) VALUES ('0ac952cd-040a-407f-9fdd-7012358583de', '2012-12-16 10:35:04+02', 16106127360, '00000000-0000-0000-0000-000000000000', '00000000-0000-0000-0000-000000000000', 1, '2012-12-16 10:35:05+02', '12e33af5-1101-4b85-820d-0de3b905147a', 2, 4, '4d42b3cf-7f99-4a09-8d45-7648f54287f4', '2012-12-16 10:35:03.465624+02', '2012-12-16 10:40:40.140904+02', '00000000-0000-0000-0000-000000000000', true);


--
-- Data for Name: job; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: job_subject_entity; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: lun_storage_server_connection_map; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO lun_storage_server_connection_map (lun_id, storage_server_connection) VALUES ('1Dafna-si25-011355317', '71d07b63-7977-488d-a857-b2046130bac1');
INSERT INTO lun_storage_server_connection_map (lun_id, storage_server_connection) VALUES ('1Dafna-si25-021355317', 'c1e2f9cb-48bf-48f2-a7e4-1fe271da552e');
INSERT INTO lun_storage_server_connection_map (lun_id, storage_server_connection) VALUES ('1Dafna-si25-031355317', '3fbf0347-f1f6-4685-8415-c32b776b64a1');


--
-- Data for Name: luns; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO luns (physical_volume_id, lun_id, volume_group_id, serial, lun_mapping, vendor_id, product_id, device_size) VALUES ('7PrE7S-xk2t-5isG-2xrr-vglV-bwpq-pYLkyu', '1Dafna-si25-011355317', 'QnvQg0-98i8-cYRC-z8XM-PCPb-Z89Y-9TTPpH', 'SIET_VIRTUAL-DISK', 1, 'IET', 'VIRTUAL-DISK', 100);
INSERT INTO luns (physical_volume_id, lun_id, volume_group_id, serial, lun_mapping, vendor_id, product_id, device_size) VALUES ('C8qzHi-fyIN-r1sx-NRfF-LUG8-omqa-hVacQU', '1Dafna-si25-021355317', 'i7hrKn-gbvs-fnKu-gz1g-fkJN-sEB0-1xL39S', 'SIET_VIRTUAL-DISK', 1, 'IET', 'VIRTUAL-DISK', 100);
INSERT INTO luns (physical_volume_id, lun_id, volume_group_id, serial, lun_mapping, vendor_id, product_id, device_size) VALUES ('HT5id5-rbta-IuXv-CBVA-RDH1-RUhJ-mKiHfv', '1Dafna-si25-031355317', 'QCyMvG-iyZQ-qwHu-HiAr-9wDS-HpaF-5sO3XO', 'SIET_VIRTUAL-DISK', 1, 'IET', 'VIRTUAL-DISK', 100);


--
-- Data for Name: network; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO network (id, name, description, type, addr, subnet, gateway, vlan_id, stp, storage_pool_id, mtu, vm_network) VALUES ('00000000-0000-0000-0000-000000000009', 'rhevm', 'Management Network', NULL, NULL, NULL, NULL, NULL, false, '4d801098-4448-11e2-9eb6-001a4a169741', NULL, true);
INSERT INTO network (id, name, description, type, addr, subnet, gateway, vlan_id, stp, storage_pool_id, mtu, vm_network) VALUES ('e90d14c0-e1e9-4614-98ea-a1e9d476671d', 'rhevm', 'Management Network', NULL, NULL, NULL, NULL, NULL, false, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 0, true);
INSERT INTO network (id, name, description, type, addr, subnet, gateway, vlan_id, stp, storage_pool_id, mtu, vm_network) VALUES ('02b8130e-bb10-44f9-8a0a-8ca0c6c721c9', 'rhevm', 'Management Network', NULL, NULL, NULL, NULL, NULL, false, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 0, true);


--
-- Data for Name: network_cluster; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO network_cluster (network_id, cluster_id, status, is_display, required) VALUES ('00000000-0000-0000-0000-000000000009', '99408929-82cf-4dc7-a532-9d998063fa95', 1, false, true);
INSERT INTO network_cluster (network_id, cluster_id, status, is_display, required) VALUES ('02b8130e-bb10-44f9-8a0a-8ca0c6c721c9', '84caf0c2-4759-11e2-a95e-001a4a169741', 1, false, true);
INSERT INTO network_cluster (network_id, cluster_id, status, is_display, required) VALUES ('e90d14c0-e1e9-4614-98ea-a1e9d476671d', '3e4ad610-4463-11e2-b9d2-001a4a169741', 1, false, true);


--
-- Data for Name: object_column_white_list; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_group_id');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_group_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_group_description');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'selection_algorithm');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_id');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'ip');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_unique_id');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'host_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'port');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_strength');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'server_ssl_enabled');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_type');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pm_type');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pm_user');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pm_password');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pm_port');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pm_options');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pm_enabled');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_spm_priority');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'hooks');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'status');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_cores');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_model');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_speed_mh');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'if_total_speed');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'kvm_enabled');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'physical_mem_mb');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pending_vcpus_count');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'pending_vmem_size');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'mem_commited');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vm_active');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vm_count');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vm_migrating');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vms_cores_count');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_over_commit_time_stamp');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'hypervisor_type');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'net_config_dirty');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'high_utilization');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'low_utilization');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'max_vds_memory_over_commit');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_over_commit_duration_minutes');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'storage_pool_id');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'storage_pool_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'reserved_mem');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'guest_overhead');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'software_version');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'version_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'build_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'previous_status');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_idle');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_load');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_sys');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_user');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'usage_mem_percent');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'usage_cpu_percent');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'usage_network_percent');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'mem_available');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'mem_shared');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'swap_free');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'swap_total');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'ksm_cpu_percent');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'ksm_pages');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'ksm_state');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_flags');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_group_cpu_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'cpu_sockets');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_spm_id');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'otp_validity');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'spm_status');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'supported_cluster_levels');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'supported_engines');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'vds_group_compatibility_version');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'host_os');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'kvm_version');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'spice_version');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'kernel_version');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'iscsi_initiator_name');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'transparent_hugepages_state');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'anonymous_hugepages');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'non_operational_reason');
INSERT INTO object_column_white_list (object_name, column_name) VALUES ('vds', 'recoverable');


--
-- Data for Name: object_column_white_list_sql; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: permissions; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('57807718-4448-11e2-a727-001a4a169741', 'def00009-0000-0000-0000-def000000009', 'eee00000-0000-0000-0000-123456789eee', '00000000-0000-0000-0000-000000000000', 4);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('59e0b3b0-4448-11e2-a2d4-001a4a169741', '00000000-0000-0000-0000-000000000001', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'aaa00000-0000-0000-0000-123456789aaa', 1);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8ce3257f-d6e3-47a0-8849-1ef79625f601', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '88a12e6e-37ad-4ddd-8100-5d2beb1fb473', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('67d5cf99-982c-4802-a6d0-b509e9d29bcb', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'd7d9fe83-967c-415a-9c4d-0fa99a8d5c79', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('408998bc-136f-43f1-93c5-b87c0d060b0d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'a33ed93e-59c0-4861-87c2-9c66066f5bd1', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('4a0cf4b1-968a-472f-8ba3-8a01d5546cd6', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'b18246a2-ad55-45cb-91db-8942db79e1e1', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('2e3788d6-ba1c-49b9-b947-f4b480d857fb', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e4c3f997-2154-463c-940a-0781e7c231c5', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('dcb5517b-c9dd-4add-b6c1-3b38c2173df5', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0fe2cc88-2457-4b56-b73b-75c04961792f', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('daf21da4-67c3-4af0-8920-2fe618558acc', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'a4b27b65-f139-4e0f-9e0c-759366982764', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('061abdfd-eb7d-41d1-a4f3-f3732f22af4c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0e9c5e7e-93bc-4867-b386-c58ef1f47bf7', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c3f1536b-01c1-4cee-8236-657b93454687', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '3308cd01-e41e-499b-9315-e812fe2e9094', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('6191c086-55e2-4018-9ed6-b019e38d68a9', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '45174fdb-1164-4c9c-a12c-8605b6801f86', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('90e8092b-686b-4a61-a117-047cb1ca6049', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '26c7095b-c716-40bc-8d6f-c0c04b39650d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('b72937e8-219a-40ef-ad28-b175536ce4cd', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '2392ab0f-864d-4ef5-8495-24b9b0771f6c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('eb3a8c1e-b006-4790-83fa-b2941cff610a', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c5924f97-cdbd-4cd0-968d-38f01e688939', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('52ee1950-da01-43b1-ac7d-a337c8f6485c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'b9fb1310-7053-4606-8d8e-0c3c3563d09b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('22801090-5603-4e87-ab94-97b0b4d177d1', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0f7a0f00-5f64-4640-94b2-e5f2786e9ab9', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('adbb9b61-7321-4972-97ec-39b77fc11e0c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '7bd8f82e-ec16-4c32-b37d-06de1feefec1', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c047d610-e159-4fa6-8541-fc57d7c81703', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '069b5a0c-7eb6-40b0-8f18-0a67cc71979b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('482ddb7e-2bcb-408c-8f0e-eb789827a62b', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '198d3f18-88fb-4d9a-83a5-081b446d2bd1', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e8b857d1-6a93-4c7f-9cd6-4788c8cdc22f', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e90a1ad1-5559-4847-b2e9-d63da1228670', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('50e28c8e-0d77-4dd4-9ad2-de691fbd642e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '5fb3ee14-b79e-49b7-935e-202ec8678a94', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('89c3716b-e220-471f-92c3-6862d63a865c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '7947834e-71f5-427d-b6c8-2ae5fe320eee', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('5bc27cff-1468-4285-86e6-f2277c5862da', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '791e603e-20c4-48d7-8f12-1d036514e928', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('027e1720-ff64-49ec-9d58-062e40719e4d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'aab74f09-c5b8-420e-a100-beea2529eead', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e0480998-8523-4516-909d-c7d7d7c3802e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'd6358836-70d4-4c3c-b78f-cde29a9cf7e5', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('86f59ad4-5763-4523-a1f7-dbb7de1b90b0', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '5bd4f9b7-48c1-4a93-bd02-511358d5c869', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('1e40ad20-7eae-4be4-aebd-19c2dd158d63', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'ef1acc83-087d-4005-a28b-58607de33c0e', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8db80bdd-03be-4e9b-a2cd-eaf19150e8ff', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '45f6db38-de4b-434b-bc51-6499820f91b7', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('87a44fd4-f7e7-4e55-9469-800d9b724d8d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '32d25362-2a82-4763-98c6-692de2639551', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('93f31d53-ac03-4a85-9588-232f94ff1a6f', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'dfa392ff-10be-4273-960b-ba22194591b8', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('2ab4dba5-21e3-4fa3-991d-6f186baad4ab', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '14ab50fb-106a-4d9f-8177-d71c77f6cff6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('d02b388f-0b8b-4024-86c1-4841cae8dbde', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c5ed2388-3a07-42ee-a110-2d3006a06fdb', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('3d3cdee5-53e5-4c12-8e8d-63a698dfd6b7', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '4ad2c59f-8efc-4081-b11c-f413e3b2fa28', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ae12cebc-d20a-4978-ae45-c33227bb960a', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '6bee3459-0067-4999-b13d-cf4b9262bc9d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('43cf4456-1fc1-406a-a5ae-bdc5712af9f3', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '556f7b84-2069-46f2-b948-bd42856dade3', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e58b6531-c335-44ad-a5be-329b867b4d09', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'ec635ef5-c4fe-44ac-acde-5ea4464ca038', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('f043ae05-81d7-49ec-a0c7-130d71542ab3', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'fd513cfd-364f-4679-bbee-17802b276dbe', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('845795d1-8b19-40ec-8265-f626eef97897', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '92a9d7e9-0301-49c4-bf98-04b9f37ef5ec', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('6b12b966-b78b-4483-abe1-5a66cb299652', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'ab279f0b-5bd9-42ce-8e08-610ea3512d3b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c67e3b12-cdf3-461a-819c-4a0ec11fca5c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '1b4948e8-837c-4114-a7ee-a0f1e174db0d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('414b1a58-6692-49d7-bfaa-fd15973bea4c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '2aedadf8-d3e4-4d65-8e0c-35717b3cb3e6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('5e388877-83fe-4ad1-ae31-ec9969a23962', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '9946d292-408e-4e61-986c-022132774d5b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('d5eff214-5705-4056-92b5-60641c487abf', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '7b926375-c172-4cbd-ad3f-ab36da2d5209', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('756a25cf-8510-44e2-9c01-ae3364b11fc5', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'b13d4fff-70b7-4944-99fe-1aacec657843', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('fafb5cfa-42b1-4177-880d-112480166f48', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'ff1e7b47-82ca-492b-902c-cb4fab68d907', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ec309111-fd63-40f8-ab23-5a2f8723fdbc', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0c2dedd4-599e-4a3e-880d-84fb939e52a3', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8d287789-d5a0-4267-a629-5d338f6fa8f9', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '57c69efb-9c3c-40c3-a00b-1b3903889d9d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('f2f98a71-b24e-4093-ba1b-a183acd239f6', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'ad4560ee-f7b0-42b9-bfe3-eca198e0896c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('15168c8d-6de3-401c-9122-b057c6d40a1b', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '7d14b8df-1e48-4aef-8372-c9fb18414fa2', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('f25f0f67-1d80-4f69-a745-fca79f2626a9', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '302cba38-5973-41e9-803c-3c2ebf86173c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('48c021b2-d619-498f-8524-fb38e6658582', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '4abc9820-29d3-460d-a4e9-2d23f1a1470e', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e010dce2-480c-4ca9-a565-a67c5255ae12', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '23c76677-508a-40f5-bf07-ea333a582842', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c2e6054f-dc7b-4489-b969-90eb5f653231', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '14e0de7e-0737-438f-9964-6b47147d780b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('49f6f4ec-5035-48e1-854a-3aec043b2c12', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '5df5ced5-12cb-4450-819c-ad31541b4d3d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('325fcb67-6be9-42f8-a655-d18ff17d6dae', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '261f1b30-3f11-4b62-8f42-7942a739fb8d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c757aff2-fb73-4516-b4c4-cb29a281fd70', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '75fa37c4-1eb0-43d0-b032-1a91645554c0', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('7fc212e7-adad-4101-8776-4d1e59e84f4c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '5bf6b01f-cb13-414d-b3e0-eb8d03105332', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e4f8ad39-b0cb-4c99-99fa-011410a05a4f', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '2838de6c-52ba-4f6b-bc91-0f7fd816b79e', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('3cbbe88a-4778-425f-9b21-fff0818974a3', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'cfc43a7b-ad98-486c-b51f-731ce46519c6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('60f7c1af-b611-433d-beb9-1cfc34c3e00e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '6800c37f-5c10-42b5-bfcb-fc49bf0b3248', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('3523c1ca-0469-4263-87d3-5e8b9415986a', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '5e4e0c7f-ef93-46b2-910b-d220f55314a6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('9110a1d2-eb7e-4a6a-8973-d74ed6f98c54', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'f1e9d548-1611-45c4-88f3-72255d335a4b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('78251b0d-0b98-4329-89f4-af5c769e0d85', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '56cb947b-37e4-4a05-adf9-312839e8ef4c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('676d26b5-87a1-4e8d-a5d4-60cd786901b4', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '21a0fc2d-af5e-4861-87ff-d8230a9b8927', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('49a2af44-780a-447a-8236-ae2dad69ac5d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c69d35b5-185b-43b1-b8ef-581c30de1dc3', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c8d298a5-9204-4acf-a789-e8f227a03e7d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'd406d448-719a-4029-875d-0d25cadea48c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('08df3b7a-7827-4e42-9d7c-5fb07ba0ee4c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '7635286c-db17-4cf7-9182-610ca694756d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('eede1e9d-8329-44e1-80c6-cdf71f73ae53', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '00d5c42c-699b-4fa9-84b9-ed2107842bfb', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('52c3d81c-9b62-4e28-928b-d9e5f36ce9da', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '9a7eb640-3365-40a8-9216-6e73ec3e5d03', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('30807981-5347-456e-b913-822aae2a47c2', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'a5d8ab9c-4491-4f0c-81ee-b8d1ab1429a6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('be9addd8-9aee-4853-b970-4ec0ebc11f04', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '76472c25-51de-4ad0-884a-f6d78bd41fdc', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('df2f6413-3897-4059-8eeb-7af5c2cc68e0', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '018ec071-0316-44ec-a523-8ec2c15ebe38', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('a8d2d253-76fb-4ed0-8d84-94c94d565e6c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c1d155f1-cb79-42a4-af17-13008d32b097', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8b78694b-db98-444b-8419-1c059ff0dff0', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'b42e6ad3-7797-4992-81cc-8bf1b2c9a26f', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('53369d30-e4a0-4386-9330-449b844af4d9', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'db5c669f-61e7-4258-834d-06fcd4e78782', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('09dacb35-64ca-4266-9ce2-f6eaea1c4956', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '173815f8-67a1-427c-bb7c-126bfd095090', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ff7b57cf-6138-48d5-aa7e-79e26b142454', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'b79518a8-b6e8-4bcc-9917-54b6c3ead38c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('0a72c9c4-ebcb-47be-b5ae-e5e16671d950', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e7bcdecd-0555-4bb1-bfe0-2a3c14ecf960', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('0fbc6b5c-65c3-460c-977b-babdc792e0bf', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '1910482e-8a65-4954-8a49-47e7b42c61b5', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('59567bd8-a1cd-4da3-a89a-7a5371599188', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '3a4ca506-7363-45fc-a8fe-4842913649dd', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ec79f0a6-8255-495a-9c47-fe037f17b250', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '37860926-8943-45e0-9cbe-1c3d881086c8', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('18f67286-d61d-47d9-8bc0-a35ef7b00eeb', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '88dab8e0-4c36-4f52-bc01-6b19af2d6245', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ac72903f-19c8-4d92-8b48-07e1af57ff68', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c6308118-e3b7-480d-a25d-387727af0232', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ed4c1aa9-df4d-4684-afc0-8eab13ab50fb', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'cbf40da2-87e4-47d6-8791-dc587c977ae1', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('383d85b5-2305-4df3-9815-721beca2ffe5', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '9c0013a3-02d5-46c0-a04c-0264598f6db0', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('340763d3-f194-4213-86d4-b14935c5b9e6', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '31cda908-5ddd-4d77-b326-db35ea8e917a', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8a82bc39-297d-4934-959f-2989e4a40156', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '240dbddd-3b3d-43d9-a0d2-b5327c9f7b4b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('2de2611f-222a-4757-89eb-4006d2419e47', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '32a6fef5-f2ff-4889-a108-ce2f4a35099b', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('103cc9db-d1f9-48ca-9f53-39798778280d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e37343aa-d41b-4d41-9044-7f9d11a9b6ae', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ec286aa3-5d87-4803-8d9a-e8037f088c0d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'fbf48ce3-7af7-490b-9f4a-ddd839501832', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e6c66310-a75f-4bf3-b125-70521765c25d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '4cb07ab6-a50f-4f06-92ae-7e1d01087410', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('64513a3e-ac27-4055-976a-af2528d33bf9', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '28935de0-37e5-4d08-8f41-05ff4c933b69', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('54635f15-a3ff-4257-97d4-5ce58643c04f', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '644fb2fa-9246-4d62-8a93-30e89463c25d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('3a4fd59d-844c-4dc7-805c-40ab64914ab6', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0c08577b-a3ed-427d-a8cd-fbd7765a423e', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c2a42d10-f082-44f3-af27-baacc4d17e2e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'fc5b4871-828e-428a-b271-95fd37f67214', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('2f6b5802-a8d0-43a3-9211-25b9fbef2f9e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'fca95d0d-ac95-40c8-8334-ae34c242e2e7', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('89e9e91a-11bd-446b-b8a0-6466849c52b8', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '30cca0e4-153b-4d1b-9542-9403f9095d99', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e669ec0e-9161-45e3-bdc3-7391b4499afb', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e5ce2434-79a1-4a7f-bd10-14100baf22bc', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('31e1fe95-6c47-44b9-a076-eaff17b38e73', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '8b9c9dbc-9687-46d7-b556-f2ee56f38642', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('26c0985d-b8c3-4556-92bf-c8ff195bf523', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e7a13c4c-4932-40d9-ab88-37c0f826f70e', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('f72533af-518f-4e3c-b3f0-e369859b01c1', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '49f56667-0cc7-4dcd-b950-8da82daf8641', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('92c1182e-80ea-4690-8c05-c62996621fbd', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c2ca4f84-4176-424a-8f2b-fbd94906bb39', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c56f4ec6-9dc7-4c95-b4ec-d29ee4adb6d8', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '4471aa6a-f3bc-41a5-9cd8-e43931b41981', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('757ddb6a-c5e9-47cc-a930-9d6c553913e8', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '9487cd8e-1815-44e7-b593-65bf8c25489a', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('5563f3cf-eace-48f9-af0c-ea34b05d122f', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '2b45d9e1-8199-4b62-8cc5-3c337a21b358', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('1db9ee37-d0e6-41ae-a574-7abc30ec4295', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'f4617618-5188-4d7a-999c-d6296693f2b7', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8d7139b9-6591-481f-8ee0-34355f0ecdc0', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0cff6f10-81a3-47f1-8d05-2be711b87d68', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('fe3ab85b-c823-4537-bc66-7eb9370c5abe', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'a16a695f-cd82-4c60-ad5c-4070ca75c9bc', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('3e634b54-c81a-4a35-bdf0-1cad438594c5', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '222c944c-7a3d-4d06-ac79-02378c3814c6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('31896aef-6592-4a1b-8ac9-9d977e28eab8', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'a49295e8-332b-4660-a291-3e41a435eec1', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('95b251fb-f8ee-4137-8791-200c903a2565', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e289aedf-579e-4a91-804c-ad0a450f6a38', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('5fa51f64-4423-400f-b671-63f7faa67d64', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '5823a9b6-da79-46f0-ba92-a2c5bb6ab2de', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('7accc557-41db-46ad-93a9-8433583a9300', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c48ed978-54a4-4c7b-9587-a724960e52a5', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('fc1046a9-bea9-4911-ba2a-25108d328cdb', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '32f40469-1251-46f8-b46b-9aa8f40406d4', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('2f54306c-f31f-4ab6-a0ff-9f55f497a908', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '70ae5c23-4b70-498c-a8f0-17e2720ed519', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('fbf024fe-7c75-44c1-bbce-9d1c68262e18', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '39812cfb-177a-45ad-ac39-bda5611531a6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('57f28004-0197-4ee6-8935-daa731ce0b1e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'cc23b212-977d-4266-a9e5-46f28fe8cad6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('5102ba7a-b64d-427c-a583-acc3785e08b2', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'ed86b11e-d69e-4885-b601-078ddbcd61f7', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('086c4d58-d2c6-4d57-91e5-9ecee57a3ef9', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '2ba7dd8e-a70c-4428-9c42-c95be5373500', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ce93b1c5-7e29-4dc3-b975-8f7c6b205a09', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'b03bca31-5813-40e2-8748-9bdc12e3d7fd', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8740d25c-aa7e-49b8-aab7-75e0b7874ba0', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'bdd52730-ab15-4c2d-a25f-07aab232f04e', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('c132db57-994c-4bc9-8203-d3dcad3d92f9', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0d6784b8-1551-4b31-b044-190aae5d8c64', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ea887da5-a41e-4443-8079-d1211abf516d', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '3fc441bd-607b-4ff1-9d19-ed025b56c925', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8a08e0a9-dc4a-4043-bd37-b89eee33a05c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '3d27bf7a-8a53-4513-a982-b3a30fea6629', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('f6e26a38-e3f2-4e58-b0c2-09dc0dab97e1', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '8c5cf4ae-dac7-4e30-88fe-561899a076ac', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('dcf0a229-b24d-4b1a-8fac-b21a6be4a10e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '75246dee-6695-4ad6-9220-05fe19357917', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('4666ab75-42d0-4311-9b8c-f2dc0393e3c2', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '134bc55e-7685-4ef0-9401-eb063dac7193', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('fdc61025-bb81-4e25-abcd-2942c07a41da', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'd35afcab-7753-4dba-9314-e0545f75d2d2', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('defdc65f-2a94-4e3d-91fa-6360491f381e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '8af0a122-94d3-4d84-8ec8-482cba776f43', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('ec1c567d-d835-4ed0-8537-603f075f0ff1', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '5a7c5206-0cb9-4116-a41e-44cc2048abd8', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('869d0c01-fb9c-4e60-84ee-ac2fb6012e27', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'b050ac7e-b60e-47ff-a137-0bb55a283462', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('283487c9-b812-440e-afab-2685e923ac17', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '047aa96b-db72-41b2-a7a7-547fcb71b1e9', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('911027ae-2d4a-4ebe-9b16-415468d99310', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '0e7dc678-922b-4908-869e-ef5b38e3a355', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('72b2bf5c-17d2-4fc1-996f-c85d9490bb56', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '6994afdc-ae3b-4f24-bcd2-e1aa68371b42', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('d3ca1e5a-6909-493f-97d2-7cd3f71a7405', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '8fc3c1f3-2c45-4450-b708-6f907ea518ae', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('379dabaf-a5d9-4555-b770-bc746c472184', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '3779bd01-ef16-4edb-b89c-fb6654d5bdf9', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('8124091a-61b1-4d22-ae39-7b7416f9c29e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '9459adc0-497e-4ba7-976e-85a45e3c4d24', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('817dc59f-b824-44b4-8617-81b21079513c', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'afd4e03a-57d6-45bc-a268-acbd2b19447a', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('790397cf-b504-4fab-ac47-610c97001067', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'baed2d93-3781-4d2c-85a6-e338d696829d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('25cd4887-5419-486e-91d9-a8abb221489e', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '8d9bb35f-25bc-4655-86c4-958b67c71340', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('602b55e1-6982-40c1-b184-ebed20e393f2', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'f9a12498-6924-4fbc-abc6-3ce3a3c4c416', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('983e20fe-e3f6-4896-99f8-6f7a842a60fd', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '92f6bbc4-86c7-4982-a8d8-7e2ba0fffce6', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('23d1e195-8e31-418f-bcba-e2583a347e64', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '3ab91d1b-26d2-4a61-880f-30380a69b8cb', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('da630e26-d1b3-4fa3-9744-4f0b5a717be3', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'dfaed92e-42d7-4b4d-a8bf-61e7a5a66720', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('746cf962-1016-4039-8d92-77e12faa35f7', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '7ce936f7-b4ff-44aa-a51f-37f10e68da24', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('d2597b05-14b6-4403-8424-2f63a32a0a3a', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '7f97e2c1-ccd9-4916-99e2-827508a17bd5', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('54b730fe-7e35-4851-ac9d-74ffa12a1761', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '37d71127-a322-49cc-8ac6-b529a7648ad7', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('14379af6-cebb-45bc-a9c1-e01efd9d6631', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'e8366711-6fc5-4705-8196-498fa98c1f9f', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('639135f0-f513-4370-ab5f-c1fba49295ca', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '319e002a-3e71-4c8d-9bba-9062c0ab8d3d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('d862db84-83f3-4814-9fc9-d08652b673eb', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '8a58956b-8bb3-4ea3-b57d-73434aa8cc1c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('03907f55-2fff-4eda-81dd-cc6edadc0715', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '432c29ab-7aa5-45dd-bdc8-5d8f9547bf9e', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('87d10a94-bd16-4ddf-8f82-fb11b1fbbc19', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '09d5c469-b3d8-448c-a656-00a60fcd3d44', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('2b5ec39c-34df-4f09-b4c1-78d466de006b', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '26b03e8d-56bc-4efd-9863-5164a850e1f5', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('b4cf40bc-bb2a-413c-b2e4-8c136e4288ff', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'c3a50041-be1a-4aac-bf5c-47d33a2b57f1', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('1dd111d0-8497-431f-9e3d-e4d8c211910a', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '8d0fb5b8-8b8c-4632-8c62-32c981100a6c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('637396db-5aa1-429d-8323-73187465a311', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '30f649e5-ee81-4f6b-a887-ceba004e9dd3', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('a1b58153-861e-41e0-86e6-d4aba4dd1035', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '4559b2fd-c3da-424d-88ea-57666d62f828', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('920ebd6c-90db-4fa2-ab94-0ce1359f73e4', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'a26826b7-bf50-423c-af14-831a2e23747d', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('b815fe02-8872-491a-8314-633cc67f5f95', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'fe40613c-464b-472f-8431-7882f85ddc13', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('edf7e937-b697-4461-a27e-6ad8e32249f6', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '032f2820-47e3-4e3c-b76c-67f52fc90e1c', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('0fd23699-3d5f-4f57-a0b4-574fd7783c36', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'd562ce17-5d4a-484e-8aa3-8fa7b0fb545f', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('a57cd189-925a-4d88-a11e-94836732a831', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '4d6d1920-688e-4444-a501-a5be20012196', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('e8f07932-a8af-4aa0-be95-973b727a48c1', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '605ffdab-b87f-441e-a957-5b042585f329', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('b90f031e-8be1-4e5c-8e81-1222a6bcfe29', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', 'acb99e88-db92-4eb0-b5be-13533d831dc8', 19);
INSERT INTO permissions (id, role_id, ad_element_id, object_id, object_type_id) VALUES ('7c4bd1f1-aa7b-49bd-9428-b96d07f42450', 'def0000a-0000-0000-0000-def00000000b', 'fdfc627c-d875-11e0-90f0-83df133b58cc', '28032f26-c7cc-4a42-a416-eb456a4c3ba8', 19);


--
-- Data for Name: quota; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: quota_limitation; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: repo_file_meta_data; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: roles; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('00000000-0000-0000-0001-000000000001', 'UserRole', 'Standard User Role', true, 2, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00006-0000-0000-0000-def000000006', 'UserVmManager', 'User Role, with permission for any operation on Vms', true, 2, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00008-0000-0000-0000-def000000008', 'TemplateAdmin', 'Administrator Role, permission for all operations on a specific Template', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00009-0000-0000-0000-def000000009', 'UserTemplateBasedVm', 'User Role, with permissions only to use Templates', true, 2, false);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('00000000-0000-0000-0000-000000000001', 'SuperUser', 'System Administrators with permission for all operations', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00001-0000-0000-0000-def000000001', 'ClusterAdmin', 'Administrator Role, permission for all the objects underneath a specific Cluster', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00002-0000-0000-0000-def000000002', 'DataCenterAdmin', 'Administrator Role, permission for all the objects underneath a specific Data Center, except Storage', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00003-0000-0000-0000-def000000003', 'StorageAdmin', 'Administrator Role, permission for all operations on a specific Storage Domain', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00004-0000-0000-0000-def000000004', 'HostAdmin', 'Administrator Role, permission for all operations on a specific Host', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00005-0000-0000-0000-def000000005', 'NetworkAdmin', 'Administrator Role, permission for all operations on a specific Logical Network', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def00007-0000-0000-0000-def000000007', 'VmPoolAdmin', 'Administrator Role, permission for all operations on a specific VM Pool', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def0000a-0000-0000-0000-def00000000a', 'QuotaConsumer', 'User Role, permissions to consume the Quota resources', true, 2, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def0000a-0000-0000-0000-def00000000b', 'DiskOperator', 'User Role, permissions for all operations on a specific disk', true, 2, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def0000a-0000-0000-0000-def00000000c', 'DiskCreator', 'User Role, permission to create Disks', true, 2, false);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def0000a-0000-0000-0000-def00000000d', 'VmCreator', 'User Role, permission to create VMs', true, 2, false);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def0000a-0000-0000-0000-def00000000e', 'TemplateCreator', 'User Role, permission to create Templates', true, 2, false);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def0000a-0000-0000-0000-def00000000f', 'TemplateOwner', 'User Role, permissions for all operations on Templates', true, 2, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('def0000b-0000-0000-0000-def00000000b', 'GlusterAdmin', 'Administrator Role, permissions for operations on Gluster objects', true, 1, true);
INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children) VALUES ('00000000-0000-0000-0001-000000000002', 'PowerUserRole', 'User Role, allowed to create VMs, Templates and Disks', true, 2, false);


--
-- Data for Name: roles_groups; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 2);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 3);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 4);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 5);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 6);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 7);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 8);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 9);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 10);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 11);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 12);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 200);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 201);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 202);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 203);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 204);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 301);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 302);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 303);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 400);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 401);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 402);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 403);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 500);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 501);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 502);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 600);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 601);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 602);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 603);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 700);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 701);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 702);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 703);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000001', 4);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000001', 5);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000001', 7);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000001', 303);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000002', 1);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000002', 200);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 1);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 2);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 3);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 4);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 5);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 6);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 7);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 8);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 9);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 10);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 11);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 12);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 301);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 302);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 303);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 400);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 401);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 402);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 403);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 2);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 3);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 4);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 5);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 6);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 7);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 8);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 9);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 10);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 11);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 12);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 200);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 201);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 202);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 203);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 204);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 301);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 302);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 303);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 400);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 401);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 402);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 403);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 700);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 701);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 702);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 703);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 600);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 601);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 602);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 603);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 600);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 601);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 602);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 603);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00005-0000-0000-0000-def000000005', 104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00005-0000-0000-0000-def000000005', 103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00005-0000-0000-0000-def000000005', 403);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 1);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 2);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 3);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 4);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 5);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 6);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 7);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 8);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 9);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 10);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 11);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 12);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00007-0000-0000-0000-def000000007', 300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00007-0000-0000-0000-def000000007', 301);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00007-0000-0000-0000-def000000007', 302);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00007-0000-0000-0000-def000000007', 303);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00008-0000-0000-0000-def000000008', 200);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00008-0000-0000-0000-def000000008', 201);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00008-0000-0000-0000-def000000008', 202);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00008-0000-0000-0000-def000000008', 203);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00008-0000-0000-0000-def000000008', 204);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000a', 901);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00009-0000-0000-0000-def000000009', 1);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 800);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 900);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 900);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 901);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 901);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000002', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 1101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 1102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 1103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 1104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 1101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 1102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 1103);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 1104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 1101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 1102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 1104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000b', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000b', 1101);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000b', 1102);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000b', 1104);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000c', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1000);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1001);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1002);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000b-0000-0000-0000-def00000000b', 1000);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000b-0000-0000-0000-def00000000b', 1001);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000b-0000-0000-0000-def00000000b', 1002);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 13);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000d', 1);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000e', 200);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1200);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1200);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000001', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0001-000000000002', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00003-0000-0000-0000-def000000003', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00004-0000-0000-0000-def000000004', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00005-0000-0000-0000-def000000005', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00007-0000-0000-0000-def000000007', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00008-0000-0000-0000-def000000008', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000b', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000c', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000d', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000e', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000b-0000-0000-0000-def00000000b', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000f', 201);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000f', 202);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000f', 203);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000f', 204);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000f', 1300);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('00000000-0000-0000-0000-000000000001', 14);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 14);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 14);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000d', 1100);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00001-0000-0000-0000-def000000001', 502);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00002-0000-0000-0000-def000000002', 502);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000f', 502);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def0000a-0000-0000-0000-def00000000b', 502);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00006-0000-0000-0000-def000000006', 502);
INSERT INTO roles_groups (role_id, action_group_id) VALUES ('def00007-0000-0000-0000-def000000007', 1);


--
-- Data for Name: roles_relations; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: schema_version; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (1, '03000000', 'upgrade/03_00_0000_add_schema_version.sql', '0', 'postgres', '2012-12-12 12:40:10.628475', '2012-12-12 12:40:10.628475', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (2, '03000010', 'upgrade/03_00_0010_add_group_ids_to_users.sql', '134a5cda68ff78a8ee6c5dd52021d8c6', 'engine', '2012-12-12 12:40:26.2028', '2012-12-12 12:40:26.253388', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (3, '03000030', 'upgrade/03_00_0030_change_storage_format_type_to_str.sql', '6bfded79aa68ed713bb171b73347965f', 'engine', '2012-12-12 12:40:26.282294', '2012-12-12 12:40:26.556471', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (4, '03000040', 'upgrade/03_00_0040_change_vm_dynamic_vm_ip_type.sql', 'e53ab476dd8e9f4ffc34763c1af6b4d2', 'engine', '2012-12-12 12:40:26.603114', '2012-12-12 12:40:26.843905', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (5, '03000050', 'upgrade/03_00_0050_make_blank_template_pulic.sql', 'ea6d296b7c111a2e0b534d04705e74db', 'engine', '2012-12-12 12:40:27.063615', '2012-12-12 12:40:27.111422', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (6, '03000060', 'upgrade/03_00_0060_add_group_everyone.sql', 'dcbbd9ac86497d12ed94f33bd83a9106', 'engine', '2012-12-12 12:40:27.15118', '2012-12-12 12:40:27.19614', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (7, '03000100', 'upgrade/03_00_0100_add_device_size_to_luns.sql', '7d5ea403964625620682e28528e13205', 'engine', '2012-12-12 12:40:27.225875', '2012-12-12 12:40:27.406791', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (8, '03000120', 'upgrade/03_00_0120_add_update_date_to_vm_templates.sql', '6584113b71bb9690ad3e4172c9b638e3', 'engine', '2012-12-12 12:40:27.45734', '2012-12-12 12:40:27.661601', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (9, '03000130', 'upgrade/03_00_0130_change_dwh_history_timekeeping_date_type.sql', '7d6575c9706b4317d670e2512d7825aa', 'engine', '2012-12-12 12:40:27.711762', '2012-12-12 12:40:27.785431', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (10, '03000150', 'upgrade/03_00_0150_update_roles.sql', 'dd7f5e70f6018748a2316c6cc0439b77', 'engine', '2012-12-12 12:40:27.820454', '2012-12-12 12:40:28.080459', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (11, '03000180', 'upgrade/03_00_0180_add_guest_disk_size.sql', 'fe6599ec2e6b59280a3f93986e445023', 'engine', '2012-12-12 12:40:28.145446', '2012-12-12 12:40:28.271472', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (12, '03000190', 'upgrade/03_00_0190_add_latency_vm_disks.sql', '01624a2a2add97685aa6f8a8ca551030', 'engine', '2012-12-12 12:40:28.321983', '2012-12-12 12:40:28.594104', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (13, '03000220', 'upgrade/03_00_0220_add_MaxAuditLogMessageLength_to_config.sql', '9d5bd71f8a3d2f64e0ab83035e512e45', 'engine', '2012-12-12 12:40:29.270572', '2012-12-12 12:40:30.091157', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (14, '03000260', 'upgrade/03_00_0260_change_app_list_type_to_text.sql', 'b2eb516a44d9a68727ffa899b4c5f463', 'engine', '2012-12-12 12:40:30.138076', '2012-12-12 12:40:30.62303', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (15, '03000270', 'upgrade/03_00_0270_change_users_group_ids_field_to_text.sql', '52a822350fbb283aef9a36a9454d9b7e', 'engine', '2012-12-12 12:40:30.659381', '2012-12-12 12:40:30.895549', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (16, '03000280', 'upgrade/03_00_0280_change_blank_template_default_display_type_to_spice.sql', 'ef601e207388c22fcdad41d62a78dfb7', 'engine', '2012-12-12 12:40:30.936858', '2012-12-12 12:40:30.994509', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (17, '03000300', 'upgrade/03_00_0300_add_local_admin_user.sql', 'e2585ccc9eae241ef664f08018c0e6cd', 'engine', '2012-12-12 12:40:31.038561', '2012-12-12 12:40:31.109659', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (18, '03000330', 'upgrade/03_00_0330_add_configuration_action_group_to_super_user_role.sql', '3ce7b989d0a60997ced61880b770ee0f', 'engine', '2012-12-12 12:40:31.157601', '2012-12-12 12:40:31.208616', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (19, '03000360', 'upgrade/03_00_0360_upgrade_default_vds_group_thp.sql', '83c2bb9b40415fe75b376a92bd4161bb', 'engine', '2012-12-12 12:40:31.240985', '2012-12-12 12:40:31.276293', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (20, '03000380', 'upgrade/03_00_0380_add_otp_validity_to_vds_static.sql', 'eeaa26a093dc33dc6ac5eb86131f00b3', 'engine', '2012-12-12 12:40:31.316697', '2012-12-12 12:40:31.432448', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (21, '03000410', 'upgrade/03_00_0410_add_disks_usage.sql', '6e56398bc15899dda06129529059f20e', 'engine', '2012-12-12 12:40:31.490207', '2012-12-12 12:40:31.691139', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (23, '03010010', 'upgrade/03_01_0010_change_action_parameters_type.sql', 'd150d7c28ce61440d020afe2c3ea3464', 'engine', '2012-12-12 12:40:32.151505', '2012-12-12 12:40:32.588689', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (24, '03010030', 'upgrade/03_01_0030_change_vds_static_pm_password_to_text.sql', 'd2912fe7077d1a5b96ce526d55d9ad95', 'engine', '2012-12-12 12:40:32.653626', '2012-12-12 12:40:32.719074', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (25, '03010040', 'upgrade/03_01_0040_add_AddPermission_to_PowerUserRole.sql', '90bba693f2c0dcd8ec7d0dc96257414d', 'engine', '2012-12-12 12:40:32.765144', '2012-12-12 12:40:32.82047', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (26, '03010050', 'upgrade/03_01_0050_add_disks_table.sql', 'c7efa2cfffa6ba5ec2e5aa37db422f4a', 'engine', '2012-12-12 12:40:32.872042', '2012-12-12 12:40:33.008635', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (27, '03010060', 'upgrade/03_01_0060_add_cancel_migration_to_action_version_map.sql', '4adceafcd1bbac7eb71b5679f71e08c4', 'engine', '2012-12-12 12:40:33.036036', '2012-12-12 12:40:33.08015', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (28, '03010070', 'upgrade/03_01_0070_populate_disks_table.sql', '63d35d28d3e7e4f98f9f7c7eb8e07625', 'engine', '2012-12-12 12:40:33.107746', '2012-12-12 12:40:33.177472', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (29, '03010090', 'upgrade/03_01_0090_add_template_columns_to_vm_static.sql', '7ee271c5d6276f6c4aeb50e9b0f8970a', 'engine', '2012-12-12 12:40:33.207859', '2012-12-12 12:40:34.329584', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (30, '03010100', 'upgrade/03_01_0100_migrate_templates_to_vm_static.sql', '9f5102025bf4c306927ab0d6a4662c98', 'engine', '2012-12-12 12:40:34.36017', '2012-12-12 12:40:34.460469', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (31, '03010110', 'upgrade/03_01_0110_add_vds_spm_priority_col.sql', '4e8ba0896b2a3be8426bc34c5f2966ae', 'engine', '2012-12-12 12:40:34.490183', '2012-12-12 12:40:34.668705', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (32, '03010140', 'upgrade/03_01_0140_drop_vm_templates_tables.sql', 'cf4583bfd8bc3eea122f30002cbd77c3', 'engine', '2012-12-12 12:40:34.69573', '2012-12-12 12:40:34.753768', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (33, '03010150', 'upgrade/03_01_0150_remove_status_from_disks.sql', '7d01ad9dc455f539fcbbafa09f3581ae', 'engine', '2012-12-12 12:40:34.790871', '2012-12-12 12:40:34.83794', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (34, '03010170', 'upgrade/03_01_0170_add_quota_tables.sql', 'aba743c5bc8ab01d17b45603342462d9', 'engine', '2012-12-12 12:40:34.868066', '2012-12-12 12:40:35.122109', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (35, '03010180', 'upgrade/03_01_0180_add_quota_fields.sql', '880c231ee37365453af75f1f96e6cd3e', 'engine', '2012-12-12 12:40:35.151485', '2012-12-12 12:40:35.277084', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (36, '03010200', 'upgrade/03_01_0200_add_vm_device_table.sql', '6430c8c27457831ada452d7bb63afccf', 'engine', '2012-12-12 12:40:35.339057', '2012-12-12 12:40:35.715385', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (37, '03010210', 'upgrade/03_01_0210_add_hash_column_to_vm_dynamic.sql', 'e2c889816ff5996cc6472e00948d4963', 'engine', '2012-12-12 12:40:35.741581', '2012-12-12 12:40:35.798554', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (38, '03010220', 'upgrade/03_01_0220_vm_device_upgrade_data.sql', '4c528abb6a46d03cae8fc47cbd07291c', 'engine', '2012-12-12 12:40:35.829063', '2012-12-12 12:40:36.014131', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (39, '03010240', 'upgrade/03_01_0240_remove_is_shared_column_from_vm_device.sql', '92ebe7d871cda5cba7b0c09a6b3c7b82', 'engine', '2012-12-12 12:40:36.057178', '2012-12-12 12:40:36.122949', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (40, '03010260', 'upgrade/03_01_0260_add_job_table.sql', 'c74d309cfb8f9d802e54f2ff66d560b4', 'engine', '2012-12-12 12:40:36.156169', '2012-12-12 12:40:36.432811', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (41, '03010270', 'upgrade/03_01_0270_add_job_subject_entity_table.sql', 'e0b6f4691334b29aaa0af2d5b76a09e4', 'engine', '2012-12-12 12:40:36.480238', '2012-12-12 12:40:36.677227', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (42, '03010280', 'upgrade/03_01_0280_add_step_table.sql', 'a1563b0f16f91967245dda2df0a4752c', 'engine', '2012-12-12 12:40:36.706439', '2012-12-12 12:40:37.027812', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (43, '03010300', 'upgrade/03_01_0300_vds_static_unique_fields.sql', 'cba234a8027e5baf8e1e8fa28aa0d755', 'engine', '2012-12-12 12:40:37.069295', '2012-12-12 12:40:37.198903', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (44, '03010320', 'upgrade/03_01_0320_rename_audit_log_keys_from_merge_to_remove.sql', '9e59796c803a3308b68c2ec751cc7068', 'engine', '2012-12-12 12:40:37.247706', '2012-12-12 12:40:37.302389', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (45, '03010330', 'upgrade/03_01_0330_add_step_id_column_to_async_task.sql', '90e3fa27ab57714bf3d38a92a5e287ca', 'engine', '2012-12-12 12:40:37.348017', '2012-12-12 12:40:37.411968', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (46, '03010370', 'upgrade/03_01_0370_vm_device_upgrade_data.sql', 'a2b96c1ce7eb82f59724e7d8b1af6870', 'engine', '2012-12-12 12:40:37.486553', '2012-12-12 12:40:37.747526', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (47, '03010380', 'upgrade/03_01_0380_add_correlation_and_job_to_audit_log.sql', '3392dd1578c7f98765894f63f1a30936', 'engine', '2012-12-12 12:40:37.790355', '2012-12-12 12:40:37.854501', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (48, '03010390', 'upgrade/03_01_0390_add_snapshots_table.sql', 'a2258a3d6cb12541c0b67e6e5c634f3d', 'engine', '2012-12-12 12:40:37.890031', '2012-12-12 12:40:38.0764', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (49, '03010410', 'upgrade/03_01_0410_remove_image_templates_table.sql', 'a1af5216e9e08e5b458d7196a8fc30ca', 'engine', '2012-12-12 12:40:38.105701', '2012-12-12 12:40:38.19818', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (50, '03010421', 'upgrade/03_01_0421_update_EmulateMachine_config.sql', 'd904428151c77d0a5ebf6cb10f025c45', 'engine', '2012-12-12 12:40:38.229362', '2012-12-12 12:40:38.33392', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (51, '03010430', 'upgrade/03_01_0430_add_image_domain_map_table.sql', 'fa998f400b764935aa28ba75380a0353', 'engine', '2012-12-12 12:40:38.375606', '2012-12-12 12:40:39.142047', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (52, '03010440', 'upgrade/03_01_0440_vm_device_upgrade_data.sql', 'da76d200a169151cd6a3988308a71e13', 'engine', '2012-12-12 12:40:39.244359', '2012-12-12 12:40:39.501369', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (53, '03010460', 'upgrade/03_01_0460_add_defalut_quota_column.sql', 'd29504f5fd159d4f0d93a11d5a5dfc7b', 'engine', '2012-12-12 12:40:39.551974', '2012-12-12 12:40:39.585303', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (54, '03010470', 'upgrade/03_01_0470_add_quota_permissions.sql', 'd73669ad5c89f84f303181bd27307747', 'engine', '2012-12-12 12:40:39.626388', '2012-12-12 12:40:39.716711', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (55, '03010480', 'upgrade/03_01_0480_add_quota_consume_role.sql', '63850abaa8f2fbfc92cd1cdee09242e6', 'engine', '2012-12-12 12:40:39.772564', '2012-12-12 12:40:39.80814', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (56, '03010490', 'upgrade/03_01_0490_add_audit_log_columns.sql', 'b732b61a545e58cb0514127318b7318f', 'engine', '2012-12-12 12:40:39.847995', '2012-12-12 12:40:39.941507', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (57, '03010500', 'upgrade/03_01_0500_add_unique_name_constraint.sql', '5d666d9f27f3f744b152229878f3e862', 'engine', '2012-12-12 12:40:39.982945', '2012-12-12 12:40:40.121879', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (58, '03010510', 'upgrade/03_01_0510_add_permission_to_consume_quota.sql', 'ffb73d1f995f3f95353d25433afd72d3', 'engine', '2012-12-12 12:40:40.1681', '2012-12-12 12:40:40.236676', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (60, '03010530', 'upgrade/03_01_0530_migrate_image_vm_pool_map.sql', 'b2cace20320eb8f70175a2111b41d82f', 'engine', '2012-12-12 12:40:40.342095', '2012-12-12 12:40:40.410816', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (61, '03010540', 'upgrade/03_01_0540_add_prestarted_vms_col.sql', 'beabe33c20903c00f1ae145c214aaff2', 'engine', '2012-12-12 12:40:40.45421', '2012-12-12 12:40:40.684877', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (62, '03010560', 'upgrade/03_01_0560_vm_device_upgrade_data.sql', 'fe363e860c205c04c76c77b6709e3153', 'engine', '2012-12-12 12:40:40.719365', '2012-12-12 12:40:40.973155', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (63, '03010580', 'upgrade/03_01_0580_recoverable.sql', 'f776d02f0c24b78f587c06465dc70bca', 'engine', '2012-12-12 12:40:41.00269', '2012-12-12 12:40:41.470082', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (64, '03010600', 'upgrade/03_01_0600_migrate_images_to_snapshots.sql', 'fac05b263671b0ac97069b9a26822c18', 'engine', '2012-12-12 12:40:41.501916', '2012-12-12 12:40:41.593883', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (65, '03010610', 'upgrade/03_01_0610_drop_stateless_vm_image_map_table.sql', '674163efd7be6efe09028b5c688fa580', 'engine', '2012-12-12 12:40:41.62647', '2012-12-12 12:40:41.695185', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (66, '03010620', 'upgrade/03_01_0620_add_service_columns_to_vds_groups.sql', 'c104ae9a9fe75bfefa8784d249730e7f', 'engine', '2012-12-12 12:40:41.737499', '2012-12-12 12:40:42.104734', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (67, '03010630', 'upgrade/03_01_0630_add_disk_name.sql', '7f8342f914e58878f70309a3484a652b', 'engine', '2012-12-12 12:40:42.143512', '2012-12-12 12:40:42.389319', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (68, '03010650', 'upgrade/03_01_0650_add_volume_to_audit_log.sql', '0ae331dc028f2b6de29ec97de6c97ebc', 'engine', '2012-12-12 12:40:42.534317', '2012-12-12 12:40:42.660861', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (69, '03010660', 'upgrade/03_01_0660_migrate_image_vm_map.sql', '3ce048ac7480c3551a209a31412aa37a', 'engine', '2012-12-12 12:40:42.730472', '2012-12-12 12:40:42.910912', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (70, '03010680', 'upgrade/03_01_0680_add_setupnetwork_to_action_version_map.sql', '22c21785fc6332759e2af8fcce20589b', 'engine', '2012-12-12 12:40:42.939069', '2012-12-12 12:40:42.985496', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (71, '03010690', 'upgrade/03_01_0690_add_gluster_volume_tables.sql', '4182c39539dae6a56c75fbc9e3428b85', 'engine', '2012-12-12 12:40:43.03086', '2012-12-12 12:40:44.491263', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (72, '03010720', 'upgrade/03_01_0720_remove_unused_images_columns.sql', '7893d25a36e766930161a92d3f6bbd14', 'engine', '2012-12-12 12:40:44.533873', '2012-12-12 12:40:44.8835', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (73, '03010730', 'upgrade/03_01_0730_add_empty_cd_to_vm.sql', 'd5ebec05f89287d315295cef24832482', 'engine', '2012-12-12 12:40:44.929513', '2012-12-12 12:40:44.995136', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (74, '03010740', 'upgrade/03_01_0740_add_vm_device_soundcard.sql', '0e66a473af429db0eb5bb5615d92c29c', 'engine', '2012-12-12 12:40:45.034852', '2012-12-12 12:40:45.097713', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (75, '03010750', 'upgrade/03_01_0750_add_mtu_column.sql', '35666390372749282b67f83d16de266d', 'engine', '2012-12-12 12:40:45.128852', '2012-12-12 12:40:45.1927', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (76, '03010760', 'upgrade/03_01_0760_add_bridgeless_columns.sql', '0bd9cc27a3aebad4639dc407f8e408af', 'engine', '2012-12-12 12:40:45.220515', '2012-12-12 12:40:45.804836', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (77, '03010770', 'upgrade/03_01_0770_remove_disk_type_column.sql', 'd0aae058fbcd0993e6cd242eb4518b85', 'engine', '2012-12-12 12:40:45.83924', '2012-12-12 12:40:45.922233', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (78, '03010780', 'upgrade/03_01_0780_add_action_version_map_add_vm_from_snapshot.sql', 'a722cbc187a15b6dc936448554982ef2', 'engine', '2012-12-12 12:40:45.954963', '2012-12-12 12:40:46.007501', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (79, '03010790', 'upgrade/03_01_0790_resize_disk_alias_column.sql', '189b036124fe8bca7292c2a442ad6fd0', 'engine', '2012-12-12 12:40:46.052586', '2012-12-12 12:40:46.229989', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (80, '03010800', 'upgrade/03_01_0800_upgrade_disk_alias_name.sql', 'd5678c58d1940c21a40972f724dcaa2a', 'engine', '2012-12-12 12:40:46.261201', '2012-12-12 12:40:46.311595', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (81, '03010810', 'upgrade/03_01_0810_update_dc_ver_add_vm_from_snapshot.sql', '5396bb15b03e1836b15f2268fc1a01f5', 'engine', '2012-12-12 12:40:46.364692', '2012-12-12 12:40:46.415562', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (82, '03010830', 'upgrade/03_01_0830_change_disk_alias_upper_case.sql', '9d4e26089b4eb76e184f85d0c7e1d649', 'engine', '2012-12-12 12:40:46.448129', '2012-12-12 12:40:46.48678', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (83, '03010840', 'upgrade/03_01_0840_change_storage_type_all_to_new_value.sql', 'e111c20dd735761a765a5803b6db03e6', 'engine', '2012-12-12 12:40:46.537391', '2012-12-12 12:40:46.575397', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (84, '03010850', 'upgrade/03_01_0850_add_gluster_transport_types.sql', 'a4c7c9c60cbf2d577c933e2d1d804635', 'engine', '2012-12-12 12:40:46.60706', '2012-12-12 12:40:46.810731', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (85, '03010870', 'upgrade/03_01_0870_add_posix_fs_support_columns_to_connection.sql', '54d583cb804a6268c7b0d161bd68d8ae', 'engine', '2012-12-12 12:40:46.845443', '2012-12-12 12:40:46.988917', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (86, '03010880', 'upgrade/03_01_0880_rename_disks_table_to_base_disks.sql', 'd46da5171ebae178a8f2e42fdf4a72b4', 'engine', '2012-12-12 12:40:47.036713', '2012-12-12 12:40:47.080071', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (87, '03010890', 'upgrade/03_01_0890_add_disk_lun_map_table.sql', '95a1fe3b4d3c5cedb2ccce605fff661f', 'engine', '2012-12-12 12:40:47.124148', '2012-12-12 12:40:47.244709', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (88, '03010910', 'upgrade/03_01_0910_add_shared_disk.sql', '902f39bf81b5c762574c4ff8341d3ba3', 'engine', '2012-12-12 12:40:47.354303', '2012-12-12 12:40:47.555804', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (89, '03010920', 'upgrade/03_01_0920_remove_config_entries_from_schema_version.sql', '992e3189e8b8056b528f9db673a6d9d4', 'engine', '2012-12-12 12:40:47.585992', '2012-12-12 12:40:47.665655', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (90, '03010930', 'upgrade/03_01_0930_convert_spec_param_to_json.sql', 'ba1dc220fba5015c30f45c5b96823c8a', 'engine', '2012-12-12 12:40:47.69421', '2012-12-12 12:40:47.799225', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (91, '03010940', 'upgrade/03_01_0940_add_disks_roles.sql', 'b81dc001d6562fee7b3ff7d5fb8cfdde', 'engine', '2012-12-12 12:40:47.830324', '2012-12-12 12:40:47.916826', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (92, '03010950', 'upgrade/03_01_0950_add_permissions_on_storage_to_users.sql', '101824bc36d8b2bba4ec5863cd15caa7', 'engine', '2012-12-12 12:40:47.949986', '2012-12-12 12:40:48.033265', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (93, '03010960', 'upgrade/03_01_0960_fix_default_quota_name.sql', '2d5f90738fe6876ff7f594887d75b588', 'engine', '2012-12-12 12:40:48.065874', '2012-12-12 12:40:48.217667', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (94, '03010970', 'upgrade/03_01_0970_add_addposixstorage_domain_to_action_version_map.sql', '125374e67bfe35f119d34e6c9764b210', 'engine', '2012-12-12 12:40:48.260598', '2012-12-12 12:40:48.31686', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (95, '03010980', 'upgrade/03_01_0980_add_version.sql', 'ebb5f7d7ebc052b7c34fba3de3715917', 'engine', '2012-12-12 12:40:48.368476', '2012-12-12 12:40:49.020849', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (96, '03010990', 'upgrade/03_01_0990_add_dwh_to_event_map.sql', '5f5deb97e253cbae1d31bb896d96100e', 'engine', '2012-12-12 12:40:49.241346', '2012-12-12 12:40:49.567309', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (97, '03011000', 'upgrade/03_01_1000_gluster_role_maps.sql', 'c790bf71e7b3af5be098aecfd8bceea9', 'engine', '2012-12-12 12:40:49.625917', '2012-12-12 12:40:49.727082', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (98, '03011010', 'upgrade/03_01_1010_add_bootable_column_to_base_disk.sql', 'fd6570f9921a0407cf85160bab360e2d', 'engine', '2012-12-12 12:40:49.758082', '2012-12-12 12:40:49.897012', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (99, '03011020', 'upgrade/03_01_1020_add_command_id_to_async_tasks_table.sql', 'f2a5bdcb599453bbb719d19aff09f787', 'engine', '2012-12-12 12:40:49.931545', '2012-12-12 12:40:50.143497', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (100, '03011030', 'upgrade/03_01_1030_add_allow_console_reconnect.sql', 'b385aff2b357ed379f947890b91d35ae', 'engine', '2012-12-12 12:40:50.175366', '2012-12-12 12:40:50.505582', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (101, '03011040', 'upgrade/03_01_1040_add_allow_console_reconnect_permission.sql', 'f7155a94af7d654f8c9d1eb2a0552752', 'engine', '2012-12-12 12:40:50.540281', '2012-12-12 12:40:50.593499', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (102, '03011050', 'upgrade/03_01_1050_drop_license_usage_table.sql', 'ec594ac1e522e0a36f608771ee1a66bd', 'engine', '2012-12-12 12:40:50.648658', '2012-12-12 12:40:50.719798', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (103, '03011060', 'upgrade/03_01_1060_rename_luns_column.sql', '59d65718765a3cfaa8f470a84134a0b3', 'engine', '2012-12-12 12:40:50.753842', '2012-12-12 12:40:50.80965', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (104, '03011070', 'upgrade/03_01_1070_add_create_update_dates_to_vm_device.sql', '77271903b305946caa16126a8726305a', 'engine', '2012-12-12 12:40:50.839638', '2012-12-12 12:40:51.031504', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (105, '03011080', 'upgrade/03_01_1080_add_allow_snapshot.sql', '1d3db00b071fb9cc3f7dd104f3b0910f', 'engine', '2012-12-12 12:40:51.065445', '2012-12-12 12:40:51.282622', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (106, '03011090', 'upgrade/03_01_1090_gluster_brick_option_id.sql', '18fa9982f9d0718bb585d6cfd065ecfd', 'engine', '2012-12-12 12:40:51.334655', '2012-12-12 12:40:51.789373', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (107, '03011100', 'upgrade/03_01_1100_add_inheritable_roles.sql', 'f38ff961ad0ead97a3111a9da4bfa7c5', 'engine', '2012-12-12 12:40:51.818908', '2012-12-12 12:40:51.98056', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (108, '03011110', 'upgrade/03_01_1110_rename_inheritable_roles_columns.sql', '56098c7cb0b5ee24af2760c0554cdbd4', 'engine', '2012-12-12 12:40:52.007642', '2012-12-12 12:40:52.269097', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (109, '03011120', 'upgrade/03_01_1120_vm_device_add_alias_column.sql', '7baf00fe0dc3507bf42bad6332530615', 'engine', '2012-12-12 12:40:52.31384', '2012-12-12 12:40:52.444366', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (110, '03011130', 'upgrade/03_01_1130_update_role_allows_viewing_children_column.sql', 'a6eecbddc93903bdb2ecf41ed253948f', 'engine', '2012-12-12 12:40:52.489034', '2012-12-12 12:40:52.535294', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (111, '03011140', 'upgrade/03_01_1140_add_creator_roles.sql', '14c4e6f0ddfbdc40ff74b50a8eb9d030', 'engine', '2012-12-12 12:40:52.571352', '2012-12-12 12:40:52.655833', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (112, '03011150', 'upgrade/03_01_1150_remove_unneeded_groups_from_disk_creator.sql', 'eda9817cec2a76e9141c3033386de078', 'engine', '2012-12-12 12:40:52.808809', '2012-12-12 12:40:52.986155', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (113, '03011160', 'upgrade/03_01_1160_add_cpu_pinning.sql', '7fb9e9b5b9b4697f82189eddc720a53a', 'engine', '2012-12-12 12:40:53.022964', '2012-12-12 12:40:53.190667', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (114, '03011170', 'upgrade/03_01_1170_remove_internal_drive_mapping_column.sql', '8b58650faa236c5beba95f0e1b37da1c', 'engine', '2012-12-12 12:40:53.225186', '2012-12-12 12:40:53.284923', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (115, '03011180', 'upgrade/03_01_1180_remove_and_rename_columns_vm_dynamic.sql', '0ade79cff7e12937f0a051c1e4a21d4b', 'engine', '2012-12-12 12:40:53.333735', '2012-12-12 12:40:53.412112', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (116, '03011190', 'upgrade/03_01_1190_add_port_mirroring_to_vm_interface.sql', '8d02dc727f657f8b587101bed36e1129', 'engine', '2012-12-12 12:40:53.441382', '2012-12-12 12:40:54.755526', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (117, '03011200', 'upgrade/03_01_1200_blank_template_usb_policy.sql', '1f675e822a0dc54dc71d26b7f2578ff9', 'engine', '2012-12-12 12:40:54.791241', '2012-12-12 12:40:54.891634', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (118, '03011210', 'upgrade/03_01_1210_gluster_event_map.sql', 'dc28321b76f639a5aeda79d2d849204e', 'engine', '2012-12-12 12:40:54.940756', '2012-12-12 12:40:55.610081', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (119, '03011220', 'upgrade/03_01_1220_add_volume_brick_order_column.sql', 'e8b1c5f587e7bad8841d323877131dd7', 'engine', '2012-12-12 12:40:55.640818', '2012-12-12 12:40:55.907824', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (120, '03011230', 'upgrade/03_01_1230_add_login_action_group.sql', 'a69f1d3e4bb7e0321ef706d23b7dcbc8', 'engine', '2012-12-12 12:40:55.978509', '2012-12-12 12:40:56.048696', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (121, '03011240', 'upgrade/03_01_1240_add_template_owner_role.sql', '1d3d7c21ba7ae7c12545472c6521fa6d', 'engine', '2012-12-12 12:40:56.094969', '2012-12-12 12:40:56.254836', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (122, '03011250', 'upgrade/03_01_1250_add_custom_props_action_group.sql', '15a414bbe5a80b386449bda535835966', 'engine', '2012-12-12 12:40:56.362866', '2012-12-12 12:40:56.505606', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (123, '03011260', 'upgrade/03_01_1260_remove_time_lease_vm_pool_map_table.sql', '51db1778c1f87d42babd7b90cf131b21', 'engine', '2012-12-12 12:40:56.537068', '2012-12-12 12:40:56.609162', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (124, '03011270', 'upgrade/03_01_1270_add_task_idx_audit_log.sql', '9e8a9a0e37942ae7b7f872fb936c738a', 'engine', '2012-12-12 12:40:56.655046', '2012-12-12 12:40:56.850568', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (125, '03011280', 'upgrade/03_01_1280_add_async_task_entities_table.sql', 'c1bca1c7934b37b503290a4de7c6b44e', 'engine', '2012-12-12 12:40:56.963929', '2012-12-12 12:40:57.061743', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (126, '03011290', 'upgrade/03_01_1290_add_last_time_used_as_master_col.sql', 'd17d6e307e06b9d9ac6c1eaa20d82827', 'engine', '2012-12-12 12:40:57.104737', '2012-12-12 12:40:57.179061', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (127, '03011300', 'upgrade/03_01_1300_remove_allow_snapshot_col.sql', '749611f3029a2782ce24a3671702adc1', 'engine', '2012-12-12 12:40:57.211223', '2012-12-12 12:40:57.259155', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (128, '03011310', 'upgrade/03_01_1310_remove_default_quota.sql', 'e233bdaf1840063c22db95f3f1e3c049', 'engine', '2012-12-12 12:40:57.291262', '2012-12-12 12:40:57.408272', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (129, '03011320', 'upgrade/03_01_1320_update_usb_policy_of_linux_vms.sql', 'dfef6737506e50a03607135aacc11451', 'engine', '2012-12-12 12:40:57.437101', '2012-12-12 12:40:57.468557', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (130, '03011330', 'upgrade/03_01_1330_add_disk_permissions_to_vm_creator_role.sql', '95ee75c32bc510e110f1e2e8e07f9e90', 'engine', '2012-12-12 12:40:57.528155', '2012-12-12 12:40:57.578661', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (131, '03011340', 'upgrade/03_01_1340_add_AddPermission_to_roles.sql', '3f0be0febc19e1a065d81b6a6404bf38', 'engine', '2012-12-12 12:40:57.604638', '2012-12-12 12:40:57.705938', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (132, '03011350', 'upgrade/03_01_1350_add_vdsm_rpm_version_column.sql', '7c1a5e97b616922a34f8c68a99dfce6c', 'engine', '2012-12-12 12:40:57.746207', '2012-12-12 12:40:57.870915', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (133, '03011360', 'upgrade/03_01_1360_update_roles_description.sql', '2b0f440747e72dd1ccc3e2095f2a5a9b', 'engine', '2012-12-12 12:40:57.902183', '2012-12-12 12:40:58.098261', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (134, '03011370', 'upgrade/03_01_1370_update_power_user_role.sql', 'dff60288fedcd475ef11fd7f3f430a2a', 'engine', '2012-12-12 12:40:58.140513', '2012-12-12 12:40:58.199294', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (135, '03011380', 'upgrade/03_01_1380_change_storage_status.sql', '9d7e433933e6dfc739d2a717f0ec445e', 'engine', '2012-12-12 12:40:58.230579', '2012-12-12 12:40:58.266761', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (136, '03011390', 'upgrade/03_01_1390_add_host_time_drift_event.sql', 'd2066c759fae307e2293a398efd823f4', 'engine', '2012-12-12 12:40:58.297607', '2012-12-12 12:40:58.376495', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (137, '03011400', 'upgrade/03_01_1400_add_create_vm_to_vm_pool_admin.sql', '8dbcfabba9a4c98aad284067da6bf977', 'engine', '2012-12-12 12:40:58.419473', '2012-12-12 12:40:59.070467', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (138, '03011410', 'upgrade/03_01_1410_extend_host_mac_address_size.sql', 'bddc83a9de40e63be68b54dba6c48ca6', 'engine', '2012-12-12 12:40:59.548119', '2012-12-12 12:41:00.025558', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (139, '03011420', 'upgrade/03_01_1420_encrypt_chap_password.sh', 'ce584a8cfa0547dce90e5ee3e5d87aa6', 'engine', '2012-12-12 12:41:00.054256', '2012-12-12 12:41:00.266258', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (140, '03011430', 'upgrade/03_01_1430_add_timestamp_to_async_tasks_and_compensation.sql', 'f61b2aa2acd0b72b04cb10caf299b39a', 'engine', '2012-12-12 12:41:00.30273', '2012-12-12 12:41:00.57707', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (141, '03011440', 'upgrade/03_01_1440_add_storage_pool_id_and_task_type_to_async_tasks.sql', 'ffcfe39e397124fd04e2efc7d2114486', 'engine', '2012-12-12 12:41:00.606322', '2012-12-12 12:41:00.746173', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (142, '03011450', 'upgrade/03_01_1450_change_nfs_version_to_string.sql', 'faebe526e881acdad205156be6a25ced', 'engine', '2012-12-12 12:41:00.80645', '2012-12-12 12:41:00.967782', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (143, '03011451', 'upgrade/03_01_1451_add_fk_vm_interface_vm_static_template.sql', '052067976e5059b421ea8d53a96ee9c7', 'engine', '2012-12-12 12:41:01.02813', '2012-12-12 12:41:01.090363', 'INSTALLED', false, '');
INSERT INTO schema_version (id, version, script, checksum, installed_by, started_at, ended_at, state, current, comment) VALUES (144, '03011460', 'upgrade/03_01_1460_configure_disk_storage_action_group_changes.sql', '6e419b61500d285c05c1edf6cb0dda8d', 'engine', '2012-12-12 12:41:01.1213', '2012-12-12 12:41:01.171509', 'INSTALLED', true, '');


--
-- Data for Name: snapshots; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: step; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: storage_domain_dynamic; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO storage_domain_dynamic (id, available_disk_size, used_disk_size) VALUES ('9d625863-2423-46d3-8439-d19e805a93fe', 170, 520);
INSERT INTO storage_domain_dynamic (id, available_disk_size, used_disk_size) VALUES ('72ec1321-a114-451f-bee1-6790cbca1bc6', 5813, 112);
INSERT INTO storage_domain_dynamic (id, available_disk_size, used_disk_size) VALUES ('a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 92, 7);
INSERT INTO storage_domain_dynamic (id, available_disk_size, used_disk_size) VALUES ('13d2f06b-2c3b-412c-9fa7-771cf8557509', 95, 4);
INSERT INTO storage_domain_dynamic (id, available_disk_size, used_disk_size) VALUES ('f1ec1456-736f-4fa6-8b8e-639ed994bd25', 92, 7);


--
-- Data for Name: storage_domain_static; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO storage_domain_static (id, storage, storage_name, storage_domain_type, storage_type, storage_domain_format_type, _create_date, _update_date, recoverable, last_time_used_as_master) VALUES ('a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', 'QnvQg0-98i8-cYRC-z8XM-PCPb-Z89Y-9TTPpH', 'Dafna-si25-01', 0, 3, '3', '2012-12-12 15:54:18.465714+02', '2012-12-12 15:54:27.419499+02', true, 0);
INSERT INTO storage_domain_static (id, storage, storage_name, storage_domain_type, storage_type, storage_domain_format_type, _create_date, _update_date, recoverable, last_time_used_as_master) VALUES ('f1ec1456-736f-4fa6-8b8e-639ed994bd25', 'i7hrKn-gbvs-fnKu-gz1g-fkJN-sEB0-1xL39S', 'Dafna-si25-02', 1, 3, '3', '2012-12-12 15:57:41.896257+02', '2012-12-12 15:57:41.953036+02', true, 0);
INSERT INTO storage_domain_static (id, storage, storage_name, storage_domain_type, storage_type, storage_domain_format_type, _create_date, _update_date, recoverable, last_time_used_as_master) VALUES ('13d2f06b-2c3b-412c-9fa7-771cf8557509', 'QCyMvG-iyZQ-qwHu-HiAr-9wDS-HpaF-5sO3XO', 'Dafna-si25-03', 1, 3, '3', '2012-12-12 15:58:15.967772+02', '2012-12-12 15:58:16.00328+02', true, 0);
INSERT INTO storage_domain_static (id, storage, storage_name, storage_domain_type, storage_type, storage_domain_format_type, _create_date, _update_date, recoverable, last_time_used_as_master) VALUES ('72ec1321-a114-451f-bee1-6790cbca1bc6', '320f6ee1-aa80-40cc-a321-6ea47e3c0bf4', 'New_Export', 3, 1, '0', '2012-12-12 16:16:35.633986+02', NULL, true, 0);
INSERT INTO storage_domain_static (id, storage, storage_name, storage_domain_type, storage_type, storage_domain_format_type, _create_date, _update_date, recoverable, last_time_used_as_master) VALUES ('9d625863-2423-46d3-8439-d19e805a93fe', '1affec00-0d6a-4dbb-8d7c-2d401aee0317', 'NFs', 0, 1, '3', '2012-12-16 10:31:12.38866+02', '2012-12-16 10:31:20.009424+02', true, 0);


--
-- Data for Name: storage_pool; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO storage_pool (id, name, description, storage_pool_type, storage_pool_format_type, status, master_domain_version, spm_vds_id, compatibility_version, _create_date, _update_date, quota_enforcement_type) VALUES ('4d801098-4448-11e2-9eb6-001a4a169741', 'Default', 'The default Data Center', 3, NULL, 0, 0, NULL, '3.1', '2012-12-12 12:40:10.309617+02', '2012-12-12 12:42:05.522055+02', NULL);
INSERT INTO storage_pool (id, name, description, storage_pool_type, storage_pool_format_type, status, master_domain_version, spm_vds_id, compatibility_version, _create_date, _update_date, quota_enforcement_type) VALUES ('3e5c47da-2abc-4930-bdf5-7f045cf6e553', 'NFS', '', 1, '3', 4, 1, NULL, '3.1', '2012-12-16 10:20:51.727878+02', '2012-12-20 11:40:25.147294+02', 0);
INSERT INTO storage_pool (id, name, description, storage_pool_type, storage_pool_format_type, status, master_domain_version, spm_vds_id, compatibility_version, _create_date, _update_date, quota_enforcement_type) VALUES ('6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 'iSCSI', '', 3, '3', 1, 1, '0a5d3a04-445a-11e2-b7cb-001a4a169741', '3.1', '2012-12-12 15:52:55.792361+02', '2012-12-20 15:10:54.990022+02', 0);


--
-- Data for Name: storage_pool_iso_map; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO storage_pool_iso_map (storage_id, storage_pool_id, status, owner) VALUES ('9d625863-2423-46d3-8439-d19e805a93fe', '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 0, 0);
INSERT INTO storage_pool_iso_map (storage_id, storage_pool_id, status, owner) VALUES ('72ec1321-a114-451f-bee1-6790cbca1bc6', '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 0, 0);
INSERT INTO storage_pool_iso_map (storage_id, storage_pool_id, status, owner) VALUES ('a738573e-35dd-41ee-bd5a-c83e6f5a0f7e', '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 3, 0);
INSERT INTO storage_pool_iso_map (storage_id, storage_pool_id, status, owner) VALUES ('13d2f06b-2c3b-412c-9fa7-771cf8557509', '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 3, 0);
INSERT INTO storage_pool_iso_map (storage_id, storage_pool_id, status, owner) VALUES ('f1ec1456-736f-4fa6-8b8e-639ed994bd25', '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 3, 0);


--
-- Data for Name: storage_server_connections; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO storage_server_connections (id, connection, user_name, password, iqn, port, portal, storage_type, mount_options, vfs_type, nfs_version, nfs_timeo, nfs_retrans) VALUES ('71d07b63-7977-488d-a857-b2046130bac1', '10.35.64.10', NULL, NULL, 'Dafna-si25-01', '3260', '1', 3, NULL, NULL, NULL, NULL, NULL);
INSERT INTO storage_server_connections (id, connection, user_name, password, iqn, port, portal, storage_type, mount_options, vfs_type, nfs_version, nfs_timeo, nfs_retrans) VALUES ('c1e2f9cb-48bf-48f2-a7e4-1fe271da552e', '10.35.64.10', NULL, NULL, 'Dafna-si25-02', '3260', '1', 3, NULL, NULL, NULL, NULL, NULL);
INSERT INTO storage_server_connections (id, connection, user_name, password, iqn, port, portal, storage_type, mount_options, vfs_type, nfs_version, nfs_timeo, nfs_retrans) VALUES ('3fbf0347-f1f6-4685-8415-c32b776b64a1', '10.35.64.10', NULL, NULL, 'Dafna-si25-03', '3260', '1', 3, NULL, NULL, NULL, NULL, NULL);
INSERT INTO storage_server_connections (id, connection, user_name, password, iqn, port, portal, storage_type, mount_options, vfs_type, nfs_version, nfs_timeo, nfs_retrans) VALUES ('320f6ee1-aa80-40cc-a321-6ea47e3c0bf4', 'wolf.qa.lab.tlv.redhat.com:/volumes/wolf/Dafna_New_Export_0_nfs_71122241851338', NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL);
INSERT INTO storage_server_connections (id, connection, user_name, password, iqn, port, portal, storage_type, mount_options, vfs_type, nfs_version, nfs_timeo, nfs_retrans) VALUES ('1affec00-0d6a-4dbb-8d7c-2d401aee0317', 'orion:/export/Dafna/data', NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL);


--
-- Data for Name: tags; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: tags_user_group_map; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: tags_user_map; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: tags_vds_map; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: tags_vm_map; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: tags_vm_pool_map; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: user_sessions; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: users; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO users (user_id, name, surname, domain, username, groups, department, role, user_icon_path, desktop_device, email, note, status, session_count, last_admin_check_status, group_ids) VALUES ('fdfc627c-d875-11e0-90f0-83df133b58cc', 'admin', NULL, 'internal', 'admin@internal', '', NULL, '', '', '', NULL, '', 1, 0, true, '');


--
-- Data for Name: vdc_db_log; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: vdc_options; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (2, 'CpuPinningEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (3, 'CpuPinningEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (4, 'CpuPinningEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (5, 'AdminDomain', 'internal', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (7, 'AdminUser', 'admin', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (8, 'AdUserId', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (9, 'AdUserName', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (10, 'AdUserPassword', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (11, 'AdvancedNFSOptionsEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (12, 'AdvancedNFSOptionsEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (13, 'AdvancedNFSOptionsEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (14, 'AgentAppName', 'RHEV-Agent', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (16, 'AllowDuplicateMacAddresses', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (19, 'AsyncPollingCyclesBeforeRefreshSuspend', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (20, 'AsyncTaskPollingRate', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (21, 'AsyncTaskStatusCacheRefreshRateInSeconds', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (22, 'AsyncTaskStatusCachingTimeInMinutes', '1', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (24, 'AuditLogAgingThreashold', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (25, 'AuditLogCleanupTime', '03:35:35', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (26, 'OnlyRequiredNetworksMandatoryForVdsSelection', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (27, 'AuthenticationMethod', 'LDAP', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (28, 'AutoMode', 'PerServer', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (29, 'AutoRecoverySchedule', '0 0/5 * * * ?', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (30, 'AutoRepoDomainRefreshTime', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (31, 'AutoSuspendTimeInMinutes', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (32, 'BlockMigrationOnSwapUsagePercentage', '0', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (36, 'CBCCertificateScriptName', '/usr/share/vdsm-reg/vdsm-gen-cert', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (37, 'CbcCheckOnVdsChange', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (38, 'CBCCloseCertificateScriptName', '/usr/share/vdsm-reg/vdsm-complete', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (41, 'CertificateFingerPrint', '73 18 22 44 5d 98 b0 5d c0 f7 36 7d f8 1d 85 da e1 3c f1 c6', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (43, 'CipherSuite', 'DEFAULT', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (45, 'ConnectToServerTimeoutInSeconds', '20', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (46, 'CpuOverCommitDurationMinutes', '2', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (51, 'DebugTimerLogging', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (52, 'DefaultMaxThreadPoolSize', '500', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (53, 'DefaultMinThreadPoolSize', '50', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (55, 'DefaultWorkgroup', 'WORKGROUP', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (56, 'DesktopAudioDeviceType', 'default,ac97', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (57, 'DesktopAudioDeviceType', 'WindowsXP,ac97,RHEL4,ac97,RHEL3,ac97,Windows2003x64,ac97,RHEL4x64,ac97,RHEL3x64,ac97,OtherLinux,ac97,Other,ac97,default,ich6', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (58, 'DesktopAudioDeviceType', 'WindowsXP,ac97,RHEL4,ac97,RHEL3,ac97,Windows2003x64,ac97,RHEL4x64,ac97,RHEL3x64,ac97,OtherLinux,ac97,Other,ac97,default,ich6', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (59, 'DisableFenceAtStartupInSec', '300', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (60, 'DiskConfigurationList', 'System,Sparse,COW,true;Data,Preallocated,RAW,false;Shared,Preallocated,RAW,false;Swap,Preallocated,RAW,false;Temp,Sparse,COW,false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (61, 'DirectLUNDiskEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (62, 'DirectLUNDiskEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (63, 'DirectLUNDiskEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (64, 'DocsURL', 'docs', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (69, 'EnableHostTimeDrift', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (70, 'EnableSpiceRootCertificateValidation', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (71, 'EnableSwapCheck', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (72, 'EnableUSBAsDefault', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (73, 'EnableVdsLoadBalancing', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (75, 'EngineMode', 'Active', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (76, 'ENMailDomain', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (77, 'ENMailIsBodyHtml', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (78, 'ENMailUseDefaultCredentials', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (79, 'FailedJobCleanupTimeInMinutes', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (81, 'FenceAgentMapping', 'ilo3=ipmilan', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (82, 'FenceQuietTimeBetweenOperationsInSec', '180', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (83, 'FenceStartStatusDelayBetweenRetriesInSec', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (84, 'FenceStartStatusRetries', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (85, 'FenceStopStatusDelayBetweenRetriesInSec', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (86, 'FenceStopStatusRetries', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (87, 'FilteringLUNsEnabled', 'true', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (88, 'FilteringLUNsEnabled', 'true', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (89, 'FilteringLUNsEnabled', 'false', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (90, 'FindFenceProxyDelayBetweenRetriesInSec', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (91, 'FindFenceProxyRetries', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (92, 'FreeSpaceCriticalLowInGB', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (93, 'FreeSpaceLow', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (94, 'GlusterVolumeOptionGroupVirtValue', 'virt', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (1, 'CpuPinMigrationEnabled', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (47, 'CustomPublicConfig_AppsWebSite', 'http://marketplace.redhat.com/rhev?origin=rhevm-$EngineVersion', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (49, 'DBEngine', 'Postgres', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (50, 'DebugSearchLogging', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (54, 'DefaultTimeZone', '(GMT) GMT Standard Time', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (68, 'EmulatedMachine', 'rhel6.3.0', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (80, 'FenceAgentDefaultParams', 'ilo3:lanplus,power_wait=4', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (23, 'AsyncTaskZombieTaskLifeInMinutes', '3000', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (33, 'CABaseDirectory', '/etc/pki/ovirt-engine', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (74, 'ENGINEEARLib', '/usr/share/ovirt-engine/engine.ear', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (65, 'DomainName', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (66, 'EmulatedMachine', 'rhel5.5.0', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (35, 'CAEngineKey', '/etc/pki/ovirt-engine/private/ca.pem', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (67, 'EmulatedMachine', 'rhel6.2.0', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (39, 'CertAlias', 'engine', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (34, 'CACertificatePath', '/etc/pki/ovirt-engine/ca.pem', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (48, 'DataDir', '/usr/share/ovirt-engine', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (18, 'AsyncPollingCyclesBeforeCallbackCleanup', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (44, 'ConfigDir', '/etc/ovirt-engine', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (95, 'GlusterVolumeOptionOwnerUserVirtValue', '36', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (96, 'GlusterVolumeOptionOwnerGroupVirtValue', '36', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (97, 'GuestToolsSetupIsoPrefix', 'RHEV-toolsSetup_', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (98, 'HighUtilizationForEvenlyDistribute', '75', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (99, 'HighUtilizationForPowerSave', '75', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (100, 'HostTimeDriftInSec', '300', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (101, 'HotPlugEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (102, 'HotPlugEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (103, 'HotPlugEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (105, 'HotPlugUnsupportedOsList', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (106, 'InitStorageSparseSizeInGB', '1', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (108, 'IoOpTimeoutSec', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (110, 'IPTablesConfigForGluster', '
# glusterd
-A INPUT -p tcp -m tcp --dport 24007 -j ACCEPT

# portmapper
-A INPUT -p udp -m udp --dport 111   -j ACCEPT
-A INPUT -p tcp -m tcp --dport 38465 -j ACCEPT
-A INPUT -p tcp -m tcp --dport 38466 -j ACCEPT

# nfs
-A INPUT -p tcp -m tcp --dport 38467 -j ACCEPT

# status
-A INPUT -p tcp -m tcp --dport 39543 -j ACCEPT
-A INPUT -p tcp -m tcp --dport 55863 -j ACCEPT

# nlockmgr
-A INPUT -p tcp -m tcp --dport 38468 -j ACCEPT
-A INPUT -p udp -m udp --dport 963   -j ACCEPT
-A INPUT -p tcp -m tcp --dport 965   -j ACCEPT

# ctdbd
-A INPUT -p tcp -m tcp --dport 4379  -j ACCEPT

# smbd
-A INPUT -p tcp -m tcp --dport 139   -j ACCEPT
-A INPUT -p tcp -m tcp --dport 445   -j ACCEPT

# Ports for gluster volume bricks (default 100 ports)
-A INPUT -p tcp -m tcp --dport 24009:24108 -j ACCEPT
', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (111, 'IPTablesConfigForVirt', '
# libvirt tls
-A INPUT -p tcp --dport 16514 -j ACCEPT

# guest consoles
-A INPUT -p tcp -m multiport --dports 5634:6166 -j ACCEPT

# migration
-A INPUT -p tcp -m multiport --dports 49152:49216 -j ACCEPT
', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (113, 'IsNeedSupportForOldVgAPI', 'true', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (114, 'IsNeedSupportForOldVgAPI', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (115, 'JobCleanupRateInMinutes', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (116, 'JobPageSize', '100', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (119, 'LdapQueryPageSize', '1000', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (120, 'LDAPQueryTimeout', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (121, 'LDAPConnectTimeout', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (122, 'LDAPOperationTimeout', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (124, 'LDAPServerPort', '389', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (125, 'LdapServers', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (127, 'LeaseRetries', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (128, 'LeaseTimeSec', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (129, 'LicenseCertificateFingerPrint', '5f 38 41 89 b1 33 49 0c 24 13 6b b3 e5 ba 9e c7 fd 83 80 3b', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (130, 'LimitNumberOfNetworkInterfaces', 'true', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (131, 'LimitNumberOfNetworkInterfaces', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (132, 'LimitNumberOfNetworkInterfaces', 'false', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (133, 'LiveSnapshotEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (134, 'LiveSnapshotEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (135, 'LiveSnapshotEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (136, 'LiveStorageMigrationEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (137, 'LiveStorageMigrationEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (138, 'LiveStorageMigrationEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (140, 'LocalStorageEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (141, 'LocalStorageEnabled', 'true', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (142, 'LocalStorageEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (143, 'LockPolicy', 'ON', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (144, 'LockRenewalIntervalSec', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (145, 'LogDBCommands', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (146, 'LogPhysicalMemoryThresholdInMB', '1024', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (147, 'LogXmlRpcData', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (148, 'LowUtilizationForEvenlyDistribute', '0', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (149, 'LowUtilizationForPowerSave', '20', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (151, 'ManagedDevicesWhiteList', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (152, 'ManagementNetwork', 'rhevm', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (153, 'MaxAuditLogMessageLength', '10000', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (154, 'MaxBlockDiskSize', '8192', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (155, 'MaxLDAPQueryPartsNumber', '100', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (156, 'MaxMacsCountInPool', '100000', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (157, 'MaxNumberOfHostsInStoragePool', '250', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (158, 'MaxNumOfCpuPerSocket', '16', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (159, 'MaxNumOfCpuPerSocket', '16', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (160, 'MaxNumOfCpuPerSocket', '16', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (161, 'MaxNumOfVmCpus', '16', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (162, 'MaxNumOfVmCpus', '64', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (163, 'MaxNumOfVmCpus', '64', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (164, 'MaxNumOfVmSockets', '16', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (165, 'MaxNumOfVmSockets', '16', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (166, 'MaxNumOfVmSockets', '16', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (167, 'MaxRerunVmOnVdsCount', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (168, 'MaxStorageVdsDelayCheckSec', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (169, 'MaxStorageVdsTimeoutCheckSec', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (170, 'MaxVdsMemOverCommit', '200', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (171, 'MaxVdsMemOverCommitForServers', '150', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (172, 'MaxVdsNameLength', '255', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (173, 'MaxVmNameLengthNonWindows', '64', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (174, 'MaxVmNameLengthWindows', '15', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (175, 'MaxVmsInPool', '1000', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (112, 'IsMultilevelAdministrationOn', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (176, 'MinimalETLVersion', '3.1.0', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (104, 'DisconnectPoolOnReconstruct', '0,2,3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (107, 'InstallVds', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (150, 'MacPoolRanges', '00:1A:4A:23:61:00-00:1A:4A:23:61:FF', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (123, 'LDAPSecurityAuthentication', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (126, 'LDAPProviderTypes', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (118, 'keystoreUrl', '/etc/pki/ovirt-engine/.keystore', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (117, 'keystorePass', 'mypass', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (139, 'LocalAdminPassword', 'cC+DBfBgfnkedaCvczyO1/gz8utO4Q5Ikya4fCm2fsg5mYbJ7rQX9tqkS52IAm8tXxj3v4XmOBAD
MIv/Hy3F+GXUWCAwLSzYfXEH0LILRD4HjjCk5a3SWbE+Rax9vjsu4cKT5NgxOAPxSxbJW32R5X2h
Y+RJlBipWX32ISjNkgcg9dI+cPG+TMch2VuukYTTBzYbudRJbuRNlw09aYOJjhG3O0l2hGKL4jrB
oOlU//sqG2sxtLgx2OMF4y6rCHBGLm3TX6MyfWju+ONSfBTDXRfuav7i78QavvKlRvxR7mQSyti3
ddR2yu+3E3YLLmWbP/Bw5M5a4+eMMrl/oaowog==', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (177, 'NativeUSBEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (178, 'NativeUSBEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (179, 'NativeUSBEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (180, 'NicDHCPDelayGraceInMS', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (181, 'NonVmNetworkSupported', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (182, 'NonVmNetworkSupported', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (183, 'NonVmNetworkSupported', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (184, 'NumberOfFailedRunsOnVds', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (185, 'NumberOfUSBSlots', '4', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (186, 'NumberOfVmsForTopSizeVms', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (187, 'NumberVmRefreshesBeforeSave', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (188, 'SupportBridgesReportByVDSM', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (189, 'SupportBridgesReportByVDSM', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (191, 'EnableMACAntiSpoofingFilterRules', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (192, 'EnableMACAntiSpoofingFilterRules', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (193, 'EnableMACAntiSpoofingFilterRules', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (194, 'MTUOverrideSupported', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (195, 'MTUOverrideSupported', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (196, 'MTUOverrideSupported', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (199, 'OvfVirtualSystemType', 'ENGINE', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (200, 'OvirtInitialSupportedIsoVersion', '5.8', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (201, 'OvirtIsoPrefix', 'rhevh', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (203, 'oVirtUpgradeScriptName', '/usr/share/vdsm-reg/vdsm-upgrade', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (204, 'oVirtUploadPath', '/data/updates/ovirt-node-image.iso', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (205, 'PayloadSize', '8192', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (206, 'PosixStorageEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (207, 'PosixStorageEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (208, 'PosixStorageEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (209, 'PostgresI18NPrefix', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (210, 'PostgresLikeSyntax', 'ILIKE', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (212, 'PostgresPagingType', 'Offset', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (214, 'PowerClientAllowRunningGuestsWithoutTools', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (215, 'PowerClientAllowUsingAsIRS', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (216, 'PowerClientAutoAdjustMemoryBaseOnAvailableMemory', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (217, 'PowerClientAutoAdjustMemory', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (218, 'PowerClientAutoAdjustMemoryGeneralReserve', '768', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (219, 'PowerClientAutoAdjustMemoryLog', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (220, 'PowerClientAutoAdjustMemoryMaxMemory', '2048', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (221, 'PowerClientAutoAdjustMemoryModulus', '64', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (222, 'PowerClientAutoAdjustMemorySpicePerMonitorReserve', '0', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (223, 'PowerClientAutoAdjustMemorySpicePerSessionReserve', '0', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (224, 'PowerClientAutoApprovePatterns', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (225, 'PowerClientAutoInstallCertificateOnApprove', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (226, 'PowerClientAutoMigrateFromPowerClientToVdsWhenConnectingFromRegularClient', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (227, 'PowerClientAutoMigrateToPowerClientOnConnect', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (228, 'PowerClientAutoRegistrationDefaultVdsGroupID', '99408929-82CF-4DC7-A532-9D998063FA95', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (229, 'PowerClientDedicatedVmLaunchOnVdsWhilePowerClientStarts', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (230, 'PowerClientGUI', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (231, 'PowerClientLogDetection', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (232, 'PowerClientMaxNumberOfConcurrentVMs', '1', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (233, 'PowerClientRunVmShouldVerifyPendingVMsAsWell', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (234, 'PowerClientSpiceDynamicCompressionManagement', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (235, 'PredefinedVMProperties', '', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (236, 'PredefinedVMProperties', 'sap_agent=^(true|false)$;sndbuf=^[0-9]+$;vhost=^(([a-zA-Z0-9_]*):(true|false))(,(([a-zA-Z0-9_]*):(true|false)))*$;viodiskcache=^(none|writeback|writethrough)$', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (237, 'PredefinedVMProperties', 'sap_agent=^(true|false)$;sndbuf=^[0-9]+$;vhost=^(([a-zA-Z0-9_]*):(true|false))(,(([a-zA-Z0-9_]*):(true|false)))*$;viodiskcache=^(none|writeback|writethrough)$', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (238, 'ProductKey2003', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (239, 'ProductKey2003x64', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (240, 'ProductKey2008', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (241, 'ProductKey2008R2', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (242, 'ProductKey2008x64', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (243, 'ProductKey', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (244, 'ProductKeyWindow7', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (245, 'ProductKeyWindow7x64', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (248, 'QuotaGraceStorage', '20', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (249, 'QuotaGraceVdsGroup', '20', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (250, 'QuotaThresholdStorage', '80', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (251, 'QuotaThresholdVdsGroup', '80', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (252, 'RDPLoginWithFQN', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (253, 'RedirectServletReportsPageError', 'Reports not installed, please contact your administrator', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (254, 'RedirectServletReportsPage', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (255, 'RenewGuestIpOnVdsSubnetChange', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (256, 'RenewGuestIpOnVdsSubnetChangeOnParseError', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (258, 'SANWipeAfterDelete', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (259, 'SASL_QOP', 'auth-conf', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (261, 'SearchesRefreshRateInSeconds', '1', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (262, 'SearchResultsLimit', '100', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (263, 'SelectCommandTimeout', '120', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (264, 'SendSMPOnRunVm', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (265, 'SendVmTicketUID', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (266, 'SendVmTicketUID', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (267, 'SendVmTicketUID', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (211, 'PostgresPagingSyntax', 'OFFSET (%1$s -1) LIMIT %2$s', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (213, 'PostgresSearchTemplate', 'SELECT * FROM (%2$s) %1$s) as T1 %3$s', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (257, 'RhevhLocalFSPath', '/data/images/rhev', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (190, 'SupportBridgesReportByVDSM', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (198, 'OriginType', 'RHEV', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (202, 'oVirtISOsRepositoryPath', '/usr/share/rhev-hypervisor', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (197, 'OrganizationName', 'RedHat', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (247, 'PublicURLPort', '80', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (260, 'ScriptsPath', '/usr/share/ovirt-engine', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (246, 'ProductRPMVersion', '3.1.0-33.el6ev', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (271, 'ServerRebootTimeout', '300', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (272, 'SetupNetworksPollingTimeout', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (273, 'ShareableDiskEnabled', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (274, 'ShareableDiskEnabled', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (275, 'ShareableDiskEnabled', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (276, 'SignCertTimeoutInSeconds', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (280, 'SpiceReleaseCursorKeys', 'shift+f12', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (281, 'SpiceToggleFullScreenKeys', 'shift+f11', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (282, 'SpiceUsbAutoShare', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (283, 'WANDisableEffects', 'animation', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (284, 'WANColorDepth', '16', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (285, 'SpmCommandFailOverRetries', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (286, 'SPMFailOverAttempts', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (287, 'SpmVCpuConsumption', '1', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (288, 'SQLServerI18NPrefix', 'N', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (289, 'SQLServerLikeSyntax', 'LIKE', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (290, 'SQLServerPagingSyntax', ' WHERE RowNum BETWEEN %1$s AND %2$s', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (291, 'SQLServerPagingType', 'Range', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (292, 'SQLServerSearchTemplate', 'SELECT * FROM (SELECT *, ROW_NUMBER() OVER(%1$s) as RowNum FROM (%2$s)) as T1) as T2 %3$s', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (293, 'SSHInactivityTimoutSeconds', '600', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (295, 'StorageDomainFalureTimeoutInMinutes', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (296, 'StorageDomainNameSizeLimit', '50', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (297, 'StoragePoolNameSizeLimit', '40', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (298, 'StoragePoolNonOperationalResetTimeoutInMin', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (299, 'StoragePoolRefreshTimeInSeconds', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (300, 'SucceededJobCleanupTimeInMinutes', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (301, 'SupportCustomProperties', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (302, 'SupportCustomProperties', 'true', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (303, 'SupportCustomProperties', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (305, 'SupportedStorageFormats', '0', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (306, 'SupportedStorageFormats', '0,2', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (309, 'SupportGetDevicesVisibility', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (310, 'SupportGetDevicesVisibility', 'true', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (311, 'SupportGetDevicesVisibility', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (312, 'SupportStorageFormat', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (313, 'SupportStorageFormat', 'true', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (314, 'SupportStorageFormat', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (315, 'SupportForceCreateVG', 'false', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (316, 'SupportForceCreateVG', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (317, 'SupportForceCreateVG', 'true', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (322, 'SysPrepDefaultPassword', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (323, 'SysPrepDefaultUser', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (327, 'TimeoutToResetVdsInSeconds', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (328, 'TimeToReduceFailedRunOnVdsInMinutes', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (331, 'UknownTaskPrePollingLapse', '60000', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (332, 'UserDefinedVMProperties', '', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (333, 'UserDefinedVMProperties', '', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (334, 'UserDefinedVMProperties', '', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (335, 'UserRefreshRate', '3600', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (336, 'UserSessionTimeOutInterval', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (337, 'UseRtl8139_pv', 'true', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (338, 'UseRtl8139_pv', 'false', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (339, 'UseRtl8139_pv', 'false', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (341, 'UseVdsBrokerInProc', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (342, 'UtilizationThresholdInPercent', '80', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (343, 'ValidNumOfMonitors', '1,2,4', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (344, 'VcpuConsumptionPercentage', '10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (347, 'VDSAttemptsToResetCount', '2', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (348, 'VdsCertificateValidityInYears', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (269, 'ServerCPUList', '3:Intel Conroe Family:vmx,nx,model_Conroe:Conroe; 4:Intel Penryn Family:vmx,nx,model_Penryn:Penryn; 5:Intel Nehalem Family:vmx,nx,model_Nehalem:Nehalem; 6:Intel Westmere Family:aes,vmx,nx,model_Westmere:Westmere; 2:AMD Opteron G1:svm,nx,model_Opteron_G1:Opteron_G1; 3:AMD Opteron G2:svm,nx,model_Opteron_G2:Opteron_G2; 4:AMD Opteron G3:svm,nx,model_Opteron_G3:Opteron_G3;', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (277, 'SignLockFile', '/var/lock/ovirt-engine/.openssl.exclusivelock', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (270, 'ServerCPUList', '3:Intel Conroe Family:vmx,nx,model_Conroe:Conroe; 4:Intel Penryn Family:vmx,nx,model_Penryn:Penryn; 5:Intel Nehalem Family:vmx,nx,model_Nehalem:Nehalem; 6:Intel Westmere Family:aes,vmx,nx,model_Westmere:Westmere; 7:Intel SandyBridge Family:vmx,nx,model_SandyBridge:SandyBridge; 2:AMD Opteron G1:svm,nx,model_Opteron_G1:Opteron_G1; 3:AMD Opteron G2:svm,nx,model_Opteron_G2:Opteron_G2; 4:AMD Opteron G3:svm,nx,model_Opteron_G3:Opteron_G3; 5:AMD Opteron G4:svm,nx,model_Opteron_G4:Opteron_G4;', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (279, 'SpiceDriverNameInGuest', '{"windows": "RHEV-Spice", "linux" : "xorg-x11-drv-qxl" }', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (304, 'SupportedClusterLevels', '3.0,3.1', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (307, 'SupportedStorageFormats', '0,2,3', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (308, 'SupportedVDSMVersions', '4.5,4.9,4.10', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (346, 'VdcVersion', '3.1.0.0', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (319, 'SysPrep2K8Path', '/etc/ovirt-engine/sysprep/sysprep.2k8x86', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (330, 'TruststoreUrl', '/etc/pki/ovirt-engine/.keystore', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (325, 'SysPrepWindows7x64Path', '/etc/ovirt-engine/sysprep/sysprep.w7x64', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (345, 'VdcBootStrapUrl', 'http://dafna-web-admin.qa.lab.tlv.redhat.com:80/Components/vds/', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (321, 'SysPrep2K8x64Path', '/etc/ovirt-engine/sysprep/sysprep.2k8', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (340, 'UseSecureConnectionWithServers', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (294, 'SSLEnabled', 'true', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (329, 'TruststorePass', 'mypass', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (318, 'SysPrep2K3Path', '/etc/ovirt-engine/sysprep/sysprep.2k3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (278, 'SignScriptName', 'SignReq.sh', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (320, 'SysPrep2K8R2Path', '/etc/ovirt-engine/sysprep/sysprep.2k8', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (326, 'SysPrepXPPath', '/etc/ovirt-engine/sysprep/sysprep.xp', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (324, 'SysPrepWindows7Path', '/etc/ovirt-engine/sysprep/sysprep.w7', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (350, 'VdsFenceOptions', '', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (351, 'VdsFenceOptionTypes', 'secure=bool,port=int,slot=int', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (354, 'VdsFenceType', 'alom,apc,bladecenter,drac5,eps,ilo,ilo3,ipmilan,rsa,rsb,wti,cisco_ucs', '3.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (355, 'VdsLoadBalancingeIntervalInMinutes', '1', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (358, 'VdsRecoveryTimeoutInMintues', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (359, 'VdsRefreshRate', '2', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (360, 'VdsSelectionAlgorithm', 'None', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (361, 'vdsTimeout', '180', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (362, 'VirtualMachineDomainName', 'VirtualMachineDomainName', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (363, 'VM32BitMaxMemorySizeInMB', '20480', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (364, 'VM64BitMaxMemorySizeInMB', '262144', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (365, 'VM64BitMaxMemorySizeInMB', '524288', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (366, 'VM64BitMaxMemorySizeInMB', '524288', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (368, 'VmGracefulShutdownTimeout', '30', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (369, 'VMMinMemorySizeInMB', '256', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (370, 'VmPoolMaxSubsequentFailures', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (371, 'VmPoolMonitorBatchSize', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (372, 'VmPoolMonitorIntervalInMinutes', '5', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (373, 'VmPoolMonitorMaxAttempts', '3', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (374, 'VmPriorityMaxValue', '100', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (375, 'VncKeyboardLayout', 'en-us', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (376, 'WaitForVdsInitInSec', '60', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (377, 'NetworkConnectivityCheckTimeoutInSeconds', '120', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (17, 'ApplicationMode', '255', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (15, 'AllowClusterWithVirtGlusterEnabled', 'false', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (109, 'IPTablesConfig', '
# oVirt default firewall configuration. Automatically generated by vdsm bootstrap script.
*filter
:INPUT ACCEPT [0:0]
:FORWARD ACCEPT [0:0]
:OUTPUT ACCEPT [0:0]
-A INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT

-A INPUT -i lo -j ACCEPT
# vdsm
-A INPUT -p tcp --dport 54321 -j ACCEPT
# SSH
-A INPUT -p tcp --dport 22 -j ACCEPT
# snmp
-A INPUT -p udp --dport 161 -j ACCEPT

@CUSTOM_RULES@

# Reject any other input traffic
-A INPUT -j REJECT --reject-with icmp-host-prohibited
-A FORWARD -m physdev ! --physdev-is-bridged -j REJECT --reject-with icmp-host-prohibited
COMMIT
', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (268, 'ServerCPUList', '2:Intel Xeon w/o XD/NX:vmx,sse2:qemu64,-nx,+sse2; 3:Intel Xeon:vmx,sse2,nx:qemu64,+sse2; 4:Intel Conroe Family:vmx,sse2,nx,cx16,ssse3:qemu64,+sse2,+cx16,+ssse3; 5:Intel Penryn Family:vmx,sse2,nx,cx16,ssse3,sse4_1:qemu64,+sse2,+cx16,+ssse3,+sse4.1; 6:Intel Nehalem Family:vmx,sse2,nx,cx16,ssse3,sse4_1,sse4_2,popcnt:qemu64,+sse2,+cx16,+ssse3,+sse4.1,+sse4.2,+popcnt; 2:AMD Opteron G1 w/o NX:svm,sse2:qemu64,-nx,+sse2; 3:AMD Opteron G1:svm,sse2,nx:qemu64,+sse2; 4:AMD Opteron G2:svm,sse2,nx,cx16:qemu64,+sse2,+cx16; 5:AMD Opteron G3:svm,sse2,nx,cx16,sse4a,misalignsse,popcnt,abm:qemu64,+sse2,+cx16,+sse4a,+misalignsse,+popcnt,+abm;', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (378, 'AutoRecoveryAllowedTypes', '{"storage domains":"false","hosts":"true"}', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (349, 'VdsFenceOptionMapping', 'alom:secure=secure,port=ipport;apc:secure=secure,port=ipport,slot=port;bladecenter:secure=secure,port=ipport,slot=port;drac5:secure=secure,slot=port;eps:slot=port;ilo:secure=ssl,port=ipport;ipmilan:;rsa:secure=secure,port=ipport;rsb:;wti:secure=secure,port=ipport,slot=port;cisco_ucs:secure=ssl,slot=port;ilo3:', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (352, 'VdsFenceType', 'alom,apc,bladecenter,drac5,eps,ilo,ilo3,ipmilan,rsa,rsb,wti,cisco_ucs', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (353, 'VdsFenceType', 'alom,apc,bladecenter,drac5,eps,ilo,ilo3,ipmilan,rsa,rsb,wti,cisco_ucs', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (367, 'VmGracefulShutdownMessage', 'The Engine is shutting down this Virtual Machine', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (356, 'VdsLocalDisksCriticallyLowFreeSpace', '500', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (357, 'VdsLocalDisksLowFreeSpace', '1000', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (379, 'SpiceSecureChannels', 'smain,sinputs', '2.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (380, 'SpiceSecureChannels', 'smain,sinputs', '3.0');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (381, 'SpiceSecureChannels', 'smain,sinputs,scursor,splayback,srecord,sdisplay,susbredir,ssmartcard', '3.1');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (382, 'SpiceSecureChannels', 'smain,sinputs,scursor,splayback,srecord,sdisplay,susbredir,ssmartcard', '3.2');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (40, 'CertificateFileName', '/etc/pki/ovirt-engine/certs/engine.cer', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (42, 'CertificatePassword', 'RmwDQBmVvzP7gogBnomjaMI00kOeeTkY3RcG3qwmZPqFDq3eNCEVS4dvr2XlatNfs+/sZ5H8nLYo
KwR0+AxJHyctqeT/peUVmW2hYBY981YoHULgOm1oXtdBAKKio3LFStJSeS4Onj/3zmPGD2B5077n
+Af+JJXxGTBer9WUSLQ/4JWCfd2Rrf4X8usFLkFqfr/WnTFtEYtUSyNUZPq17iJJLYjOCI+Mgtq+
aLMt8SNXYiDnw3wVXyk5+/fNFNpywH1lIO+4mzS/mG1mb1o791kke6P1+kpweeTap4IVrr3iPsa7
fyg4zSuC9n75tIRuVzYImB/lMSpGnxBT5Ci7hg==', 'general');
INSERT INTO vdc_options (option_id, option_name, option_value, version) VALUES (6, 'AdminPassword', 'W3iGwmi6Z+R8QlCM/WyAnhITJeH4+edbnn2lJzQb6f+pqV+mDcyewrLy6jzb6R0xiDQA9jmkWVuI
6wyUuDTDRyMxwrwswSuFYfswHXlMekTLG/YIYy1tVYlrsgbnXNdzX5dyxQ0s0hti0jHs3KbVFTi0
NbPl+iIyRhtebijr+NRg9N1MNfuUYAmi0myJFFxKq2motQ8Z/Fs6j2E7DLuh5XiJBAB4kVJlirti
MbJ70haLS7pCHLOvhEwp6lVc6NgcBo0LVZr05Hc3o75/ovFdUuXBON8L0gheB98BdkxyIrKLXaCa
QTgF8Sesvm5yvoNFOu1xdfvg66wReUjEHF5jvw==', 'general');


--
-- Data for Name: vds_dynamic; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vds_dynamic (vds_id, status, cpu_cores, cpu_model, cpu_speed_mh, if_total_speed, kvm_enabled, physical_mem_mb, mem_commited, vm_active, vm_count, vm_migrating, reserved_mem, guest_overhead, software_version, version_name, build_name, previous_status, cpu_flags, cpu_over_commit_time_stamp, hypervisor_type, vms_cores_count, pending_vcpus_count, cpu_sockets, net_config_dirty, supported_cluster_levels, host_os, kvm_version, spice_version, kernel_version, iscsi_initiator_name, transparent_hugepages_state, anonymous_hugepages, hooks, _update_date, non_operational_reason, pending_vmem_size, supported_engines, rpm_version) VALUES ('1650e6f2-4514-11e2-bb11-001a4a169741', 3, 8, 'Intel(R) Xeon(R) CPU           E5504  @ 2.00GHz', 2000, NULL, true, 32098, 0, 0, 0, 0, 321, 65, '4.9', 'Snow Man', NULL, 0, 'fpu,vme,de,pse,tsc,msr,pae,mce,cx8,apic,mtrr,pge,mca,cmov,pat,pse36,clflush,dts,acpi,mmx,fxsr,sse,sse2,ss,ht,tm,pbe,syscall,nx,rdtscp,lm,constant_tsc,arch_perfmon,pebs,bts,rep_good,xtopology,nonstop_tsc,aperfmperf,pni,dtes64,monitor,ds_cpl,vmx,est,tm2,ssse3,cx16,xtpr,pdcm,dca,sse4_1,sse4_2,popcnt,lahf_lm,dts,tpr_shadow,vnmi,flexpriority,ept,vpid,model_Nehalem,model_Conroe,model_Penryn', '2012-12-13 13:08:53.75+02', 0, 0, 0, 2, false, '3.0,3.1', 'RHEL - 6Server - 6.3.0.3.el6', '0.12.1.2 - 2.295.el6_3.10', '0.10.1 - 10.el6', '2.6.32 - 279.14.1.el6.x86_64', 'iqn.1994-05.com.redhat:e57b7d218dd5', 2, 306, '{}', '2012-12-20 15:10:55.66197+02', 0, 0, NULL, 'vdsm-4.9.6-44.2.el6_3');
INSERT INTO vds_dynamic (vds_id, status, cpu_cores, cpu_model, cpu_speed_mh, if_total_speed, kvm_enabled, physical_mem_mb, mem_commited, vm_active, vm_count, vm_migrating, reserved_mem, guest_overhead, software_version, version_name, build_name, previous_status, cpu_flags, cpu_over_commit_time_stamp, hypervisor_type, vms_cores_count, pending_vcpus_count, cpu_sockets, net_config_dirty, supported_cluster_levels, host_os, kvm_version, spice_version, kernel_version, iscsi_initiator_name, transparent_hugepages_state, anonymous_hugepages, hooks, _update_date, non_operational_reason, pending_vmem_size, supported_engines, rpm_version) VALUES ('7e6484de-445a-11e2-bcc7-001a4a169741', 3, 8, 'Intel(R) Xeon(R) CPU           E5504  @ 2.00GHz', 2000, NULL, true, 32098, 0, 0, 0, 0, 321, 65, '4.9', 'Snow Man', NULL, 3, 'fpu,vme,de,pse,tsc,msr,pae,mce,cx8,apic,mtrr,pge,mca,cmov,pat,pse36,clflush,dts,acpi,mmx,fxsr,sse,sse2,ss,ht,tm,pbe,syscall,nx,rdtscp,lm,constant_tsc,arch_perfmon,pebs,bts,rep_good,xtopology,nonstop_tsc,aperfmperf,pni,dtes64,monitor,ds_cpl,vmx,est,tm2,ssse3,cx16,xtpr,pdcm,dca,sse4_1,sse4_2,popcnt,lahf_lm,dts,tpr_shadow,vnmi,flexpriority,ept,vpid,model_Nehalem,model_Conroe,model_Penryn', '2012-12-12 14:58:51.688+02', 0, 0, 0, 2, false, '3.0,3.1', 'RHEL - 6Server - 6.3.0.3.el6', '0.12.1.2 - 2.295.el6_3.10', '0.10.1 - 10.el6', '2.6.32 - 279.14.1.el6.x86_64', 'iqn.1994-05.com.redhat:5bd6b1436122', 2, 196, '{}', '2012-12-20 15:10:57.593161+02', 0, 0, NULL, 'vdsm-4.9.6-44.2.el6_3');
INSERT INTO vds_dynamic (vds_id, status, cpu_cores, cpu_model, cpu_speed_mh, if_total_speed, kvm_enabled, physical_mem_mb, mem_commited, vm_active, vm_count, vm_migrating, reserved_mem, guest_overhead, software_version, version_name, build_name, previous_status, cpu_flags, cpu_over_commit_time_stamp, hypervisor_type, vms_cores_count, pending_vcpus_count, cpu_sockets, net_config_dirty, supported_cluster_levels, host_os, kvm_version, spice_version, kernel_version, iscsi_initiator_name, transparent_hugepages_state, anonymous_hugepages, hooks, _update_date, non_operational_reason, pending_vmem_size, supported_engines, rpm_version) VALUES ('0a5d3a04-445a-11e2-b7cb-001a4a169741', 3, 8, 'Intel(R) Xeon(R) CPU           E5504  @ 2.00GHz', 2000, NULL, true, 32098, 0, 0, 0, 0, 321, 65, '4.9', 'Snow Man', NULL, 3, 'fpu,vme,de,pse,tsc,msr,pae,mce,cx8,apic,mtrr,pge,mca,cmov,pat,pse36,clflush,dts,acpi,mmx,fxsr,sse,sse2,ss,ht,tm,pbe,syscall,nx,rdtscp,lm,constant_tsc,arch_perfmon,pebs,bts,rep_good,xtopology,nonstop_tsc,aperfmperf,pni,dtes64,monitor,ds_cpl,vmx,est,tm2,ssse3,cx16,xtpr,pdcm,dca,sse4_1,sse4_2,popcnt,lahf_lm,dts,tpr_shadow,vnmi,flexpriority,ept,vpid,model_Nehalem,model_Conroe,model_Penryn', '2012-12-12 14:54:34.24+02', 0, 0, 0, 2, false, '3.0,3.1', 'RHEL - 6Server - 6.3.0.3.el6', '0.12.1.2 - 2.295.el6_3.10', '0.10.1 - 10.el6', '2.6.32 - 279.14.1.el6.x86_64', 'iqn.1994-05.com.redhat:a7f8e5ca6817', 2, 194, '{}', '2012-12-20 15:10:55.667175+02', 0, 0, NULL, 'vdsm-4.9.6-44.2.el6_3');


--
-- Data for Name: vds_groups; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vds_groups (vds_group_id, name, description, cpu_name, _create_date, _update_date, selection_algorithm, high_utilization, low_utilization, cpu_over_commit_duration_minutes, hypervisor_type, storage_pool_id, max_vds_memory_over_commit, compatibility_version, transparent_hugepages, migrate_on_error, virt_service, gluster_service) VALUES ('99408929-82cf-4dc7-a532-9d998063fa95', 'Default', 'The default server cluster', NULL, '2012-12-12 12:40:10.309617+02', NULL, 0, 75, 0, 2, 0, '4d801098-4448-11e2-9eb6-001a4a169741', 100, '3.1', true, 1, true, false);
INSERT INTO vds_groups (vds_group_id, name, description, cpu_name, _create_date, _update_date, selection_algorithm, high_utilization, low_utilization, cpu_over_commit_duration_minutes, hypervisor_type, storage_pool_id, max_vds_memory_over_commit, compatibility_version, transparent_hugepages, migrate_on_error, virt_service, gluster_service) VALUES ('3e4ad610-4463-11e2-b9d2-001a4a169741', 'iSCSI', NULL, 'Intel Conroe Family', '2012-12-12 15:53:01.207062+02', NULL, 0, -1, -1, 2, 0, '6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 100, '3.1', true, 1, true, false);
INSERT INTO vds_groups (vds_group_id, name, description, cpu_name, _create_date, _update_date, selection_algorithm, high_utilization, low_utilization, cpu_over_commit_duration_minutes, hypervisor_type, storage_pool_id, max_vds_memory_over_commit, compatibility_version, transparent_hugepages, migrate_on_error, virt_service, gluster_service) VALUES ('84caf0c2-4759-11e2-a95e-001a4a169741', 'NFS', NULL, 'Intel Conroe Family', '2012-12-16 10:20:58.008642+02', NULL, 0, -1, -1, 2, 0, '3e5c47da-2abc-4930-bdf5-7f045cf6e553', 100, '3.1', true, 1, true, false);


--
-- Data for Name: vds_interface; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('8bd3a260-de8e-48aa-94fe-5274f4b2e102', 'bond4', NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:54:27.287768+02', '2012-12-20 15:10:43.929127+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('507af7ac-1ddd-4cdf-9c2b-b4e6d6d3a2a7', 'bond3', NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:54:27.337977+02', '2012-12-20 15:10:43.941351+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('a1eae31e-4ef1-4b50-a1c5-f2c9bbda3391', 'bond0', NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:54:27.438093+02', '2012-12-20 15:10:44.071757+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('5b0c46b7-5083-4342-aadc-5c9c5e794295', 'bond3', NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:58:46.90919+02', '2012-12-20 15:10:47.048752+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('1e4edb6b-430b-4baf-b602-106db963d91f', 'bond0', NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:58:46.941864+02', '2012-12-20 15:10:47.059581+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('0843ad62-8b0e-4555-8763-433b515049b9', 'bond1', NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:58:46.987609+02', '2012-12-20 15:10:47.140543+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('c4fb3f45-870f-4f2e-8bb4-be8a78e1c3de', 'bond2', NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:58:47.025058+02', '2012-12-20 15:10:47.161648+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('d774a353-1f13-4c82-8741-5584c206c017', 'eth1', NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', '00:21:5E:99:3F:DE', NULL, NULL, NULL, NULL, NULL, 0, '', '', NULL, 1, 0, '2012-12-12 14:58:46.617987+02', '2012-12-20 15:10:47.175605+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('30e8719b-cb12-4f91-98be-279f796bc926', 'eth0', 'rhevm', '7e6484de-445a-11e2-bcc7-001a4a169741', '00:21:5E:99:3F:DC', NULL, NULL, NULL, NULL, NULL, 1000, '10.35.116.2', '255.255.255.0', '10.35.116.254', 1, 2, '2012-12-12 14:58:46.689806+02', '2012-12-20 15:10:47.201569+02', 1500, true);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('bc5e10f2-1081-40d3-b4b4-e70e69190fbf', 'bond4', NULL, '7e6484de-445a-11e2-bcc7-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:58:46.835184+02', '2012-12-20 15:10:47.217994+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('9743b679-e385-473d-8328-46153333173d', 'bond0', NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-13 13:08:46.08988+02', '2012-12-20 15:10:40.798873+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('00fbcfe2-cb91-4703-b1cd-1323fd39e836', 'bond1', NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-13 13:08:46.133905+02', '2012-12-20 15:10:40.823454+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('198988c1-7a94-4014-8035-cdec95347420', 'bond2', NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-13 13:08:46.185381+02', '2012-12-20 15:10:40.836544+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('ea3da2dd-667a-4fe7-aec0-601aeb9173e3', 'eth1', NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', '00:21:5E:99:08:0A', NULL, NULL, NULL, NULL, NULL, 0, '', '', NULL, 0, 0, '2012-12-13 13:08:45.781366+02', '2012-12-20 15:10:40.852176+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('0168843c-6c3e-46f4-8a5d-989230b089ea', 'eth0', 'rhevm', '1650e6f2-4514-11e2-bb11-001a4a169741', '00:21:5E:99:08:08', NULL, NULL, NULL, NULL, NULL, 1000, '10.35.115.22', '255.255.255.0', '10.35.115.254', 1, 2, '2012-12-13 13:08:45.879325+02', '2012-12-20 15:10:40.883805+02', 1500, true);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('fddb328b-c5c5-4b8c-b6d7-01e8b2f40466', 'bond4', NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-13 13:08:45.951035+02', '2012-12-20 15:10:40.914439+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('91f22033-9a0e-490a-8d5d-565525da273a', 'bond3', NULL, '1650e6f2-4514-11e2-bb11-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-13 13:08:46.029396+02', '2012-12-20 15:10:40.930535+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('11412598-fa99-4b6a-8d54-611ad26549db', 'bond1', NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:54:27.50539+02', '2012-12-20 15:10:43.816405+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('43b6720d-8271-4efc-8ed7-b0ffd2defcf8', 'bond2', NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', '00:00:00:00:00:00', true, NULL, NULL, NULL, NULL, NULL, '', '', NULL, 0, 0, '2012-12-12 14:54:27.526209+02', '2012-12-20 15:10:43.833842+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('7361bcaa-bc2f-4fc0-81f8-7ad64b2039b4', 'eth1', NULL, '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'E4:1F:13:CC:B7:32', NULL, NULL, NULL, NULL, NULL, 0, '', '', NULL, 1, 0, '2012-12-12 14:54:27.192724+02', '2012-12-20 15:10:43.841048+02', 1500, false);
INSERT INTO vds_interface (id, name, network_name, vds_id, mac_addr, is_bond, bond_name, bond_type, bond_opts, vlan_id, speed, addr, subnet, gateway, boot_protocol, type, _create_date, _update_date, mtu, bridged) VALUES ('bad3d109-b8df-42ef-b3e2-19beb8b58c62', 'eth0', 'rhevm', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 'E4:1F:13:CC:B7:30', NULL, NULL, NULL, NULL, NULL, 1000, '10.35.115.21', '255.255.255.0', '10.35.115.254', 1, 2, '2012-12-12 14:54:27.24639+02', '2012-12-20 15:10:43.851156+02', 1500, true);


--
-- Data for Name: vds_interface_statistics; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('7361bcaa-bc2f-4fc0-81f8-7ad64b2039b4', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('bad3d109-b8df-42ef-b3e2-19beb8b58c62', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 1, 0, 0, 0, 1);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('8bd3a260-de8e-48aa-94fe-5274f4b2e102', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('507af7ac-1ddd-4cdf-9c2b-b4e6d6d3a2a7', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('a1eae31e-4ef1-4b50-a1c5-f2c9bbda3391', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('11412598-fa99-4b6a-8d54-611ad26549db', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('43b6720d-8271-4efc-8ed7-b0ffd2defcf8', '0a5d3a04-445a-11e2-b7cb-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('d774a353-1f13-4c82-8741-5584c206c017', '7e6484de-445a-11e2-bcc7-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('30e8719b-cb12-4f91-98be-279f796bc926', '7e6484de-445a-11e2-bcc7-001a4a169741', 0, 0, 0, 0, 1);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('bc5e10f2-1081-40d3-b4b4-e70e69190fbf', '7e6484de-445a-11e2-bcc7-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('5b0c46b7-5083-4342-aadc-5c9c5e794295', '7e6484de-445a-11e2-bcc7-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('1e4edb6b-430b-4baf-b602-106db963d91f', '7e6484de-445a-11e2-bcc7-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('0843ad62-8b0e-4555-8763-433b515049b9', '7e6484de-445a-11e2-bcc7-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('c4fb3f45-870f-4f2e-8bb4-be8a78e1c3de', '7e6484de-445a-11e2-bcc7-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('ea3da2dd-667a-4fe7-aec0-601aeb9173e3', '1650e6f2-4514-11e2-bb11-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('0168843c-6c3e-46f4-8a5d-989230b089ea', '1650e6f2-4514-11e2-bb11-001a4a169741', 0, 0, 0, 0, 1);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('fddb328b-c5c5-4b8c-b6d7-01e8b2f40466', '1650e6f2-4514-11e2-bb11-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('91f22033-9a0e-490a-8d5d-565525da273a', '1650e6f2-4514-11e2-bb11-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('9743b679-e385-473d-8328-46153333173d', '1650e6f2-4514-11e2-bb11-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('00fbcfe2-cb91-4703-b1cd-1323fd39e836', '1650e6f2-4514-11e2-bb11-001a4a169741', 0, 0, 0, 0, 2);
INSERT INTO vds_interface_statistics (id, vds_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('198988c1-7a94-4014-8035-cdec95347420', '1650e6f2-4514-11e2-bb11-001a4a169741', 0, 0, 0, 0, 2);


--
-- Data for Name: vds_spm_id_map; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vds_spm_id_map (storage_pool_id, vds_spm_id, vds_id) VALUES ('6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 1, '7e6484de-445a-11e2-bcc7-001a4a169741');
INSERT INTO vds_spm_id_map (storage_pool_id, vds_spm_id, vds_id) VALUES ('6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 2, '0a5d3a04-445a-11e2-b7cb-001a4a169741');
INSERT INTO vds_spm_id_map (storage_pool_id, vds_spm_id, vds_id) VALUES ('6d873e0e-80d5-4390-a3dd-f77f59bfdb09', 3, '1650e6f2-4514-11e2-bb11-001a4a169741');


--
-- Data for Name: vds_static; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vds_static (vds_id, vds_name, ip, vds_unique_id, host_name, port, vds_group_id, server_ssl_enabled, vds_type, vds_strength, pm_type, pm_user, pm_password, pm_port, pm_options, pm_enabled, _create_date, _update_date, otp_validity, vds_spm_priority, recoverable) VALUES ('7e6484de-445a-11e2-bcc7-001a4a169741', 'camel-vdsb', NULL, '6A7E2852-C2CC-11DE-9297-00215E993FDC', 'camel-vdsb.qa.lab.tlv.redhat.com', 54321, '3e4ad610-4463-11e2-b9d2-001a4a169741', true, 0, 100, NULL, NULL, NULL, NULL, 'port,secure=false', false, '2012-12-12 14:50:23.276021+02', '2012-12-20 11:40:25.719967+02', 0, 2, true);
INSERT INTO vds_static (vds_id, vds_name, ip, vds_unique_id, host_name, port, vds_group_id, server_ssl_enabled, vds_type, vds_strength, pm_type, pm_user, pm_password, pm_port, pm_options, pm_enabled, _create_date, _update_date, otp_validity, vds_spm_priority, recoverable) VALUES ('0a5d3a04-445a-11e2-b7cb-001a4a169741', 'gold-vdsc', NULL, '58BF6CC0-8ED1-11E0-A8E7-CFC2C2C2C2D6', 'gold-vdsc.qa.lab.tlv.redhat.com', 54321, '3e4ad610-4463-11e2-b9d2-001a4a169741', true, 0, 100, NULL, NULL, NULL, NULL, 'port,secure=false', false, '2012-12-12 14:47:08.61158+02', '2012-12-20 11:40:32.494958+02', 0, 5, true);
INSERT INTO vds_static (vds_id, vds_name, ip, vds_unique_id, host_name, port, vds_group_id, server_ssl_enabled, vds_type, vds_strength, pm_type, pm_user, pm_password, pm_port, pm_options, pm_enabled, _create_date, _update_date, otp_validity, vds_spm_priority, recoverable) VALUES ('1650e6f2-4514-11e2-bb11-001a4a169741', 'gold-vdsd', NULL, 'C51D3582-C2CC-11DE-A221-00215E990808', 'gold-vdsd.qa.lab.tlv.redhat.com', 54321, '3e4ad610-4463-11e2-b9d2-001a4a169741', true, 0, 100, NULL, NULL, NULL, NULL, 'port,secure=false', false, '2012-12-13 12:58:55.056569+02', '2012-12-20 11:40:37.865298+02', 0, 2, true);


--
-- Data for Name: vds_statistics; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vds_statistics (vds_id, cpu_idle, cpu_load, cpu_sys, cpu_user, usage_mem_percent, usage_cpu_percent, usage_network_percent, mem_available, mem_shared, swap_free, swap_total, ksm_cpu_percent, ksm_pages, ksm_state) VALUES ('1650e6f2-4514-11e2-bb11-001a4a169741', 100, 2, 0, 0, 4, 0, 0, 30777, 0, 15999, 15999, 0, 100, true);
INSERT INTO vds_statistics (vds_id, cpu_idle, cpu_load, cpu_sys, cpu_user, usage_mem_percent, usage_cpu_percent, usage_network_percent, mem_available, mem_shared, swap_free, swap_total, ksm_cpu_percent, ksm_pages, ksm_state) VALUES ('0a5d3a04-445a-11e2-b7cb-001a4a169741', 99, 7, 0, 1, 3, 0, 0, 30901, 0, 15999, 15999, 0, 100, true);
INSERT INTO vds_statistics (vds_id, cpu_idle, cpu_load, cpu_sys, cpu_user, usage_mem_percent, usage_cpu_percent, usage_network_percent, mem_available, mem_shared, swap_free, swap_total, ksm_cpu_percent, ksm_pages, ksm_state) VALUES ('7e6484de-445a-11e2-bcc7-001a4a169741', 100, 1, 0, 0, 3, 0, 0, 30925, 0, 16119, 16119, 0, 100, true);


--
-- Data for Name: vm_device; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('5fb7a384-4448-11e2-85ff-001a4a169741', '00000000-0000-0000-0000-000000000000', 'video', 'qxl', '', NULL, '{ "vram" : "65536" }', true, NULL, false, '2012-12-12 12:40:50.862664+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('b0154168-3b49-4109-8c70-4742a93c7218', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'disk', 'cdrom', '', 0, '{
  "path" : ""
}', true, true, true, '2012-12-12 16:26:32.233907+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('ca9c8e35-cc1f-47ed-8a68-9ddd3665001c', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'video', 'cirrus', '', 0, '{
  "vram" : "65536"
}', true, true, false, '2012-12-12 16:26:32.266324+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('a8402909-c2c8-4716-a24c-e2555ccc46b7', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'disk', 'disk', '', 0, NULL, true, true, false, '2012-12-16 10:35:03.101967+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('39a8ded2-ed3d-4a89-b7b5-242412a6f867', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'interface', 'bridge', '', 0, NULL, true, true, false, '2012-12-16 10:35:03.151765+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('a8eb3963-520a-435d-aba4-80a0dd2d9983', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'disk', 'disk', '', 0, NULL, true, true, false, '2012-12-12 16:26:32.177175+02', '2012-12-12 16:26:32.34509+02', '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('507a339d-b343-4aa6-abfe-dbe9a8325ce7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'interface', 'bridge', '', 0, NULL, true, true, false, '2012-12-12 16:26:32.209564+02', '2012-12-12 16:26:32.35842+02', '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('1075e762-caad-4c3d-98c1-38670d0b39dc', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'disk', 'cdrom', '', 0, '{
  "path" : ""
}', true, true, true, '2012-12-16 10:35:03.190914+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('ec11faac-5ac1-4af7-88b4-6772bdca0ecc', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'video', 'cirrus', '', 0, '{
  "vram" : "65536"
}', true, true, false, '2012-12-16 10:35:03.204342+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('4d42b3cf-7f99-4a09-8d45-7648f54287f4', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'disk', 'disk', '', 0, NULL, true, true, false, '2012-12-16 10:35:04.963506+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('d2ad4739-244c-4b30-8b5c-2ceaea24a4ba', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'interface', 'bridge', '', 0, NULL, true, true, false, '2012-12-16 10:35:05.013419+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('c2ff1908-0941-4298-8a0e-b08948487192', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'disk', 'cdrom', '', 0, '{
  "path" : ""
}', true, true, true, '2012-12-16 10:35:05.03924+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('880b58b3-ed1b-48b4-b26e-59d3443b63ad', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'video', 'cirrus', '', 0, '{
  "vram" : "65536"
}', true, true, false, '2012-12-16 10:35:05.060006+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('866bd625-cd01-4f6f-8f44-3cfd2439c67b', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'interface', 'bridge', '', 0, NULL, true, true, false, '2012-12-12 17:59:41.251096+02', '2012-12-12 17:59:41.493439+02', '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('aab71a1c-42cb-4137-b2ae-1e576458f2eb', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'disk', 'disk', '', 0, NULL, true, true, false, '2012-12-12 17:59:41.231806+02', '2012-12-12 17:59:41.479132+02', '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('e1c6a992-38f7-4c32-b354-2b7add945c28', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'disk', 'cdrom', '', 0, '{
  "path" : ""
}', true, true, true, '2012-12-12 17:59:41.293748+02', NULL, '');
INSERT INTO vm_device (device_id, vm_id, type, device, address, boot_order, spec_params, is_managed, is_plugged, is_readonly, _create_date, _update_date, alias) VALUES ('a9ad5838-650a-4771-a2a3-6defed8ee6c6', '4dd3914f-70da-4200-9031-e79dd447c1ce', 'video', 'cirrus', '', 0, '{
  "vram" : "65536"
}', true, true, false, '2012-12-12 17:59:41.336623+02', NULL, '');


--
-- Data for Name: vm_dynamic; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: vm_interface; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vm_interface (id, network_name, vm_guid, vmt_guid, mac_addr, name, speed, type, _create_date, _update_date, port_mirroring) VALUES ('507a339d-b343-4aa6-abfe-dbe9a8325ce7', 'rhevm', NULL, 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', NULL, 'nic1', 100, 1, '2012-12-12 16:26:31.579997+02', NULL, false);
INSERT INTO vm_interface (id, network_name, vm_guid, vmt_guid, mac_addr, name, speed, type, _create_date, _update_date, port_mirroring) VALUES ('866bd625-cd01-4f6f-8f44-3cfd2439c67b', 'rhevm', NULL, '4dd3914f-70da-4200-9031-e79dd447c1ce', NULL, 'nic1', 1000, 3, '2012-12-12 17:59:40.350748+02', NULL, false);
INSERT INTO vm_interface (id, network_name, vm_guid, vmt_guid, mac_addr, name, speed, type, _create_date, _update_date, port_mirroring) VALUES ('39a8ded2-ed3d-4a89-b7b5-242412a6f867', 'rhevm', NULL, 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', NULL, 'nic1', 1000, 3, '2012-12-16 10:35:01.81998+02', NULL, false);
INSERT INTO vm_interface (id, network_name, vm_guid, vmt_guid, mac_addr, name, speed, type, _create_date, _update_date, port_mirroring) VALUES ('d2ad4739-244c-4b30-8b5c-2ceaea24a4ba', 'rhevm', NULL, '2de994d1-0c9f-42fc-b100-72f5079f0d5c', NULL, 'nic1', 100, 1, '2012-12-16 10:35:03.465624+02', NULL, false);


--
-- Data for Name: vm_interface_statistics; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vm_interface_statistics (id, vm_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('507a339d-b343-4aa6-abfe-dbe9a8325ce7', 'f17519c2-6abd-4c88-b4a7-b86e02a1e558', NULL, NULL, NULL, NULL, NULL);
INSERT INTO vm_interface_statistics (id, vm_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('866bd625-cd01-4f6f-8f44-3cfd2439c67b', '4dd3914f-70da-4200-9031-e79dd447c1ce', NULL, NULL, NULL, NULL, NULL);
INSERT INTO vm_interface_statistics (id, vm_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('39a8ded2-ed3d-4a89-b7b5-242412a6f867', 'fa237384-7d1b-44c6-a2f3-6db0fedaecf5', NULL, NULL, NULL, NULL, NULL);
INSERT INTO vm_interface_statistics (id, vm_id, rx_rate, tx_rate, rx_drop, tx_drop, iface_status) VALUES ('d2ad4739-244c-4b30-8b5c-2ceaea24a4ba', '2de994d1-0c9f-42fc-b100-72f5079f0d5c', NULL, NULL, NULL, NULL, NULL);


--
-- Data for Name: vm_pool_map; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: vm_pools; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Data for Name: vm_static; Type: TABLE DATA; Schema: public; Owner: engine
--

INSERT INTO vm_static (vm_guid, vm_name, mem_size_mb, vmt_guid, os, description, vds_group_id, domain, creation_date, num_of_monitors, is_initialized, is_auto_suspend, num_of_sockets, cpu_per_socket, usb_policy, time_zone, is_stateless, fail_back, _create_date, _update_date, dedicated_vm_for_vds, auto_startup, vm_type, hypervisor_type, operation_mode, nice_level, default_boot_sequence, default_display_type, priority, iso_path, origin, initrd_url, kernel_url, kernel_params, migration_support, userdefined_properties, predefined_properties, min_allocated_mem, entity_type, child_count, template_status, quota_id, allow_console_reconnect, cpu_pinning) VALUES ('00000000-0000-0000-0000-000000000000', 'Blank', 512, '00000000-0000-0000-0000-000000000000', 0, 'Blank template', '99408929-82cf-4dc7-a532-9d998063fa95', '', '2008-04-01 00:00:00+03', 1, NULL, false, 1, 1, 1, NULL, NULL, false, '2012-12-12 12:40:34.397341+02', '2012-12-12 12:40:27.483701+02', NULL, NULL, 0, 0, 0, 0, 0, 1, 0, '', 0, NULL, NULL, NULL, 0, NULL, NULL, 0, 'TEMPLATE', 0, 0, NULL, false, NULL);
INSERT INTO vm_static (vm_guid, vm_name, mem_size_mb, vmt_guid, os, description, vds_group_id, domain, creation_date, num_of_monitors, is_initialized, is_auto_suspend, num_of_sockets, cpu_per_socket, usb_policy, time_zone, is_stateless, fail_back, _create_date, _update_date, dedicated_vm_for_vds, auto_startup, vm_type, hypervisor_type, operation_mode, nice_level, default_boot_sequence, default_display_type, priority, iso_path, origin, initrd_url, kernel_url, kernel_params, migration_support, userdefined_properties, predefined_properties, min_allocated_mem, entity_type, child_count, template_status, quota_id, allow_console_reconnect, cpu_pinning) VALUES ('4dd3914f-70da-4200-9031-e79dd447c1ce', 'NFS-RHEL6_iSCSI', 512, '00000000-0000-0000-0000-000000000000', 19, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', '', '2011-09-26 11:57:26+03', 1, NULL, false, 1, 1, 1, '', false, false, '2012-12-12 17:59:40.350748+02', '2012-12-13 17:55:07.997784+02', NULL, false, 1, 0, 0, 0, 0, 0, 0, '', 0, NULL, NULL, NULL, 0, NULL, NULL, 0, 'TEMPLATE', 0, 0, '00000000-0000-0000-0000-000000000000', false, NULL);
INSERT INTO vm_static (vm_guid, vm_name, mem_size_mb, vmt_guid, os, description, vds_group_id, domain, creation_date, num_of_monitors, is_initialized, is_auto_suspend, num_of_sockets, cpu_per_socket, usb_policy, time_zone, is_stateless, fail_back, _create_date, _update_date, dedicated_vm_for_vds, auto_startup, vm_type, hypervisor_type, operation_mode, nice_level, default_boot_sequence, default_display_type, priority, iso_path, origin, initrd_url, kernel_url, kernel_params, migration_support, userdefined_properties, predefined_properties, min_allocated_mem, entity_type, child_count, template_status, quota_id, allow_console_reconnect, cpu_pinning) VALUES ('f17519c2-6abd-4c88-b4a7-b86e02a1e558', 'XP_iSCSI', 1024, '00000000-0000-0000-0000-000000000000', 0, '', '3e4ad610-4463-11e2-b9d2-001a4a169741', '', '2011-08-30 16:49:21+03', 1, NULL, false, 1, 1, 1, '', false, false, '2012-12-12 16:26:31.579997+02', '2012-12-12 17:59:40.633519+02', NULL, false, 0, 0, 0, 0, 0, 0, 0, '', 0, NULL, NULL, NULL, 0, NULL, NULL, 0, 'TEMPLATE', 0, 0, '00000000-0000-0000-0000-000000000000', false, NULL);
INSERT INTO vm_static (vm_guid, vm_name, mem_size_mb, vmt_guid, os, description, vds_group_id, domain, creation_date, num_of_monitors, is_initialized, is_auto_suspend, num_of_sockets, cpu_per_socket, usb_policy, time_zone, is_stateless, fail_back, _create_date, _update_date, dedicated_vm_for_vds, auto_startup, vm_type, hypervisor_type, operation_mode, nice_level, default_boot_sequence, default_display_type, priority, iso_path, origin, initrd_url, kernel_url, kernel_params, migration_support, userdefined_properties, predefined_properties, min_allocated_mem, entity_type, child_count, template_status, quota_id, allow_console_reconnect, cpu_pinning) VALUES ('2de994d1-0c9f-42fc-b100-72f5079f0d5c', 'XP_iSCSI_Copy', 1024, '00000000-0000-0000-0000-000000000000', 0, '', '84caf0c2-4759-11e2-a95e-001a4a169741', '', '2011-08-30 16:49:21+03', 1, NULL, false, 1, 1, 1, 'Etc/GMT+12', false, false, '2012-12-16 10:35:03.465624+02', '2012-12-16 13:04:00.374536+02', NULL, false, 0, 0, 0, 0, 0, 1, 1, '', 0, '', '', '', 0, NULL, NULL, 0, 'TEMPLATE', 0, 0, '00000000-0000-0000-0000-000000000000', false, NULL);
INSERT INTO vm_static (vm_guid, vm_name, mem_size_mb, vmt_guid, os, description, vds_group_id, domain, creation_date, num_of_monitors, is_initialized, is_auto_suspend, num_of_sockets, cpu_per_socket, usb_policy, time_zone, is_stateless, fail_back, _create_date, _update_date, dedicated_vm_for_vds, auto_startup, vm_type, hypervisor_type, operation_mode, nice_level, default_boot_sequence, default_display_type, priority, iso_path, origin, initrd_url, kernel_url, kernel_params, migration_support, userdefined_properties, predefined_properties, min_allocated_mem, entity_type, child_count, template_status, quota_id, allow_console_reconnect, cpu_pinning) VALUES ('fa237384-7d1b-44c6-a2f3-6db0fedaecf5', 'NFS-RHEL6_iSCSI_Copy', 512, '00000000-0000-0000-0000-000000000000', 19, '', '84caf0c2-4759-11e2-a95e-001a4a169741', '', '2011-09-26 11:57:26+03', 1, NULL, false, 1, 1, 1, 'Etc/GMT+12', false, false, '2012-12-16 10:35:01.81998+02', '2012-12-16 13:03:50.965425+02', NULL, false, 1, 0, 0, 0, 0, 1, 1, '', 0, '', '', '', 0, NULL, NULL, 0, 'TEMPLATE', 0, 0, '00000000-0000-0000-0000-000000000000', false, NULL);


--
-- Data for Name: vm_statistics; Type: TABLE DATA; Schema: public; Owner: engine
--



--
-- Name: disk_lun_map_pk; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY disk_lun_map
    ADD CONSTRAINT disk_lun_map_pk PRIMARY KEY (disk_id, lun_id);


--
-- Name: idx_gluster_volume_bricks_volume_server_brickdir; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY gluster_volume_bricks
    ADD CONSTRAINT idx_gluster_volume_bricks_volume_server_brickdir UNIQUE (volume_id, server_id, brick_dir);


--
-- Name: idx_gluster_volume_options_volume_id_option_key; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY gluster_volume_options
    ADD CONSTRAINT idx_gluster_volume_options_volume_id_option_key UNIQUE (volume_id, option_key);


--
-- Name: pk_action_version_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY action_version_map
    ADD CONSTRAINT pk_action_version_map PRIMARY KEY (action_type);


--
-- Name: pk_ad_group_id; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY ad_groups
    ADD CONSTRAINT pk_ad_group_id PRIMARY KEY (id);


--
-- Name: pk_async_tasks; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY async_tasks
    ADD CONSTRAINT pk_async_tasks PRIMARY KEY (task_id);


--
-- Name: pk_audit_log; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY audit_log
    ADD CONSTRAINT pk_audit_log PRIMARY KEY (audit_log_id);


--
-- Name: pk_bookmarks; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY bookmarks
    ADD CONSTRAINT pk_bookmarks PRIMARY KEY (bookmark_id);


--
-- Name: pk_custom_actions; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY custom_actions
    ADD CONSTRAINT pk_custom_actions PRIMARY KEY (action_name, tab);


--
-- Name: pk_disk_image_dynamic; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY disk_image_dynamic
    ADD CONSTRAINT pk_disk_image_dynamic PRIMARY KEY (image_id);


--
-- Name: pk_disks; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY base_disks
    ADD CONSTRAINT pk_disks PRIMARY KEY (disk_id);


--
-- Name: pk_event_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY event_map
    ADD CONSTRAINT pk_event_map PRIMARY KEY (event_up_name);


--
-- Name: pk_event_notification_methods; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY event_notification_methods
    ADD CONSTRAINT pk_event_notification_methods PRIMARY KEY (method_id);


--
-- Name: pk_event_subscriber; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY event_subscriber
    ADD CONSTRAINT pk_event_subscriber PRIMARY KEY (subscriber_id, event_up_name, method_id, tag_name);


--
-- Name: pk_gluster_volume_access_protocols; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY gluster_volume_access_protocols
    ADD CONSTRAINT pk_gluster_volume_access_protocols PRIMARY KEY (volume_id, access_protocol);


--
-- Name: pk_gluster_volume_bricks; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY gluster_volume_bricks
    ADD CONSTRAINT pk_gluster_volume_bricks PRIMARY KEY (id);


--
-- Name: pk_gluster_volume_options; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY gluster_volume_options
    ADD CONSTRAINT pk_gluster_volume_options PRIMARY KEY (id);


--
-- Name: pk_gluster_volume_transport_types; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY gluster_volume_transport_types
    ADD CONSTRAINT pk_gluster_volume_transport_types PRIMARY KEY (volume_id, transport_type);


--
-- Name: pk_gluster_volumes; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY gluster_volumes
    ADD CONSTRAINT pk_gluster_volumes PRIMARY KEY (id);


--
-- Name: pk_id; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY business_entity_snapshot
    ADD CONSTRAINT pk_id PRIMARY KEY (id);


--
-- Name: pk_image_storage_domain_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY image_storage_domain_map
    ADD CONSTRAINT pk_image_storage_domain_map PRIMARY KEY (image_id, storage_domain_id);


--
-- Name: pk_images; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY images
    ADD CONSTRAINT pk_images PRIMARY KEY (image_guid);


--
-- Name: pk_jobs; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY job
    ADD CONSTRAINT pk_jobs PRIMARY KEY (job_id);


--
-- Name: pk_jobs_subject_entity; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY job_subject_entity
    ADD CONSTRAINT pk_jobs_subject_entity PRIMARY KEY (job_id, entity_id);


--
-- Name: pk_lun_storage_server_connection_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY lun_storage_server_connection_map
    ADD CONSTRAINT pk_lun_storage_server_connection_map PRIMARY KEY (lun_id, storage_server_connection);


--
-- Name: pk_luns; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY luns
    ADD CONSTRAINT pk_luns PRIMARY KEY (lun_id);


--
-- Name: pk_network; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY network
    ADD CONSTRAINT pk_network PRIMARY KEY (id);


--
-- Name: pk_network_cluster; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY network_cluster
    ADD CONSTRAINT pk_network_cluster PRIMARY KEY (network_id, cluster_id);


--
-- Name: pk_object_column_white_list; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY object_column_white_list
    ADD CONSTRAINT pk_object_column_white_list PRIMARY KEY (object_name, column_name);


--
-- Name: pk_object_column_white_list_sql; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY object_column_white_list_sql
    ADD CONSTRAINT pk_object_column_white_list_sql PRIMARY KEY (object_name);


--
-- Name: pk_permissions_id; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY permissions
    ADD CONSTRAINT pk_permissions_id PRIMARY KEY (id);


--
-- Name: pk_quota; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY quota
    ADD CONSTRAINT pk_quota PRIMARY KEY (id);


--
-- Name: pk_quota_limitation; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY quota_limitation
    ADD CONSTRAINT pk_quota_limitation PRIMARY KEY (id);


--
-- Name: pk_repo_file_meta_data; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY repo_file_meta_data
    ADD CONSTRAINT pk_repo_file_meta_data PRIMARY KEY (repo_domain_id, repo_file_name);


--
-- Name: pk_roles_groups; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY roles_groups
    ADD CONSTRAINT pk_roles_groups PRIMARY KEY (role_id, action_group_id);


--
-- Name: pk_roles_id; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY roles
    ADD CONSTRAINT pk_roles_id PRIMARY KEY (id);


--
-- Name: pk_roles_relations; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY roles_relations
    ADD CONSTRAINT pk_roles_relations PRIMARY KEY (role_id, role_container_id);


--
-- Name: pk_snapshots; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY snapshots
    ADD CONSTRAINT pk_snapshots PRIMARY KEY (snapshot_id);


--
-- Name: pk_steps; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY step
    ADD CONSTRAINT pk_steps PRIMARY KEY (step_id);


--
-- Name: pk_storage; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY storage_domain_static
    ADD CONSTRAINT pk_storage PRIMARY KEY (id);


--
-- Name: pk_storage_domain_dynamic; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY storage_domain_dynamic
    ADD CONSTRAINT pk_storage_domain_dynamic PRIMARY KEY (id);


--
-- Name: pk_storage_domain_pool_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY storage_pool_iso_map
    ADD CONSTRAINT pk_storage_domain_pool_map PRIMARY KEY (storage_id, storage_pool_id);


--
-- Name: pk_storage_pool; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY storage_pool
    ADD CONSTRAINT pk_storage_pool PRIMARY KEY (id);


--
-- Name: pk_storage_server; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY storage_server_connections
    ADD CONSTRAINT pk_storage_server PRIMARY KEY (id);


--
-- Name: pk_tags_id; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY tags
    ADD CONSTRAINT pk_tags_id PRIMARY KEY (tag_id);


--
-- Name: pk_tags_user_group_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY tags_user_group_map
    ADD CONSTRAINT pk_tags_user_group_map PRIMARY KEY (tag_id, group_id);


--
-- Name: pk_tags_user_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY tags_user_map
    ADD CONSTRAINT pk_tags_user_map PRIMARY KEY (tag_id, user_id);


--
-- Name: pk_tags_vds_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY tags_vds_map
    ADD CONSTRAINT pk_tags_vds_map PRIMARY KEY (tag_id, vds_id);


--
-- Name: pk_tags_vm_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY tags_vm_map
    ADD CONSTRAINT pk_tags_vm_map PRIMARY KEY (tag_id, vm_id);


--
-- Name: pk_tags_vm_pool_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY tags_vm_pool_map
    ADD CONSTRAINT pk_tags_vm_pool_map PRIMARY KEY (tag_id, vm_pool_id);


--
-- Name: pk_user_sessions; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY user_sessions
    ADD CONSTRAINT pk_user_sessions PRIMARY KEY (user_id, session_id);


--
-- Name: pk_users; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY users
    ADD CONSTRAINT pk_users PRIMARY KEY (user_id);


--
-- Name: pk_vdc_db_log; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vdc_db_log
    ADD CONSTRAINT pk_vdc_db_log PRIMARY KEY (error_id);


--
-- Name: pk_vdc_options; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vdc_options
    ADD CONSTRAINT pk_vdc_options PRIMARY KEY (option_id);


--
-- Name: pk_vds_dynamic; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_dynamic
    ADD CONSTRAINT pk_vds_dynamic PRIMARY KEY (vds_id);


--
-- Name: pk_vds_groups; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_groups
    ADD CONSTRAINT pk_vds_groups PRIMARY KEY (vds_group_id);


--
-- Name: pk_vds_interface; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_interface
    ADD CONSTRAINT pk_vds_interface PRIMARY KEY (id);


--
-- Name: pk_vds_interface_statistics; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_interface_statistics
    ADD CONSTRAINT pk_vds_interface_statistics PRIMARY KEY (id);


--
-- Name: pk_vds_spm_id_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_spm_id_map
    ADD CONSTRAINT pk_vds_spm_id_map PRIMARY KEY (storage_pool_id, vds_spm_id);


--
-- Name: pk_vds_static; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_static
    ADD CONSTRAINT pk_vds_static PRIMARY KEY (vds_id);


--
-- Name: pk_vds_statistics; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_statistics
    ADD CONSTRAINT pk_vds_statistics PRIMARY KEY (vds_id);


--
-- Name: pk_vm_device; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_device
    ADD CONSTRAINT pk_vm_device PRIMARY KEY (device_id, vm_id);


--
-- Name: pk_vm_dynamic; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_dynamic
    ADD CONSTRAINT pk_vm_dynamic PRIMARY KEY (vm_guid);


--
-- Name: pk_vm_interface; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_interface
    ADD CONSTRAINT pk_vm_interface PRIMARY KEY (id);


--
-- Name: pk_vm_interface_statistics; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_interface_statistics
    ADD CONSTRAINT pk_vm_interface_statistics PRIMARY KEY (id);


--
-- Name: pk_vm_pool_map; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_pool_map
    ADD CONSTRAINT pk_vm_pool_map PRIMARY KEY (vm_guid);


--
-- Name: pk_vm_pools; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_pools
    ADD CONSTRAINT pk_vm_pools PRIMARY KEY (vm_pool_id);


--
-- Name: pk_vm_static; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_static
    ADD CONSTRAINT pk_vm_static PRIMARY KEY (vm_guid);


--
-- Name: pk_vm_statistics; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vm_statistics
    ADD CONSTRAINT pk_vm_statistics PRIMARY KEY (vm_guid);


--
-- Name: quota_quota_name_unique; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY quota
    ADD CONSTRAINT quota_quota_name_unique UNIQUE (quota_name);


--
-- Name: schema_version_primary_key; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY schema_version
    ADD CONSTRAINT schema_version_primary_key PRIMARY KEY (id);


--
-- Name: uq_command_id_entity_id; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY business_entity_snapshot
    ADD CONSTRAINT uq_command_id_entity_id UNIQUE (command_id, entity_id, entity_type, snapshot_type);


--
-- Name: vds_static_host_name_unique; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_static
    ADD CONSTRAINT vds_static_host_name_unique UNIQUE (host_name);


--
-- Name: vds_static_vds_name_unique; Type: CONSTRAINT; Schema: public; Owner: engine; Tablespace: 
--

ALTER TABLE ONLY vds_static
    ADD CONSTRAINT vds_static_vds_name_unique UNIQUE (vds_name);


--
-- Name: idx_audit_correlation_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_correlation_id ON audit_log USING btree (correlation_id);


--
-- Name: idx_audit_log_job_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_job_id ON audit_log USING btree (job_id);


--
-- Name: idx_audit_log_log_time; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_log_time ON audit_log USING btree (log_time);


--
-- Name: idx_audit_log_storage_domain_name; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_storage_domain_name ON audit_log USING btree (storage_domain_name);


--
-- Name: idx_audit_log_storage_pool_name; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_storage_pool_name ON audit_log USING btree (storage_pool_name);


--
-- Name: idx_audit_log_user_name; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_user_name ON audit_log USING btree (user_name);


--
-- Name: idx_audit_log_vds_name; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_vds_name ON audit_log USING btree (vds_name);


--
-- Name: idx_audit_log_vm_name; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_vm_name ON audit_log USING btree (vm_name);


--
-- Name: idx_audit_log_vm_template_name; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_audit_log_vm_template_name ON audit_log USING btree (vm_template_name);


--
-- Name: idx_business_entity_snapshot_command_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_business_entity_snapshot_command_id ON business_entity_snapshot USING btree (command_id);


--
-- Name: idx_combined_ad_role_object; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE UNIQUE INDEX idx_combined_ad_role_object ON permissions USING btree (ad_element_id, role_id, object_id);


--
-- Name: idx_gluster_volume_access_protocols_volume_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_gluster_volume_access_protocols_volume_id ON gluster_volume_access_protocols USING btree (volume_id);


--
-- Name: idx_gluster_volume_bricks_volume_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_gluster_volume_bricks_volume_id ON gluster_volume_bricks USING btree (volume_id);


--
-- Name: idx_gluster_volume_options_volume_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_gluster_volume_options_volume_id ON gluster_volume_options USING btree (volume_id);


--
-- Name: idx_gluster_volume_transport_types_volume_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_gluster_volume_transport_types_volume_id ON gluster_volume_transport_types USING btree (volume_id);


--
-- Name: idx_gluster_volumes_cluster_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_gluster_volumes_cluster_id ON gluster_volumes USING btree (cluster_id);


--
-- Name: idx_gluster_volumes_name_unique; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_gluster_volumes_name_unique ON gluster_volumes USING btree (cluster_id, vol_name);


--
-- Name: idx_job_subject_entity_entity_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_job_subject_entity_entity_id ON job_subject_entity USING btree (entity_id);


--
-- Name: idx_permissions_ad_element_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_permissions_ad_element_id ON permissions USING btree (ad_element_id);


--
-- Name: idx_permissions_object_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_permissions_object_id ON permissions USING btree (object_id);


--
-- Name: idx_permissions_role_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_permissions_role_id ON permissions USING btree (role_id);


--
-- Name: idx_quota_limitation_quota_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_quota_limitation_quota_id ON quota_limitation USING btree (quota_id);


--
-- Name: idx_quota_limitation_storage_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_quota_limitation_storage_id ON quota_limitation USING btree (storage_id) WHERE (storage_id IS NOT NULL);


--
-- Name: idx_quota_limitation_vds_group_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_quota_limitation_vds_group_id ON quota_limitation USING btree (vds_group_id) WHERE (vds_group_id IS NOT NULL);


--
-- Name: idx_repo_file_file_type; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_repo_file_file_type ON repo_file_meta_data USING btree (file_type);


--
-- Name: idx_roles_groups_action_group_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_roles_groups_action_group_id ON roles_groups USING btree (action_group_id);


--
-- Name: idx_step_job_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_step_job_id ON step USING btree (job_id);


--
-- Name: idx_step_parent_step_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_step_parent_step_id ON step USING btree (parent_step_id);


--
-- Name: idx_storage_pool_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_storage_pool_id ON quota USING btree (storage_pool_id) WHERE (storage_pool_id IS NOT NULL);


--
-- Name: idx_vds_interface_vds_id; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_vds_interface_vds_id ON vds_interface USING btree (vds_id);


--
-- Name: idx_vm_dynamic_run_on_vds; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_vm_dynamic_run_on_vds ON vm_dynamic USING btree (run_on_vds);


--
-- Name: idx_vm_interface_vm_vmt_guid; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_vm_interface_vm_vmt_guid ON vm_interface USING btree (vm_guid, vmt_guid);


--
-- Name: idx_vm_static_vm_name; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX idx_vm_static_vm_name ON vm_static USING btree (vm_name);


--
-- Name: ix_vdc_options; Type: INDEX; Schema: public; Owner: engine; Tablespace: 
--

CREATE INDEX ix_vdc_options ON vdc_options USING btree (option_name);


--
-- Name: disk_lun_to_disk_fk; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY disk_lun_map
    ADD CONSTRAINT disk_lun_to_disk_fk FOREIGN KEY (disk_id) REFERENCES base_disks(disk_id);


--
-- Name: disk_lun_to_lun_fk; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY disk_lun_map
    ADD CONSTRAINT disk_lun_to_lun_fk FOREIGN KEY (lun_id) REFERENCES luns(lun_id);


--
-- Name: fk_async_task_entity; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY async_tasks_entities
    ADD CONSTRAINT fk_async_task_entity FOREIGN KEY (async_task_id) REFERENCES async_tasks(task_id) ON DELETE CASCADE;


--
-- Name: fk_disk_image_dynamic_images; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY disk_image_dynamic
    ADD CONSTRAINT fk_disk_image_dynamic_images FOREIGN KEY (image_id) REFERENCES images(image_guid) ON DELETE CASCADE;


--
-- Name: fk_event_notification_hist_audit_log; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY event_notification_hist
    ADD CONSTRAINT fk_event_notification_hist_audit_log FOREIGN KEY (audit_log_id) REFERENCES audit_log(audit_log_id) ON DELETE CASCADE;


--
-- Name: fk_event_notification_users; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY event_notification_hist
    ADD CONSTRAINT fk_event_notification_users FOREIGN KEY (subscriber_id) REFERENCES users(user_id) ON DELETE CASCADE;


--
-- Name: fk_event_subscriber_event_map; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY event_subscriber
    ADD CONSTRAINT fk_event_subscriber_event_map FOREIGN KEY (event_up_name) REFERENCES event_map(event_up_name) ON DELETE CASCADE;


--
-- Name: fk_event_subscriber_event_notification_methods; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY event_subscriber
    ADD CONSTRAINT fk_event_subscriber_event_notification_methods FOREIGN KEY (method_id) REFERENCES event_notification_methods(method_id) ON DELETE CASCADE;


--
-- Name: fk_event_subscriber_users; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY event_subscriber
    ADD CONSTRAINT fk_event_subscriber_users FOREIGN KEY (subscriber_id) REFERENCES users(user_id) ON DELETE CASCADE;


--
-- Name: fk_image_storage_domain_map_images; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY image_storage_domain_map
    ADD CONSTRAINT fk_image_storage_domain_map_images FOREIGN KEY (image_id) REFERENCES images(image_guid) ON DELETE CASCADE;


--
-- Name: fk_image_storage_domain_map_storage_domain_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY image_storage_domain_map
    ADD CONSTRAINT fk_image_storage_domain_map_storage_domain_static FOREIGN KEY (storage_domain_id) REFERENCES storage_domain_static(id) ON DELETE CASCADE;


--
-- Name: fk_job_subject_entity_job; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY job_subject_entity
    ADD CONSTRAINT fk_job_subject_entity_job FOREIGN KEY (job_id) REFERENCES job(job_id) ON DELETE CASCADE;


--
-- Name: fk_lun_storage_server_connection_map_luns; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY lun_storage_server_connection_map
    ADD CONSTRAINT fk_lun_storage_server_connection_map_luns FOREIGN KEY (lun_id) REFERENCES luns(lun_id) ON DELETE CASCADE;


--
-- Name: fk_lun_storage_server_connection_map_storage_server_connections; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY lun_storage_server_connection_map
    ADD CONSTRAINT fk_lun_storage_server_connection_map_storage_server_connections FOREIGN KEY (storage_server_connection) REFERENCES storage_server_connections(id) ON DELETE CASCADE;


--
-- Name: fk_network_cluster_network; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY network_cluster
    ADD CONSTRAINT fk_network_cluster_network FOREIGN KEY (network_id) REFERENCES network(id) ON DELETE CASCADE;


--
-- Name: fk_network_cluster_vds_groups; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY network_cluster
    ADD CONSTRAINT fk_network_cluster_vds_groups FOREIGN KEY (cluster_id) REFERENCES vds_groups(vds_group_id) ON DELETE CASCADE;


--
-- Name: fk_network_storage_pool; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY network
    ADD CONSTRAINT fk_network_storage_pool FOREIGN KEY (storage_pool_id) REFERENCES storage_pool(id) ON DELETE SET NULL;


--
-- Name: fk_permissions_roles; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY permissions
    ADD CONSTRAINT fk_permissions_roles FOREIGN KEY (role_id) REFERENCES roles(id) ON DELETE CASCADE;


--
-- Name: fk_repo_file_meta_data_storage_domain_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY repo_file_meta_data
    ADD CONSTRAINT fk_repo_file_meta_data_storage_domain_static FOREIGN KEY (repo_domain_id) REFERENCES storage_domain_static(id) ON DELETE CASCADE;


--
-- Name: fk_roles_groups_action_id; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY roles_groups
    ADD CONSTRAINT fk_roles_groups_action_id FOREIGN KEY (role_id) REFERENCES roles(id) ON DELETE CASCADE;


--
-- Name: fk_roles_relations_container_id; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY roles_relations
    ADD CONSTRAINT fk_roles_relations_container_id FOREIGN KEY (role_container_id) REFERENCES roles(id);


--
-- Name: fk_roles_relations_role_id; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY roles_relations
    ADD CONSTRAINT fk_roles_relations_role_id FOREIGN KEY (role_id) REFERENCES roles(id);


--
-- Name: fk_snapshot_vm; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY snapshots
    ADD CONSTRAINT fk_snapshot_vm FOREIGN KEY (vm_id) REFERENCES vm_static(vm_guid);


--
-- Name: fk_step_job; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY step
    ADD CONSTRAINT fk_step_job FOREIGN KEY (job_id) REFERENCES job(job_id) ON DELETE CASCADE;


--
-- Name: fk_storage_domain_dynamic_storage_domain_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY storage_domain_dynamic
    ADD CONSTRAINT fk_storage_domain_dynamic_storage_domain_static FOREIGN KEY (id) REFERENCES storage_domain_static(id);


--
-- Name: fk_storage_domain_pool_map_storage_domain_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY storage_pool_iso_map
    ADD CONSTRAINT fk_storage_domain_pool_map_storage_domain_static FOREIGN KEY (storage_id) REFERENCES storage_domain_static(id) ON DELETE CASCADE;


--
-- Name: fk_storage_domain_pool_map_storage_pool; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY storage_pool_iso_map
    ADD CONSTRAINT fk_storage_domain_pool_map_storage_pool FOREIGN KEY (storage_pool_id) REFERENCES storage_pool(id) ON DELETE CASCADE;


--
-- Name: fk_tags_vm_pool_map_tag; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_vm_pool_map
    ADD CONSTRAINT fk_tags_vm_pool_map_tag FOREIGN KEY (tag_id) REFERENCES tags(tag_id) ON DELETE CASCADE;


--
-- Name: fk_tags_vm_pool_map_vm_pool; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_vm_pool_map
    ADD CONSTRAINT fk_tags_vm_pool_map_vm_pool FOREIGN KEY (vm_pool_id) REFERENCES vm_pools(vm_pool_id) ON DELETE CASCADE;


--
-- Name: fk_users; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY user_sessions
    ADD CONSTRAINT fk_users FOREIGN KEY (user_id) REFERENCES users(user_id) ON DELETE CASCADE;


--
-- Name: fk_vds_groups_storage_pool_id; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_groups
    ADD CONSTRAINT fk_vds_groups_storage_pool_id FOREIGN KEY (storage_pool_id) REFERENCES storage_pool(id) ON DELETE SET NULL;


--
-- Name: fk_vds_groups_vm_pools; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_pools
    ADD CONSTRAINT fk_vds_groups_vm_pools FOREIGN KEY (vds_group_id) REFERENCES vds_groups(vds_group_id);


--
-- Name: fk_vds_interface_statistics_vds_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_interface_statistics
    ADD CONSTRAINT fk_vds_interface_statistics_vds_static FOREIGN KEY (vds_id) REFERENCES vds_static(vds_id) ON DELETE CASCADE;


--
-- Name: fk_vds_interface_vds_interface; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_interface
    ADD CONSTRAINT fk_vds_interface_vds_interface FOREIGN KEY (vds_id) REFERENCES vds_static(vds_id) ON DELETE CASCADE;


--
-- Name: fk_vds_spm_id_map_storage_pool; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_spm_id_map
    ADD CONSTRAINT fk_vds_spm_id_map_storage_pool FOREIGN KEY (storage_pool_id) REFERENCES storage_pool(id) ON DELETE CASCADE;


--
-- Name: fk_vds_spm_id_map_vds_id; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_spm_id_map
    ADD CONSTRAINT fk_vds_spm_id_map_vds_id FOREIGN KEY (vds_id) REFERENCES vds_static(vds_id) ON DELETE CASCADE;


--
-- Name: fk_vds_static_vm_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_static
    ADD CONSTRAINT fk_vds_static_vm_static FOREIGN KEY (dedicated_vm_for_vds) REFERENCES vds_static(vds_id);


--
-- Name: fk_vm_device_vm_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_device
    ADD CONSTRAINT fk_vm_device_vm_static FOREIGN KEY (vm_id) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: fk_vm_interface_statistics_vm_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_interface_statistics
    ADD CONSTRAINT fk_vm_interface_statistics_vm_static FOREIGN KEY (vm_id) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: fk_vm_interface_vm_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_interface
    ADD CONSTRAINT fk_vm_interface_vm_static FOREIGN KEY (vm_guid) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: fk_vm_interface_vm_static_template; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_interface
    ADD CONSTRAINT fk_vm_interface_vm_static_template FOREIGN KEY (vmt_guid) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: gluster_volume_access_protocols_volume_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY gluster_volume_access_protocols
    ADD CONSTRAINT gluster_volume_access_protocols_volume_id_fkey FOREIGN KEY (volume_id) REFERENCES gluster_volumes(id) ON DELETE CASCADE;


--
-- Name: gluster_volume_bricks_server_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY gluster_volume_bricks
    ADD CONSTRAINT gluster_volume_bricks_server_id_fkey FOREIGN KEY (server_id) REFERENCES vds_static(vds_id) ON DELETE CASCADE;


--
-- Name: gluster_volume_bricks_volume_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY gluster_volume_bricks
    ADD CONSTRAINT gluster_volume_bricks_volume_id_fkey FOREIGN KEY (volume_id) REFERENCES gluster_volumes(id) ON DELETE CASCADE;


--
-- Name: gluster_volume_options_volume_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY gluster_volume_options
    ADD CONSTRAINT gluster_volume_options_volume_id_fkey FOREIGN KEY (volume_id) REFERENCES gluster_volumes(id) ON DELETE CASCADE;


--
-- Name: gluster_volume_transport_types_volume_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY gluster_volume_transport_types
    ADD CONSTRAINT gluster_volume_transport_types_volume_id_fkey FOREIGN KEY (volume_id) REFERENCES gluster_volumes(id) ON DELETE CASCADE;


--
-- Name: gluster_volumes_cluster_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY gluster_volumes
    ADD CONSTRAINT gluster_volumes_cluster_id_fkey FOREIGN KEY (cluster_id) REFERENCES vds_groups(vds_group_id) ON DELETE CASCADE;


--
-- Name: image_templates_images; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY images
    ADD CONSTRAINT image_templates_images FOREIGN KEY (it_guid) REFERENCES images(image_guid);


--
-- Name: quota_limitation_quota_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY quota_limitation
    ADD CONSTRAINT quota_limitation_quota_id_fkey FOREIGN KEY (quota_id) REFERENCES quota(id) ON DELETE CASCADE;


--
-- Name: quota_limitation_storage_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY quota_limitation
    ADD CONSTRAINT quota_limitation_storage_id_fkey FOREIGN KEY (storage_id) REFERENCES storage_domain_static(id) ON DELETE CASCADE;


--
-- Name: quota_limitation_vds_group_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY quota_limitation
    ADD CONSTRAINT quota_limitation_vds_group_id_fkey FOREIGN KEY (vds_group_id) REFERENCES vds_groups(vds_group_id) ON DELETE CASCADE;


--
-- Name: quota_storage_pool_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY quota
    ADD CONSTRAINT quota_storage_pool_id_fkey FOREIGN KEY (storage_pool_id) REFERENCES storage_pool(id) ON DELETE CASCADE;


--
-- Name: tags_user_group_map_tag; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_user_group_map
    ADD CONSTRAINT tags_user_group_map_tag FOREIGN KEY (tag_id) REFERENCES tags(tag_id);


--
-- Name: tags_user_map_tag; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_user_map
    ADD CONSTRAINT tags_user_map_tag FOREIGN KEY (tag_id) REFERENCES tags(tag_id);


--
-- Name: tags_user_map_user; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_user_map
    ADD CONSTRAINT tags_user_map_user FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: tags_user_map_user_group; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_user_group_map
    ADD CONSTRAINT tags_user_map_user_group FOREIGN KEY (group_id) REFERENCES ad_groups(id);


--
-- Name: tags_vds_map_tag; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_vds_map
    ADD CONSTRAINT tags_vds_map_tag FOREIGN KEY (tag_id) REFERENCES tags(tag_id);


--
-- Name: tags_vds_map_vds; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_vds_map
    ADD CONSTRAINT tags_vds_map_vds FOREIGN KEY (vds_id) REFERENCES vds_static(vds_id);


--
-- Name: tags_vm_map_tag; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_vm_map
    ADD CONSTRAINT tags_vm_map_tag FOREIGN KEY (tag_id) REFERENCES tags(tag_id);


--
-- Name: tags_vm_map_vm; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY tags_vm_map
    ADD CONSTRAINT tags_vm_map_vm FOREIGN KEY (vm_id) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: vds_groups_vds_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_static
    ADD CONSTRAINT vds_groups_vds_static FOREIGN KEY (vds_group_id) REFERENCES vds_groups(vds_group_id);


--
-- Name: vds_groups_vm_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_static
    ADD CONSTRAINT vds_groups_vm_static FOREIGN KEY (vds_group_id) REFERENCES vds_groups(vds_group_id);


--
-- Name: vds_static_vds_dynamic; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_dynamic
    ADD CONSTRAINT vds_static_vds_dynamic FOREIGN KEY (vds_id) REFERENCES vds_static(vds_id);


--
-- Name: vds_static_vds_statistics; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vds_statistics
    ADD CONSTRAINT vds_static_vds_statistics FOREIGN KEY (vds_id) REFERENCES vds_static(vds_id);


--
-- Name: vds_static_vm_dynamic_m; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_dynamic
    ADD CONSTRAINT vds_static_vm_dynamic_m FOREIGN KEY (migrating_to_vds) REFERENCES vds_static(vds_id);


--
-- Name: vds_static_vm_dynamic_r; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_dynamic
    ADD CONSTRAINT vds_static_vm_dynamic_r FOREIGN KEY (run_on_vds) REFERENCES vds_static(vds_id);


--
-- Name: vm_guid_pools; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_pool_map
    ADD CONSTRAINT vm_guid_pools FOREIGN KEY (vm_guid) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: vm_pools_vm; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_pool_map
    ADD CONSTRAINT vm_pools_vm FOREIGN KEY (vm_pool_id) REFERENCES vm_pools(vm_pool_id);


--
-- Name: vm_static_vm_dynamic; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_dynamic
    ADD CONSTRAINT vm_static_vm_dynamic FOREIGN KEY (vm_guid) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: vm_static_vm_statistics; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_statistics
    ADD CONSTRAINT vm_static_vm_statistics FOREIGN KEY (vm_guid) REFERENCES vm_static(vm_guid) ON DELETE CASCADE;


--
-- Name: vm_templates_vm_static; Type: FK CONSTRAINT; Schema: public; Owner: engine
--

ALTER TABLE ONLY vm_static
    ADD CONSTRAINT vm_templates_vm_static FOREIGN KEY (vmt_guid) REFERENCES vm_static(vm_guid);


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

